Class: PinterestSdkClient::Ad

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/ad.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ad

Initializes the object



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/pinterest_sdk/models/ad.rb', line 276

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::Ad` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::Ad`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_group_id')
    self.ad_group_id = attributes[:'ad_group_id']
  else
    self.ad_group_id = nil
  end

  if attributes.key?(:'android_deep_link')
    self.android_deep_link = attributes[:'android_deep_link']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'carousel_android_deep_links')
    if (value = attributes[:'carousel_android_deep_links']).is_a?(Array)
      self.carousel_android_deep_links = value
    end
  end

  if attributes.key?(:'carousel_destination_urls')
    if (value = attributes[:'carousel_destination_urls']).is_a?(Array)
      self.carousel_destination_urls = value
    end
  end

  if attributes.key?(:'carousel_ios_deep_links')
    if (value = attributes[:'carousel_ios_deep_links']).is_a?(Array)
      self.carousel_ios_deep_links = value
    end
  end

  if attributes.key?(:'carting_platform_type')
    self.carting_platform_type = attributes[:'carting_platform_type']
  end

  if attributes.key?(:'carting_products')
    if (value = attributes[:'carting_products']).is_a?(Array)
      self.carting_products = value
    end
  end

  if attributes.key?(:'click_tracking_url')
    self.click_tracking_url = attributes[:'click_tracking_url']
  end

  if attributes.key?(:'collection_items_destination_url_template')
    self.collection_items_destination_url_template = attributes[:'collection_items_destination_url_template']
  end

  if attributes.key?(:'collections_header_type')
    self.collections_header_type = attributes[:'collections_header_type']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'creative_type')
    self.creative_type = attributes[:'creative_type']
  else
    self.creative_type = nil
  end

  if attributes.key?(:'customizable_cta_type')
    self.customizable_cta_type = attributes[:'customizable_cta_type']
  end

  if attributes.key?(:'destination_url')
    self.destination_url = attributes[:'destination_url']
  end

  if attributes.key?(:'disclosure_type')
    self.disclosure_type = attributes[:'disclosure_type']
  end

  if attributes.key?(:'disclosure_url')
    self.disclosure_url = attributes[:'disclosure_url']
  end

  if attributes.key?(:'grid_click_type')
    self.grid_click_type = attributes[:'grid_click_type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'ios_deep_link')
    self.ios_deep_link = attributes[:'ios_deep_link']
  end

  if attributes.key?(:'is_carting')
    self.is_carting = attributes[:'is_carting']
  end

  if attributes.key?(:'is_collage_accepted_terms')
    self.is_collage_accepted_terms = attributes[:'is_collage_accepted_terms']
  end

  if attributes.key?(:'is_collage_single_destination')
    self.is_collage_single_destination = attributes[:'is_collage_single_destination']
  end

  if attributes.key?(:'is_pin_deleted')
    self.is_pin_deleted = attributes[:'is_pin_deleted']
  end

  if attributes.key?(:'is_removable')
    self.is_removable = attributes[:'is_removable']
  end

  if attributes.key?(:'lead_form_id')
    self.lead_form_id = attributes[:'lead_form_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'pin_id')
    self.pin_id = attributes[:'pin_id']
  else
    self.pin_id = nil
  end

  if attributes.key?(:'quiz_pin_data')
    self.quiz_pin_data = attributes[:'quiz_pin_data']
  end

  if attributes.key?(:'rejected_reasons')
    if (value = attributes[:'rejected_reasons']).is_a?(Array)
      self.rejected_reasons = value
    end
  else
    self.rejected_reasons = nil
  end

  if attributes.key?(:'rejection_labels')
    if (value = attributes[:'rejection_labels']).is_a?(Array)
      self.rejection_labels = value
    end
  else
    self.rejection_labels = nil
  end

  if attributes.key?(:'review_status')
    self.review_status = attributes[:'review_status']
  else
    self.review_status = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'summary_status')
    self.summary_status = attributes[:'summary_status']
  else
    self.summary_status = nil
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end

  if attributes.key?(:'view_tracking_url')
    self.view_tracking_url = attributes[:'view_tracking_url']
  end
end

Instance Attribute Details

#ad_account_idObject

The ID of the advertiser that this ad belongs to.



19
20
21
# File 'lib/pinterest_sdk/models/ad.rb', line 19

def 
  
end

#ad_group_idObject

ID of the ad group that contains the ad.



22
23
24
# File 'lib/pinterest_sdk/models/ad.rb', line 22

def ad_group_id
  @ad_group_id
end

Deep link URL for Android devices.



25
26
27
# File 'lib/pinterest_sdk/models/ad.rb', line 25

def android_deep_link
  @android_deep_link
end

#campaign_idObject

ID of the ad campaign that contains this ad.



28
29
30
# File 'lib/pinterest_sdk/models/ad.rb', line 28

def campaign_id
  @campaign_id
end

Comma-separated deep links for the carousel pin on Android.



31
32
33
# File 'lib/pinterest_sdk/models/ad.rb', line 31

def carousel_android_deep_links
  @carousel_android_deep_links
end

Comma-separated destination URLs for the carousel pin to promote.



34
35
36
# File 'lib/pinterest_sdk/models/ad.rb', line 34

def carousel_destination_urls
  @carousel_destination_urls
end

Comma-separated deep links for the carousel pin on iOS.



37
38
39
# File 'lib/pinterest_sdk/models/ad.rb', line 37

def carousel_ios_deep_links
  @carousel_ios_deep_links
end

#carting_platform_typeObject

The vendor platform type of the carting/WTB ad.



40
41
42
# File 'lib/pinterest_sdk/models/ad.rb', line 40

def carting_platform_type
  @carting_platform_type
end

#carting_productsObject

Array of carting/WTB products for the ad.



43
44
45
# File 'lib/pinterest_sdk/models/ad.rb', line 43

def carting_products
  @carting_products
end

#click_tracking_urlObject

Tracking url for the ad clicks.



46
47
48
# File 'lib/pinterest_sdk/models/ad.rb', line 46

def click_tracking_url
  @click_tracking_url
end

#collection_items_destination_url_templateObject

Destination URL template for all items within a collections drawer.



49
50
51
# File 'lib/pinterest_sdk/models/ad.rb', line 49

def collection_items_destination_url_template
  @collection_items_destination_url_template
end

#collections_header_typeObject

Returns the value of attribute collections_header_type.



51
52
53
# File 'lib/pinterest_sdk/models/ad.rb', line 51

def collections_header_type
  @collections_header_type
end

#created_timeObject

Pin creation time. Unix timestamp in seconds.



54
55
56
# File 'lib/pinterest_sdk/models/ad.rb', line 54

def created_time
  @created_time
end

#creative_typeObject

Returns the value of attribute creative_type.



56
57
58
# File 'lib/pinterest_sdk/models/ad.rb', line 56

def creative_type
  @creative_type
end

#customizable_cta_typeObject

Returns the value of attribute customizable_cta_type.



58
59
60
# File 'lib/pinterest_sdk/models/ad.rb', line 58

def customizable_cta_type
  @customizable_cta_type
end

#destination_urlObject

Destination URL.



61
62
63
# File 'lib/pinterest_sdk/models/ad.rb', line 61

def destination_url
  @destination_url
end

#disclosure_typeObject

Returns the value of attribute disclosure_type.



63
64
65
# File 'lib/pinterest_sdk/models/ad.rb', line 63

def disclosure_type
  @disclosure_type
end

#disclosure_urlObject

URL for a page that provides disclosures about a pharmaceutical product, such as potential side effects. Make sure the URL takes the user directly to the disclosure content and the referenced site is secure.



66
67
68
# File 'lib/pinterest_sdk/models/ad.rb', line 66

def disclosure_url
  @disclosure_url
end

#grid_click_typeObject

Returns the value of attribute grid_click_type.



68
69
70
# File 'lib/pinterest_sdk/models/ad.rb', line 68

def grid_click_type
  @grid_click_type
end

#idObject

The ID of this ad.



71
72
73
# File 'lib/pinterest_sdk/models/ad.rb', line 71

def id
  @id
end

Deep link URL for iOS devices.



74
75
76
# File 'lib/pinterest_sdk/models/ad.rb', line 74

def ios_deep_link
  @ios_deep_link
end

#is_cartingObject

Is the ad a carting/WTB ad?



77
78
79
# File 'lib/pinterest_sdk/models/ad.rb', line 77

def is_carting
  @is_carting
end

#is_collage_accepted_termsObject

Whether the advertiser has accepted the terms and conditions for collage ad.



80
81
82
# File 'lib/pinterest_sdk/models/ad.rb', line 80

def is_collage_accepted_terms
  @is_collage_accepted_terms
end

#is_collage_single_destinationObject

Whether the collage ad has a single destination url override.



83
84
85
# File 'lib/pinterest_sdk/models/ad.rb', line 83

def is_collage_single_destination
  @is_collage_single_destination
end

#is_pin_deletedObject

Is original pin deleted?



86
87
88
# File 'lib/pinterest_sdk/models/ad.rb', line 86

def is_pin_deleted
  @is_pin_deleted
end

#is_removableObject

Is pin repinnable?



89
90
91
# File 'lib/pinterest_sdk/models/ad.rb', line 89

def is_removable
  @is_removable
end

#lead_form_idObject

Lead form ID for lead ad generation.



92
93
94
# File 'lib/pinterest_sdk/models/ad.rb', line 92

def lead_form_id
  @lead_form_id
end

#nameObject

Name of the ad - 255 chars max.



95
96
97
# File 'lib/pinterest_sdk/models/ad.rb', line 95

def name
  @name
end

#pin_idObject

Pin ID. This field may only be updated for draft ads.



98
99
100
# File 'lib/pinterest_sdk/models/ad.rb', line 98

def pin_id
  @pin_id
end

#quiz_pin_dataObject

Before creating a quiz ad, you must create an organic Pin using POST/Create Pin for each result in the quiz. Quiz ads cannot be saved by a Pinner. Quiz ad results can be saved.



101
102
103
# File 'lib/pinterest_sdk/models/ad.rb', line 101

def quiz_pin_data
  @quiz_pin_data
end

#rejected_reasonsObject

Enum reason why the pin was rejected. Returned if review_status is "REJECTED".



104
105
106
# File 'lib/pinterest_sdk/models/ad.rb', line 104

def rejected_reasons
  @rejected_reasons
end

#rejection_labelsObject

Text reason why the pin was rejected. Returned if review_status is "REJECTED".



107
108
109
# File 'lib/pinterest_sdk/models/ad.rb', line 107

def rejection_labels
  @rejection_labels
end

#review_statusObject

Ad review status



110
111
112
# File 'lib/pinterest_sdk/models/ad.rb', line 110

def review_status
  @review_status
end

#statusObject

Returns the value of attribute status.



112
113
114
# File 'lib/pinterest_sdk/models/ad.rb', line 112

def status
  @status
end

#summary_statusObject

Ad summary status



115
116
117
# File 'lib/pinterest_sdk/models/ad.rb', line 115

def summary_status
  @summary_status
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



117
118
119
# File 'lib/pinterest_sdk/models/ad.rb', line 117

def tracking_urls
  @tracking_urls
end

#typeObject

Always "ad".



120
121
122
# File 'lib/pinterest_sdk/models/ad.rb', line 120

def type
  @type
end

#updated_timeObject

Last update time. Unix timestamp in seconds.



123
124
125
# File 'lib/pinterest_sdk/models/ad.rb', line 123

def updated_time
  @updated_time
end

#view_tracking_urlObject

Tracking URL for ad impressions.



126
127
128
# File 'lib/pinterest_sdk/models/ad.rb', line 126

def view_tracking_url
  @view_tracking_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



196
197
198
# File 'lib/pinterest_sdk/models/ad.rb', line 196

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



201
202
203
# File 'lib/pinterest_sdk/models/ad.rb', line 201

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/pinterest_sdk/models/ad.rb', line 151

def self.attribute_map
  {
    :'ad_account_id' => :'ad_account_id',
    :'ad_group_id' => :'ad_group_id',
    :'android_deep_link' => :'android_deep_link',
    :'campaign_id' => :'campaign_id',
    :'carousel_android_deep_links' => :'carousel_android_deep_links',
    :'carousel_destination_urls' => :'carousel_destination_urls',
    :'carousel_ios_deep_links' => :'carousel_ios_deep_links',
    :'carting_platform_type' => :'carting_platform_type',
    :'carting_products' => :'carting_products',
    :'click_tracking_url' => :'click_tracking_url',
    :'collection_items_destination_url_template' => :'collection_items_destination_url_template',
    :'collections_header_type' => :'collections_header_type',
    :'created_time' => :'created_time',
    :'creative_type' => :'creative_type',
    :'customizable_cta_type' => :'customizable_cta_type',
    :'destination_url' => :'destination_url',
    :'disclosure_type' => :'disclosure_type',
    :'disclosure_url' => :'disclosure_url',
    :'grid_click_type' => :'grid_click_type',
    :'id' => :'id',
    :'ios_deep_link' => :'ios_deep_link',
    :'is_carting' => :'is_carting',
    :'is_collage_accepted_terms' => :'is_collage_accepted_terms',
    :'is_collage_single_destination' => :'is_collage_single_destination',
    :'is_pin_deleted' => :'is_pin_deleted',
    :'is_removable' => :'is_removable',
    :'lead_form_id' => :'lead_form_id',
    :'name' => :'name',
    :'pin_id' => :'pin_id',
    :'quiz_pin_data' => :'quiz_pin_data',
    :'rejected_reasons' => :'rejected_reasons',
    :'rejection_labels' => :'rejection_labels',
    :'review_status' => :'review_status',
    :'status' => :'status',
    :'summary_status' => :'summary_status',
    :'tracking_urls' => :'tracking_urls',
    :'type' => :'type',
    :'updated_time' => :'updated_time',
    :'view_tracking_url' => :'view_tracking_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
# File 'lib/pinterest_sdk/models/ad.rb', line 831

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/pinterest_sdk/models/ad.rb', line 251

def self.openapi_nullable
  Set.new([
    :'android_deep_link',
    :'carousel_android_deep_links',
    :'carousel_destination_urls',
    :'carousel_ios_deep_links',
    :'click_tracking_url',
    :'collection_items_destination_url_template',
    :'collections_header_type',
    :'customizable_cta_type',
    :'destination_url',
    :'disclosure_type',
    :'disclosure_url',
    :'grid_click_type',
    :'ios_deep_link',
    :'lead_form_id',
    :'name',
    :'quiz_pin_data',
    :'tracking_urls',
    :'view_tracking_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/pinterest_sdk/models/ad.rb', line 206

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'ad_group_id' => :'String',
    :'android_deep_link' => :'String',
    :'campaign_id' => :'String',
    :'carousel_android_deep_links' => :'Array<String>',
    :'carousel_destination_urls' => :'Array<String>',
    :'carousel_ios_deep_links' => :'Array<String>',
    :'carting_platform_type' => :'Integer',
    :'carting_products' => :'Array<CartingProduct>',
    :'click_tracking_url' => :'String',
    :'collection_items_destination_url_template' => :'String',
    :'collections_header_type' => :'AdCollectionsHeaderType',
    :'created_time' => :'Integer',
    :'creative_type' => :'CreativeType',
    :'customizable_cta_type' => :'CustomizableCTAType',
    :'destination_url' => :'String',
    :'disclosure_type' => :'DisclosureType',
    :'disclosure_url' => :'String',
    :'grid_click_type' => :'GridClickType',
    :'id' => :'String',
    :'ios_deep_link' => :'String',
    :'is_carting' => :'Boolean',
    :'is_collage_accepted_terms' => :'Boolean',
    :'is_collage_single_destination' => :'Boolean',
    :'is_pin_deleted' => :'Boolean',
    :'is_removable' => :'Boolean',
    :'lead_form_id' => :'String',
    :'name' => :'String',
    :'pin_id' => :'String',
    :'quiz_pin_data' => :'QuizPinData',
    :'rejected_reasons' => :'Array<AdDisapprovalReasons>',
    :'rejection_labels' => :'Array<String>',
    :'review_status' => :'AdReviewStatus',
    :'status' => :'EntityStatus',
    :'summary_status' => :'PinPromotionSummaryStatus',
    :'tracking_urls' => :'TrackingUrls',
    :'type' => :'String',
    :'updated_time' => :'Integer',
    :'view_tracking_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
# File 'lib/pinterest_sdk/models/ad.rb', line 772

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      ad_group_id == o.ad_group_id &&
      android_deep_link == o.android_deep_link &&
      campaign_id == o.campaign_id &&
      carousel_android_deep_links == o.carousel_android_deep_links &&
      carousel_destination_urls == o.carousel_destination_urls &&
      carousel_ios_deep_links == o.carousel_ios_deep_links &&
      carting_platform_type == o.carting_platform_type &&
      carting_products == o.carting_products &&
      click_tracking_url == o.click_tracking_url &&
      collection_items_destination_url_template == o.collection_items_destination_url_template &&
      collections_header_type == o.collections_header_type &&
      created_time == o.created_time &&
      creative_type == o.creative_type &&
      customizable_cta_type == o.customizable_cta_type &&
      destination_url == o.destination_url &&
      disclosure_type == o.disclosure_type &&
      disclosure_url == o.disclosure_url &&
      grid_click_type == o.grid_click_type &&
      id == o.id &&
      ios_deep_link == o.ios_deep_link &&
      is_carting == o.is_carting &&
      is_collage_accepted_terms == o.is_collage_accepted_terms &&
      is_collage_single_destination == o.is_collage_single_destination &&
      is_pin_deleted == o.is_pin_deleted &&
      is_removable == o.is_removable &&
      lead_form_id == o.lead_form_id &&
      name == o.name &&
      pin_id == o.pin_id &&
      quiz_pin_data == o.quiz_pin_data &&
      rejected_reasons == o.rejected_reasons &&
      rejection_labels == o.rejection_labels &&
      review_status == o.review_status &&
      status == o.status &&
      summary_status == o.summary_status &&
      tracking_urls == o.tracking_urls &&
      type == o.type &&
      updated_time == o.updated_time &&
      view_tracking_url == o.view_tracking_url
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


818
819
820
# File 'lib/pinterest_sdk/models/ad.rb', line 818

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



824
825
826
# File 'lib/pinterest_sdk/models/ad.rb', line 824

def hash
  [, ad_group_id, android_deep_link, campaign_id, carousel_android_deep_links, carousel_destination_urls, carousel_ios_deep_links, carting_platform_type, carting_products, click_tracking_url, collection_items_destination_url_template, collections_header_type, created_time, creative_type, customizable_cta_type, destination_url, disclosure_type, disclosure_url, grid_click_type, id, ios_deep_link, is_carting, is_collage_accepted_terms, is_collage_single_destination, is_pin_deleted, is_removable, lead_form_id, name, pin_id, quiz_pin_data, rejected_reasons, rejection_labels, review_status, status, summary_status, tracking_urls, type, updated_time, view_tracking_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/pinterest_sdk/models/ad.rb', line 483

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if .nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if  !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  if @ad_group_id.nil?
    invalid_properties.push('invalid value for "ad_group_id", ad_group_id cannot be nil.')
  end

  pattern = Regexp.new(/^(AG)?\d+$/)
  if @ad_group_id !~ pattern
    invalid_properties.push("invalid value for \"ad_group_id\", must conform to the pattern #{pattern}.")
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @campaign_id !~ pattern
    invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.")
  end

  if !@carting_platform_type.nil? && @carting_platform_type > 2
    invalid_properties.push('invalid value for "carting_platform_type", must be smaller than or equal to 2.')
  end

  if !@carting_platform_type.nil? && @carting_platform_type < 1
    invalid_properties.push('invalid value for "carting_platform_type", must be greater than or equal to 1.')
  end

  if @creative_type.nil?
    invalid_properties.push('invalid value for "creative_type", creative_type cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 18
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 18.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^(AG)?\d+$/)
  if !@lead_form_id.nil? && @lead_form_id !~ pattern
    invalid_properties.push("invalid value for \"lead_form_id\", must conform to the pattern #{pattern}.")
  end

  if @pin_id.nil?
    invalid_properties.push('invalid value for "pin_id", pin_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @pin_id !~ pattern
    invalid_properties.push("invalid value for \"pin_id\", must conform to the pattern #{pattern}.")
  end

  if @rejected_reasons.nil?
    invalid_properties.push('invalid value for "rejected_reasons", rejected_reasons cannot be nil.')
  end

  if @rejection_labels.nil?
    invalid_properties.push('invalid value for "rejection_labels", rejection_labels cannot be nil.')
  end

  if @review_status.nil?
    invalid_properties.push('invalid value for "review_status", review_status cannot be nil.')
  end

  if @summary_status.nil?
    invalid_properties.push('invalid value for "summary_status", summary_status cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



853
854
855
856
857
858
859
860
861
862
863
864
865
# File 'lib/pinterest_sdk/models/ad.rb', line 853

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/pinterest_sdk/models/ad.rb', line 577

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if .nil?
  return false if  !~ Regexp.new(/^\d+$/)
  return false if @ad_group_id.nil?
  return false if @ad_group_id !~ Regexp.new(/^(AG)?\d+$/)
  return false if @campaign_id.nil?
  return false if @campaign_id !~ Regexp.new(/^\d+$/)
  return false if !@carting_platform_type.nil? && @carting_platform_type > 2
  return false if !@carting_platform_type.nil? && @carting_platform_type < 1
  return false if @creative_type.nil?
  return false if @id.nil?
  return false if @id.to_s.length > 18
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if !@lead_form_id.nil? && @lead_form_id !~ Regexp.new(/^(AG)?\d+$/)
  return false if @pin_id.nil?
  return false if @pin_id !~ Regexp.new(/^\d+$/)
  return false if @rejected_reasons.nil?
  return false if @rejection_labels.nil?
  return false if @review_status.nil?
  return false if @summary_status.nil?
  return false if @type.nil?
  true
end