Class: PinterestSdkClient::AdAccountAnalyticsItems

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/ad_account_analytics_items.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdAccountAnalyticsItems

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 56

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccountAnalyticsItems` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccountAnalyticsItems`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end
end

Instance Attribute Details

#ad_account_idObject

Returns the value of attribute ad_account_id.



18
19
20
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 18

def 
  @ad_account_id
end

#dateObject

Returns the value of attribute date.



20
21
22
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 20

def date
  @date
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



31
32
33
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 23

def self.attribute_map
  {
    :'ad_account_id' => :'AD_ACCOUNT_ID',
    :'date' => :'DATE'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 146

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 49

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 41

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'date' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



124
125
126
127
128
129
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 124

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      date == o.date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 133

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



139
140
141
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 139

def hash
  [, date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 83

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @ad_account_id !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



100
101
102
103
104
105
# File 'lib/pinterest_sdk/models/ad_account_analytics_items.rb', line 100

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ad_account_id.nil?
  return false if @ad_account_id !~ Regexp.new(/^\d+$/)
  true
end