Class: PinterestSdkClient::AdAccountToBusinessSharedAudience
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdAccountToBusinessSharedAudience
- Defined in:
- lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb
Instance Attribute Summary collapse
-
#audience_id ⇒ Object
Unique identifier of an audience.
-
#permissions ⇒ Object
Permissions granted to the recipients.
-
#recipient_business_ids ⇒ Object
Business IDs to share with or revoke from (request) / that received the audience (response).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdAccountToBusinessSharedAudience
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdAccountToBusinessSharedAudience
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccountToBusinessSharedAudience` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccountToBusinessSharedAudience`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'audience_id') self.audience_id = attributes[:'audience_id'] else self.audience_id = nil end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'recipient_business_ids') if (value = attributes[:'recipient_business_ids']).is_a?(Array) self.recipient_business_ids = value end else self.recipient_business_ids = nil end end |
Instance Attribute Details
#audience_id ⇒ Object
Unique identifier of an audience
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 19 def audience_id @audience_id end |
#permissions ⇒ Object
Permissions granted to the recipients.
22 23 24 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 22 def @permissions end |
#recipient_business_ids ⇒ Object
Business IDs to share with or revoke from (request) / that received the audience (response).
25 26 27 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 25 def recipient_business_ids @recipient_business_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 28 def self.attribute_map { :'audience_id' => :'audience_id', :'permissions' => :'permissions', :'recipient_business_ids' => :'recipient_business_ids' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 47 def self.openapi_types { :'audience_id' => :'String', :'permissions' => :'Array<Role>', :'recipient_business_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && audience_id == o.audience_id && == o. && recipient_business_ids == o.recipient_business_ids end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 172 def hash [audience_id, , recipient_business_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 100 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @audience_id.nil? invalid_properties.push('invalid value for "audience_id", audience_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @audience_id !~ pattern invalid_properties.push("invalid value for \"audience_id\", must conform to the pattern #{pattern}.") end if @recipient_business_ids.nil? invalid_properties.push('invalid value for "recipient_business_ids", recipient_business_ids cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/ad_account_to_business_shared_audience.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @audience_id.nil? return false if @audience_id !~ Regexp.new(/^\d+$/) return false if @recipient_business_ids.nil? true end |