Class: PinterestSdkClient::AdAccountsAudienceCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdAccountsAudienceCreate
- Defined in:
- lib/pinterest_sdk/models/ad_accounts_audience_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Ad account ID.
-
#audience_type ⇒ Object
[Audience types](/docs/reference/glossary/#Audience Types): ACTALIKE, ENGAGEMENT, CUSTOMER_LIST and VISITOR.
-
#description ⇒ Object
Audience description.
-
#name ⇒ Object
Audience name.
-
#rule ⇒ Object
Returns the value of attribute rule.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdAccountsAudienceCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdAccountsAudienceCreate
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccountsAudienceCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccountsAudienceCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'audience_type') self.audience_type = attributes[:'audience_type'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Ad account ID.
20 21 22 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 20 def ad_account_id @ad_account_id end |
#audience_type ⇒ Object
[Audience types](/docs/reference/glossary/#Audience Types): ACTALIKE, ENGAGEMENT, CUSTOMER_LIST and VISITOR
23 24 25 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 23 def audience_type @audience_type end |
#description ⇒ Object
Audience description.
26 27 28 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 26 def description @description end |
#name ⇒ Object
Audience name.
29 30 31 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 29 def name @name end |
#rule ⇒ Object
Returns the value of attribute rule.
31 32 33 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 31 def rule @rule end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 56 def self.attribute_map { :'ad_account_id' => :'ad_account_id', :'audience_type' => :'audience_type', :'description' => :'description', :'name' => :'name', :'rule' => :'rule' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 88 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 77 def self.openapi_types { :'ad_account_id' => :'String', :'audience_type' => :'AudienceType', :'description' => :'String', :'name' => :'String', :'rule' => :'AdAccountsAudienceRule' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && audience_type == o.audience_type && description == o.description && name == o.name && rule == o.rule end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 187 def hash [ad_account_id, audience_type, description, name, rule].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 |
# File 'lib/pinterest_sdk/models/ad_accounts_audience_create.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) true end |