Class: PinterestSdkClient::AdAccountsAudienceUpdate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/ad_accounts_audience_update.rb

Overview

Resource create or update operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdAccountsAudienceUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccountsAudienceUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccountsAudienceUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'audience_type')
    self.audience_type = attributes[:'audience_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'operation_type')
    self.operation_type = attributes[:'operation_type']
  end

  if attributes.key?(:'rule')
    self.rule = attributes[:'rule']
  end
end

Instance Attribute Details

#ad_account_idObject

Ad account ID.



20
21
22
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 20

def 
  @ad_account_id
end

#audience_typeObject

[Audience types](/docs/reference/glossary/#Audience Types): ACTALIKE, ENGAGEMENT, CUSTOMER_LIST and VISITOR



23
24
25
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 23

def audience_type
  @audience_type
end

#descriptionObject

Audience description.



26
27
28
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 26

def description
  @description
end

#nameObject

Audience name.



29
30
31
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 29

def name
  @name
end

#operation_typeObject

Audience operation type (update or remove). Only valid in update request body.



32
33
34
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 32

def operation_type
  @operation_type
end

#ruleObject

Returns the value of attribute rule.



34
35
36
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 34

def rule
  @rule
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 59

def self.attribute_map
  {
    :'ad_account_id' => :'ad_account_id',
    :'audience_type' => :'audience_type',
    :'description' => :'description',
    :'name' => :'name',
    :'operation_type' => :'operation_type',
    :'rule' => :'rule'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 93

def self.openapi_nullable
  Set.new([
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 81

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'audience_type' => :'AudienceType',
    :'description' => :'String',
    :'name' => :'String',
    :'operation_type' => :'AudienceUpdateOperationType',
    :'rule' => :'AdAccountsAudienceRule'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



178
179
180
181
182
183
184
185
186
187
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 178

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      audience_type == o.audience_type &&
      description == o.description &&
      name == o.name &&
      operation_type == o.operation_type &&
      rule == o.rule
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 197

def hash
  [, audience_type, description, name, operation_type, rule].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@ad_account_id.nil? && @ad_account_id !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
# File 'lib/pinterest_sdk/models/ad_accounts_audience_update.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/)
  true
end