Class: PinterestSdkClient::AdCreate

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/ad_create.rb

Overview

Resource create operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/pinterest_sdk/models/ad_create.rb', line 217

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_group_id')
    self.ad_group_id = attributes[:'ad_group_id']
  else
    self.ad_group_id = nil
  end

  if attributes.key?(:'android_deep_link')
    self.android_deep_link = attributes[:'android_deep_link']
  end

  if attributes.key?(:'carousel_android_deep_links')
    if (value = attributes[:'carousel_android_deep_links']).is_a?(Array)
      self.carousel_android_deep_links = value
    end
  end

  if attributes.key?(:'carousel_destination_urls')
    if (value = attributes[:'carousel_destination_urls']).is_a?(Array)
      self.carousel_destination_urls = value
    end
  end

  if attributes.key?(:'carousel_ios_deep_links')
    if (value = attributes[:'carousel_ios_deep_links']).is_a?(Array)
      self.carousel_ios_deep_links = value
    end
  end

  if attributes.key?(:'click_tracking_url')
    self.click_tracking_url = attributes[:'click_tracking_url']
  end

  if attributes.key?(:'collection_items_destination_url_template')
    self.collection_items_destination_url_template = attributes[:'collection_items_destination_url_template']
  end

  if attributes.key?(:'collections_header_type')
    self.collections_header_type = attributes[:'collections_header_type']
  end

  if attributes.key?(:'creative_type')
    self.creative_type = attributes[:'creative_type']
  else
    self.creative_type = nil
  end

  if attributes.key?(:'customizable_cta_type')
    self.customizable_cta_type = attributes[:'customizable_cta_type']
  end

  if attributes.key?(:'destination_url')
    self.destination_url = attributes[:'destination_url']
  end

  if attributes.key?(:'disclosure_type')
    self.disclosure_type = attributes[:'disclosure_type']
  end

  if attributes.key?(:'disclosure_url')
    self.disclosure_url = attributes[:'disclosure_url']
  end

  if attributes.key?(:'grid_click_type')
    self.grid_click_type = attributes[:'grid_click_type']
  end

  if attributes.key?(:'ios_deep_link')
    self.ios_deep_link = attributes[:'ios_deep_link']
  end

  if attributes.key?(:'is_carting')
    self.is_carting = attributes[:'is_carting']
  end

  if attributes.key?(:'is_collage_accepted_terms')
    self.is_collage_accepted_terms = attributes[:'is_collage_accepted_terms']
  end

  if attributes.key?(:'is_collage_single_destination')
    self.is_collage_single_destination = attributes[:'is_collage_single_destination']
  end

  if attributes.key?(:'is_pin_deleted')
    self.is_pin_deleted = attributes[:'is_pin_deleted']
  end

  if attributes.key?(:'is_removable')
    self.is_removable = attributes[:'is_removable']
  end

  if attributes.key?(:'lead_form_id')
    self.lead_form_id = attributes[:'lead_form_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'pin_id')
    self.pin_id = attributes[:'pin_id']
  else
    self.pin_id = nil
  end

  if attributes.key?(:'quiz_pin_data')
    self.quiz_pin_data = attributes[:'quiz_pin_data']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end

  if attributes.key?(:'view_tracking_url')
    self.view_tracking_url = attributes[:'view_tracking_url']
  end
end

Instance Attribute Details

#ad_group_idObject

ID of the ad group that contains the ad.



20
21
22
# File 'lib/pinterest_sdk/models/ad_create.rb', line 20

def ad_group_id
  @ad_group_id
end

Deep link URL for Android devices.



23
24
25
# File 'lib/pinterest_sdk/models/ad_create.rb', line 23

def android_deep_link
  @android_deep_link
end

Comma-separated deep links for the carousel pin on Android.



26
27
28
# File 'lib/pinterest_sdk/models/ad_create.rb', line 26

def carousel_android_deep_links
  @carousel_android_deep_links
end

Comma-separated destination URLs for the carousel pin to promote.



29
30
31
# File 'lib/pinterest_sdk/models/ad_create.rb', line 29

def carousel_destination_urls
  @carousel_destination_urls
end

Comma-separated deep links for the carousel pin on iOS.



32
33
34
# File 'lib/pinterest_sdk/models/ad_create.rb', line 32

def carousel_ios_deep_links
  @carousel_ios_deep_links
end

#click_tracking_urlObject

Tracking url for the ad clicks.



35
36
37
# File 'lib/pinterest_sdk/models/ad_create.rb', line 35

def click_tracking_url
  @click_tracking_url
end

#collection_items_destination_url_templateObject

Destination URL template for all items within a collections drawer.



38
39
40
# File 'lib/pinterest_sdk/models/ad_create.rb', line 38

def collection_items_destination_url_template
  @collection_items_destination_url_template
end

#collections_header_typeObject

Returns the value of attribute collections_header_type.



40
41
42
# File 'lib/pinterest_sdk/models/ad_create.rb', line 40

def collections_header_type
  @collections_header_type
end

#creative_typeObject

Returns the value of attribute creative_type.



42
43
44
# File 'lib/pinterest_sdk/models/ad_create.rb', line 42

def creative_type
  @creative_type
end

#customizable_cta_typeObject

Returns the value of attribute customizable_cta_type.



44
45
46
# File 'lib/pinterest_sdk/models/ad_create.rb', line 44

def customizable_cta_type
  @customizable_cta_type
end

#destination_urlObject

Destination URL.



47
48
49
# File 'lib/pinterest_sdk/models/ad_create.rb', line 47

def destination_url
  @destination_url
end

#disclosure_typeObject

Returns the value of attribute disclosure_type.



49
50
51
# File 'lib/pinterest_sdk/models/ad_create.rb', line 49

def disclosure_type
  @disclosure_type
end

#disclosure_urlObject

URL for a page that provides disclosures about a pharmaceutical product, such as potential side effects. Make sure the URL takes the user directly to the disclosure content and the referenced site is secure.



52
53
54
# File 'lib/pinterest_sdk/models/ad_create.rb', line 52

def disclosure_url
  @disclosure_url
end

#grid_click_typeObject

Returns the value of attribute grid_click_type.



54
55
56
# File 'lib/pinterest_sdk/models/ad_create.rb', line 54

def grid_click_type
  @grid_click_type
end

Deep link URL for iOS devices.



57
58
59
# File 'lib/pinterest_sdk/models/ad_create.rb', line 57

def ios_deep_link
  @ios_deep_link
end

#is_cartingObject

Is the ad a carting/WTB ad?



60
61
62
# File 'lib/pinterest_sdk/models/ad_create.rb', line 60

def is_carting
  @is_carting
end

#is_collage_accepted_termsObject

Whether the advertiser has accepted the terms and conditions for collage ad.



63
64
65
# File 'lib/pinterest_sdk/models/ad_create.rb', line 63

def is_collage_accepted_terms
  @is_collage_accepted_terms
end

#is_collage_single_destinationObject

Whether the collage ad has a single destination url override.



66
67
68
# File 'lib/pinterest_sdk/models/ad_create.rb', line 66

def is_collage_single_destination
  @is_collage_single_destination
end

#is_pin_deletedObject

Is original pin deleted?



69
70
71
# File 'lib/pinterest_sdk/models/ad_create.rb', line 69

def is_pin_deleted
  @is_pin_deleted
end

#is_removableObject

Is pin repinnable?



72
73
74
# File 'lib/pinterest_sdk/models/ad_create.rb', line 72

def is_removable
  @is_removable
end

#lead_form_idObject

Lead form ID for lead ad generation.



75
76
77
# File 'lib/pinterest_sdk/models/ad_create.rb', line 75

def lead_form_id
  @lead_form_id
end

#nameObject

Name of the ad - 255 chars max.



78
79
80
# File 'lib/pinterest_sdk/models/ad_create.rb', line 78

def name
  @name
end

#pin_idObject

Pin ID. This field may only be updated for draft ads.



81
82
83
# File 'lib/pinterest_sdk/models/ad_create.rb', line 81

def pin_id
  @pin_id
end

#quiz_pin_dataObject

Before creating a quiz ad, you must create an organic Pin using POST/Create Pin for each result in the quiz. Quiz ads cannot be saved by a Pinner. Quiz ad results can be saved.



84
85
86
# File 'lib/pinterest_sdk/models/ad_create.rb', line 84

def quiz_pin_data
  @quiz_pin_data
end

#statusObject

Returns the value of attribute status.



86
87
88
# File 'lib/pinterest_sdk/models/ad_create.rb', line 86

def status
  @status
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



88
89
90
# File 'lib/pinterest_sdk/models/ad_create.rb', line 88

def tracking_urls
  @tracking_urls
end

#view_tracking_urlObject

Tracking URL for ad impressions.



91
92
93
# File 'lib/pinterest_sdk/models/ad_create.rb', line 91

def view_tracking_url
  @view_tracking_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



149
150
151
# File 'lib/pinterest_sdk/models/ad_create.rb', line 149

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



154
155
156
# File 'lib/pinterest_sdk/models/ad_create.rb', line 154

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/pinterest_sdk/models/ad_create.rb', line 116

def self.attribute_map
  {
    :'ad_group_id' => :'ad_group_id',
    :'android_deep_link' => :'android_deep_link',
    :'carousel_android_deep_links' => :'carousel_android_deep_links',
    :'carousel_destination_urls' => :'carousel_destination_urls',
    :'carousel_ios_deep_links' => :'carousel_ios_deep_links',
    :'click_tracking_url' => :'click_tracking_url',
    :'collection_items_destination_url_template' => :'collection_items_destination_url_template',
    :'collections_header_type' => :'collections_header_type',
    :'creative_type' => :'creative_type',
    :'customizable_cta_type' => :'customizable_cta_type',
    :'destination_url' => :'destination_url',
    :'disclosure_type' => :'disclosure_type',
    :'disclosure_url' => :'disclosure_url',
    :'grid_click_type' => :'grid_click_type',
    :'ios_deep_link' => :'ios_deep_link',
    :'is_carting' => :'is_carting',
    :'is_collage_accepted_terms' => :'is_collage_accepted_terms',
    :'is_collage_single_destination' => :'is_collage_single_destination',
    :'is_pin_deleted' => :'is_pin_deleted',
    :'is_removable' => :'is_removable',
    :'lead_form_id' => :'lead_form_id',
    :'name' => :'name',
    :'pin_id' => :'pin_id',
    :'quiz_pin_data' => :'quiz_pin_data',
    :'status' => :'status',
    :'tracking_urls' => :'tracking_urls',
    :'view_tracking_url' => :'view_tracking_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/pinterest_sdk/models/ad_create.rb', line 500

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/pinterest_sdk/models/ad_create.rb', line 192

def self.openapi_nullable
  Set.new([
    :'android_deep_link',
    :'carousel_android_deep_links',
    :'carousel_destination_urls',
    :'carousel_ios_deep_links',
    :'click_tracking_url',
    :'collection_items_destination_url_template',
    :'collections_header_type',
    :'customizable_cta_type',
    :'destination_url',
    :'disclosure_type',
    :'disclosure_url',
    :'grid_click_type',
    :'ios_deep_link',
    :'lead_form_id',
    :'name',
    :'quiz_pin_data',
    :'tracking_urls',
    :'view_tracking_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pinterest_sdk/models/ad_create.rb', line 159

def self.openapi_types
  {
    :'ad_group_id' => :'String',
    :'android_deep_link' => :'String',
    :'carousel_android_deep_links' => :'Array<String>',
    :'carousel_destination_urls' => :'Array<String>',
    :'carousel_ios_deep_links' => :'Array<String>',
    :'click_tracking_url' => :'String',
    :'collection_items_destination_url_template' => :'String',
    :'collections_header_type' => :'AdCollectionsHeaderType',
    :'creative_type' => :'CreativeType',
    :'customizable_cta_type' => :'CustomizableCTAType',
    :'destination_url' => :'String',
    :'disclosure_type' => :'DisclosureType',
    :'disclosure_url' => :'String',
    :'grid_click_type' => :'GridClickType',
    :'ios_deep_link' => :'String',
    :'is_carting' => :'Boolean',
    :'is_collage_accepted_terms' => :'Boolean',
    :'is_collage_single_destination' => :'Boolean',
    :'is_pin_deleted' => :'Boolean',
    :'is_removable' => :'Boolean',
    :'lead_form_id' => :'String',
    :'name' => :'String',
    :'pin_id' => :'String',
    :'quiz_pin_data' => :'QuizPinData',
    :'status' => :'EntityStatus',
    :'tracking_urls' => :'TrackingUrls',
    :'view_tracking_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/pinterest_sdk/models/ad_create.rb', line 453

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ad_group_id == o.ad_group_id &&
      android_deep_link == o.android_deep_link &&
      carousel_android_deep_links == o.carousel_android_deep_links &&
      carousel_destination_urls == o.carousel_destination_urls &&
      carousel_ios_deep_links == o.carousel_ios_deep_links &&
      click_tracking_url == o.click_tracking_url &&
      collection_items_destination_url_template == o.collection_items_destination_url_template &&
      collections_header_type == o.collections_header_type &&
      creative_type == o.creative_type &&
      customizable_cta_type == o.customizable_cta_type &&
      destination_url == o.destination_url &&
      disclosure_type == o.disclosure_type &&
      disclosure_url == o.disclosure_url &&
      grid_click_type == o.grid_click_type &&
      ios_deep_link == o.ios_deep_link &&
      is_carting == o.is_carting &&
      is_collage_accepted_terms == o.is_collage_accepted_terms &&
      is_collage_single_destination == o.is_collage_single_destination &&
      is_pin_deleted == o.is_pin_deleted &&
      is_removable == o.is_removable &&
      lead_form_id == o.lead_form_id &&
      name == o.name &&
      pin_id == o.pin_id &&
      quiz_pin_data == o.quiz_pin_data &&
      status == o.status &&
      tracking_urls == o.tracking_urls &&
      view_tracking_url == o.view_tracking_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


487
488
489
# File 'lib/pinterest_sdk/models/ad_create.rb', line 487

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



493
494
495
# File 'lib/pinterest_sdk/models/ad_create.rb', line 493

def hash
  [ad_group_id, android_deep_link, carousel_android_deep_links, carousel_destination_urls, carousel_ios_deep_links, click_tracking_url, collection_items_destination_url_template, collections_header_type, creative_type, customizable_cta_type, destination_url, disclosure_type, disclosure_url, grid_click_type, ios_deep_link, is_carting, is_collage_accepted_terms, is_collage_single_destination, is_pin_deleted, is_removable, lead_form_id, name, pin_id, quiz_pin_data, status, tracking_urls, view_tracking_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/pinterest_sdk/models/ad_create.rb', line 354

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ad_group_id.nil?
    invalid_properties.push('invalid value for "ad_group_id", ad_group_id cannot be nil.')
  end

  pattern = Regexp.new(/^(AG)?\d+$/)
  if @ad_group_id !~ pattern
    invalid_properties.push("invalid value for \"ad_group_id\", must conform to the pattern #{pattern}.")
  end

  if @creative_type.nil?
    invalid_properties.push('invalid value for "creative_type", creative_type cannot be nil.')
  end

  pattern = Regexp.new(/^(AG)?\d+$/)
  if !@lead_form_id.nil? && @lead_form_id !~ pattern
    invalid_properties.push("invalid value for \"lead_form_id\", must conform to the pattern #{pattern}.")
  end

  if @pin_id.nil?
    invalid_properties.push('invalid value for "pin_id", pin_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @pin_id !~ pattern
    invalid_properties.push("invalid value for \"pin_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/pinterest_sdk/models/ad_create.rb', line 522

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



389
390
391
392
393
394
395
396
397
398
# File 'lib/pinterest_sdk/models/ad_create.rb', line 389

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ad_group_id.nil?
  return false if @ad_group_id !~ Regexp.new(/^(AG)?\d+$/)
  return false if @creative_type.nil?
  return false if !@lead_form_id.nil? && @lead_form_id !~ Regexp.new(/^(AG)?\d+$/)
  return false if @pin_id.nil?
  return false if @pin_id !~ Regexp.new(/^\d+$/)
  true
end