Class: PinterestSdkClient::AdGroupAudienceSizingCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdGroupAudienceSizingCreate
- Defined in:
- lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group.
-
#creative_types ⇒ Object
Pin creative types filter.
-
#keywords ⇒ Object
Array of keyword objects.
- #placement_group ⇒ Object
-
#product_group_ids ⇒ Object
Targeted product group IDs.
-
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdGroupAudienceSizingCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdGroupAudienceSizingCreate
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupAudienceSizingCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupAudienceSizingCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_targeting_enabled') self.auto_targeting_enabled = attributes[:'auto_targeting_enabled'] else self.auto_targeting_enabled = true end if attributes.key?(:'creative_types') if (value = attributes[:'creative_types']).is_a?(Array) self.creative_types = value end end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'placement_group') self.placement_group = attributes[:'placement_group'] end if attributes.key?(:'product_group_ids') if (value = attributes[:'product_group_ids']).is_a?(Array) self.product_group_ids = value end end if attributes.key?(:'targeting_spec') self.targeting_spec = attributes[:'targeting_spec'] end end |
Instance Attribute Details
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group. Default value is True. Also known as Pinterest Performance+ targeting.
20 21 22 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 20 def auto_targeting_enabled @auto_targeting_enabled end |
#creative_types ⇒ Object
Pin creative types filter. Note: SHOP_THE_PIN has been deprecated. Please use COLLECTION instead.
23 24 25 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 23 def creative_types @creative_types end |
#keywords ⇒ Object
Array of keyword objects. If the keywords field is missing, all keywords will be targeted.
26 27 28 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 26 def keywords @keywords end |
#placement_group ⇒ Object
29 30 31 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 29 def placement_group @placement_group end |
#product_group_ids ⇒ Object
Targeted product group IDs. Note: This can only be combined with shopping/catalog sales campaigns. For more information, click here. SHOPPING_RETARGETING must be included in targeting_spec object or this field will be ignored.
32 33 34 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 32 def product_group_ids @product_group_ids end |
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
34 35 36 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 34 def targeting_spec @targeting_spec end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 59 def self.attribute_map { :'auto_targeting_enabled' => :'auto_targeting_enabled', :'creative_types' => :'creative_types', :'keywords' => :'keywords', :'placement_group' => :'placement_group', :'product_group_ids' => :'product_group_ids', :'targeting_spec' => :'targeting_spec' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 97 98 99 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 93 def self.openapi_nullable Set.new([ :'creative_types', :'keywords', :'product_group_ids', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 81 def self.openapi_types { :'auto_targeting_enabled' => :'Boolean', :'creative_types' => :'Array<AdGroupAudienceSizingCreativeTypes>', :'keywords' => :'Array<AdGroupAudienceSizingKeyword>', :'placement_group' => :'AdgroupPlacementGroupType', :'product_group_ids' => :'Array<String>', :'targeting_spec' => :'TargetingSpecOptimal' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && auto_targeting_enabled == o.auto_targeting_enabled && creative_types == o.creative_types && keywords == o.keywords && placement_group == o.placement_group && product_group_ids == o.product_group_ids && targeting_spec == o.targeting_spec end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 186 def hash [auto_targeting_enabled, creative_types, keywords, placement_group, product_group_ids, targeting_spec].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 |
# File 'lib/pinterest_sdk/models/ad_group_audience_sizing_create.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |