Class: PinterestSdkClient::AdGroupCreateCreate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/ad_group_create_create.rb

Overview

Resource create operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdGroupCreateCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 228

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupCreateCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupCreateCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_targeting_enabled')
    self.auto_targeting_enabled = attributes[:'auto_targeting_enabled']
  end

  if attributes.key?(:'bid_in_micro_currency')
    self.bid_in_micro_currency = attributes[:'bid_in_micro_currency']
  end

  if attributes.key?(:'bid_multiplier')
    self.bid_multiplier = attributes[:'bid_multiplier']
  end

  if attributes.key?(:'bid_strategy_type')
    self.bid_strategy_type = attributes[:'bid_strategy_type']
  end

  if attributes.key?(:'billable_event')
    self.billable_event = attributes[:'billable_event']
  else
    self.billable_event = nil
  end

  if attributes.key?(:'budget_in_micro_currency')
    self.budget_in_micro_currency = attributes[:'budget_in_micro_currency']
  end

  if attributes.key?(:'budget_type')
    self.budget_type = attributes[:'budget_type']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'customer_segment_id')
    self.customer_segment_id = attributes[:'customer_segment_id']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'ext_features')
    self.ext_features = attributes[:'ext_features']
  end

  if attributes.key?(:'feed_profile_id')
    self.feed_profile_id = attributes[:'feed_profile_id']
  end

  if attributes.key?(:'is_creative_optimization')
    self.is_creative_optimization = attributes[:'is_creative_optimization']
  end

  if attributes.key?(:'is_local_inventory')
    self.is_local_inventory = attributes[:'is_local_inventory']
  end

  if attributes.key?(:'lifetime_frequency_cap')
    self.lifetime_frequency_cap = attributes[:'lifetime_frequency_cap']
  end

  if attributes.key?(:'local_inventory_radius_in_miles')
    self.local_inventory_radius_in_miles = attributes[:'local_inventory_radius_in_miles']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'optimization_goal_metadata')
    self. = attributes[:'optimization_goal_metadata']
  end

  if attributes.key?(:'pacing_delivery_type')
    self.pacing_delivery_type = attributes[:'pacing_delivery_type']
  end

  if attributes.key?(:'performance_plus_campaign_settings')
    self.performance_plus_campaign_settings = attributes[:'performance_plus_campaign_settings']
  end

  if attributes.key?(:'placement_group')
    self.placement_group = attributes[:'placement_group']
  end

  if attributes.key?(:'placement_traffic_type')
    self.placement_traffic_type = attributes[:'placement_traffic_type']
  end

  if attributes.key?(:'promotion_application_level')
    self.promotion_application_level = attributes[:'promotion_application_level']
  end

  if attributes.key?(:'promotion_id')
    self.promotion_id = attributes[:'promotion_id']
  else
    self.promotion_id = '0'
  end

  if attributes.key?(:'promotion_ids')
    if (value = attributes[:'promotion_ids']).is_a?(Array)
      self.promotion_ids = value
    end
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'targeting_spec')
    self.targeting_spec = attributes[:'targeting_spec']
  end

  if attributes.key?(:'targeting_template_ids')
    if (value = attributes[:'targeting_template_ids']).is_a?(Array)
      self.targeting_template_ids = value
    end
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end
end

Instance Attribute Details

#auto_targeting_enabledObject

Enable auto-targeting for ad group. Default value is True. Also known as "Performance+ targeting".



20
21
22
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 20

def auto_targeting_enabled
  @auto_targeting_enabled
end

#bid_in_micro_currencyObject

Bid price in micro currency. This field is REQUIRED for the following campaign objective_type/billable_event combinations: AWARENESS/IMPRESSION, CONSIDERATION/CLICKTHROUGH, CATALOG_SALES/CLICKTHROUGH, VIDEO_VIEW/VIDEO_V_50_MRC.



23
24
25
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 23

def bid_in_micro_currency
  @bid_in_micro_currency
end

#bid_multiplierObject

Open beta Bid multiplier for ad group. This value is a double between 0.1 and 10.0. Enter 0 to remove the bid multiplier. - Not currently supported for Performance+ campaigns.



26
27
28
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 26

def bid_multiplier
  @bid_multiplier
end

#bid_strategy_typeObject

Returns the value of attribute bid_strategy_type.



28
29
30
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 28

def bid_strategy_type
  @bid_strategy_type
end

#billable_eventObject

Returns the value of attribute billable_event.



30
31
32
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 30

def billable_event
  @billable_event
end

#budget_in_micro_currencyObject

Budget in micro currency. This field is REQUIRED for non-CBO (campaign budget optimization) campaigns. A CBO campaign automatically generates ad group budgets from its campaign budget to maximize campaign outcome. A CBO campaign is limited to 70 or less ad groups.



33
34
35
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 33

def budget_in_micro_currency
  @budget_in_micro_currency
end

#budget_typeObject

Returns the value of attribute budget_type.



35
36
37
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 35

def budget_type
  @budget_type
end

#campaign_idObject

Campaign ID of the ad group.



38
39
40
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 38

def campaign_id
  @campaign_id
end

#customer_segment_idObject

Customer segment ID applied to the ad group. We currently only support 1 customer segment per ad group. To use customer segments, do not set the targeting_template_ids field as well as the AUDIENCE_INCLUDE field of the targeting_spec. To clear the customer segment ID, set this field to '0'.



41
42
43
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 41

def customer_segment_id
  @customer_segment_id
end

#end_timeObject

Timestamp in Unix format for scheduling when ads in the ad group stop appearing. If not specified, ads run indefinitely unless you update the ad group by changing their status to paused. Cannot occur after end_time for parent campaign (if specified). Learn about scheduling ads. For certain organizations (Closed beta): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.



44
45
46
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 44

def end_time
  @end_time
end

#ext_featuresObject

Returns the value of attribute ext_features.



46
47
48
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 46

def ext_features
  @ext_features
end

#feed_profile_idObject

Feed Profile ID associated to the adgroup.



49
50
51
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 49

def feed_profile_id
  @feed_profile_id
end

#is_creative_optimizationObject

Enable creative optimization for the ad group, default value is FALSE. When enabled, you allow Pinterest to automatically turn your product Pins into ads in different formats (collections and shopping) and deliver those ads to users at scale.



52
53
54
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 52

def is_creative_optimization
  @is_creative_optimization
end

#is_local_inventoryObject

Indicates whether the ad group should use the local inventory.



55
56
57
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 55

def is_local_inventory
  @is_local_inventory
end

#lifetime_frequency_capObject

Set a limit to the number of times a promoted pin from this campaign can be impressed by a pinner within the past rolling 30 days. Only available for CPM (cost per mille (1000 impressions)) ad groups. A CPM ad group has an IMPRESSION billable_event value. This field REQUIRES the end_time field.



58
59
60
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 58

def lifetime_frequency_cap
  @lifetime_frequency_cap
end

#local_inventory_radius_in_milesObject

The targeting radius of the local inventory ads in miles.



61
62
63
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 61

def local_inventory_radius_in_miles
  @local_inventory_radius_in_miles
end

#nameObject

Ad group name.



64
65
66
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 64

def name
  @name
end

#optimization_goal_metadataObject

Optimization goals for objective-based performance campaigns. REQUIRED when campaign's objective_type is set to \"WEB_CONVERSION\".



67
68
69
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 67

def 
  @optimization_goal_metadata
end

#pacing_delivery_typeObject

Returns the value of attribute pacing_delivery_type.



69
70
71
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 69

def pacing_delivery_type
  @pacing_delivery_type
end

#performance_plus_campaign_settingsObject

Pinterest Performance+ campaign settings.



72
73
74
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 72

def performance_plus_campaign_settings
  @performance_plus_campaign_settings
end

#placement_groupObject



75
76
77
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 75

def placement_group
  @placement_group
end

#placement_traffic_typeObject

A targeting option that enables advertisers to choose whether to run ads in fullscreen feed, two column feed, or both



78
79
80
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 78

def placement_traffic_type
  @placement_traffic_type
end

#promotion_application_levelObject

Specify if the promotion is applied at ad group or item level



81
82
83
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 81

def promotion_application_level
  @promotion_application_level
end

#promotion_idObject

Promotion ID. To clear this field, set to null.



84
85
86
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 84

def promotion_id
  @promotion_id
end

#promotion_idsObject

Promotion IDs list. To clear this field, set to an empty array [].



87
88
89
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 87

def promotion_ids
  @promotion_ids
end

#start_timeObject

Timestamp in Unix format for scheduling when ads in the ad group start to appear. If not specified, ads appear during parent campaign's start_time. Cannot precede start_time for parent campaign (if specified). Learn about scheduling ads. For certain organizations (Closed beta): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.



90
91
92
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 90

def start_time
  @start_time
end

#statusObject

Ad group/entity status.



93
94
95
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 93

def status
  @status
end

#targeting_specObject

Returns the value of attribute targeting_spec.



95
96
97
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 95

def targeting_spec
  @targeting_spec
end

#targeting_template_idsObject

Targeting template IDs applied to the ad group. We currently only support 1 targeting template per ad group. To use targeting templates, do not set any other targeting fields: targeting_spec, tracking_urls, auto_targeting_enabled, placement_group. To clear all targeting template IDs, set this field to ['0'].



98
99
100
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 98

def targeting_template_ids
  @targeting_template_ids
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



100
101
102
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 100

def tracking_urls
  @tracking_urls
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



161
162
163
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 161

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



166
167
168
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 166

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 125

def self.attribute_map
  {
    :'auto_targeting_enabled' => :'auto_targeting_enabled',
    :'bid_in_micro_currency' => :'bid_in_micro_currency',
    :'bid_multiplier' => :'bid_multiplier',
    :'bid_strategy_type' => :'bid_strategy_type',
    :'billable_event' => :'billable_event',
    :'budget_in_micro_currency' => :'budget_in_micro_currency',
    :'budget_type' => :'budget_type',
    :'campaign_id' => :'campaign_id',
    :'customer_segment_id' => :'customer_segment_id',
    :'end_time' => :'end_time',
    :'ext_features' => :'ext_features',
    :'feed_profile_id' => :'feed_profile_id',
    :'is_creative_optimization' => :'is_creative_optimization',
    :'is_local_inventory' => :'is_local_inventory',
    :'lifetime_frequency_cap' => :'lifetime_frequency_cap',
    :'local_inventory_radius_in_miles' => :'local_inventory_radius_in_miles',
    :'name' => :'name',
    :'optimization_goal_metadata' => :'optimization_goal_metadata',
    :'pacing_delivery_type' => :'pacing_delivery_type',
    :'performance_plus_campaign_settings' => :'performance_plus_campaign_settings',
    :'placement_group' => :'placement_group',
    :'placement_traffic_type' => :'placement_traffic_type',
    :'promotion_application_level' => :'promotion_application_level',
    :'promotion_id' => :'promotion_id',
    :'promotion_ids' => :'promotion_ids',
    :'start_time' => :'start_time',
    :'status' => :'status',
    :'targeting_spec' => :'targeting_spec',
    :'targeting_template_ids' => :'targeting_template_ids',
    :'tracking_urls' => :'tracking_urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 579

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 207

def self.openapi_nullable
  Set.new([
    :'bid_in_micro_currency',
    :'bid_strategy_type',
    :'budget_in_micro_currency',
    :'end_time',
    :'ext_features',
    :'is_creative_optimization',
    :'optimization_goal_metadata',
    :'performance_plus_campaign_settings',
    :'placement_traffic_type',
    :'promotion_application_level',
    :'promotion_id',
    :'start_time',
    :'targeting_template_ids',
    :'tracking_urls'
  ])
end

.openapi_typesObject

Attribute type mapping.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 171

def self.openapi_types
  {
    :'auto_targeting_enabled' => :'Boolean',
    :'bid_in_micro_currency' => :'Integer',
    :'bid_multiplier' => :'Float',
    :'bid_strategy_type' => :'BidStrategyType',
    :'billable_event' => :'ActionType',
    :'budget_in_micro_currency' => :'Integer',
    :'budget_type' => :'BudgetType',
    :'campaign_id' => :'String',
    :'customer_segment_id' => :'String',
    :'end_time' => :'Integer',
    :'ext_features' => :'AdgroupTrackingFeatures',
    :'feed_profile_id' => :'String',
    :'is_creative_optimization' => :'Boolean',
    :'is_local_inventory' => :'Boolean',
    :'lifetime_frequency_cap' => :'Integer',
    :'local_inventory_radius_in_miles' => :'Float',
    :'name' => :'String',
    :'optimization_goal_metadata' => :'NullableOptimizationGoalMetadata',
    :'pacing_delivery_type' => :'PacingDeliveryType',
    :'performance_plus_campaign_settings' => :'PerformancePlusCampaignSettings',
    :'placement_group' => :'PlacementGroupType',
    :'placement_traffic_type' => :'PlacementTrafficType',
    :'promotion_application_level' => :'PromotionApplicationLevel',
    :'promotion_id' => :'String',
    :'promotion_ids' => :'Array<String>',
    :'start_time' => :'Integer',
    :'status' => :'EntityStatus',
    :'targeting_spec' => :'TargetingSpecOptimal',
    :'targeting_template_ids' => :'Array<String>',
    :'tracking_urls' => :'AdGroupTrackingURLs'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 529

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_targeting_enabled == o.auto_targeting_enabled &&
      bid_in_micro_currency == o.bid_in_micro_currency &&
      bid_multiplier == o.bid_multiplier &&
      bid_strategy_type == o.bid_strategy_type &&
      billable_event == o.billable_event &&
      budget_in_micro_currency == o.budget_in_micro_currency &&
      budget_type == o.budget_type &&
      campaign_id == o.campaign_id &&
      customer_segment_id == o.customer_segment_id &&
      end_time == o.end_time &&
      ext_features == o.ext_features &&
      feed_profile_id == o.feed_profile_id &&
      is_creative_optimization == o.is_creative_optimization &&
      is_local_inventory == o.is_local_inventory &&
      lifetime_frequency_cap == o.lifetime_frequency_cap &&
      local_inventory_radius_in_miles == o.local_inventory_radius_in_miles &&
      name == o.name &&
       == o. &&
      pacing_delivery_type == o.pacing_delivery_type &&
      performance_plus_campaign_settings == o.performance_plus_campaign_settings &&
      placement_group == o.placement_group &&
      placement_traffic_type == o.placement_traffic_type &&
      promotion_application_level == o.promotion_application_level &&
      promotion_id == o.promotion_id &&
      promotion_ids == o.promotion_ids &&
      start_time == o.start_time &&
      status == o.status &&
      targeting_spec == o.targeting_spec &&
      targeting_template_ids == o.targeting_template_ids &&
      tracking_urls == o.tracking_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


566
567
568
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 566

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



572
573
574
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 572

def hash
  [auto_targeting_enabled, bid_in_micro_currency, bid_multiplier, bid_strategy_type, billable_event, budget_in_micro_currency, budget_type, campaign_id, customer_segment_id, end_time, ext_features, feed_profile_id, is_creative_optimization, is_local_inventory, lifetime_frequency_cap, local_inventory_radius_in_miles, name, , pacing_delivery_type, performance_plus_campaign_settings, placement_group, placement_traffic_type, promotion_application_level, promotion_id, promotion_ids, start_time, status, targeting_spec, targeting_template_ids, tracking_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 377

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@bid_multiplier.nil? && @bid_multiplier > 10
    invalid_properties.push('invalid value for "bid_multiplier", must be smaller than or equal to 10.')
  end

  if !@bid_multiplier.nil? && @bid_multiplier < 0
    invalid_properties.push('invalid value for "bid_multiplier", must be greater than or equal to 0.')
  end

  if @billable_event.nil?
    invalid_properties.push('invalid value for "billable_event", billable_event cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  pattern = Regexp.new(/^[C]?\d+$/)
  if @campaign_id !~ pattern
    invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@customer_segment_id.nil? && @customer_segment_id !~ pattern
    invalid_properties.push("invalid value for \"customer_segment_id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@promotion_id.nil? && @promotion_id !~ pattern
    invalid_properties.push("invalid value for \"promotion_id\", must conform to the pattern #{pattern}.")
  end

  if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1
    invalid_properties.push('invalid value for "targeting_template_ids", number of items must be less than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



601
602
603
604
605
606
607
608
609
610
611
612
613
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 601

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/pinterest_sdk/models/ad_group_create_create.rb', line 424

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@bid_multiplier.nil? && @bid_multiplier > 10
  return false if !@bid_multiplier.nil? && @bid_multiplier < 0
  return false if @billable_event.nil?
  return false if @campaign_id.nil?
  return false if @campaign_id !~ Regexp.new(/^[C]?\d+$/)
  return false if !@customer_segment_id.nil? && @customer_segment_id !~ Regexp.new(/^\d+$/)
  return false if @name.nil?
  return false if !@promotion_id.nil? && @promotion_id !~ Regexp.new(/^\d+$/)
  return false if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1
  true
end