Class: PinterestSdkClient::AdGroupCreateRequestAllOf1
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdGroupCreateRequestAllOf1
- Defined in:
- lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group.
-
#bid_multiplier ⇒ Object
<a href="/docs/getting-started/using-beta-and-restricted-features/" target="blank>Open beta Bid multiplier for ad group.
-
#budget_type ⇒ Object
Returns the value of attribute budget_type.
-
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdGroupCreateRequestAllOf1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdGroupCreateRequestAllOf1
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupCreateRequestAllOf1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupCreateRequestAllOf1`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_targeting_enabled') self.auto_targeting_enabled = attributes[:'auto_targeting_enabled'] end if attributes.key?(:'bid_multiplier') self.bid_multiplier = attributes[:'bid_multiplier'] end if attributes.key?(:'budget_type') self.budget_type = attributes[:'budget_type'] end if attributes.key?(:'pacing_delivery_type') self.pacing_delivery_type = attributes[:'pacing_delivery_type'] end end |
Instance Attribute Details
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group. Default value is True. Also known as <a href="https://help.pinterest.com/en/business/article/performance-plus-targeting" target="_blank">"Pinterest Performance+ targeting".
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 19 def auto_targeting_enabled @auto_targeting_enabled end |
#bid_multiplier ⇒ Object
<a href="/docs/getting-started/using-beta-and-restricted-features/" target="blank>Open beta Bid multiplier for ad group. This value is a double between 0.1 and 10.0. Enter 0 to remove the bid multiplier. - Make sure the bid_strategy type for your ad group is set to AUTOMATIC_BID. - Not currently supported for <a href="/docs/api-features/pinterest-performance-plus-setup/" target="blank">Pinterest Performance+ campaigns.
22 23 24 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 22 def bid_multiplier @bid_multiplier end |
#budget_type ⇒ Object
Returns the value of attribute budget_type.
24 25 26 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 24 def budget_type @budget_type end |
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
26 27 28 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 26 def pacing_delivery_type @pacing_delivery_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 51 def self.attribute_map { :'auto_targeting_enabled' => :'auto_targeting_enabled', :'bid_multiplier' => :'bid_multiplier', :'budget_type' => :'budget_type', :'pacing_delivery_type' => :'pacing_delivery_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 71 def self.openapi_types { :'auto_targeting_enabled' => :'Boolean', :'bid_multiplier' => :'Float', :'budget_type' => :'BudgetType', :'pacing_delivery_type' => :'PacingDeliveryType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && auto_targeting_enabled == o.auto_targeting_enabled && bid_multiplier == o.bid_multiplier && budget_type == o.budget_type && pacing_delivery_type == o.pacing_delivery_type end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 181 def hash [auto_targeting_enabled, bid_multiplier, budget_type, pacing_delivery_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@bid_multiplier.nil? && @bid_multiplier > 10 invalid_properties.push('invalid value for "bid_multiplier", must be smaller than or equal to 10.') end if !@bid_multiplier.nil? && @bid_multiplier < 0 invalid_properties.push('invalid value for "bid_multiplier", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 |
# File 'lib/pinterest_sdk/models/ad_group_create_request_all_of1.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@bid_multiplier.nil? && @bid_multiplier > 10 return false if !@bid_multiplier.nil? && @bid_multiplier < 0 true end |