Class: PinterestSdkClient::AdGroupUpdateRequestAllOf1

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdGroupUpdateRequestAllOf1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupUpdateRequestAllOf1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupUpdateRequestAllOf1`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bid_multiplier')
    self.bid_multiplier = attributes[:'bid_multiplier']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'targeting_spec_operations')
    if (value = attributes[:'targeting_spec_operations']).is_a?(Array)
      self.targeting_spec_operations = value
    end
  end
end

Instance Attribute Details

#bid_multiplierObject

<a href="/docs/getting-started/using-beta-and-restricted-features/" target="blank>Open beta Bid multiplier for ad group. This value is a double between 0.1 and 10.0. Enter 0 to remove the bid multiplier. - Make sure the bid_strategy type for your ad group is set to AUTOMATIC_BID. - Not currently supported for <a href="/docs/api-features/pinterest-performance-plus-setup/" target="blank">Pinterest Performance+ campaigns.



19
20
21
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 19

def bid_multiplier
  @bid_multiplier
end

#idObject

Ad group ID.



22
23
24
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 22

def id
  @id
end

#targeting_spec_operationsObject

Targeting spec operations define modifications to apply to the targeting spec.

NOTE: The targeting_spec and targeting_spec_operations cannot be sent at the same time.

The supported operations are:
  • SET: sets the field with the given values. If value is set to null, the field will be removed.
  • ADD: adds the given values to the field.
  • REMOVE: removes the given values from the field.
Note the following:
  • Same items are not added and removed at the same time.
  • For a given field, only ADD/REMOVE or SET operations are allowed, not a mix of them.
  • Only one SET operation is allowed for a given field.
  • The AGE_BUCKET, MAXIMUM_AGE, MINIMUM_AGE and SHOPPING_RETARGETING fields only support the SET operation.


25
26
27
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 25

def targeting_spec_operations
  @targeting_spec_operations
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 28

def self.attribute_map
  {
    :'bid_multiplier' => :'bid_multiplier',
    :'id' => :'id',
    :'targeting_spec_operations' => :'targeting_spec_operations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 47

def self.openapi_types
  {
    :'bid_multiplier' => :'Float',
    :'id' => :'String',
    :'targeting_spec_operations' => :'Array<TargetingSpecOperations>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bid_multiplier == o.bid_multiplier &&
      id == o.id &&
      targeting_spec_operations == o.targeting_spec_operations
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 181

def hash
  [bid_multiplier, id, targeting_spec_operations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@bid_multiplier.nil? && @bid_multiplier > 10
    invalid_properties.push('invalid value for "bid_multiplier", must be smaller than or equal to 10.')
  end

  if !@bid_multiplier.nil? && @bid_multiplier < 0
    invalid_properties.push('invalid value for "bid_multiplier", must be greater than or equal to 0.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
125
126
127
128
# File 'lib/pinterest_sdk/models/ad_group_update_request_all_of1.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@bid_multiplier.nil? && @bid_multiplier > 10
  return false if !@bid_multiplier.nil? && @bid_multiplier < 0
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  true
end