Class: PinterestSdkClient::AdvancedAuctionItemsSubmitDeleteRecord

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb

Overview

Object describing an item bid option deletion operation

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdvancedAuctionItemsSubmitDeleteRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdvancedAuctionItemsSubmitDeleteRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdvancedAuctionItemsSubmitDeleteRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end

  if attributes.key?(:'item_id')
    self.item_id = attributes[:'item_id']
  else
    self.item_id = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  else
    self.operation = nil
  end
end

Instance Attribute Details

#countryObject

Returns the value of attribute country.



19
20
21
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 19

def country
  @country
end

#errorsObject

Array with validation errors for the supplied item bid option modification operation. A non empty errors list means this single item operation was not applied.



22
23
24
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 22

def errors
  @errors
end

#item_idObject

The catalog retail item id in the merchant namespace



25
26
27
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 25

def item_id
  @item_id
end

#languageObject

Returns the value of attribute language.



27
28
29
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 27

def language
  @language
end

#operationObject

Returns the value of attribute operation.



29
30
31
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 29

def operation
  @operation
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 54

def self.attribute_map
  {
    :'country' => :'country',
    :'errors' => :'errors',
    :'item_id' => :'item_id',
    :'language' => :'language',
    :'operation' => :'operation'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 75

def self.openapi_types
  {
    :'country' => :'Country',
    :'errors' => :'Array<AdvancedAuctionOperationError>',
    :'item_id' => :'String',
    :'language' => :'Language',
    :'operation' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      errors == o.errors &&
      item_id == o.item_id &&
      language == o.language &&
      operation == o.operation
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 235

def hash
  [country, errors, item_id, language, operation].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @item_id.nil?
    invalid_properties.push('invalid value for "item_id", item_id cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if @operation.nil?
    invalid_properties.push('invalid value for "operation", operation cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
172
173
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_delete_record.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @country.nil?
  return false if @item_id.nil?
  return false if @language.nil?
  return false if @operation.nil?
  operation_validator = EnumAttributeValidator.new('String', ["DELETE"])
  return false unless operation_validator.valid?(@operation)
  true
end