Class: PinterestSdkClient::AdvancedAuctionItemsSubmitUpsertRecord
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdvancedAuctionItemsSubmitUpsertRecord
- Defined in:
- lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb
Overview
Object describing an item bid option upsert operation
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bid_options ⇒ Object
Returns the value of attribute bid_options.
-
#country ⇒ Object
Returns the value of attribute country.
-
#errors ⇒ Object
Array with validation errors for the supplied item bid option modification operation.
-
#item_id ⇒ Object
The catalog retail item id in the merchant namespace.
-
#language ⇒ Object
Returns the value of attribute language.
-
#operation ⇒ Object
Returns the value of attribute operation.
-
#update_mask ⇒ Object
The list of item bid option fields to be set or updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdvancedAuctionItemsSubmitUpsertRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdvancedAuctionItemsSubmitUpsertRecord
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdvancedAuctionItemsSubmitUpsertRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdvancedAuctionItemsSubmitUpsertRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bid_options') self. = attributes[:'bid_options'] else self. = nil end if attributes.key?(:'country') self.country = attributes[:'country'] else self.country = nil end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] else self.item_id = nil end if attributes.key?(:'language') self.language = attributes[:'language'] else self.language = nil end if attributes.key?(:'operation') self.operation = attributes[:'operation'] else self.operation = nil end if attributes.key?(:'update_mask') if (value = attributes[:'update_mask']).is_a?(Array) self.update_mask = value end else self.update_mask = nil end end |
Instance Attribute Details
#bid_options ⇒ Object
Returns the value of attribute bid_options.
19 20 21 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 19 def end |
#country ⇒ Object
Returns the value of attribute country.
21 22 23 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 21 def country @country end |
#errors ⇒ Object
Array with validation errors for the supplied item bid option modification operation. A non empty errors list means this single item operation was not applied.
24 25 26 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 24 def errors @errors end |
#item_id ⇒ Object
The catalog retail item id in the merchant namespace
27 28 29 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 27 def item_id @item_id end |
#language ⇒ Object
Returns the value of attribute language.
29 30 31 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 29 def language @language end |
#operation ⇒ Object
Returns the value of attribute operation.
31 32 33 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 31 def operation @operation end |
#update_mask ⇒ Object
The list of item bid option fields to be set or updated. Fields specified in the updated mask without a value specified in the bid_options object in the body will be set to null. If an item bid option record is being created, fields not specified in the update mask will be initialized to null.
34 35 36 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 34 def update_mask @update_mask end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 59 def self.attribute_map { :'bid_options' => :'bid_options', :'country' => :'country', :'errors' => :'errors', :'item_id' => :'item_id', :'language' => :'language', :'operation' => :'operation', :'update_mask' => :'update_mask' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 95 def self.openapi_nullable Set.new([ :'update_mask' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 82 def self.openapi_types { :'bid_options' => :'AdvancedAuctionBidOptions', :'country' => :'Country', :'errors' => :'Array<AdvancedAuctionOperationError>', :'item_id' => :'String', :'language' => :'Language', :'operation' => :'String', :'update_mask' => :'Array<UpdateMaskBidOptionField>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && country == o.country && errors == o.errors && item_id == o.item_id && language == o.language && operation == o.operation && update_mask == o.update_mask end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 276 def hash [, country, errors, item_id, language, operation, update_mask].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if .nil? invalid_properties.push('invalid value for "bid_options", bid_options cannot be nil.') end if @country.nil? invalid_properties.push('invalid value for "country", country cannot be nil.') end if @item_id.nil? invalid_properties.push('invalid value for "item_id", item_id cannot be nil.') end if @language.nil? invalid_properties.push('invalid value for "language", language cannot be nil.') end if @operation.nil? invalid_properties.push('invalid value for "operation", operation cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/pinterest_sdk/models/advanced_auction_items_submit_upsert_record.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if .nil? return false if @country.nil? return false if @item_id.nil? return false if @language.nil? return false if @operation.nil? operation_validator = EnumAttributeValidator.new('String', ["UPSERT"]) return false unless operation_validator.valid?(@operation) true end |