Class: PinterestSdkClient::AggregatedPinComment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/aggregated_pin_comment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AggregatedPinComment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 165

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AggregatedPinComment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AggregatedPinComment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ai_disclosures')
    self.ai_disclosures = attributes[:'ai_disclosures']
  end

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'board_id')
    self.board_id = attributes[:'board_id']
  end

  if attributes.key?(:'board_owner')
    self.board_owner = attributes[:'board_owner']
  end

  if attributes.key?(:'board_section_id')
    self.board_section_id = attributes[:'board_section_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'creative_type')
    self.creative_type = attributes[:'creative_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'dominant_color')
    self.dominant_color = attributes[:'dominant_color']
  end

  if attributes.key?(:'has_been_promoted')
    self.has_been_promoted = attributes[:'has_been_promoted']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'is_owner')
    self.is_owner = attributes[:'is_owner']
  end

  if attributes.key?(:'is_product')
    self.is_product = attributes[:'is_product']
  end

  if attributes.key?(:'is_standard')
    self.is_standard = attributes[:'is_standard']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'media')
    self.media = attributes[:'media']
  end

  if attributes.key?(:'parent_pin_id')
    self.parent_pin_id = attributes[:'parent_pin_id']
  end

  if attributes.key?(:'pin_metrics')
    self.pin_metrics = attributes[:'pin_metrics']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#ai_disclosuresObject

AI disclosure declarations the creator has made about this Pin.



19
20
21
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 19

def ai_disclosures
  @ai_disclosures
end

#alt_textObject

Returns the value of attribute alt_text.



21
22
23
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 21

def alt_text
  @alt_text
end

#board_idObject

The board to which this Pin belongs.



24
25
26
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 24

def board_id
  @board_id
end

#board_ownerObject

Returns the value of attribute board_owner.



26
27
28
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 26

def board_owner
  @board_owner
end

#board_section_idObject

The board section to which this Pin belongs.



29
30
31
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 29

def board_section_id
  @board_section_id
end

#created_atObject

Returns the value of attribute created_at.



31
32
33
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 31

def created_at
  @created_at
end

#creative_typeObject

Returns the value of attribute creative_type.



33
34
35
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 33

def creative_type
  @creative_type
end

#descriptionObject

Returns the value of attribute description.



35
36
37
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 35

def description
  @description
end

#dominant_colorObject

Dominant pin color. Hex number, e.g. #6E7874.



38
39
40
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 38

def dominant_color
  @dominant_color
end

#has_been_promotedObject

Whether the Pin has been promoted or not.



41
42
43
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 41

def has_been_promoted
  @has_been_promoted
end

#idObject

Returns the value of attribute id.



43
44
45
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 43

def id
  @id
end

#is_ownerObject

Whether the "operation user_account" is the Pin owner.



46
47
48
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 46

def is_owner
  @is_owner
end

#is_productObject

Whether the Pin is a product Pin.



49
50
51
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 49

def is_product
  @is_product
end

#is_standardObject

Whether the Pin is standard or not. See documentation on Changes to Pin creation for more information.



52
53
54
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 52

def is_standard
  @is_standard
end

Returns the value of attribute link.



54
55
56
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 54

def link
  @link
end

#mediaObject

Returns the value of attribute media.



56
57
58
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 56

def media
  @media
end

#parent_pin_idObject

The source pin id if this pin was saved from another pin. Learn more.



59
60
61
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 59

def parent_pin_id
  @parent_pin_id
end

#pin_metricsObject

Pin metrics with associated time intervals if any.



62
63
64
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 62

def pin_metrics
  @pin_metrics
end

#titleObject

Returns the value of attribute title.



64
65
66
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 64

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



114
115
116
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 114

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 119

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 89

def self.attribute_map
  {
    :'ai_disclosures' => :'ai_disclosures',
    :'alt_text' => :'alt_text',
    :'board_id' => :'board_id',
    :'board_owner' => :'board_owner',
    :'board_section_id' => :'board_section_id',
    :'created_at' => :'created_at',
    :'creative_type' => :'creative_type',
    :'description' => :'description',
    :'dominant_color' => :'dominant_color',
    :'has_been_promoted' => :'has_been_promoted',
    :'id' => :'id',
    :'is_owner' => :'is_owner',
    :'is_product' => :'is_product',
    :'is_standard' => :'is_standard',
    :'link' => :'link',
    :'media' => :'media',
    :'parent_pin_id' => :'parent_pin_id',
    :'pin_metrics' => :'pin_metrics',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 455

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 149

def self.openapi_nullable
  Set.new([
    :'alt_text',
    :'board_section_id',
    :'creative_type',
    :'description',
    :'dominant_color',
    :'link',
    :'parent_pin_id',
    :'pin_metrics',
    :'title'
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 124

def self.openapi_types
  {
    :'ai_disclosures' => :'AiDisclosures',
    :'alt_text' => :'String',
    :'board_id' => :'String',
    :'board_owner' => :'BoardOwner',
    :'board_section_id' => :'String',
    :'created_at' => :'Time',
    :'creative_type' => :'CreativeType',
    :'description' => :'String',
    :'dominant_color' => :'String',
    :'has_been_promoted' => :'Boolean',
    :'id' => :'String',
    :'is_owner' => :'Boolean',
    :'is_product' => :'Boolean',
    :'is_standard' => :'Boolean',
    :'link' => :'String',
    :'media' => :'PinMedia',
    :'parent_pin_id' => :'String',
    :'pin_metrics' => :'Object',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 416

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ai_disclosures == o.ai_disclosures &&
      alt_text == o.alt_text &&
      board_id == o.board_id &&
      board_owner == o.board_owner &&
      board_section_id == o.board_section_id &&
      created_at == o.created_at &&
      creative_type == o.creative_type &&
      description == o.description &&
      dominant_color == o.dominant_color &&
      has_been_promoted == o.has_been_promoted &&
      id == o.id &&
      is_owner == o.is_owner &&
      is_product == o.is_product &&
      is_standard == o.is_standard &&
      link == o.link &&
      media == o.media &&
      parent_pin_id == o.parent_pin_id &&
      pin_metrics == o.pin_metrics &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


442
443
444
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 442

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



448
449
450
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 448

def hash
  [ai_disclosures, alt_text, board_id, board_owner, board_section_id, created_at, creative_type, description, dominant_color, has_been_promoted, id, is_owner, is_product, is_standard, link, media, parent_pin_id, pin_metrics, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 260

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@alt_text.nil? && @alt_text.to_s.length > 500
    invalid_properties.push('invalid value for "alt_text", the character length must be smaller than or equal to 500.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@board_id.nil? && @board_id !~ pattern
    invalid_properties.push("invalid value for \"board_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@board_section_id.nil? && @board_section_id !~ pattern
    invalid_properties.push("invalid value for \"board_section_id\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 800
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 800.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@link.nil? && @link.to_s.length > 2048
    invalid_properties.push('invalid value for "link", the character length must be smaller than or equal to 2048.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@parent_pin_id.nil? && @parent_pin_id !~ pattern
    invalid_properties.push("invalid value for \"parent_pin_id\", must conform to the pattern #{pattern}.")
  end

  if !@title.nil? && @title.to_s.length > 100
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 477

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/pinterest_sdk/models/aggregated_pin_comment.rb', line 308

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@alt_text.nil? && @alt_text.to_s.length > 500
  return false if !@board_id.nil? && @board_id !~ Regexp.new(/^\d+$/)
  return false if !@board_section_id.nil? && @board_section_id !~ Regexp.new(/^\d+$/)
  return false if !@description.nil? && @description.to_s.length > 800
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if !@link.nil? && @link.to_s.length > 2048
  return false if !@parent_pin_id.nil? && @parent_pin_id !~ Regexp.new(/^\d+$/)
  return false if !@title.nil? && @title.to_s.length > 100
  true
end