Class: PinterestSdkClient::AssetGroupBinding

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/asset_group_binding.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AssetGroupBinding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AssetGroupBinding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AssetGroupBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_accounts_ids')
    if (value = attributes[:'ad_accounts_ids']).is_a?(Array)
      self.ad_accounts_ids = value
    end
  else
    self.ad_accounts_ids = nil
  end

  if attributes.key?(:'asset_group_description')
    self.asset_group_description = attributes[:'asset_group_description']
  else
    self.asset_group_description = nil
  end

  if attributes.key?(:'asset_group_name')
    self.asset_group_name = attributes[:'asset_group_name']
  else
    self.asset_group_name = nil
  end

  if attributes.key?(:'asset_group_types')
    if (value = attributes[:'asset_group_types']).is_a?(Array)
      self.asset_group_types = value
    end
  else
    self.asset_group_types = nil
  end

  if attributes.key?(:'catalogs_ids')
    if (value = attributes[:'catalogs_ids']).is_a?(Array)
      self.catalogs_ids = value
    end
  else
    self.catalogs_ids = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  else
    self.created_time = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'owner')
    self.owner = attributes[:'owner']
  else
    self.owner = nil
  end

  if attributes.key?(:'profiles_ids')
    if (value = attributes[:'profiles_ids']).is_a?(Array)
      self.profiles_ids = value
    end
  else
    self.profiles_ids = nil
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  else
    self.updated_time = nil
  end
end

Instance Attribute Details

#ad_accounts_idsObject

A list of ad account IDs under the asset group



19
20
21
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 19

def ad_accounts_ids
  @ad_accounts_ids
end

#asset_group_descriptionObject

Asset group description



22
23
24
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 22

def asset_group_description
  @asset_group_description
end

#asset_group_nameObject

Asset Group name



25
26
27
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 25

def asset_group_name
  @asset_group_name
end

#asset_group_typesObject

Asset group types



28
29
30
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 28

def asset_group_types
  @asset_group_types
end

#catalogs_idsObject

A list of catalog IDs under asset group



31
32
33
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 31

def catalogs_ids
  @catalogs_ids
end

#created_byObject

The data of the user that created the asset group.



34
35
36
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 34

def created_by
  @created_by
end

#created_timeObject

The creation time of the asset group



37
38
39
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 37

def created_time
  @created_time
end

#idObject

Asset Group ID.



40
41
42
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 40

def id
  @id
end

#ownerObject

The data of the business that owns the asset group.



43
44
45
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 43

def owner
  @owner
end

#profiles_idsObject

A list of profile IDs under asset group



46
47
48
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 46

def profiles_ids
  @profiles_ids
end

#updated_timeObject

The last update time of the asset group



49
50
51
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 49

def updated_time
  @updated_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 52

def self.attribute_map
  {
    :'ad_accounts_ids' => :'ad_accounts_ids',
    :'asset_group_description' => :'asset_group_description',
    :'asset_group_name' => :'asset_group_name',
    :'asset_group_types' => :'asset_group_types',
    :'catalogs_ids' => :'catalogs_ids',
    :'created_by' => :'created_by',
    :'created_time' => :'created_time',
    :'id' => :'id',
    :'owner' => :'owner',
    :'profiles_ids' => :'profiles_ids',
    :'updated_time' => :'updated_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
100
101
102
103
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 96

def self.openapi_nullable
  Set.new([
    :'asset_group_description',
    :'asset_group_name',
    :'created_time',
    :'updated_time'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 79

def self.openapi_types
  {
    :'ad_accounts_ids' => :'Array<String>',
    :'asset_group_description' => :'String',
    :'asset_group_name' => :'String',
    :'asset_group_types' => :'Array<String>',
    :'catalogs_ids' => :'Array<String>',
    :'created_by' => :'BusinessAccessUserSummary',
    :'created_time' => :'Integer',
    :'id' => :'String',
    :'owner' => :'BusinessAccessUserSummary',
    :'profiles_ids' => :'Array<String>',
    :'updated_time' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 329

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ad_accounts_ids == o.ad_accounts_ids &&
      asset_group_description == o.asset_group_description &&
      asset_group_name == o.asset_group_name &&
      asset_group_types == o.asset_group_types &&
      catalogs_ids == o.catalogs_ids &&
      created_by == o.created_by &&
      created_time == o.created_time &&
      id == o.id &&
      owner == o.owner &&
      profiles_ids == o.profiles_ids &&
      updated_time == o.updated_time
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 353

def hash
  [ad_accounts_ids, asset_group_description, asset_group_name, asset_group_types, catalogs_ids, created_by, created_time, id, owner, profiles_ids, updated_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 198

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ad_accounts_ids.nil?
    invalid_properties.push('invalid value for "ad_accounts_ids", ad_accounts_ids cannot be nil.')
  end

  if @asset_group_types.nil?
    invalid_properties.push('invalid value for "asset_group_types", asset_group_types cannot be nil.')
  end

  if @catalogs_ids.nil?
    invalid_properties.push('invalid value for "catalogs_ids", catalogs_ids cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @owner.nil?
    invalid_properties.push('invalid value for "owner", owner cannot be nil.')
  end

  if @profiles_ids.nil?
    invalid_properties.push('invalid value for "profiles_ids", profiles_ids cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/pinterest_sdk/models/asset_group_binding.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ad_accounts_ids.nil?
  return false if @asset_group_types.nil?
  return false if @catalogs_ids.nil?
  return false if @created_by.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @owner.nil?
  return false if @profiles_ids.nil?
  true
end