Class: PinterestSdkClient::AudienceInsights

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/audience_insights.rb

Overview

Audience interests and demographics.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AudienceInsights

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AudienceInsights` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AudienceInsights`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'categories')
    if (value = attributes[:'categories']).is_a?(Array)
      self.categories = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'demographics')
    self.demographics = attributes[:'demographics']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'size_is_upper_bound')
    self.size_is_upper_bound = attributes[:'size_is_upper_bound']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#categoriesObject

Category interest distribution



20
21
22
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 20

def categories
  @categories
end

#dateObject

Generation date



23
24
25
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 23

def date
  @date
end

#demographicsObject

Returns the value of attribute demographics.



25
26
27
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 25

def demographics
  @demographics
end

#sizeObject

Population count.



28
29
30
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 28

def size
  @size
end

#size_is_upper_boundObject

Indicates whether the audience size has been rounded up to the next highest upper boundary.



31
32
33
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 31

def size_is_upper_bound
  @size_is_upper_bound
end

#typeObject

Returns the value of attribute type.



33
34
35
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 33

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 58

def self.attribute_map
  {
    :'categories' => :'categories',
    :'date' => :'date',
    :'demographics' => :'demographics',
    :'size' => :'size',
    :'size_is_upper_bound' => :'size_is_upper_bound',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 92

def self.openapi_nullable
  Set.new([
    :'date',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 80

def self.openapi_types
  {
    :'categories' => :'Array<AudienceCategory>',
    :'date' => :'String',
    :'demographics' => :'AudienceDemographics',
    :'size' => :'Integer',
    :'size_is_upper_bound' => :'Boolean',
    :'type' => :'AudienceInsightType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      categories == o.categories &&
      date == o.date &&
      demographics == o.demographics &&
      size == o.size &&
      size_is_upper_bound == o.size_is_upper_bound &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 194

def hash
  [categories, date, demographics, size, size_is_upper_bound, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}$/)
  if !@date.nil? && @date !~ pattern
    invalid_properties.push("invalid value for \"date\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
# File 'lib/pinterest_sdk/models/audience_insights.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@date.nil? && @date !~ Regexp.new(/^\d{4}-\d{2}-\d{2}$/)
  true
end