Class: PinterestSdkClient::BaseInviteDataResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/base_invite_data_response.rb

Overview

Common invite/request data returned by the business access endpoints.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BaseInviteDataResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BaseInviteDataResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BaseInviteDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'invite_data')
    self.invite_data = attributes[:'invite_data']
  end

  if attributes.key?(:'is_received_invite')
    self.is_received_invite = attributes[:'is_received_invite']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end
end

Instance Attribute Details

#idObject

Unique identifier of the invite/request.



20
21
22
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 20

def id
  @id
end

#invite_dataObject

Returns the value of attribute invite_data.



22
23
24
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 22

def invite_data
  @invite_data
end

#is_received_inviteObject

Indicates whether the invite/request was received.



25
26
27
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 25

def is_received_invite
  @is_received_invite
end

#userObject

Metadata for the member/partner that was sent the invite/request.



28
29
30
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 28

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 31

def self.attribute_map
  {
    :'id' => :'id',
    :'invite_data' => :'invite_data',
    :'is_received_invite' => :'is_received_invite',
    :'user' => :'user'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 51

def self.openapi_types
  {
    :'id' => :'String',
    :'invite_data' => :'InviteDataResponse',
    :'is_received_invite' => :'Boolean',
    :'user' => :'BusinessAccessUserSummary'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      invite_data == o.invite_data &&
      is_received_invite == o.is_received_invite &&
      user == o.user
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 154

def hash
  [id, invite_data, is_received_invite, user].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



101
102
103
104
105
106
107
108
109
110
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 101

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
117
118
# File 'lib/pinterest_sdk/models/base_invite_data_response.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/)
  true
end