Class: PinterestSdkClient::BidFloorSpec

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/bid_floor_spec.rb

Overview

Bid floor specification for a given campaign configuration.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BidFloorSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BidFloorSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BidFloorSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'billable_event')
    self.billable_event = attributes[:'billable_event']
  else
    self.billable_event = nil
  end

  if attributes.key?(:'countries')
    if (value = attributes[:'countries']).is_a?(Array)
      self.countries = value
    end
  end

  if attributes.key?(:'creative_type')
    self.creative_type = attributes[:'creative_type']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'objective_type')
    self.objective_type = attributes[:'objective_type']
  end

  if attributes.key?(:'optimization_goal_metadata')
    self. = attributes[:'optimization_goal_metadata']
  end
end

Instance Attribute Details

#billable_eventObject

Ad group billable event type.



20
21
22
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 20

def billable_event
  @billable_event
end

#countriesObject

List of ISO 3166-1 alpha-2 country codes.



23
24
25
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 23

def countries
  @countries
end

#creative_typeObject

Creative type for the bid floor request.



26
27
28
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 26

def creative_type
  @creative_type
end

#currencyObject

Currency for the bid floor value.



29
30
31
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 29

def currency
  @currency
end

#objective_typeObject

Campaign objective type.



32
33
34
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 32

def objective_type
  @objective_type
end

#optimization_goal_metadataObject

Optimization goal metadata.



35
36
37
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 35

def 
  
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 60

def self.attribute_map
  {
    :'billable_event' => :'billable_event',
    :'countries' => :'countries',
    :'creative_type' => :'creative_type',
    :'currency' => :'currency',
    :'objective_type' => :'objective_type',
    :'optimization_goal_metadata' => :'optimization_goal_metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 82

def self.openapi_types
  {
    :'billable_event' => :'ActionType',
    :'countries' => :'Array<Country>',
    :'creative_type' => :'CreativeType',
    :'currency' => :'Currency',
    :'objective_type' => :'BidFloorObjectiveType',
    :'optimization_goal_metadata' => :'OptimizationGoalMetadata'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      billable_event == o.billable_event &&
      countries == o.countries &&
      creative_type == o.creative_type &&
      currency == o.currency &&
      objective_type == o.objective_type &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 212

def hash
  [billable_event, countries, creative_type, currency, objective_type, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @billable_event.nil?
    invalid_properties.push('invalid value for "billable_event", billable_event cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
# File 'lib/pinterest_sdk/models/bid_floor_spec.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @billable_event.nil?
  return false if @currency.nil?
  true
end