Class: PinterestSdkClient::BidOptionsAppTypeMultipliers

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb

Overview

This represents a mapping from app type targeting criteria to a bid price change value. Values represent the change in bid price and can be positive or negative. For percentage changes, a value of 500.0 means a 5% change. For value changes, the amount represents the direct bid adjustment. All app type multipliers must be set at the same time. If a multiplier is not provided it is assumed to be 0 (no bid adjustment). The change must still remain between the range of 0 and 10.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BidOptionsAppTypeMultipliers

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BidOptionsAppTypeMultipliers` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BidOptionsAppTypeMultipliers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'android_mobile')
    self.android_mobile = attributes[:'android_mobile']
  end

  if attributes.key?(:'android_tablet')
    self.android_tablet = attributes[:'android_tablet']
  end

  if attributes.key?(:'ipad')
    self.ipad = attributes[:'ipad']
  end

  if attributes.key?(:'iphone')
    self.iphone = attributes[:'iphone']
  end

  if attributes.key?(:'web')
    self.web = attributes[:'web']
  end

  if attributes.key?(:'web_mobile')
    self.web_mobile = attributes[:'web_mobile']
  end
end

Instance Attribute Details

#android_mobileObject

Returns the value of attribute android_mobile.



19
20
21
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 19

def android_mobile
  @android_mobile
end

#android_tabletObject

Returns the value of attribute android_tablet.



21
22
23
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 21

def android_tablet
  @android_tablet
end

#ipadObject

Returns the value of attribute ipad.



23
24
25
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 23

def ipad
  @ipad
end

#iphoneObject

Returns the value of attribute iphone.



25
26
27
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 25

def iphone
  @iphone
end

#webObject

Returns the value of attribute web.



27
28
29
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 27

def web
  @web
end

#web_mobileObject

Returns the value of attribute web_mobile.



29
30
31
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 29

def web_mobile
  @web_mobile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 32

def self.attribute_map
  {
    :'android_mobile' => :'android_mobile',
    :'android_tablet' => :'android_tablet',
    :'ipad' => :'ipad',
    :'iphone' => :'iphone',
    :'web' => :'web',
    :'web_mobile' => :'web_mobile'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 155

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 54

def self.openapi_types
  {
    :'android_mobile' => :'Float',
    :'android_tablet' => :'Float',
    :'ipad' => :'Float',
    :'iphone' => :'Float',
    :'web' => :'Float',
    :'web_mobile' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



129
130
131
132
133
134
135
136
137
138
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 129

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      android_mobile == o.android_mobile &&
      android_tablet == o.android_tablet &&
      ipad == o.ipad &&
      iphone == o.iphone &&
      web == o.web &&
      web_mobile == o.web_mobile
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 142

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



148
149
150
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 148

def hash
  [android_mobile, android_tablet, ipad, iphone, web, web_mobile].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 177

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
125
# File 'lib/pinterest_sdk/models/bid_options_app_type_multipliers.rb', line 122

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end