Class: PinterestSdkClient::BidOptionsAudienceMultipliers
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BidOptionsAudienceMultipliers
- Defined in:
- lib/pinterest_sdk/models/bid_options_audience_multipliers.rb
Overview
This represents a mapping from Audience ID to a bid price change value. This is paired with the bid_multipliers schedule type Values represent the change in bid price and can be positive or negative. For percentage changes, a value of 500.0 means a 5% change. For value changes, the amount represents the direct bid adjustment. All audience multipliers must be set at the same time. If a multiplier is not provided it is assumed to be 0 (no bid adjustment). The change must still remain between the range of 0 and 10.
Instance Attribute Summary collapse
-
#audience_id ⇒ Object
Returns the value of attribute audience_id.
-
#multiplier ⇒ Object
Returns the value of attribute multiplier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BidOptionsAudienceMultipliers
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BidOptionsAudienceMultipliers
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BidOptionsAudienceMultipliers` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BidOptionsAudienceMultipliers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'audience_id') self.audience_id = attributes[:'audience_id'] else self.audience_id = nil end if attributes.key?(:'multiplier') self.multiplier = attributes[:'multiplier'] else self.multiplier = nil end end |
Instance Attribute Details
#audience_id ⇒ Object
Returns the value of attribute audience_id.
19 20 21 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 19 def audience_id @audience_id end |
#multiplier ⇒ Object
Returns the value of attribute multiplier.
21 22 23 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 21 def multiplier @multiplier end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 24 def self.attribute_map { :'audience_id' => :'audience_id', :'multiplier' => :'multiplier' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 42 def self.openapi_types { :'audience_id' => :'String', :'multiplier' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && audience_id == o.audience_id && multiplier == o.multiplier end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 157 def hash [audience_id, multiplier].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @audience_id.nil? invalid_properties.push('invalid value for "audience_id", audience_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @audience_id !~ pattern invalid_properties.push("invalid value for \"audience_id\", must conform to the pattern #{pattern}.") end if @multiplier.nil? invalid_properties.push('invalid value for "multiplier", multiplier cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/bid_options_audience_multipliers.rb', line 107 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @audience_id.nil? return false if @audience_id !~ Regexp.new(/^\d+$/) return false if @multiplier.nil? true end |