Class: PinterestSdkClient::BidOptionsPlacementMultipliers
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BidOptionsPlacementMultipliers
- Defined in:
- lib/pinterest_sdk/models/bid_options_placement_multipliers.rb
Overview
This represents a mapping from placement to a bid price change value. Values represent the change in bid price and can be positive or negative. For percentage changes, a value of 500.0 means a 5% change. For value changes, the amount represents the direct bid adjustment. All placement multipliers must be set at the same time. If a multiplier is not provided it is assumed to be 0 (no bid adjustment). The change must still remain between the range of 0 and 10.
Instance Attribute Summary collapse
-
#browse ⇒ Object
Returns the value of attribute browse.
-
#related_pins ⇒ Object
Returns the value of attribute related_pins.
-
#search ⇒ Object
Returns the value of attribute search.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BidOptionsPlacementMultipliers
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BidOptionsPlacementMultipliers
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BidOptionsPlacementMultipliers` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BidOptionsPlacementMultipliers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'browse') self.browse = attributes[:'browse'] end if attributes.key?(:'related_pins') self. = attributes[:'related_pins'] end if attributes.key?(:'search') self.search = attributes[:'search'] end end |
Instance Attribute Details
#browse ⇒ Object
Returns the value of attribute browse.
19 20 21 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 19 def browse @browse end |
#related_pins ⇒ Object
Returns the value of attribute related_pins.
21 22 23 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 21 def @related_pins end |
#search ⇒ Object
Returns the value of attribute search.
23 24 25 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 23 def search @search end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 26 def self.attribute_map { :'browse' => :'browse', :'related_pins' => :'related_pins', :'search' => :'search' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 128 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 45 def self.openapi_types { :'browse' => :'Float', :'related_pins' => :'Float', :'search' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 105 def ==(o) return true if self.equal?(o) self.class == o.class && browse == o.browse && == o. && search == o.search end |
#eql?(o) ⇒ Boolean
115 116 117 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 115 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 121 def hash [browse, , search].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 |
# File 'lib/pinterest_sdk/models/bid_options_placement_multipliers.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |