Class: PinterestSdkClient::BillingApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/billing_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BillingApi

Returns a new instance of BillingApi.



19
20
21
# File 'lib/pinterest_sdk/api/billing_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/billing_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#ads_credit_redeem(ad_account_id, ads_credit_redeem_create, opts = {}) ⇒ AdsCreditRedeem

Redeem ad credits Redeem ads credit on behalf of the ad account id and apply it towards billing. This endpoint might not be available to all apps. Learn more.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ads_credit_redeem_create (AdsCreditRedeemCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/pinterest_sdk/api/billing_api.rb', line 28

def ads_credit_redeem(, ads_credit_redeem_create, opts = {})
  data, _status_code, _headers = ads_credit_redeem_with_http_info(, ads_credit_redeem_create, opts)
  data
end

#ads_credit_redeem_with_http_info(ad_account_id, ads_credit_redeem_create, opts = {}) ⇒ Array<(AdsCreditRedeem, Integer, Hash)>

Redeem ad credits Redeem ads credit on behalf of the ad account id and apply it towards billing. This endpoint might not be available to all apps. Learn more.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ads_credit_redeem_create (AdsCreditRedeemCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AdsCreditRedeem, Integer, Hash)>)

    AdsCreditRedeem data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/pinterest_sdk/api/billing_api.rb', line 39

def ads_credit_redeem_with_http_info(, ads_credit_redeem_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ads_credit_redeem ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ads_credit_redeem"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ads_credit_redeem, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ads_credit_redeem, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'ads_credit_redeem_create' is set
  if @api_client.config.client_side_validation && ads_credit_redeem_create.nil?
    fail ArgumentError, "Missing the required parameter 'ads_credit_redeem_create' when calling BillingApi.ads_credit_redeem"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ads_credit/redeem'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(ads_credit_redeem_create)

  # return_type
  return_type = opts[:debug_return_type] || 'AdsCreditRedeem'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ads_credit_redeem",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ads_credit_redeem\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ads_credits_discounts_get(ad_account_id, opts = {}) ⇒ AdsCreditsDiscountsGet200Response

Get ads credit discounts Returns the list of discounts applied to the account. This endpoint might not be available to all apps. Learn more.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



112
113
114
115
# File 'lib/pinterest_sdk/api/billing_api.rb', line 112

def ads_credits_discounts_get(, opts = {})
  data, _status_code, _headers = ads_credits_discounts_get_with_http_info(, opts)
  data
end

#ads_credits_discounts_get_with_http_info(ad_account_id, opts = {}) ⇒ Array<(AdsCreditsDiscountsGet200Response, Integer, Hash)>

Get ads credit discounts Returns the list of discounts applied to the account. This endpoint might not be available to all apps. Learn more.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pinterest_sdk/api/billing_api.rb', line 124

def ads_credits_discounts_get_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ads_credits_discounts_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ads_credits_discounts_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ads_credits_discounts_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ads_credits_discounts_get, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ads_credits_discounts_get, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ads_credits_discounts_get, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ads_credit/discounts'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AdsCreditsDiscountsGet200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ads_credits_discounts_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ads_credits_discounts_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#billing_invoice_download_get(ad_account_id, billing_invoice_id, opts = {}) ⇒ BillingInvoiceDownloadResponse

Get download url for a billing invoice Get download url for a billing invoice.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • billing_invoice_id (String)

    Unique identifier of a billing invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



197
198
199
200
# File 'lib/pinterest_sdk/api/billing_api.rb', line 197

def billing_invoice_download_get(, billing_invoice_id, opts = {})
  data, _status_code, _headers = billing_invoice_download_get_with_http_info(, billing_invoice_id, opts)
  data
end

#billing_invoice_download_get_with_http_info(ad_account_id, billing_invoice_id, opts = {}) ⇒ Array<(BillingInvoiceDownloadResponse, Integer, Hash)>

Get download url for a billing invoice Get download url for a billing invoice.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • billing_invoice_id (String)

    Unique identifier of a billing invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/pinterest_sdk/api/billing_api.rb', line 208

def billing_invoice_download_get_with_http_info(, billing_invoice_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.billing_invoice_download_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.billing_invoice_download_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.billing_invoice_download_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.billing_invoice_download_get, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'billing_invoice_id' is set
  if @api_client.config.client_side_validation && billing_invoice_id.nil?
    fail ArgumentError, "Missing the required parameter 'billing_invoice_id' when calling BillingApi.billing_invoice_download_get"
  end
  if @api_client.config.client_side_validation && billing_invoice_id.to_s.length > 18
    fail ArgumentError, 'invalid value for "billing_invoice_id" when calling BillingApi.billing_invoice_download_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && billing_invoice_id !~ pattern
    fail ArgumentError, "invalid value for 'billing_invoice_id' when calling BillingApi.billing_invoice_download_get, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/billing_invoice/{billing_invoice_id}/download'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{billing_invoice_id}', CGI.escape(billing_invoice_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BillingInvoiceDownloadResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.billing_invoice_download_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#billing_invoice_download_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#billing_invoices_get(ad_account_id, opts = {}) ⇒ BillingInvoicesGet200Response

Get billing invoices Get billing invoices in the advertiser account.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

  • :order (PinterestLibPaginationOrder)

    The order in which to sort the items returned: &quot;ASCENDING&quot; or &quot;DESCENDING&quot; by ID. Note that higher-value IDs are associated with more-recently added items.

  • :sort (BillingInvoiceSortField)

    Field of which to sort billing invoices (default to 'DUE_DATE')

  • :status (BillingInvoiceStatus)

    Status of billing invoices to filter by

  • :document_type (BillingInvoiceDocumentType)

    Document type of billing invoices to filter by

  • :start_due_date (Date)

    Starting point for due dates when searching for invoices. Format: YYYY-MM-DD

  • :end_due_date (Date)

    Ending point for due dates when searching for invoices. Format: YYYY-MM-DD

Returns:



291
292
293
294
# File 'lib/pinterest_sdk/api/billing_api.rb', line 291

def billing_invoices_get(, opts = {})
  data, _status_code, _headers = billing_invoices_get_with_http_info(, opts)
  data
end

#billing_invoices_get_with_http_info(ad_account_id, opts = {}) ⇒ Array<(BillingInvoicesGet200Response, Integer, Hash)>

Get billing invoices Get billing invoices in the advertiser account.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

  • :order (PinterestLibPaginationOrder)

    The order in which to sort the items returned: &quot;ASCENDING&quot; or &quot;DESCENDING&quot; by ID. Note that higher-value IDs are associated with more-recently added items.

  • :sort (BillingInvoiceSortField)

    Field of which to sort billing invoices (default to 'DUE_DATE')

  • :status (BillingInvoiceStatus)

    Status of billing invoices to filter by

  • :document_type (BillingInvoiceDocumentType)

    Document type of billing invoices to filter by

  • :start_due_date (Date)

    Starting point for due dates when searching for invoices. Format: YYYY-MM-DD

  • :end_due_date (Date)

    Ending point for due dates when searching for invoices. Format: YYYY-MM-DD

Returns:



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/pinterest_sdk/api/billing_api.rb', line 309

def billing_invoices_get_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.billing_invoices_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.billing_invoices_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.billing_invoices_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.billing_invoices_get, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.billing_invoices_get, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.billing_invoices_get, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/billing_invoices'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'document_type'] = opts[:'document_type'] if !opts[:'document_type'].nil?
  query_params[:'start_due_date'] = opts[:'start_due_date'] if !opts[:'start_due_date'].nil?
  query_params[:'end_due_date'] = opts[:'end_due_date'] if !opts[:'end_due_date'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BillingInvoicesGet200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.billing_invoices_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#billing_invoices_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#billing_profiles_get(is_active, ad_account_id, opts = {}) ⇒ BillingProfilesGet200Response

Get billing profiles Get billing profiles in the advertiser account. This endpoint might not be available to all apps. Learn more.

Parameters:

  • is_active (Boolean)

    Return active billing profiles, if false return all billing profiles.

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



390
391
392
393
# File 'lib/pinterest_sdk/api/billing_api.rb', line 390

def billing_profiles_get(is_active, , opts = {})
  data, _status_code, _headers = billing_profiles_get_with_http_info(is_active, , opts)
  data
end

#billing_profiles_get_with_http_info(is_active, ad_account_id, opts = {}) ⇒ Array<(BillingProfilesGet200Response, Integer, Hash)>

Get billing profiles Get billing profiles in the advertiser account. This endpoint might not be available to all apps. Learn more.

Parameters:

  • is_active (Boolean)

    Return active billing profiles, if false return all billing profiles.

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/pinterest_sdk/api/billing_api.rb', line 403

def billing_profiles_get_with_http_info(is_active, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.billing_profiles_get ...'
  end
  # verify the required parameter 'is_active' is set
  if @api_client.config.client_side_validation && is_active.nil?
    fail ArgumentError, "Missing the required parameter 'is_active' when calling BillingApi.billing_profiles_get"
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.billing_profiles_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.billing_profiles_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.billing_profiles_get, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.billing_profiles_get, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.billing_profiles_get, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/billing_profiles'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'is_active'] = is_active
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BillingProfilesGet200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.billing_profiles_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#billing_profiles_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_accounts_get(ad_account_id, opts = {}) ⇒ SSIOAccount

Get Salesforce account details including bill-to information. Get Salesforce account details including bill-to information to be used in insertion orders process for ad_account_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



480
481
482
483
# File 'lib/pinterest_sdk/api/billing_api.rb', line 480

def ssio_accounts_get(, opts = {})
  data, _status_code, _headers = ssio_accounts_get_with_http_info(, opts)
  data
end

#ssio_accounts_get_with_http_info(ad_account_id, opts = {}) ⇒ Array<(SSIOAccount, Integer, Hash)>

Get Salesforce account details including bill-to information. Get Salesforce account details including bill-to information to be used in insertion orders process for `ad_account_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SSIOAccount, Integer, Hash)>)

    SSIOAccount data, response status code and response headers



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/pinterest_sdk/api/billing_api.rb', line 490

def ssio_accounts_get_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_accounts_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_accounts_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_accounts_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_accounts_get, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/accounts'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SSIOAccount'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_accounts_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_accounts_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_insertion_order_create(ad_account_id, ssio_insertion_order_create, opts = {}) ⇒ SSIOInsertionOrder

Create insertion order through SSIO. Create insertion order through SSIO for ad_account_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ssio_insertion_order_create (SSIOInsertionOrderCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



553
554
555
556
# File 'lib/pinterest_sdk/api/billing_api.rb', line 553

def ssio_insertion_order_create(, ssio_insertion_order_create, opts = {})
  data, _status_code, _headers = ssio_insertion_order_create_with_http_info(, ssio_insertion_order_create, opts)
  data
end

#ssio_insertion_order_create_with_http_info(ad_account_id, ssio_insertion_order_create, opts = {}) ⇒ Array<(SSIOInsertionOrder, Integer, Hash)>

Create insertion order through SSIO. Create insertion order through SSIO for `ad_account_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ssio_insertion_order_create (SSIOInsertionOrderCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SSIOInsertionOrder, Integer, Hash)>)

    SSIOInsertionOrder data, response status code and response headers



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/pinterest_sdk/api/billing_api.rb', line 564

def ssio_insertion_order_create_with_http_info(, ssio_insertion_order_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_insertion_order_create ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_insertion_order_create"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_insertion_order_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_insertion_order_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'ssio_insertion_order_create' is set
  if @api_client.config.client_side_validation && ssio_insertion_order_create.nil?
    fail ArgumentError, "Missing the required parameter 'ssio_insertion_order_create' when calling BillingApi.ssio_insertion_order_create"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/insertion_orders'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(ssio_insertion_order_create)

  # return_type
  return_type = opts[:debug_return_type] || 'SSIOInsertionOrder'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_insertion_order_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_insertion_order_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_insertion_order_edit(ad_account_id, ssio_insertion_order_update, opts = {}) ⇒ SSIOInsertionOrder

Edit insertion order through SSIO. Edit insertion order through SSIO for ad_account_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ssio_insertion_order_update (SSIOInsertionOrderUpdate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



636
637
638
639
# File 'lib/pinterest_sdk/api/billing_api.rb', line 636

def ssio_insertion_order_edit(, ssio_insertion_order_update, opts = {})
  data, _status_code, _headers = ssio_insertion_order_edit_with_http_info(, ssio_insertion_order_update, opts)
  data
end

#ssio_insertion_order_edit_with_http_info(ad_account_id, ssio_insertion_order_update, opts = {}) ⇒ Array<(SSIOInsertionOrder, Integer, Hash)>

Edit insertion order through SSIO. Edit insertion order through SSIO for `ad_account_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • ssio_insertion_order_update (SSIOInsertionOrderUpdate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SSIOInsertionOrder, Integer, Hash)>)

    SSIOInsertionOrder data, response status code and response headers



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
# File 'lib/pinterest_sdk/api/billing_api.rb', line 647

def ssio_insertion_order_edit_with_http_info(, ssio_insertion_order_update, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_insertion_order_edit ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_insertion_order_edit"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_insertion_order_edit, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_insertion_order_edit, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'ssio_insertion_order_update' is set
  if @api_client.config.client_side_validation && ssio_insertion_order_update.nil?
    fail ArgumentError, "Missing the required parameter 'ssio_insertion_order_update' when calling BillingApi.ssio_insertion_order_edit"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/insertion_orders'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(ssio_insertion_order_update)

  # return_type
  return_type = opts[:debug_return_type] || 'SSIOInsertionOrder'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_insertion_order_edit",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_insertion_order_edit\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_insertion_orders_status_get_by_ad_account(ad_account_id, opts = {}) ⇒ SsioInsertionOrdersStatusGetByAdAccount200Response

Get insertion order status by ad account id. Get insertion order status for ad_account_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



720
721
722
723
# File 'lib/pinterest_sdk/api/billing_api.rb', line 720

def (, opts = {})
  data, _status_code, _headers = (, opts)
  data
end

#ssio_insertion_orders_status_get_by_ad_account_with_http_info(ad_account_id, opts = {}) ⇒ Array<(SsioInsertionOrdersStatusGetByAdAccount200Response, Integer, Hash)>

Get insertion order status by ad account id. Get insertion order status for `ad_account_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/pinterest_sdk/api/billing_api.rb', line 732

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_insertion_orders_status_get_by_ad_account ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_insertion_orders_status_get_by_ad_account"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_insertion_orders_status_get_by_ad_account, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_insertion_orders_status_get_by_ad_account, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ssio_insertion_orders_status_get_by_ad_account, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ssio_insertion_orders_status_get_by_ad_account, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/insertion_orders/status'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SsioInsertionOrdersStatusGetByAdAccount200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_insertion_orders_status_get_by_ad_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_insertion_orders_status_get_by_ad_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_insertion_orders_status_get_by_pin_order_id(ad_account_id, pin_order_id, opts = {}) ⇒ SSIOInsertionOrderStatusResponse

Get insertion order status by pin order id. Get insertion order status for pin_order_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • pin_order_id (String)

    The pin order id associated with the ssio insertion order

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



805
806
807
808
# File 'lib/pinterest_sdk/api/billing_api.rb', line 805

def ssio_insertion_orders_status_get_by_pin_order_id(, pin_order_id, opts = {})
  data, _status_code, _headers = ssio_insertion_orders_status_get_by_pin_order_id_with_http_info(, pin_order_id, opts)
  data
end

#ssio_insertion_orders_status_get_by_pin_order_id_with_http_info(ad_account_id, pin_order_id, opts = {}) ⇒ Array<(SSIOInsertionOrderStatusResponse, Integer, Hash)>

Get insertion order status by pin order id. Get insertion order status for `pin_order_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • pin_order_id (String)

    The pin order id associated with the ssio insertion order

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
# File 'lib/pinterest_sdk/api/billing_api.rb', line 816

def ssio_insertion_orders_status_get_by_pin_order_id_with_http_info(, pin_order_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_insertion_orders_status_get_by_pin_order_id ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_insertion_orders_status_get_by_pin_order_id"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_insertion_orders_status_get_by_pin_order_id, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_insertion_orders_status_get_by_pin_order_id, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'pin_order_id' is set
  if @api_client.config.client_side_validation && pin_order_id.nil?
    fail ArgumentError, "Missing the required parameter 'pin_order_id' when calling BillingApi.ssio_insertion_orders_status_get_by_pin_order_id"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/insertion_orders/{pin_order_id}/status'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{pin_order_id}', CGI.escape(pin_order_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SSIOInsertionOrderStatusResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_insertion_orders_status_get_by_pin_order_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_insertion_orders_status_get_by_pin_order_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ssio_order_lines_get_by_ad_account(ad_account_id, opts = {}) ⇒ SsioOrderLinesGetByAdAccount200Response

Get Salesforce order lines by ad account id. Get Salesforce order lines for account id ad_account_id. - The token's user_account must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :pin_order_id (String)

    The pin order id associated with the SSIO insertion order

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



885
886
887
888
# File 'lib/pinterest_sdk/api/billing_api.rb', line 885

def (, opts = {})
  data, _status_code, _headers = (, opts)
  data
end

#ssio_order_lines_get_by_ad_account_with_http_info(ad_account_id, opts = {}) ⇒ Array<(SsioOrderLinesGetByAdAccount200Response, Integer, Hash)>

Get Salesforce order lines by ad account id. Get Salesforce order lines for account id `ad_account_id`. - The token's `user_account` must either be the owner of the specified ad account, or have one of the necessary roles granted via Business Access: Admin, Finance, Campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :pin_order_id (String)

    The pin order id associated with the SSIO insertion order

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
# File 'lib/pinterest_sdk/api/billing_api.rb', line 898

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.ssio_order_lines_get_by_ad_account ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BillingApi.ssio_order_lines_get_by_ad_account"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BillingApi.ssio_order_lines_get_by_ad_account, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BillingApi.ssio_order_lines_get_by_ad_account, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ssio_order_lines_get_by_ad_account, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling BillingApi.ssio_order_lines_get_by_ad_account, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/ssio/order_lines'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'pin_order_id'] = opts[:'pin_order_id'] if !opts[:'pin_order_id'].nil?
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SsioOrderLinesGetByAdAccount200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BillingApi.ssio_order_lines_get_by_ad_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#ssio_order_lines_get_by_ad_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end