Class: PinterestSdkClient::BillingProfilesResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/billing_profiles_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BillingProfilesResponse

Initializes the object



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BillingProfilesResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BillingProfilesResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'advertiser_id')
    self.advertiser_id = attributes[:'advertiser_id']
  end

  if attributes.key?(:'billing_type')
    self.billing_type = attributes[:'billing_type']
  end

  if attributes.key?(:'card_type')
    self.card_type = attributes[:'card_type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'payment_method_brand')
    self.payment_method_brand = attributes[:'payment_method_brand']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#advertiser_idObject

Advertiser ID of the billing.



19
20
21
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 19

def advertiser_id
  @advertiser_id
end

#billing_typeObject

Billing type of the advertiser



22
23
24
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 22

def billing_type
  @billing_type
end

#card_typeObject

Type of the card.



25
26
27
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 25

def card_type
  @card_type
end

#idObject

Billing ID.



28
29
30
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 28

def id
  @id
end

#payment_method_brandObject

Brand of the payment method.



31
32
33
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 31

def payment_method_brand
  @payment_method_brand
end

#statusObject

Status of the billing.



34
35
36
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 34

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 59

def self.attribute_map
  {
    :'advertiser_id' => :'advertiser_id',
    :'billing_type' => :'billing_type',
    :'card_type' => :'card_type',
    :'id' => :'id',
    :'payment_method_brand' => :'payment_method_brand',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 81

def self.openapi_types
  {
    :'advertiser_id' => :'String',
    :'billing_type' => :'BillingType',
    :'card_type' => :'BillingProfileCardType',
    :'id' => :'String',
    :'payment_method_brand' => :'BillingProfilePaymentMethodBrand',
    :'status' => :'BillingProfileStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



198
199
200
201
202
203
204
205
206
207
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      advertiser_id == o.advertiser_id &&
      billing_type == o.billing_type &&
      card_type == o.card_type &&
      id == o.id &&
      payment_method_brand == o.payment_method_brand &&
      status == o.status
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


211
212
213
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



217
218
219
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 217

def hash
  [advertiser_id, billing_type, card_type, id, payment_method_brand, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@advertiser_id.nil? && @advertiser_id !~ pattern
    invalid_properties.push("invalid value for \"advertiser_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/billing_profiles_response.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@advertiser_id.nil? && @advertiser_id !~ Regexp.new(/^\d+$/)
  return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/)
  true
end