Class: PinterestSdkClient::BrandAccountProfileImageUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BrandAccountProfileImageUpdate
- Defined in:
- lib/pinterest_sdk/models/brand_account_profile_image_update.rb
Overview
Base64-encoded image media source
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#content_type ⇒ Object
Returns the value of attribute content_type.
-
#data ⇒ Object
Returns the value of attribute data.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BrandAccountProfileImageUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BrandAccountProfileImageUpdate
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BrandAccountProfileImageUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BrandAccountProfileImageUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] end if attributes.key?(:'data') self.data = attributes[:'data'] end end |
Instance Attribute Details
#content_type ⇒ Object
Returns the value of attribute content_type.
19 20 21 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 19 def content_type @content_type end |
#data ⇒ Object
Returns the value of attribute data.
21 22 23 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 21 def data @data end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 46 def self.attribute_map { :'content_type' => :'content_type', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 64 def self.openapi_types { :'content_type' => :'String', :'data' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && content_type == o.content_type && data == o.data end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 167 def hash [content_type, data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/[a-zA-Z0-9+\/=]+/) if !@data.nil? && @data !~ pattern invalid_properties.push("invalid value for \"data\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 122 123 |
# File 'lib/pinterest_sdk/models/brand_account_profile_image_update.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' content_type_validator = EnumAttributeValidator.new('String', ["image/jpeg", "image/png"]) return false unless content_type_validator.valid?(@content_type) return false if !@data.nil? && @data !~ Regexp.new(/[a-zA-Z0-9+\/=]+/) true end |