Class: PinterestSdkClient::BrandAccountUpdate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/brand_account_update.rb

Overview

Resource create or update operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BrandAccountUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BrandAccountUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BrandAccountUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'about')
    self.about = attributes[:'about']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'profile_image')
    self.profile_image = attributes[:'profile_image']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end
end

Instance Attribute Details

#aboutObject

Brand Account about information



20
21
22
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 20

def about
  @about
end

#countryObject

Returns the value of attribute country.



22
23
24
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 22

def country
  @country
end

#nameObject

Brand Account name



25
26
27
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 25

def name
  @name
end

#profile_imageObject

Returns the value of attribute profile_image.



27
28
29
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 27

def profile_image
  @profile_image
end

#usernameObject

Brand Account username



30
31
32
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 30

def username
  @username
end

#websiteObject

Brand Account website



33
34
35
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 33

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 58

def self.attribute_map
  {
    :'about' => :'about',
    :'country' => :'country',
    :'name' => :'name',
    :'profile_image' => :'profile_image',
    :'username' => :'username',
    :'website' => :'website'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 80

def self.openapi_types
  {
    :'about' => :'String',
    :'country' => :'Country',
    :'name' => :'String',
    :'profile_image' => :'BrandAccountProfileImageUpdate',
    :'username' => :'String',
    :'website' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      about == o.about &&
      country == o.country &&
      name == o.name &&
      profile_image == o.profile_image &&
      username == o.username &&
      website == o.website
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 174

def hash
  [about, country, name, profile_image, username, website].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
# File 'lib/pinterest_sdk/models/brand_account_update.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end