Class: PinterestSdkClient::BulkApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/bulk_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BulkApi

Returns a new instance of BulkApi.



19
20
21
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#bulk_download_create(ad_account_id, bulk_download_create, opts = {}) ⇒ BulkDownload

Get advertiser entities in bulk Create an asynchronous report that may include information on campaigns, ad groups, product groups, ads, keywords, schedules,and/or labels; can filter by campaigns. Though the entities may be active, archived, or paused, only active entities will return data.

Parameters:

  • Unique identifier of an ad account.

  • (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 28

def bulk_download_create(, bulk_download_create, opts = {})
  data, _status_code, _headers = bulk_download_create_with_http_info(, bulk_download_create, opts)
  data
end

#bulk_download_create_with_http_info(ad_account_id, bulk_download_create, opts = {}) ⇒ Array<(BulkDownload, Integer, Hash)>

Get advertiser entities in bulk Create an asynchronous report that may include information on campaigns, ad groups, product groups, ads, keywords, schedules,and/or labels; can filter by campaigns. Though the entities may be active, archived, or paused, only active entities will return data.

Parameters:

  • Unique identifier of an ad account.

  • (defaults to: {})

    the optional parameters

Returns:

  • BulkDownload data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 39

def bulk_download_create_with_http_info(, bulk_download_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BulkApi.bulk_download_create ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BulkApi.bulk_download_create"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BulkApi.bulk_download_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BulkApi.bulk_download_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'bulk_download_create' is set
  if @api_client.config.client_side_validation && bulk_download_create.nil?
    fail ArgumentError, "Missing the required parameter 'bulk_download_create' when calling BulkApi.bulk_download_create"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/bulk/download'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(bulk_download_create)

  # return_type
  return_type = opts[:debug_return_type] || 'BulkDownload'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BulkApi.bulk_download_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BulkApi#bulk_download_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#bulk_request_get(ad_account_id, bulk_request_id, opts = {}) ⇒ BulkJobData

Download advertiser entities in bulk Get the status of a bulk request by request_id, along with a download URL that will allow you to download the new or updated entity data (campaigns, ad groups, product groups, ads, schedules, or keywords).

Parameters:

  • Unique identifier of an ad account.

  • Bulk request ID that is from one of the entities bulk endpoints

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_details (Boolean)

    If set to True then attach the errors/details to all the requests (default to false)

Returns:



112
113
114
115
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 112

def bulk_request_get(, bulk_request_id, opts = {})
  data, _status_code, _headers = bulk_request_get_with_http_info(, bulk_request_id, opts)
  data
end

#bulk_request_get_with_http_info(ad_account_id, bulk_request_id, opts = {}) ⇒ Array<(BulkJobData, Integer, Hash)>

Download advertiser entities in bulk Get the status of a bulk request by `request_id`, along with a download URL that will allow you to download the new or updated entity data (campaigns, ad groups, product groups, ads, schedules, or keywords).

Parameters:

  • Unique identifier of an ad account.

  • Bulk request ID that is from one of the entities bulk endpoints

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_details (Boolean)

    If set to True then attach the errors/details to all the requests (default to false)

Returns:

  • BulkJobData data, response status code and response headers



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 124

def bulk_request_get_with_http_info(, bulk_request_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BulkApi.bulk_request_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BulkApi.bulk_request_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BulkApi.bulk_request_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BulkApi.bulk_request_get, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'bulk_request_id' is set
  if @api_client.config.client_side_validation && bulk_request_id.nil?
    fail ArgumentError, "Missing the required parameter 'bulk_request_id' when calling BulkApi.bulk_request_get"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/bulk/{bulk_request_id}'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{bulk_request_id}', CGI.escape(bulk_request_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_details'] = opts[:'include_details'] if !opts[:'include_details'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BulkJobData'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials']

  new_options = opts.merge(
    :operation => :"BulkApi.bulk_request_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BulkApi#bulk_request_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#bulk_upsert_create(ad_account_id, bulk_upsert_request, opts = {}) ⇒ BulkUpsertResponse

Create/update ad entities in bulk Either create or update any combination of campaigns, ad groups, product groups, ads, keywords, schedules, or labels. Note that this request will be processed asynchronously; the response will include a request_id that can be used to obtain the status of the request.

Parameters:

  • Unique identifier of an ad account.

  • Parameters to get create/update ad entities in bulk

  • (defaults to: {})

    the optional parameters

Returns:



192
193
194
195
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 192

def bulk_upsert_create(, bulk_upsert_request, opts = {})
  data, _status_code, _headers = bulk_upsert_create_with_http_info(, bulk_upsert_request, opts)
  data
end

#bulk_upsert_create_with_http_info(ad_account_id, bulk_upsert_request, opts = {}) ⇒ Array<(BulkUpsertResponse, Integer, Hash)>

Create/update ad entities in bulk Either create or update any combination of campaigns, ad groups, product groups, ads, keywords, schedules, or labels. Note that this request will be processed asynchronously; the response will include a <code>request_id</code> that can be used to obtain the status of the request.

Parameters:

  • Unique identifier of an ad account.

  • Parameters to get create/update ad entities in bulk

  • (defaults to: {})

    the optional parameters

Returns:

  • BulkUpsertResponse data, response status code and response headers



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/pinterest_sdk/api/bulk_api.rb', line 203

def bulk_upsert_create_with_http_info(, bulk_upsert_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BulkApi.bulk_upsert_create ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling BulkApi.bulk_upsert_create"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling BulkApi.bulk_upsert_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling BulkApi.bulk_upsert_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'bulk_upsert_request' is set
  if @api_client.config.client_side_validation && bulk_upsert_request.nil?
    fail ArgumentError, "Missing the required parameter 'bulk_upsert_request' when calling BulkApi.bulk_upsert_create"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/bulk/upsert'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(bulk_upsert_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BulkUpsertResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"BulkApi.bulk_upsert_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BulkApi#bulk_upsert_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end