Class: PinterestSdkClient::BulkDownloadCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BulkDownloadCreate
- Defined in:
- lib/pinterest_sdk/models/bulk_download_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#campaign_filter ⇒ Object
Returns the value of attribute campaign_filter.
-
#entity_ids ⇒ Object
All entities specified by these IDs as well as their children and grandchildren will be downloaded if the entity type is one of the types requested to be downloaded.
-
#entity_types ⇒ Object
All entity types specified will be downloaded.
-
#output_format ⇒ Object
Returns the value of attribute output_format.
-
#updated_since ⇒ Object
Unix UTC timestamp to retrieve all entities that have changed since this time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkDownloadCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BulkDownloadCreate
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BulkDownloadCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BulkDownloadCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'campaign_filter') self.campaign_filter = attributes[:'campaign_filter'] end if attributes.key?(:'entity_ids') if (value = attributes[:'entity_ids']).is_a?(Array) self.entity_ids = value end end if attributes.key?(:'entity_types') if (value = attributes[:'entity_types']).is_a?(Array) self.entity_types = value end end if attributes.key?(:'output_format') self.output_format = attributes[:'output_format'] end if attributes.key?(:'updated_since') self.updated_since = attributes[:'updated_since'] end end |
Instance Attribute Details
#campaign_filter ⇒ Object
Returns the value of attribute campaign_filter.
19 20 21 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 19 def campaign_filter @campaign_filter end |
#entity_ids ⇒ Object
All entities specified by these IDs as well as their children and grandchildren will be downloaded if the entity type is one of the types requested to be downloaded.
22 23 24 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 22 def entity_ids @entity_ids end |
#entity_types ⇒ Object
All entity types specified will be downloaded. Fewer types result in faster downloads.
25 26 27 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 25 def entity_types @entity_types end |
#output_format ⇒ Object
Returns the value of attribute output_format.
27 28 29 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 27 def output_format @output_format end |
#updated_since ⇒ Object
Unix UTC timestamp to retrieve all entities that have changed since this time.
30 31 32 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 30 def updated_since @updated_since end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 55 def self.attribute_map { :'campaign_filter' => :'campaign_filter', :'entity_ids' => :'entity_ids', :'entity_types' => :'entity_types', :'output_format' => :'output_format', :'updated_since' => :'updated_since' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 224 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 76 def self.openapi_types { :'campaign_filter' => :'BulkDownloadCampaignFilter', :'entity_ids' => :'Array<String>', :'entity_types' => :'Array<BulkEntityType>', :'output_format' => :'BulkOutputFormat', :'updated_since' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && campaign_filter == o.campaign_filter && entity_ids == o.entity_ids && entity_types == o.entity_types && output_format == o.output_format && updated_since == o.updated_since end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 217 def hash [campaign_filter, entity_ids, entity_types, output_format, updated_since].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@entity_types.nil? && @entity_types.length > 6 invalid_properties.push('invalid value for "entity_types", number of items must be less than or equal to 6.') end if !@entity_types.nil? && @entity_types.length < 1 invalid_properties.push('invalid value for "entity_types", number of items must be greater than or equal to 1.') end pattern = Regexp.new(/^\d+$/) if !@updated_since.nil? && @updated_since !~ pattern invalid_properties.push("invalid value for \"updated_since\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 |
# File 'lib/pinterest_sdk/models/bulk_download_create.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@entity_types.nil? && @entity_types.length > 6 return false if !@entity_types.nil? && @entity_types.length < 1 return false if !@updated_since.nil? && @updated_since !~ Regexp.new(/^\d+$/) true end |