Class: PinterestSdkClient::BulkUpsertRequestCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BulkUpsertRequestCreate
- Defined in:
- lib/pinterest_sdk/models/bulk_upsert_request_create.rb
Overview
Request for creation of entities in bulk.
Instance Attribute Summary collapse
-
#ad_groups ⇒ Object
Returns the value of attribute ad_groups.
-
#ads ⇒ Object
Returns the value of attribute ads.
-
#campaigns ⇒ Object
Returns the value of attribute campaigns.
-
#catalog_product_groups ⇒ Object
Returns the value of attribute catalog_product_groups.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#labels ⇒ Object
Returns the value of attribute labels.
-
#product_groups ⇒ Object
Returns the value of attribute product_groups.
-
#schedules ⇒ Object
Returns the value of attribute schedules.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkUpsertRequestCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BulkUpsertRequestCreate
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BulkUpsertRequestCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BulkUpsertRequestCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_groups') if (value = attributes[:'ad_groups']).is_a?(Array) self.ad_groups = value end end if attributes.key?(:'ads') if (value = attributes[:'ads']).is_a?(Array) self.ads = value end end if attributes.key?(:'campaigns') if (value = attributes[:'campaigns']).is_a?(Array) self.campaigns = value end end if attributes.key?(:'catalog_product_groups') if (value = attributes[:'catalog_product_groups']).is_a?(Array) self.catalog_product_groups = value end end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Array) self.labels = value end end if attributes.key?(:'product_groups') if (value = attributes[:'product_groups']).is_a?(Array) self.product_groups = value end end if attributes.key?(:'schedules') if (value = attributes[:'schedules']).is_a?(Array) self.schedules = value end end end |
Instance Attribute Details
#ad_groups ⇒ Object
Returns the value of attribute ad_groups.
19 20 21 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 19 def ad_groups @ad_groups end |
#ads ⇒ Object
Returns the value of attribute ads.
21 22 23 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 21 def ads @ads end |
#campaigns ⇒ Object
Returns the value of attribute campaigns.
23 24 25 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 23 def campaigns @campaigns end |
#catalog_product_groups ⇒ Object
Returns the value of attribute catalog_product_groups.
25 26 27 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 25 def catalog_product_groups @catalog_product_groups end |
#keywords ⇒ Object
Returns the value of attribute keywords.
27 28 29 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 27 def keywords @keywords end |
#labels ⇒ Object
Returns the value of attribute labels.
29 30 31 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 29 def labels @labels end |
#product_groups ⇒ Object
Returns the value of attribute product_groups.
31 32 33 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 31 def product_groups @product_groups end |
#schedules ⇒ Object
Returns the value of attribute schedules.
33 34 35 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 33 def schedules @schedules end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 36 def self.attribute_map { :'ad_groups' => :'ad_groups', :'ads' => :'ads', :'campaigns' => :'campaigns', :'catalog_product_groups' => :'catalog_product_groups', :'keywords' => :'keywords', :'labels' => :'labels', :'product_groups' => :'product_groups', :'schedules' => :'schedules' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 189 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 60 def self.openapi_types { :'ad_groups' => :'Array<AdGroupCreateRequest>', :'ads' => :'Array<AdCreateRequest>', :'campaigns' => :'Array<CampaignCreateRequest>', :'catalog_product_groups' => :'Array<BulkUpsertRequestCreateCatalogProductGroupsItems>', :'keywords' => :'Array<KeywordsRequest>', :'labels' => :'Array<LabelBulkCreateRequest>', :'product_groups' => :'Array<ProductGroupPromotionCreateRequest>', :'schedules' => :'Array<ScheduleCreateRequest>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && ad_groups == o.ad_groups && ads == o.ads && campaigns == o.campaigns && catalog_product_groups == o.catalog_product_groups && keywords == o.keywords && labels == o.labels && product_groups == o.product_groups && schedules == o.schedules end |
#eql?(o) ⇒ Boolean
176 177 178 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 176 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 182 def hash [ad_groups, ads, campaigns, catalog_product_groups, keywords, labels, product_groups, schedules].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/pinterest_sdk/models/bulk_upsert_request_create.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |