Class: PinterestSdkClient::CampaignCreateRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/campaign_create_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 171

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bid_options')
    self.bid_options = attributes[:'bid_options']
  end

  if attributes.key?(:'intended_promotion_type')
    self.intended_promotion_type = attributes[:'intended_promotion_type']
  end

  if attributes.key?(:'is_automated_campaign')
    self.is_automated_campaign = attributes[:'is_automated_campaign']
  end

  if attributes.key?(:'is_campaign_budget_optimization')
    self.is_campaign_budget_optimization = attributes[:'is_campaign_budget_optimization']
  end

  if attributes.key?(:'is_flexible_daily_budgets')
    self.is_flexible_daily_budgets = attributes[:'is_flexible_daily_budgets']
  end

  if attributes.key?(:'is_ltv_optimized')
    self.is_ltv_optimized = attributes[:'is_ltv_optimized']
  end

  if attributes.key?(:'is_performance_plus')
    self.is_performance_plus = attributes[:'is_performance_plus']
  else
    self.is_performance_plus = false
  end

  if attributes.key?(:'is_top_of_search')
    self.is_top_of_search = attributes[:'is_top_of_search']
  else
    self.is_top_of_search = false
  end

  if attributes.key?(:'objective_type')
    self.objective_type = attributes[:'objective_type']
  else
    self.objective_type = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'daily_spend_cap')
    self.daily_spend_cap = attributes[:'daily_spend_cap']
  end

  if attributes.key?(:'default_ad_group_budget_in_micro_currency')
    self.default_ad_group_budget_in_micro_currency = attributes[:'default_ad_group_budget_in_micro_currency']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'lifetime_spend_cap')
    self.lifetime_spend_cap = attributes[:'lifetime_spend_cap']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'order_line_id')
    self.order_line_id = attributes[:'order_line_id']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end
end

Instance Attribute Details

#ad_account_idObject

Campaign's Advertiser ID. If you want to create a campaign in a Business Account shared account you need to specify the Business Access advertiser ID in both the query path param as well as the request body schema.



45
46
47
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 45

def 
  @ad_account_id
end

#bid_optionsObject

Returns the value of attribute bid_options.



18
19
20
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 18

def bid_options
  @bid_options
end

#daily_spend_capObject

Campaign daily spending cap. Required for Campaign Budget Optimization (CBO) campaigns. This and "lifetime_spend_cap" cannot be set at the same time.



48
49
50
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 48

def daily_spend_cap
  @daily_spend_cap
end

#default_ad_group_budget_in_micro_currencyObject

When transitioning from campaign budget optimization to non-campaign budget optimization, the default_ad_group_budget_in_micro_currency will propagate to each child ad groups daily budget. Unit is micro currency of the associated advertiser account.



51
52
53
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 51

def default_ad_group_budget_in_micro_currency
  @default_ad_group_budget_in_micro_currency
end

#end_timeObject

Timestamp in Unix format for scheduling when ads in the campaign stop appearing. Must occur after any end times for child ad groups. If end_time is not specified for the campaign, ads run indefinitely unless you update the campaign, changing their status to paused. Learn about <a href="/docs/api-features/managing-campaigns/#campaign-scheduling" target="blank">scheduling campaigns. Different end times can be set for the campaign's child ad groups, but they cannot occur after an end_time specified for the campaign. - If your campaign has a child ad group with an end time specified, and if you update that campaign with an end_time that is earlier than that of the ad group, the campaign end_time will supersede the ad group end_time, and the request will not return an error. - In this scenario, if you call <a href="/docs/api/v5/campaigns-list" target="blank">List campaigns or <a href="/docs/api/v5/ad_groups-list" target="blank">List ad groups, the returned campaigns or ad groups are listed with the start and end times that you assigned them, regardless of supersedence.



54
55
56
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 54

def end_time
  @end_time
end

#intended_promotion_typeObject

Returns the value of attribute intended_promotion_type.



20
21
22
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 20

def intended_promotion_type
  @intended_promotion_type
end

#is_automated_campaignObject

Note: This field is immutable unless the campaign is in draft status. Specifies whether the campaign was created in the automated campaign flow. When using Automated Campaigns, a daily spend cap must be set, and Pinterest Performance+ may not be used. The following objective types are supported: - CONSIDERATION - WEB\_CONVERSION - SALES - CATALOG\_SALES



23
24
25
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 23

def is_automated_campaign
  @is_automated_campaign
end

#is_campaign_budget_optimizationObject

Note: This field is immutable unless the campaign is in draft status. Determines if a campaign automatically generates ad-group level budgets given a campaign budget to maximize campaign outcome. When using campaign budgets with a lifetime spend cap, the end time must be provided.



26
27
28
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 26

def is_campaign_budget_optimization
  @is_campaign_budget_optimization
end

#is_flexible_daily_budgetsObject

Determine if a campaign has setup for flexible daily budgets, also known as "Pinterest Performance+ budgets". Flexible daily budgets are only supported for campaign budget optimization with a daily spend cap, and not a lifetime spend cap.



29
30
31
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 29

def is_flexible_daily_budgets
  @is_flexible_daily_budgets
end

#is_ltv_optimizedObject

Specifies whether the campaign is optimized for Lifetime Value (LTV). Only available for eligible advertisers.



32
33
34
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 32

def is_ltv_optimized
  @is_ltv_optimized
end

#is_performance_plusObject

Enable Pinterest Performance+ for your campaign. To learn more, see <a href="https://developers.pinterest.com/docs/api-features/pinterest-performance-plus-setup/"&gt;Pinterest Performance+ Setup.



35
36
37
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 35

def is_performance_plus
  @is_performance_plus
end

#is_top_of_searchObject

<a href="/docs/getting-started/using-beta-and-restricted-features/" target="blank" target="blank">Restricted Have your ads and content appear at the top of search result lists in Pinterest. You can only use this feature with the following objectives: CONSIDERATION WEB_CONVERSION CATALOG_SALES You cannot use this feature with Pinterest Performance+ or Premiere Spotlight enabled. You cannot change your true or false selection of this campaign if you <a href="https://developer.pinterest.com/docs/api/v5/campaigns-update" target="blank">update it.



38
39
40
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 38

def is_top_of_search
  @is_top_of_search
end

#lifetime_spend_capObject

Campaign total spending cap. Required for Campaign Budget Optimization (CBO) campaigns. This and "daily_spend_cap" cannot be set at the same time.



57
58
59
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 57

def lifetime_spend_cap
  @lifetime_spend_cap
end

#nameObject

Campaign name.



60
61
62
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 60

def name
  @name
end

#objective_typeObject

Returns the value of attribute objective_type.



40
41
42
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 40

def objective_type
  @objective_type
end

#order_line_idObject

Order line ID that appears on the invoice.



63
64
65
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 63

def order_line_id
  @order_line_id
end

#start_timeObject

Timestamp in Unix format for scheduling when ads in the campaign start to appear. Must precede any start times set for child ad groups. Defaults to current time if no time is specified. Learn about <a href="/docs/api-features/managing-campaigns/#campaign-scheduling" target="blank">scheduling campaigns. Different start times can be set for the campaign's child ad groups, but they cannot occur before a start_time specified for the campaign. - If your campaign has a child ad group with a start time specified, and if you update that campaign with a start_time that is later than that of the ad group, the campaign start_time will supersede the ad group start_time, and the request will not return an error. - In this scenario, if you call <a href="/docs/api/v5/campaigns-list" target="blank">List campaigns or <a href="/docs/api/v5/ad_groups-list" target="blank">List ad groups, the returned campaigns or ad groups are listed with the start and end times that you assigned them, regardless of supersedence.



66
67
68
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 66

def start_time
  @start_time
end

#statusObject

Returns the value of attribute status.



42
43
44
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 42

def status
  @status
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



68
69
70
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 68

def tracking_urls
  @tracking_urls
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



118
119
120
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 118

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



123
124
125
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 123

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 93

def self.attribute_map
  {
    :'bid_options' => :'bid_options',
    :'intended_promotion_type' => :'intended_promotion_type',
    :'is_automated_campaign' => :'is_automated_campaign',
    :'is_campaign_budget_optimization' => :'is_campaign_budget_optimization',
    :'is_flexible_daily_budgets' => :'is_flexible_daily_budgets',
    :'is_ltv_optimized' => :'is_ltv_optimized',
    :'is_performance_plus' => :'is_performance_plus',
    :'is_top_of_search' => :'is_top_of_search',
    :'objective_type' => :'objective_type',
    :'status' => :'status',
    :'ad_account_id' => :'ad_account_id',
    :'daily_spend_cap' => :'daily_spend_cap',
    :'default_ad_group_budget_in_micro_currency' => :'default_ad_group_budget_in_micro_currency',
    :'end_time' => :'end_time',
    :'lifetime_spend_cap' => :'lifetime_spend_cap',
    :'name' => :'name',
    :'order_line_id' => :'order_line_id',
    :'start_time' => :'start_time',
    :'tracking_urls' => :'tracking_urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 401

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 153

def self.openapi_nullable
  Set.new([
    :'bid_options',
    :'is_automated_campaign',
    :'is_campaign_budget_optimization',
    :'is_flexible_daily_budgets',
    :'daily_spend_cap',
    :'default_ad_group_budget_in_micro_currency',
    :'end_time',
    :'lifetime_spend_cap',
    :'order_line_id',
    :'start_time',
    :'tracking_urls'
  ])
end

.openapi_typesObject

Attribute type mapping.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 128

def self.openapi_types
  {
    :'bid_options' => :'CampaignBidOptionsCreate',
    :'intended_promotion_type' => :'IntendedPromotionType',
    :'is_automated_campaign' => :'Boolean',
    :'is_campaign_budget_optimization' => :'Boolean',
    :'is_flexible_daily_budgets' => :'Boolean',
    :'is_ltv_optimized' => :'Boolean',
    :'is_performance_plus' => :'Boolean',
    :'is_top_of_search' => :'Boolean',
    :'objective_type' => :'ObjectiveType',
    :'status' => :'EntityStatus',
    :'ad_account_id' => :'String',
    :'daily_spend_cap' => :'Integer',
    :'default_ad_group_budget_in_micro_currency' => :'Integer',
    :'end_time' => :'Integer',
    :'lifetime_spend_cap' => :'Integer',
    :'name' => :'String',
    :'order_line_id' => :'String',
    :'start_time' => :'Integer',
    :'tracking_urls' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 362

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bid_options == o.bid_options &&
      intended_promotion_type == o.intended_promotion_type &&
      is_automated_campaign == o.is_automated_campaign &&
      is_campaign_budget_optimization == o.is_campaign_budget_optimization &&
      is_flexible_daily_budgets == o.is_flexible_daily_budgets &&
      is_ltv_optimized == o.is_ltv_optimized &&
      is_performance_plus == o.is_performance_plus &&
      is_top_of_search == o.is_top_of_search &&
      objective_type == o.objective_type &&
      status == o.status &&
       == o. &&
      daily_spend_cap == o.daily_spend_cap &&
      default_ad_group_budget_in_micro_currency == o.default_ad_group_budget_in_micro_currency &&
      end_time == o.end_time &&
      lifetime_spend_cap == o.lifetime_spend_cap &&
      name == o.name &&
      order_line_id == o.order_line_id &&
      start_time == o.start_time &&
      tracking_urls == o.tracking_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


388
389
390
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 388

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



394
395
396
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 394

def hash
  [bid_options, intended_promotion_type, is_automated_campaign, is_campaign_budget_optimization, is_flexible_daily_budgets, is_ltv_optimized, is_performance_plus, is_top_of_search, objective_type, status, , daily_spend_cap, default_ad_group_budget_in_micro_currency, end_time, lifetime_spend_cap, name, order_line_id, start_time, tracking_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 274

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @objective_type.nil?
    invalid_properties.push('invalid value for "objective_type", objective_type cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @ad_account_id !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@order_line_id.nil? && @order_line_id !~ pattern
    invalid_properties.push("invalid value for \"order_line_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 423

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



304
305
306
307
308
309
310
311
312
# File 'lib/pinterest_sdk/models/campaign_create_request.rb', line 304

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @objective_type.nil?
  return false if @ad_account_id.nil?
  return false if @ad_account_id !~ Regexp.new(/^\d+$/)
  return false if @name.nil?
  return false if !@order_line_id.nil? && @order_line_id !~ Regexp.new(/^\d+$/)
  true
end