Class: PinterestSdkClient::CampaignDeliveryEstimatesResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CampaignDeliveryEstimatesResponse
- Defined in:
- lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb
Overview
Delivery estimates response for a campaign.
Instance Attribute Summary collapse
-
#curves ⇒ Object
Estimated curves.
-
#derived_metrics ⇒ Object
Returns the value of attribute derived_metrics.
-
#max_potential_spend ⇒ Object
Maximum potential spend estimate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignDeliveryEstimatesResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignDeliveryEstimatesResponse
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignDeliveryEstimatesResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignDeliveryEstimatesResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'curves') if (value = attributes[:'curves']).is_a?(Array) self.curves = value end end if attributes.key?(:'derived_metrics') self.derived_metrics = attributes[:'derived_metrics'] end if attributes.key?(:'max_potential_spend') self.max_potential_spend = attributes[:'max_potential_spend'] end end |
Instance Attribute Details
#curves ⇒ Object
Estimated curves. Each curve will pertain to a single estimation type.
20 21 22 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 20 def curves @curves end |
#derived_metrics ⇒ Object
Returns the value of attribute derived_metrics.
22 23 24 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 22 def derived_metrics @derived_metrics end |
#max_potential_spend ⇒ Object
Maximum potential spend estimate.
25 26 27 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 25 def max_potential_spend @max_potential_spend end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 28 def self.attribute_map { :'curves' => :'curves', :'derived_metrics' => :'derived_metrics', :'max_potential_spend' => :'max_potential_spend' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 47 def self.openapi_types { :'curves' => :'Array<CampaignPlanningCurveEstimate>', :'derived_metrics' => :'CampaignDeliveryEstimatesDerivedMetrics', :'max_potential_spend' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 128 def ==(o) return true if self.equal?(o) self.class == o.class && curves == o.curves && derived_metrics == o.derived_metrics && max_potential_spend == o.max_potential_spend end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 144 def hash [curves, derived_metrics, max_potential_spend].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
94 95 96 97 98 99 100 101 102 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 94 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@curves.nil? && @curves.length > 20 invalid_properties.push('invalid value for "curves", number of items must be less than or equal to 20.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_response.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@curves.nil? && @curves.length > 20 true end |