Class: PinterestSdkClient::CampaignPlanningConfidenceLevelAlert
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CampaignPlanningConfidenceLevelAlert
- Defined in:
- lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb
Overview
A confidence level alert for the delivery estimates provided in the response.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Human-readable context for debugging.
-
#reason ⇒ Object
Reason for the confidence level alert.
-
#severity ⇒ Object
Severity of the confidence level alert.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignPlanningConfidenceLevelAlert
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignPlanningConfidenceLevelAlert
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignPlanningConfidenceLevelAlert` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignPlanningConfidenceLevelAlert`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end end |
Instance Attribute Details
#description ⇒ Object
Human-readable context for debugging. Not intended for display to end users.
20 21 22 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 20 def description @description end |
#reason ⇒ Object
Reason for the confidence level alert.
23 24 25 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 23 def reason @reason end |
#severity ⇒ Object
Severity of the confidence level alert.
26 27 28 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 26 def severity @severity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 51 def self.attribute_map { :'description' => :'description', :'reason' => :'reason', :'severity' => :'severity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 70 def self.openapi_types { :'description' => :'String', :'reason' => :'CampaignPlanningConfidenceLevelAlertReason', :'severity' => :'CampaignPlanningConfidenceLevelAlertSeverity' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && reason == o.reason && severity == o.severity end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 146 def hash [description, reason, severity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 |
# File 'lib/pinterest_sdk/models/campaign_planning_confidence_level_alert.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |