Class: PinterestSdkClient::CampaignPlanningConversionAttribution

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb

Overview

Attribution windows for a conversion event.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignPlanningConversionAttribution

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignPlanningConversionAttribution` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignPlanningConversionAttribution`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'click_window_days')
    self.click_window_days = attributes[:'click_window_days']
  end

  if attributes.key?(:'engagement_window_days')
    self.engagement_window_days = attributes[:'engagement_window_days']
  end

  if attributes.key?(:'view_window_days')
    self.view_window_days = attributes[:'view_window_days']
  end
end

Instance Attribute Details

#click_window_daysObject

Number of days to use as the conversion attribution window for a pin click action.



20
21
22
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 20

def click_window_days
  @click_window_days
end

#engagement_window_daysObject

Number of days to use as the conversion attribution window for an engagement action. Engagements include saves, closeups, link clicks, and carousel card swipes.



23
24
25
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 23

def engagement_window_days
  @engagement_window_days
end

#view_window_daysObject

Number of days to use as the conversion attribution window for a view action.



26
27
28
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 26

def view_window_days
  @view_window_days
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 51

def self.attribute_map
  {
    :'click_window_days' => :'click_window_days',
    :'engagement_window_days' => :'engagement_window_days',
    :'view_window_days' => :'view_window_days'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 153

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 70

def self.openapi_types
  {
    :'click_window_days' => :'CampaignPlanningConversionAttributionWindowDays',
    :'engagement_window_days' => :'CampaignPlanningConversionAttributionWindowDays',
    :'view_window_days' => :'CampaignPlanningConversionAttributionWindowDays'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 130

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      click_window_days == o.click_window_days &&
      engagement_window_days == o.engagement_window_days &&
      view_window_days == o.view_window_days
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


140
141
142
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 140

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



146
147
148
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 146

def hash
  [click_window_days, engagement_window_days, view_window_days].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 175

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
# File 'lib/pinterest_sdk/models/campaign_planning_conversion_attribution.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end