Class: PinterestSdkClient::CampaignUpdateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CampaignUpdateRequest
- Defined in:
- lib/pinterest_sdk/models/campaign_update_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Campaign's Advertiser ID.
-
#bid_options ⇒ Object
Returns the value of attribute bid_options.
-
#daily_spend_cap ⇒ Object
Campaign daily spending cap.
-
#default_ad_group_budget_in_micro_currency ⇒ Object
When transitioning from campaign budget optimization to non-campaign budget optimization, the default_ad_group_budget_in_micro_currency will propagate to each child ad groups daily budget.
-
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the campaign stop appearing.
-
#id ⇒ Object
Campaign ID.
-
#intended_promotion_type ⇒ Object
Returns the value of attribute intended_promotion_type.
-
#is_automated_campaign ⇒ Object
Note: This field is immutable unless the campaign is in draft status.
-
#is_campaign_budget_optimization ⇒ Object
Note: This field is immutable unless the campaign is in draft status.
-
#is_flexible_daily_budgets ⇒ Object
Determine if a campaign has setup for flexible daily budgets, also known as "Pinterest Performance+ budgets".
-
#is_ltv_optimized ⇒ Object
Specifies whether the campaign is optimized for Lifetime Value (LTV).
-
#is_performance_plus ⇒ Object
Enable Pinterest Performance+ for your campaign.
-
#is_top_of_search ⇒ Object
Enable Top Of Search for your campaign.
-
#lifetime_spend_cap ⇒ Object
Campaign total spending cap.
-
#name ⇒ Object
Campaign name.
-
#objective_type ⇒ Object
Returns the value of attribute objective_type.
-
#order_line_id ⇒ Object
Order line ID that appears on the invoice.
-
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the campaign start to appear.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignUpdateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignUpdateRequest
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 177 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignUpdateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bid_options') self. = attributes[:'bid_options'] end if attributes.key?(:'intended_promotion_type') self.intended_promotion_type = attributes[:'intended_promotion_type'] end if attributes.key?(:'is_ltv_optimized') self.is_ltv_optimized = attributes[:'is_ltv_optimized'] end if attributes.key?(:'is_performance_plus') self.is_performance_plus = attributes[:'is_performance_plus'] end if attributes.key?(:'is_top_of_search') self.is_top_of_search = attributes[:'is_top_of_search'] end if attributes.key?(:'objective_type') self.objective_type = attributes[:'objective_type'] end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'daily_spend_cap') self.daily_spend_cap = attributes[:'daily_spend_cap'] end if attributes.key?(:'default_ad_group_budget_in_micro_currency') self.default_ad_group_budget_in_micro_currency = attributes[:'default_ad_group_budget_in_micro_currency'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'is_automated_campaign') self.is_automated_campaign = attributes[:'is_automated_campaign'] end if attributes.key?(:'is_campaign_budget_optimization') self.is_campaign_budget_optimization = attributes[:'is_campaign_budget_optimization'] end if attributes.key?(:'is_flexible_daily_budgets') self.is_flexible_daily_budgets = attributes[:'is_flexible_daily_budgets'] end if attributes.key?(:'lifetime_spend_cap') self.lifetime_spend_cap = attributes[:'lifetime_spend_cap'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'order_line_id') self.order_line_id = attributes[:'order_line_id'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'tracking_urls') self.tracking_urls = attributes[:'tracking_urls'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Campaign's Advertiser ID. If you want to create a campaign in a Business Account shared account you need to specify the Business Access advertiser ID in both the query path param as well as the request body schema.
34 35 36 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 34 def ad_account_id @ad_account_id end |
#bid_options ⇒ Object
Returns the value of attribute bid_options.
18 19 20 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 18 def @bid_options end |
#daily_spend_cap ⇒ Object
Campaign daily spending cap. Required for Campaign Budget Optimization (CBO) campaigns. This and "lifetime_spend_cap" cannot be set at the same time.
37 38 39 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 37 def daily_spend_cap @daily_spend_cap end |
#default_ad_group_budget_in_micro_currency ⇒ Object
When transitioning from campaign budget optimization to non-campaign budget optimization, the default_ad_group_budget_in_micro_currency will propagate to each child ad groups daily budget. Unit is micro currency of the associated advertiser account.
40 41 42 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 40 def default_ad_group_budget_in_micro_currency @default_ad_group_budget_in_micro_currency end |
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the campaign stop appearing. Must occur after any end times for child ad groups. If end_time is not specified for the campaign, ads run indefinitely unless you update the campaign, changing their status to paused. Learn about <a href="/docs/api-features/managing-campaigns/#campaign-scheduling" target="blank">scheduling campaigns. Different end times can be set for the campaign's child ad groups, but they cannot occur after an end_time specified for the campaign. - If your campaign has a child ad group with an end time specified, and if you update that campaign with an end_time that is earlier than that of the ad group, the campaign end_time will supersede the ad group end_time, and the request will not return an error. - In this scenario, if you call <a href="/docs/api/v5/campaigns-list" target="blank">List campaigns or <a href="/docs/api/v5/ad_groups-list" target="blank">List ad groups, the returned campaigns or ad groups are listed with the start and end times that you assigned them, regardless of supersedence.
43 44 45 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 43 def end_time @end_time end |
#id ⇒ Object
Campaign ID.
46 47 48 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 46 def id @id end |
#intended_promotion_type ⇒ Object
Returns the value of attribute intended_promotion_type.
20 21 22 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 20 def intended_promotion_type @intended_promotion_type end |
#is_automated_campaign ⇒ Object
Note: This field is immutable unless the campaign is in draft status. Specifies whether the campaign was created in the automated campaign flow. When using Automated Campaigns, a daily spend cap must be set, and Pinterest Performance+ may not be used. The following objective types are supported: - CONSIDERATION - WEB\_CONVERSION - SALES - CATALOG\_SALES
49 50 51 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 49 def is_automated_campaign @is_automated_campaign end |
#is_campaign_budget_optimization ⇒ Object
Note: This field is immutable unless the campaign is in draft status. Determines if a campaign automatically generates ad-group level budgets given a campaign budget to maximize campaign outcome. When using campaign budgets with a lifetime spend cap, the end time must be provided.
52 53 54 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 52 def is_campaign_budget_optimization @is_campaign_budget_optimization end |
#is_flexible_daily_budgets ⇒ Object
Determine if a campaign has setup for flexible daily budgets, also known as "Pinterest Performance+ budgets". Flexible daily budgets are only supported for campaign budget optimization with a daily spend cap, and not a lifetime spend cap.
55 56 57 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 55 def is_flexible_daily_budgets @is_flexible_daily_budgets end |
#is_ltv_optimized ⇒ Object
Specifies whether the campaign is optimized for Lifetime Value (LTV). Only available for eligible advertisers.
23 24 25 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 23 def is_ltv_optimized @is_ltv_optimized end |
#is_performance_plus ⇒ Object
Enable Pinterest Performance+ for your campaign. To learn more, see <a href="https://developers.pinterest.com/docs/api-features/pinterest-performance-plus-setup/">Pinterest Performance+ Setup. This field is immutable, except only for campaigns in draft status which may update this field.
26 27 28 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 26 def is_performance_plus @is_performance_plus end |
#is_top_of_search ⇒ Object
Enable Top Of Search for your campaign. This field is immutable, except only for campaigns in draft status which may update this field.
29 30 31 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 29 def is_top_of_search @is_top_of_search end |
#lifetime_spend_cap ⇒ Object
Campaign total spending cap. Required for Campaign Budget Optimization (CBO) campaigns. This and "daily_spend_cap" cannot be set at the same time.
58 59 60 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 58 def lifetime_spend_cap @lifetime_spend_cap end |
#name ⇒ Object
Campaign name.
61 62 63 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 61 def name @name end |
#objective_type ⇒ Object
Returns the value of attribute objective_type.
31 32 33 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 31 def objective_type @objective_type end |
#order_line_id ⇒ Object
Order line ID that appears on the invoice.
64 65 66 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 64 def order_line_id @order_line_id end |
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the campaign start to appear. Must precede any start times set for child ad groups. Defaults to current time if no time is specified. Learn about <a href="/docs/api-features/managing-campaigns/#campaign-scheduling" target="blank">scheduling campaigns. Different start times can be set for the campaign's child ad groups, but they cannot occur before a start_time specified for the campaign. - If your campaign has a child ad group with a start time specified, and if you update that campaign with a start_time that is later than that of the ad group, the campaign start_time will supersede the ad group start_time, and the request will not return an error. - In this scenario, if you call <a href="/docs/api/v5/campaigns-list" target="blank">List campaigns or <a href="/docs/api/v5/ad_groups-list" target="blank">List ad groups, the returned campaigns or ad groups are listed with the start and end times that you assigned them, regardless of supersedence.
67 68 69 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 67 def start_time @start_time end |
#status ⇒ Object
Returns the value of attribute status.
69 70 71 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 69 def status @status end |
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
71 72 73 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 71 def tracking_urls @tracking_urls end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
122 123 124 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 122 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
127 128 129 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 127 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 96 def self.attribute_map { :'bid_options' => :'bid_options', :'intended_promotion_type' => :'intended_promotion_type', :'is_ltv_optimized' => :'is_ltv_optimized', :'is_performance_plus' => :'is_performance_plus', :'is_top_of_search' => :'is_top_of_search', :'objective_type' => :'objective_type', :'ad_account_id' => :'ad_account_id', :'daily_spend_cap' => :'daily_spend_cap', :'default_ad_group_budget_in_micro_currency' => :'default_ad_group_budget_in_micro_currency', :'end_time' => :'end_time', :'id' => :'id', :'is_automated_campaign' => :'is_automated_campaign', :'is_campaign_budget_optimization' => :'is_campaign_budget_optimization', :'is_flexible_daily_budgets' => :'is_flexible_daily_budgets', :'lifetime_spend_cap' => :'lifetime_spend_cap', :'name' => :'name', :'order_line_id' => :'order_line_id', :'start_time' => :'start_time', :'status' => :'status', :'tracking_urls' => :'tracking_urls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 402 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 158 def self.openapi_nullable Set.new([ :'bid_options', :'objective_type', :'daily_spend_cap', :'default_ad_group_budget_in_micro_currency', :'end_time', :'is_automated_campaign', :'is_campaign_budget_optimization', :'is_flexible_daily_budgets', :'lifetime_spend_cap', :'order_line_id', :'start_time', :'tracking_urls' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 132 def self.openapi_types { :'bid_options' => :'CampaignBidOptionsUpdate', :'intended_promotion_type' => :'IntendedPromotionType', :'is_ltv_optimized' => :'Boolean', :'is_performance_plus' => :'Boolean', :'is_top_of_search' => :'Boolean', :'objective_type' => :'ObjectiveType', :'ad_account_id' => :'String', :'daily_spend_cap' => :'Integer', :'default_ad_group_budget_in_micro_currency' => :'Integer', :'end_time' => :'Integer', :'id' => :'String', :'is_automated_campaign' => :'Boolean', :'is_campaign_budget_optimization' => :'Boolean', :'is_flexible_daily_budgets' => :'Boolean', :'lifetime_spend_cap' => :'Integer', :'name' => :'String', :'order_line_id' => :'String', :'start_time' => :'Integer', :'status' => :'EntityStatus', :'tracking_urls' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 362 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && intended_promotion_type == o.intended_promotion_type && is_ltv_optimized == o.is_ltv_optimized && is_performance_plus == o.is_performance_plus && is_top_of_search == o.is_top_of_search && objective_type == o.objective_type && ad_account_id == o.ad_account_id && daily_spend_cap == o.daily_spend_cap && default_ad_group_budget_in_micro_currency == o.default_ad_group_budget_in_micro_currency && end_time == o.end_time && id == o.id && is_automated_campaign == o.is_automated_campaign && is_campaign_budget_optimization == o.is_campaign_budget_optimization && is_flexible_daily_budgets == o.is_flexible_daily_budgets && lifetime_spend_cap == o.lifetime_spend_cap && name == o.name && order_line_id == o.order_line_id && start_time == o.start_time && status == o.status && tracking_urls == o.tracking_urls end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 395 def hash [, intended_promotion_type, is_ltv_optimized, is_performance_plus, is_top_of_search, objective_type, ad_account_id, daily_spend_cap, default_ad_group_budget_in_micro_currency, end_time, id, is_automated_campaign, is_campaign_budget_optimization, is_flexible_daily_budgets, lifetime_spend_cap, name, order_line_id, start_time, status, tracking_urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 278 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@order_line_id.nil? && @order_line_id !~ pattern invalid_properties.push("invalid value for \"order_line_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
309 310 311 312 313 314 315 316 317 |
# File 'lib/pinterest_sdk/models/campaign_update_request.rb', line 309 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_account_id.nil? return false if @ad_account_id !~ Regexp.new(/^\d+$/) return false if @id.nil? return false if @id !~ Regexp.new(/^\d+$/) return false if !@order_line_id.nil? && @order_line_id !~ Regexp.new(/^\d+$/) true end |