Class: PinterestSdkClient::CampaignUpdateRequestAllOf2

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/campaign_update_request_all_of2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignUpdateRequestAllOf2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignUpdateRequestAllOf2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignUpdateRequestAllOf2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bid_options')
    self.bid_options = attributes[:'bid_options']
  end

  if attributes.key?(:'intended_promotion_type')
    self.intended_promotion_type = attributes[:'intended_promotion_type']
  end

  if attributes.key?(:'is_ltv_optimized')
    self.is_ltv_optimized = attributes[:'is_ltv_optimized']
  end

  if attributes.key?(:'is_performance_plus')
    self.is_performance_plus = attributes[:'is_performance_plus']
  end

  if attributes.key?(:'is_top_of_search')
    self.is_top_of_search = attributes[:'is_top_of_search']
  end

  if attributes.key?(:'objective_type')
    self.objective_type = attributes[:'objective_type']
  end
end

Instance Attribute Details

#bid_optionsObject

Returns the value of attribute bid_options.



18
19
20
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 18

def bid_options
  @bid_options
end

#intended_promotion_typeObject

Returns the value of attribute intended_promotion_type.



20
21
22
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 20

def intended_promotion_type
  @intended_promotion_type
end

#is_ltv_optimizedObject

Specifies whether the campaign is optimized for Lifetime Value (LTV). Only available for eligible advertisers.



23
24
25
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 23

def is_ltv_optimized
  @is_ltv_optimized
end

#is_performance_plusObject

Enable Pinterest Performance+ for your campaign. To learn more, see <a href="https://developers.pinterest.com/docs/api-features/pinterest-performance-plus-setup/"&gt;Pinterest Performance+ Setup. This field is immutable, except only for campaigns in draft status which may update this field.



26
27
28
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 26

def is_performance_plus
  @is_performance_plus
end

#is_top_of_searchObject

Enable Top Of Search for your campaign. This field is immutable, except only for campaigns in draft status which may update this field.



29
30
31
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 29

def is_top_of_search
  @is_top_of_search
end

#objective_typeObject

Returns the value of attribute objective_type.



31
32
33
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 31

def objective_type
  @objective_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 56

def self.attribute_map
  {
    :'bid_options' => :'bid_options',
    :'intended_promotion_type' => :'intended_promotion_type',
    :'is_ltv_optimized' => :'is_ltv_optimized',
    :'is_performance_plus' => :'is_performance_plus',
    :'is_top_of_search' => :'is_top_of_search',
    :'objective_type' => :'objective_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
95
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 90

def self.openapi_nullable
  Set.new([
    :'bid_options',
    :'objective_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 78

def self.openapi_types
  {
    :'bid_options' => :'CampaignBidOptionsUpdate',
    :'intended_promotion_type' => :'IntendedPromotionType',
    :'is_ltv_optimized' => :'Boolean',
    :'is_performance_plus' => :'Boolean',
    :'is_top_of_search' => :'Boolean',
    :'objective_type' => :'ObjectiveType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bid_options == o.bid_options &&
      intended_promotion_type == o.intended_promotion_type &&
      is_ltv_optimized == o.is_ltv_optimized &&
      is_performance_plus == o.is_performance_plus &&
      is_top_of_search == o.is_top_of_search &&
      objective_type == o.objective_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 174

def hash
  [bid_options, intended_promotion_type, is_ltv_optimized, is_performance_plus, is_top_of_search, objective_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
# File 'lib/pinterest_sdk/models/campaign_update_request_all_of2.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end