Class: PinterestSdkClient::CatalogBinding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogBinding
- Defined in:
- lib/pinterest_sdk/models/catalog_binding.rb
Overview
Information about a catalog asset.
Instance Attribute Summary collapse
-
#catalog_type ⇒ Object
Catalog type.
-
#id ⇒ Object
Catalog ID.
-
#name ⇒ Object
Catalog name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogBinding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogBinding
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogBinding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'catalog_type') self.catalog_type = attributes[:'catalog_type'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#catalog_type ⇒ Object
Catalog type
20 21 22 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 20 def catalog_type @catalog_type end |
#id ⇒ Object
Catalog ID.
23 24 25 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 23 def id @id end |
#name ⇒ Object
Catalog name
26 27 28 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 26 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 29 def self.attribute_map { :'catalog_type' => :'catalog_type', :'id' => :'id', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 152 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 48 def self.openapi_types { :'catalog_type' => :'String', :'id' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && catalog_type == o.catalog_type && id == o.id && name == o.name end |
#eql?(o) ⇒ Boolean
139 140 141 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 139 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 145 def hash [catalog_type, id, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 |
# File 'lib/pinterest_sdk/models/catalog_binding.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) true end |