Class: PinterestSdkClient::CatalogItemsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/catalog_items_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CatalogItemsApi

Returns a new instance of CatalogItemsApi.



19
20
21
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#items_batch_get(batch_id, opts = {}) ⇒ CatalogsItemsBatch

Get item batch status Get a single catalogs items batch owned by the "operating user_account". See detailed documentation here. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.

Parameters:

  • batch_id (String)

    Id of a catalogs items batch to fetch

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



28
29
30
31
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 28

def items_batch_get(batch_id, opts = {})
  data, _status_code, _headers = items_batch_get_with_http_info(batch_id, opts)
  data
end

#items_batch_get_with_http_info(batch_id, opts = {}) ⇒ Array<(CatalogsItemsBatch, Integer, Hash)>

Get item batch status Get a single catalogs items batch owned by the &quot;operating user_account&quot;. See detailed documentation here. - By default, the &quot;operation user_account&quot; is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.

Parameters:

  • batch_id (String)

    Id of a catalogs items batch to fetch

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:

  • (Array<(CatalogsItemsBatch, Integer, Hash)>)

    CatalogsItemsBatch data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 39

def items_batch_get_with_http_info(batch_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogItemsApi.items_batch_get ...'
  end
  # verify the required parameter 'batch_id' is set
  if @api_client.config.client_side_validation && batch_id.nil?
    fail ArgumentError, "Missing the required parameter 'batch_id' when calling CatalogItemsApi.items_batch_get"
  end
  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && batch_id !~ pattern
    fail ArgumentError, "invalid value for 'batch_id' when calling CatalogItemsApi.items_batch_get, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogItemsApi.items_batch_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogItemsApi.items_batch_get, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/catalogs/items/batch/{batch_id}'.sub('{batch_id}', CGI.escape(batch_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CatalogsItemsBatch'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials']

  new_options = opts.merge(
    :operation => :"CatalogItemsApi.items_batch_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogItemsApi#items_batch_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#items_batch_post(catalogs_items_batch_post_request, opts = {}) ⇒ CatalogsItemsBatch

Operate on item batch This endpoint supports multiple operations on a set of one or more catalog items owned by the "operation user_account". See detailed documentation here. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: - Access to the Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager. - The item UPSERT operation is restricted to users without a feed data source. If you plan to migrate item ingestion from feeds to the API, please reach out to your partner manager or via the Help Center to get assistance.

Parameters:

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



108
109
110
111
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 108

def items_batch_post(catalogs_items_batch_post_request, opts = {})
  data, _status_code, _headers = items_batch_post_with_http_info(catalogs_items_batch_post_request, opts)
  data
end

#items_batch_post_with_http_info(catalogs_items_batch_post_request, opts = {}) ⇒ Array<(CatalogsItemsBatch, Integer, Hash)>

Operate on item batch This endpoint supports multiple operations on a set of one or more catalog items owned by the &quot;operation user_account&quot;. See detailed documentation here. - By default, the &quot;operation user_account&quot; is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: - Access to the Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager. - The item UPSERT operation is restricted to users without a feed data source. If you plan to migrate item ingestion from feeds to the API, please reach out to your partner manager or via the Help Center to get assistance.

Parameters:

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:

  • (Array<(CatalogsItemsBatch, Integer, Hash)>)

    CatalogsItemsBatch data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 119

def items_batch_post_with_http_info(catalogs_items_batch_post_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogItemsApi.items_batch_post ...'
  end
  # verify the required parameter 'catalogs_items_batch_post_request' is set
  if @api_client.config.client_side_validation && catalogs_items_batch_post_request.nil?
    fail ArgumentError, "Missing the required parameter 'catalogs_items_batch_post_request' when calling CatalogItemsApi.items_batch_post"
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogItemsApi.items_batch_post, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogItemsApi.items_batch_post, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/catalogs/items/batch'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(catalogs_items_batch_post_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CatalogsItemsBatch'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials']

  new_options = opts.merge(
    :operation => :"CatalogItemsApi.items_batch_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogItemsApi#items_batch_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#items_post(catalogs_items_request, opts = {}) ⇒ ItemsPost200Response

Get catalogs items (POST) Get the items of the catalog owned by the "operation user_account". See detailed documentation here. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: Access to the Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager.

Parameters:

  • catalogs_items_request (CatalogsItemsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



188
189
190
191
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 188

def items_post(catalogs_items_request, opts = {})
  data, _status_code, _headers = items_post_with_http_info(catalogs_items_request, opts)
  data
end

#items_post_with_http_info(catalogs_items_request, opts = {}) ⇒ Array<(ItemsPost200Response, Integer, Hash)>

Get catalogs items (POST) Get the items of the catalog owned by the &quot;operation user_account&quot;. See detailed documentation here. - By default, the &quot;operation user_account&quot; is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: Access to the Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager.

Parameters:

  • catalogs_items_request (CatalogsItemsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:

  • (Array<(ItemsPost200Response, Integer, Hash)>)

    ItemsPost200Response data, response status code and response headers



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/pinterest_sdk/api/catalog_items_api.rb', line 199

def items_post_with_http_info(catalogs_items_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogItemsApi.items_post ...'
  end
  # verify the required parameter 'catalogs_items_request' is set
  if @api_client.config.client_side_validation && catalogs_items_request.nil?
    fail ArgumentError, "Missing the required parameter 'catalogs_items_request' when calling CatalogItemsApi.items_post"
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogItemsApi.items_post, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogItemsApi.items_post, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/catalogs/items'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(catalogs_items_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ItemsPost200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CatalogItemsApi.items_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogItemsApi#items_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end