Class: PinterestSdkClient::CatalogsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/catalogs_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CatalogsApi

Returns a new instance of CatalogsApi.



19
20
21
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#catalogs_available_filter_values(catalog_id, opts = {}) ⇒ CatalogsAvailableFilterValues

List available filter values Get the available filter attributes and values associated with a given feed or catalog owned by the "operation user_account". - By default, the "operation user_account" is the token user_account. - country, language, and feed_id are only used in retail catalogs. - Note: It is not guaranteed that all available filter values will be returned. Instead this endpoint will return values from a sample of up to 1000 items. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more

Parameters:

  • catalog_id (String)

    Filter entities for a given catalog_id.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :feed_id (String)

    Filter entities for a given feed_id. If not given, all feeds are considered.

  • :country (Country)

    Country for the Catalogs Items

  • :language (CatalogsLocale)

    Language for the Catalogs Items

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



31
32
33
34
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 31

def catalogs_available_filter_values(catalog_id, opts = {})
  data, _status_code, _headers = catalogs_available_filter_values_with_http_info(catalog_id, opts)
  data
end

#catalogs_available_filter_values_with_http_info(catalog_id, opts = {}) ⇒ Array<(CatalogsAvailableFilterValues, Integer, Hash)>

List available filter values Get the available filter attributes and values associated with a given feed or catalog owned by the &quot;operation user_account&quot;. - By default, the &quot;operation user_account&quot; is the token user_account. - `country`, `language`, and `feed_id` are only used in retail catalogs. - Note: It is not guaranteed that all available filter values will be returned. Instead this endpoint will return values from a sample of up to 1000 items. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more

Parameters:

  • catalog_id (String)

    Filter entities for a given catalog_id.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :feed_id (String)

    Filter entities for a given feed_id. If not given, all feeds are considered.

  • :country (Country)

    Country for the Catalogs Items

  • :language (CatalogsLocale)

    Language for the Catalogs Items

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 45

def catalogs_available_filter_values_with_http_info(catalog_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogsApi.catalogs_available_filter_values ...'
  end
  # verify the required parameter 'catalog_id' is set
  if @api_client.config.client_side_validation && catalog_id.nil?
    fail ArgumentError, "Missing the required parameter 'catalog_id' when calling CatalogsApi.catalogs_available_filter_values"
  end
  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && catalog_id !~ pattern
    fail ArgumentError, "invalid value for 'catalog_id' when calling CatalogsApi.catalogs_available_filter_values, must conform to the pattern #{pattern}."
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'feed_id'].nil? && opts[:'feed_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"feed_id\"]' when calling CatalogsApi.catalogs_available_filter_values, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogsApi.catalogs_available_filter_values, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogsApi.catalogs_available_filter_values, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/catalogs/available_filter_values'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'catalog_id'] = catalog_id
  query_params[:'feed_id'] = opts[:'feed_id'] if !opts[:'feed_id'].nil?
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?
  query_params[:'language'] = opts[:'language'] if !opts[:'language'].nil?
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CatalogsAvailableFilterValues'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CatalogsApi.catalogs_available_filter_values",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogsApi#catalogs_available_filter_values\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#catalogs_create(catalog_create, opts = {}) ⇒ Catalog

Create catalog Create a new catalog owned by the "operation user_account". - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more Note: Access to the Product and Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager.

Parameters:

  • catalog_create (CatalogCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:



123
124
125
126
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 123

def catalogs_create(catalog_create, opts = {})
  data, _status_code, _headers = catalogs_create_with_http_info(catalog_create, opts)
  data
end

#catalogs_create_with_http_info(catalog_create, opts = {}) ⇒ Array<(Catalog, Integer, Hash)>

Create catalog Create a new catalog owned by the &quot;operation user_account&quot;. - By default, the &quot;operation user_account&quot; is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more Note: Access to the Product and Creative Assets catalog type is restricted to a specific group of users. If you require access, please reach out to your partner manager.

Parameters:

  • catalog_create (CatalogCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

Returns:

  • (Array<(Catalog, Integer, Hash)>)

    Catalog data, response status code and response headers



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 134

def catalogs_create_with_http_info(catalog_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogsApi.catalogs_create ...'
  end
  # verify the required parameter 'catalog_create' is set
  if @api_client.config.client_side_validation && catalog_create.nil?
    fail ArgumentError, "Missing the required parameter 'catalog_create' when calling CatalogsApi.catalogs_create"
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogsApi.catalogs_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogsApi.catalogs_create, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/catalogs'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(catalog_create)

  # return_type
  return_type = opts[:debug_return_type] || 'Catalog'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CatalogsApi.catalogs_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogsApi#catalogs_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#catalogs_list(opts = {}) ⇒ CatalogsList200Response

List catalogs Fetch catalogs owned by the "operation user_account". - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



204
205
206
207
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 204

def catalogs_list(opts = {})
  data, _status_code, _headers = catalogs_list_with_http_info(opts)
  data
end

#catalogs_list_with_http_info(opts = {}) ⇒ Array<(CatalogsList200Response, Integer, Hash)>

List catalogs Fetch catalogs owned by the &quot;operation user_account&quot;. - By default, the &quot;operation user_account&quot; is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the &quot;operation user_account&quot;. In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Learn more

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:

  • (Array<(CatalogsList200Response, Integer, Hash)>)

    CatalogsList200Response data, response status code and response headers



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pinterest_sdk/api/catalogs_api.rb', line 216

def catalogs_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CatalogsApi.catalogs_list ...'
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogsApi.catalogs_list, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogsApi.catalogs_list, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CatalogsApi.catalogs_list, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CatalogsApi.catalogs_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/catalogs'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CatalogsList200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CatalogsApi.catalogs_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CatalogsApi#catalogs_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end