Class: PinterestSdkClient::CatalogsCreativeAssetsAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsCreativeAssetsAttributes
- Defined in:
- lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb
Instance Attribute Summary collapse
-
#ai_disclosures ⇒ Object
AI content disclosures for individual assets (image_link or video_link) on this creative assets item.
-
#android_deep_link ⇒ Object
Link to the creative assets page.
-
#custom_label_0 ⇒ Object
Custom grouping of creative assets.
-
#custom_label_1 ⇒ Object
Custom grouping of creative assets.
-
#custom_label_2 ⇒ Object
Custom grouping of creative assets.
-
#custom_label_3 ⇒ Object
Custom grouping of creative assets.
-
#custom_label_4 ⇒ Object
Custom grouping of creative assets.
-
#description ⇒ Object
Brief description of the creative assets.
-
#google_product_category ⇒ Object
The categorization of the product based on the standardized Google Product Taxonomy.
-
#image_link ⇒ Object
The creative assets image.
-
#ios_deep_link ⇒ Object
IOS deep link to the creative assets page.
-
#link ⇒ Object
Link to the creative assets page.
-
#title ⇒ Object
The name of the creative assets.
-
#video_link ⇒ Object
The creative assets video.
-
#visibility ⇒ Object
Visibility of the creative assets.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsCreativeAssetsAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsCreativeAssetsAttributes
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsCreativeAssetsAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsCreativeAssetsAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'android_deep_link') self.android_deep_link = attributes[:'android_deep_link'] end if attributes.key?(:'custom_label_0') self.custom_label_0 = attributes[:'custom_label_0'] end if attributes.key?(:'custom_label_1') self.custom_label_1 = attributes[:'custom_label_1'] end if attributes.key?(:'custom_label_2') self.custom_label_2 = attributes[:'custom_label_2'] end if attributes.key?(:'custom_label_3') self.custom_label_3 = attributes[:'custom_label_3'] end if attributes.key?(:'custom_label_4') self.custom_label_4 = attributes[:'custom_label_4'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'google_product_category') self.google_product_category = attributes[:'google_product_category'] end if attributes.key?(:'ios_deep_link') self.ios_deep_link = attributes[:'ios_deep_link'] end if attributes.key?(:'link') self.link = attributes[:'link'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'visibility') self.visibility = attributes[:'visibility'] end if attributes.key?(:'ai_disclosures') if (value = attributes[:'ai_disclosures']).is_a?(Array) self.ai_disclosures = value end end if attributes.key?(:'image_link') self.image_link = attributes[:'image_link'] end if attributes.key?(:'video_link') self.video_link = attributes[:'video_link'] end end |
Instance Attribute Details
#ai_disclosures ⇒ Object
AI content disclosures for individual assets (image_link or video_link) on this creative assets item. Each entry declares which disclosure types apply to a single asset URL.
55 56 57 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 55 def ai_disclosures @ai_disclosures end |
#android_deep_link ⇒ Object
Link to the creative assets page.
19 20 21 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 19 def android_deep_link @android_deep_link end |
#custom_label_0 ⇒ Object
Custom grouping of creative assets.
22 23 24 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 22 def custom_label_0 @custom_label_0 end |
#custom_label_1 ⇒ Object
Custom grouping of creative assets.
25 26 27 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 25 def custom_label_1 @custom_label_1 end |
#custom_label_2 ⇒ Object
Custom grouping of creative assets.
28 29 30 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 28 def custom_label_2 @custom_label_2 end |
#custom_label_3 ⇒ Object
Custom grouping of creative assets.
31 32 33 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 31 def custom_label_3 @custom_label_3 end |
#custom_label_4 ⇒ Object
Custom grouping of creative assets.
34 35 36 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 34 def custom_label_4 @custom_label_4 end |
#description ⇒ Object
Brief description of the creative assets.
37 38 39 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 37 def description @description end |
#google_product_category ⇒ Object
The categorization of the product based on the standardized Google Product Taxonomy. This is a set taxonomy. Both the text values and numeric codes are accepted.
40 41 42 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 40 def google_product_category @google_product_category end |
#image_link ⇒ Object
The creative assets image.
58 59 60 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 58 def image_link @image_link end |
#ios_deep_link ⇒ Object
IOS deep link to the creative assets page.
43 44 45 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 43 def ios_deep_link @ios_deep_link end |
#link ⇒ Object
Link to the creative assets page.
46 47 48 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 46 def link @link end |
#title ⇒ Object
The name of the creative assets.
49 50 51 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 49 def title @title end |
#video_link ⇒ Object
The creative assets video.
61 62 63 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 61 def video_link @video_link end |
#visibility ⇒ Object
Visibility of the creative assets. Must be one of the following values (upper or lowercase): 'visible', 'hidden'.
52 53 54 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 52 def visibility @visibility end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 64 def self.attribute_map { :'android_deep_link' => :'android_deep_link', :'custom_label_0' => :'custom_label_0', :'custom_label_1' => :'custom_label_1', :'custom_label_2' => :'custom_label_2', :'custom_label_3' => :'custom_label_3', :'custom_label_4' => :'custom_label_4', :'description' => :'description', :'google_product_category' => :'google_product_category', :'ios_deep_link' => :'ios_deep_link', :'link' => :'link', :'title' => :'title', :'visibility' => :'visibility', :'ai_disclosures' => :'ai_disclosures', :'image_link' => :'image_link', :'video_link' => :'video_link' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
131 132 133 134 135 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 131 def self.openapi_all_of [ :'CatalogsUpdatableCreativeAssetsAttributes' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 116 def self.openapi_nullable Set.new([ :'android_deep_link', :'custom_label_0', :'custom_label_1', :'custom_label_2', :'custom_label_3', :'custom_label_4', :'google_product_category', :'ios_deep_link', :'visibility', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 95 def self.openapi_types { :'android_deep_link' => :'String', :'custom_label_0' => :'String', :'custom_label_1' => :'String', :'custom_label_2' => :'String', :'custom_label_3' => :'String', :'custom_label_4' => :'String', :'description' => :'String', :'google_product_category' => :'String', :'ios_deep_link' => :'String', :'link' => :'String', :'title' => :'String', :'visibility' => :'String', :'ai_disclosures' => :'Array<CatalogsAiContentDisclosure>', :'image_link' => :'String', :'video_link' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && android_deep_link == o.android_deep_link && custom_label_0 == o.custom_label_0 && custom_label_1 == o.custom_label_1 && custom_label_2 == o.custom_label_2 && custom_label_3 == o.custom_label_3 && custom_label_4 == o.custom_label_4 && description == o.description && google_product_category == o.google_product_category && ios_deep_link == o.ios_deep_link && link == o.link && title == o.title && visibility == o.visibility && ai_disclosures == o.ai_disclosures && image_link == o.image_link && video_link == o.video_link end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 261 def hash [android_deep_link, custom_label_0, custom_label_1, custom_label_2, custom_label_3, custom_label_4, description, google_product_category, ios_deep_link, link, title, visibility, ai_disclosures, image_link, video_link].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
218 219 220 221 222 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 218 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 |
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_attributes.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |