Class: PinterestSdkClient::CatalogsCreativeAssetsFilterValuesMap

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb

Overview

A map of filter attributes to their available values.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsCreativeAssetsFilterValuesMap

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsCreativeAssetsFilterValuesMap` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsCreativeAssetsFilterValuesMap`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'custom_label_0')
    if (value = attributes[:'custom_label_0']).is_a?(Array)
      self.custom_label_0 = value
    end
  end

  if attributes.key?(:'custom_label_1')
    if (value = attributes[:'custom_label_1']).is_a?(Array)
      self.custom_label_1 = value
    end
  end

  if attributes.key?(:'custom_label_2')
    if (value = attributes[:'custom_label_2']).is_a?(Array)
      self.custom_label_2 = value
    end
  end

  if attributes.key?(:'custom_label_3')
    if (value = attributes[:'custom_label_3']).is_a?(Array)
      self.custom_label_3 = value
    end
  end

  if attributes.key?(:'custom_label_4')
    if (value = attributes[:'custom_label_4']).is_a?(Array)
      self.custom_label_4 = value
    end
  end

  if attributes.key?(:'google_product_category_0')
    if (value = attributes[:'google_product_category_0']).is_a?(Array)
      self.google_product_category_0 = value
    end
  end

  if attributes.key?(:'google_product_category_1')
    if (value = attributes[:'google_product_category_1']).is_a?(Array)
      self.google_product_category_1 = value
    end
  end

  if attributes.key?(:'google_product_category_2')
    if (value = attributes[:'google_product_category_2']).is_a?(Array)
      self.google_product_category_2 = value
    end
  end

  if attributes.key?(:'google_product_category_3')
    if (value = attributes[:'google_product_category_3']).is_a?(Array)
      self.google_product_category_3 = value
    end
  end

  if attributes.key?(:'google_product_category_4')
    if (value = attributes[:'google_product_category_4']).is_a?(Array)
      self.google_product_category_4 = value
    end
  end

  if attributes.key?(:'google_product_category_5')
    if (value = attributes[:'google_product_category_5']).is_a?(Array)
      self.google_product_category_5 = value
    end
  end

  if attributes.key?(:'google_product_category_6')
    if (value = attributes[:'google_product_category_6']).is_a?(Array)
      self.google_product_category_6 = value
    end
  end

  if attributes.key?(:'media_type')
    if (value = attributes[:'media_type']).is_a?(Array)
      self.media_type = value
    end
  end
end

Instance Attribute Details

#custom_label_0Object

Returns the value of attribute custom_label_0.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 19

def custom_label_0
  @custom_label_0
end

#custom_label_1Object

Returns the value of attribute custom_label_1.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 21

def custom_label_1
  @custom_label_1
end

#custom_label_2Object

Returns the value of attribute custom_label_2.



23
24
25
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 23

def custom_label_2
  @custom_label_2
end

#custom_label_3Object

Returns the value of attribute custom_label_3.



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 25

def custom_label_3
  @custom_label_3
end

#custom_label_4Object

Returns the value of attribute custom_label_4.



27
28
29
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 27

def custom_label_4
  @custom_label_4
end

#google_product_category_0Object

Returns the value of attribute google_product_category_0.



29
30
31
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 29

def google_product_category_0
  @google_product_category_0
end

#google_product_category_1Object

Returns the value of attribute google_product_category_1.



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 31

def google_product_category_1
  @google_product_category_1
end

#google_product_category_2Object

Returns the value of attribute google_product_category_2.



33
34
35
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 33

def google_product_category_2
  @google_product_category_2
end

#google_product_category_3Object

Returns the value of attribute google_product_category_3.



35
36
37
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 35

def google_product_category_3
  @google_product_category_3
end

#google_product_category_4Object

Returns the value of attribute google_product_category_4.



37
38
39
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 37

def google_product_category_4
  @google_product_category_4
end

#google_product_category_5Object

Returns the value of attribute google_product_category_5.



39
40
41
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 39

def google_product_category_5
  @google_product_category_5
end

#google_product_category_6Object

Returns the value of attribute google_product_category_6.



41
42
43
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 41

def google_product_category_6
  @google_product_category_6
end

#media_typeObject

Returns the value of attribute media_type.



43
44
45
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 43

def media_type
  @media_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 46

def self.attribute_map
  {
    :'custom_label_0' => :'custom_label_0',
    :'custom_label_1' => :'custom_label_1',
    :'custom_label_2' => :'custom_label_2',
    :'custom_label_3' => :'custom_label_3',
    :'custom_label_4' => :'custom_label_4',
    :'google_product_category_0' => :'google_product_category_0',
    :'google_product_category_1' => :'google_product_category_1',
    :'google_product_category_2' => :'google_product_category_2',
    :'google_product_category_3' => :'google_product_category_3',
    :'google_product_category_4' => :'google_product_category_4',
    :'google_product_category_5' => :'google_product_category_5',
    :'google_product_category_6' => :'google_product_category_6',
    :'media_type' => :'media_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 75

def self.openapi_types
  {
    :'custom_label_0' => :'Array<String>',
    :'custom_label_1' => :'Array<String>',
    :'custom_label_2' => :'Array<String>',
    :'custom_label_3' => :'Array<String>',
    :'custom_label_4' => :'Array<String>',
    :'google_product_category_0' => :'Array<String>',
    :'google_product_category_1' => :'Array<String>',
    :'google_product_category_2' => :'Array<String>',
    :'google_product_category_3' => :'Array<String>',
    :'google_product_category_4' => :'Array<String>',
    :'google_product_category_5' => :'Array<String>',
    :'google_product_category_6' => :'Array<String>',
    :'media_type' => :'Array<MediaType>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      custom_label_0 == o.custom_label_0 &&
      custom_label_1 == o.custom_label_1 &&
      custom_label_2 == o.custom_label_2 &&
      custom_label_3 == o.custom_label_3 &&
      custom_label_4 == o.custom_label_4 &&
      google_product_category_0 == o.google_product_category_0 &&
      google_product_category_1 == o.google_product_category_1 &&
      google_product_category_2 == o.google_product_category_2 &&
      google_product_category_3 == o.google_product_category_3 &&
      google_product_category_4 == o.google_product_category_4 &&
      google_product_category_5 == o.google_product_category_5 &&
      google_product_category_6 == o.google_product_category_6 &&
      media_type == o.media_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 237

def hash
  [custom_label_0, custom_label_1, custom_label_2, custom_label_3, custom_label_4, google_product_category_0, google_product_category_1, google_product_category_2, google_product_category_3, google_product_category_4, google_product_category_5, google_product_category_6, media_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_filter_values_map.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end