Class: PinterestSdkClient::CatalogsCreativeAssetsItemResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb

Overview

Object describing a creative assets item record

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsCreativeAssetsItemResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsCreativeAssetsItemResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsCreativeAssetsItemResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'creative_assets_id')
    self.creative_assets_id = attributes[:'creative_assets_id']
  end

  if attributes.key?(:'item_response_kind')
    self.item_response_kind = attributes[:'item_response_kind']
  else
    self.item_response_kind = nil
  end

  if attributes.key?(:'pins')
    if (value = attributes[:'pins']).is_a?(Array)
      self.pins = value
    end
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 19

def attributes
  @attributes
end

#catalog_typeObject

Returns the value of attribute catalog_type.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 21

def catalog_type
  @catalog_type
end

#creative_assets_idObject

The catalog creative assets id in the merchant namespace



24
25
26
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 24

def creative_assets_id
  @creative_assets_id
end

#item_response_kindObject

Discriminator literal identifying this leaf inside an ItemResponse payload.



27
28
29
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 27

def item_response_kind
  @item_response_kind
end

#pinsObject

The pins mapped to the item



30
31
32
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 30

def pins
  @pins
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 55

def self.attribute_map
  {
    :'attributes' => :'attributes',
    :'catalog_type' => :'catalog_type',
    :'creative_assets_id' => :'creative_assets_id',
    :'item_response_kind' => :'item_response_kind',
    :'pins' => :'pins'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 87

def self.openapi_nullable
  Set.new([
    :'pins'
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 76

def self.openapi_types
  {
    :'attributes' => :'CatalogsCreativeAssetsAttributes',
    :'catalog_type' => :'String',
    :'creative_assets_id' => :'String',
    :'item_response_kind' => :'String',
    :'pins' => :'Array<Pin>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attributes == o.attributes &&
      catalog_type == o.catalog_type &&
      creative_assets_id == o.creative_assets_id &&
      item_response_kind == o.item_response_kind &&
      pins == o.pins
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 220

def hash
  [attributes, catalog_type, creative_assets_id, item_response_kind, pins].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @item_response_kind.nil?
    invalid_properties.push('invalid value for "item_response_kind", item_response_kind cannot be nil.')
  end

  if !@pins.nil? && @pins.length > 11
    invalid_properties.push('invalid value for "pins", number of items must be less than or equal to 11.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
165
166
167
168
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_item_response.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["CREATIVE_ASSETS"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @item_response_kind.nil?
  item_response_kind_validator = EnumAttributeValidator.new('String', ["creative_assets_item"])
  return false unless item_response_kind_validator.valid?(@item_response_kind)
  return false if !@pins.nil? && @pins.length > 11
  true
end