Class: PinterestSdkClient::CatalogsCreativeAssetsProductGroupProductCounts

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb

Overview

Product counts for a Creative Assets CatalogsProductGroup

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsCreativeAssetsProductGroupProductCounts

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsCreativeAssetsProductGroupProductCounts` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsCreativeAssetsProductGroupProductCounts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_links')
    self.app_links = attributes[:'app_links']
  else
    self.app_links = nil
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'images')
    self.images = attributes[:'images']
  else
    self.images = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'videos')
    self.videos = attributes[:'videos']
  else
    self.videos = nil
  end
end

Instance Attribute Details

Returns the value of attribute app_links.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 19

def app_links
  @app_links
end

#catalog_typeObject

Returns the value of attribute catalog_type.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 21

def catalog_type
  @catalog_type
end

#imagesObject

Returns the value of attribute images.



23
24
25
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 23

def images
  @images
end

#totalObject

Returns the value of attribute total.



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 25

def total
  @total
end

#videosObject

Returns the value of attribute videos.



27
28
29
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 27

def videos
  @videos
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 52

def self.attribute_map
  {
    :'app_links' => :'app_links',
    :'catalog_type' => :'catalog_type',
    :'images' => :'images',
    :'total' => :'total',
    :'videos' => :'videos'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 73

def self.openapi_types
  {
    :'app_links' => :'Float',
    :'catalog_type' => :'String',
    :'images' => :'Float',
    :'total' => :'Float',
    :'videos' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_links == o.app_links &&
      catalog_type == o.catalog_type &&
      images == o.images &&
      total == o.total &&
      videos == o.videos
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 284

def hash
  [app_links, catalog_type, images, total, videos].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @app_links.nil?
    invalid_properties.push('invalid value for "app_links", app_links cannot be nil.')
  end

  if @app_links < 0
    invalid_properties.push('invalid value for "app_links", must be greater than or equal to 0.')
  end

  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @images.nil?
    invalid_properties.push('invalid value for "images", images cannot be nil.')
  end

  if @images < 0
    invalid_properties.push('invalid value for "images", must be greater than or equal to 0.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @total < 0
    invalid_properties.push('invalid value for "total", must be greater than or equal to 0.')
  end

  if @videos.nil?
    invalid_properties.push('invalid value for "videos", videos cannot be nil.')
  end

  if @videos < 0
    invalid_properties.push('invalid value for "videos", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pinterest_sdk/models/catalogs_creative_assets_product_group_product_counts.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @app_links.nil?
  return false if @app_links < 0
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["CREATIVE_ASSETS"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @images.nil?
  return false if @images < 0
  return false if @total.nil?
  return false if @total < 0
  return false if @videos.nil?
  return false if @videos < 0
  true
end