Class: PinterestSdkClient::CatalogsDbItem

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/catalogs_db_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsDbItem

Initializes the object



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsDbItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsDbItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



18
19
20
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 18

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



20
21
22
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 20

def id
  @id
end

#updated_atObject

Returns the value of attribute updated_at.



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 22

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 25

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 53

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 44

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'id' => :'String',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



155
156
157
158
159
160
161
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      id == o.id &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


165
166
167
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



171
172
173
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 171

def hash
  [created_at, id, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



115
116
117
118
119
120
121
# File 'lib/pinterest_sdk/models/catalogs_db_item.rb', line 115

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  true
end