Class: PinterestSdkClient::CatalogsFeedIngestion

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_feed_ingestion.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsFeedIngestion

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedIngestion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedIngestion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'feed_id')
    self.feed_id = attributes[:'feed_id']
  else
    self.feed_id = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#created_atObject

Timestamp of the feed ingestion.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 19

def created_at
  @created_at
end

#feed_idObject

Catalog Feed id pertaining to the feed ingestion.



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 22

def feed_id
  @feed_id
end

#idObject

Unique identifier of a feed ingestion.



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 25

def id
  @id
end

#statusObject

Status of the feed ingestion.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 28

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 53

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'feed_id' => :'feed_id',
    :'id' => :'id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 252

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 73

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'feed_id' => :'String',
    :'id' => :'String',
    :'status' => :'CatalogsFeedProcessingStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



228
229
230
231
232
233
234
235
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      feed_id == o.feed_id &&
      id == o.id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


239
240
241
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



245
246
247
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 245

def hash
  [created_at, feed_id, id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @feed_id.nil?
    invalid_properties.push('invalid value for "feed_id", feed_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @feed_id !~ pattern
    invalid_properties.push("invalid value for \"feed_id\", must conform to the pattern #{pattern}.")
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



165
166
167
168
169
170
171
172
173
174
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @feed_id.nil?
  return false if @feed_id !~ Regexp.new(/^\d+$/)
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @status.nil?
  true
end