Class: PinterestSdkClient::CatalogsFeedsUpdateRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_feeds_update_request.rb

Overview

Request object for updating a feed.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsFeedsUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedsUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedsUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'credentials')
    self.credentials = attributes[:'credentials']
  end

  if attributes.key?(:'default_availability')
    self.default_availability = attributes[:'default_availability']
  end

  if attributes.key?(:'default_currency')
    self.default_currency = attributes[:'default_currency']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'preferred_processing_schedule')
    self.preferred_processing_schedule = attributes[:'preferred_processing_schedule']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#credentialsObject

Returns the value of attribute credentials.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 19

def credentials
  @credentials
end

#default_availabilityObject

Returns the value of attribute default_availability.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 21

def default_availability
  @default_availability
end

#default_currencyObject

Returns the value of attribute default_currency.



23
24
25
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 23

def default_currency
  @default_currency
end

#formatObject

Returns the value of attribute format.



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 25

def format
  @format
end

#locationObject

The URL where a feed is available for download. This URL is what Pinterest will use to download a feed for processing.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 28

def location
  @location
end

#nameObject

A human-friendly name associated to a given feed.



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 31

def name
  @name
end

#preferred_processing_scheduleObject

Returns the value of attribute preferred_processing_schedule.



33
34
35
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 33

def preferred_processing_schedule
  @preferred_processing_schedule
end

#statusObject

Returns the value of attribute status.



35
36
37
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 35

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 60

def self.attribute_map
  {
    :'credentials' => :'credentials',
    :'default_availability' => :'default_availability',
    :'default_currency' => :'default_currency',
    :'format' => :'format',
    :'location' => :'location',
    :'name' => :'name',
    :'preferred_processing_schedule' => :'preferred_processing_schedule',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
104
105
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 98

def self.openapi_nullable
  Set.new([
    :'credentials',
    :'default_availability',
    :'default_currency',
    :'preferred_processing_schedule',
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 84

def self.openapi_types
  {
    :'credentials' => :'CatalogsFeedCredentials',
    :'default_availability' => :'ProductAvailabilityType',
    :'default_currency' => :'NullableCurrency',
    :'format' => :'CatalogsFormat',
    :'location' => :'String',
    :'name' => :'String',
    :'preferred_processing_schedule' => :'CatalogsFeedProcessingSchedule',
    :'status' => :'CatalogsStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      credentials == o.credentials &&
      default_availability == o.default_availability &&
      default_currency == o.default_currency &&
      format == o.format &&
      location == o.location &&
      name == o.name &&
      preferred_processing_schedule == o.preferred_processing_schedule &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 215

def hash
  [credentials, default_availability, default_currency, format, location, name, preferred_processing_schedule, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^(http|https|ftp|sftp):\/\//)
  if !@location.nil? && @location !~ pattern
    invalid_properties.push("invalid value for \"location\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
# File 'lib/pinterest_sdk/models/catalogs_feeds_update_request.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@location.nil? && @location !~ Regexp.new(/^(http|https|ftp|sftp):\/\//)
  true
end