Class: PinterestSdkClient::CatalogsHotelFeed

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/catalogs_hotel_feed.rb

Overview

Catalogs Hotel Feed object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsHotelFeed

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsHotelFeed` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsHotelFeed`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'catalog_id')
    self.catalog_id = attributes[:'catalog_id']
  else
    self.catalog_id = nil
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'credentials')
    self.credentials = attributes[:'credentials']
  end

  if attributes.key?(:'default_currency')
    self.default_currency = attributes[:'default_currency']
  end

  if attributes.key?(:'default_locale')
    self.default_locale = attributes[:'default_locale']
  else
    self.default_locale = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'preferred_processing_schedule')
    self.preferred_processing_schedule = attributes[:'preferred_processing_schedule']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#catalog_idObject

Catalog id pertaining to the feed. If not provided, feed will use a default catalog based on type.



20
21
22
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 20

def catalog_id
  @catalog_id
end

#catalog_typeObject

Returns the value of attribute catalog_type.



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 22

def catalog_type
  @catalog_type
end

#created_atObject

Returns the value of attribute created_at.



24
25
26
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 24

def created_at
  @created_at
end

#credentialsObject

Returns the value of attribute credentials.



26
27
28
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 26

def credentials
  @credentials
end

#default_currencyObject

Returns the value of attribute default_currency.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 28

def default_currency
  @default_currency
end

#default_localeObject

The locale used within a feed for product descriptions.



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 31

def default_locale
  @default_locale
end

#formatObject

Returns the value of attribute format.



33
34
35
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 33

def format
  @format
end

#idObject

ID of the feed entity.



36
37
38
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 36

def id
  @id
end

#locationObject

The URL where a feed is available for download. This URL is what Pinterest will use to download a feed for processing.



39
40
41
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 39

def location
  @location
end

#nameObject

A human-friendly name associated to a given feed. This value is currently nullable due to historical reasons. It is expected to become non-nullable in the future.



42
43
44
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 42

def name
  @name
end

#preferred_processing_scheduleObject

Returns the value of attribute preferred_processing_schedule.



44
45
46
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 44

def preferred_processing_schedule
  @preferred_processing_schedule
end

#statusObject

Returns the value of attribute status.



46
47
48
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 46

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



48
49
50
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 48

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 73

def self.attribute_map
  {
    :'catalog_id' => :'catalog_id',
    :'catalog_type' => :'catalog_type',
    :'created_at' => :'created_at',
    :'credentials' => :'credentials',
    :'default_currency' => :'default_currency',
    :'default_locale' => :'default_locale',
    :'format' => :'format',
    :'id' => :'id',
    :'location' => :'location',
    :'name' => :'name',
    :'preferred_processing_schedule' => :'preferred_processing_schedule',
    :'status' => :'status',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 431

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
129
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 121

def self.openapi_nullable
  Set.new([
    :'catalog_id',
    :'credentials',
    :'default_currency',
    :'name',
    :'preferred_processing_schedule',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 102

def self.openapi_types
  {
    :'catalog_id' => :'String',
    :'catalog_type' => :'String',
    :'created_at' => :'Time',
    :'credentials' => :'CatalogsFeedCredentials',
    :'default_currency' => :'NullableCurrency',
    :'default_locale' => :'String',
    :'format' => :'CatalogsFormat',
    :'id' => :'String',
    :'location' => :'String',
    :'name' => :'String',
    :'preferred_processing_schedule' => :'CatalogsFeedProcessingSchedule',
    :'status' => :'CatalogsStatus',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 398

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      catalog_id == o.catalog_id &&
      catalog_type == o.catalog_type &&
      created_at == o.created_at &&
      credentials == o.credentials &&
      default_currency == o.default_currency &&
      default_locale == o.default_locale &&
      format == o.format &&
      id == o.id &&
      location == o.location &&
      name == o.name &&
      preferred_processing_schedule == o.preferred_processing_schedule &&
      status == o.status &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


418
419
420
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 418

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



424
425
426
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 424

def hash
  [catalog_id, catalog_type, created_at, credentials, default_currency, default_locale, format, id, location, name, preferred_processing_schedule, status, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if @catalog_id !~ pattern
    invalid_properties.push("invalid value for \"catalog_id\", must conform to the pattern #{pattern}.")
  end

  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @default_locale.nil?
    invalid_properties.push('invalid value for "default_locale", default_locale cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  pattern = Regexp.new(/^(http|https|ftp|sftp):\/\//)
  if @location !~ pattern
    invalid_properties.push("invalid value for \"location\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 453

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/pinterest_sdk/models/catalogs_hotel_feed.rb', line 277

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @catalog_id !~ Regexp.new(/^\d+$/)
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["HOTEL"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @created_at.nil?
  return false if @default_locale.nil?
  return false if @format.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @location.nil?
  return false if @location !~ Regexp.new(/^(http|https|ftp|sftp):\/\//)
  return false if @status.nil?
  return false if @updated_at.nil?
  true
end