Class: PinterestSdkClient::CatalogsHotelProductGroup

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_hotel_product_group.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsHotelProductGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsHotelProductGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsHotelProductGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'catalog_id')
    self.catalog_id = attributes[:'catalog_id']
  else
    self.catalog_id = nil
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'filters')
    self.filters = attributes[:'filters']
  else
    self.filters = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#catalog_idObject

Catalog ID pertaining to the product group.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 19

def catalog_id
  @catalog_id
end

#catalog_typeObject

Returns the value of attribute catalog_type.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 21

def catalog_type
  @catalog_type
end

#created_atObject

Unix timestamp in seconds of when catalog product group was created.



24
25
26
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 24

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 26

def description
  @description
end

#filtersObject

Returns the value of attribute filters.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 28

def filters
  @filters
end

#idObject

ID of the catalog product group.



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 31

def id
  @id
end

#nameObject

Name of catalog product group



34
35
36
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 34

def name
  @name
end

#typeObject

Returns the value of attribute type.



36
37
38
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 36

def type
  @type
end

#updated_atObject

Unix timestamp in seconds of last time catalog product group was updated.



39
40
41
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 39

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 64

def self.attribute_map
  {
    :'catalog_id' => :'catalog_id',
    :'catalog_type' => :'catalog_type',
    :'created_at' => :'created_at',
    :'description' => :'description',
    :'filters' => :'filters',
    :'id' => :'id',
    :'name' => :'name',
    :'type' => :'type',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
108
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 104

def self.openapi_nullable
  Set.new([
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 89

def self.openapi_types
  {
    :'catalog_id' => :'String',
    :'catalog_type' => :'String',
    :'created_at' => :'Integer',
    :'description' => :'String',
    :'filters' => :'CatalogsHotelProductGroupFilters',
    :'id' => :'String',
    :'name' => :'String',
    :'type' => :'CatalogsHotelProductGroupType',
    :'updated_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      catalog_id == o.catalog_id &&
      catalog_type == o.catalog_type &&
      created_at == o.created_at &&
      description == o.description &&
      filters == o.filters &&
      id == o.id &&
      name == o.name &&
      type == o.type &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 311

def hash
  [catalog_id, catalog_type, created_at, description, filters, id, name, type, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @catalog_id.nil?
    invalid_properties.push('invalid value for "catalog_id", catalog_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @catalog_id !~ pattern
    invalid_properties.push("invalid value for \"catalog_id\", must conform to the pattern #{pattern}.")
  end

  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @filters.nil?
    invalid_properties.push('invalid value for "filters", filters cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @catalog_id.nil?
  return false if @catalog_id !~ Regexp.new(/^\d+$/)
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["HOTEL"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @filters.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @type.nil?
  true
end