Class: PinterestSdkClient::CatalogsHotelProductGroupProductCounts

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb

Overview

Product counts for a Hotel CatalogsProductGroup

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsHotelProductGroupProductCounts

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsHotelProductGroupProductCounts` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsHotelProductGroupProductCounts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end
end

Instance Attribute Details

#catalog_typeObject

Returns the value of attribute catalog_type.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 19

def catalog_type
  @catalog_type
end

#totalObject

Returns the value of attribute total.



21
22
23
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 21

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 46

def self.attribute_map
  {
    :'catalog_type' => :'catalog_type',
    :'total' => :'total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 64

def self.openapi_types
  {
    :'catalog_type' => :'String',
    :'total' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



164
165
166
167
168
169
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      catalog_type == o.catalog_type &&
      total == o.total
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


173
174
175
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



179
180
181
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 179

def hash
  [catalog_type, total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @total < 0
    invalid_properties.push('invalid value for "total", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



128
129
130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/catalogs_hotel_product_group_product_counts.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["HOTEL"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @total.nil?
  return false if @total < 0
  true
end