Class: PinterestSdkClient::CatalogsItemValidationDetails

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_item_validation_details.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsItemValidationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsItemValidationDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsItemValidationDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attribute_name')
    self.attribute_name = attributes[:'attribute_name']
  else
    self.attribute_name = nil
  end

  if attributes.key?(:'provided_value')
    self.provided_value = attributes[:'provided_value']
  else
    self.provided_value = nil
  end
end

Instance Attribute Details

#attribute_nameObject

Attribute that has a validation issue.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 19

def attribute_name
  @attribute_name
end

#provided_valueObject

Provided value that caused the validation issue.



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 22

def provided_value
  @provided_value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 47

def self.attribute_map
  {
    :'attribute_name' => :'attribute_name',
    :'provided_value' => :'provided_value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 73

def self.openapi_nullable
  Set.new([
    :'attribute_name',
    :'provided_value'
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 65

def self.openapi_types
  {
    :'attribute_name' => :'NullableCatalogsItemFieldType',
    :'provided_value' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attribute_name == o.attribute_name &&
      provided_value == o.provided_value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 141

def hash
  [attribute_name, provided_value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
# File 'lib/pinterest_sdk/models/catalogs_item_validation_details.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end