Class: PinterestSdkClient::CatalogsReportFeedIngestionStats

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsReportFeedIngestionStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsReportFeedIngestionStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsReportFeedIngestionStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'catalog_id')
    self.catalog_id = attributes[:'catalog_id']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'code_label')
    self.code_label = attributes[:'code_label']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'occurrences')
    self.occurrences = attributes[:'occurrences']
  end

  if attributes.key?(:'report_type')
    self.report_type = attributes[:'report_type']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end
end

Instance Attribute Details

#catalog_idObject

ID of the catalog entity.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 19

def catalog_id
  @catalog_id
end

#codeObject

The event code that a diagnostics aggregated number references



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 22

def code
  @code
end

#code_labelObject

A human-friendly label for the event code (e.g, 'AVAILABILITY_INVALID')



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 25

def code_label
  @code_label
end

#messageObject

Title message describing the diagnostic issue



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 28

def message
  @message
end

#occurrencesObject

Number of occurrences of the issue



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 31

def occurrences
  @occurrences
end

#report_typeObject

Returns the value of attribute report_type.



33
34
35
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 33

def report_type
  @report_type
end

#severityObject

An ERROR means that items have been dropped, while a WARN denotes that items have been ingested despite an issue



36
37
38
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 36

def severity
  @severity
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 61

def self.attribute_map
  {
    :'catalog_id' => :'catalog_id',
    :'code' => :'code',
    :'code_label' => :'code_label',
    :'message' => :'message',
    :'occurrences' => :'occurrences',
    :'report_type' => :'report_type',
    :'severity' => :'severity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 84

def self.openapi_types
  {
    :'catalog_id' => :'String',
    :'code' => :'Integer',
    :'code_label' => :'String',
    :'message' => :'String',
    :'occurrences' => :'Integer',
    :'report_type' => :'String',
    :'severity' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      catalog_id == o.catalog_id &&
      code == o.code &&
      code_label == o.code_label &&
      message == o.message &&
      occurrences == o.occurrences &&
      report_type == o.report_type &&
      severity == o.severity
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 229

def hash
  [catalog_id, code, code_label, message, occurrences, report_type, severity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@catalog_id.nil? && @catalog_id !~ pattern
    invalid_properties.push("invalid value for \"catalog_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
# File 'lib/pinterest_sdk/models/catalogs_report_feed_ingestion_stats.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@catalog_id.nil? && @catalog_id !~ Regexp.new(/^\d+$/)
  report_type_validator = EnumAttributeValidator.new('String', ["FEED_INGESTION_ISSUES"])
  return false unless report_type_validator.valid?(@report_type)
  severity_validator = EnumAttributeValidator.new('String', ["WARN", "ERROR"])
  return false unless severity_validator.valid?(@severity)
  true
end