Class: PinterestSdkClient::CatalogsRetailItemErrorResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb

Overview

Object describing a retail item error

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsRetailItemErrorResponse

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsRetailItemErrorResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsRetailItemErrorResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  else
    self.catalog_type = nil
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  else
    self.errors = nil
  end

  if attributes.key?(:'item_id')
    self.item_id = attributes[:'item_id']
  end

  if attributes.key?(:'item_response_kind')
    self.item_response_kind = attributes[:'item_response_kind']
  else
    self.item_response_kind = nil
  end
end

Instance Attribute Details

#catalog_typeObject

Returns the value of attribute catalog_type.



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 19

def catalog_type
  @catalog_type
end

#errorsObject

Array with the errors for the item id requested



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 22

def errors
  @errors
end

#item_idObject

The catalog item id in the merchant namespace



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 25

def item_id
  @item_id
end

#item_response_kindObject

Discriminator literal identifying this leaf inside an ItemResponse payload.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 28

def item_response_kind
  @item_response_kind
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 53

def self.attribute_map
  {
    :'catalog_type' => :'catalog_type',
    :'errors' => :'errors',
    :'item_id' => :'item_id',
    :'item_response_kind' => :'item_response_kind'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 73

def self.openapi_types
  {
    :'catalog_type' => :'String',
    :'errors' => :'Array<ItemValidationEvent>',
    :'item_id' => :'String',
    :'item_response_kind' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



195
196
197
198
199
200
201
202
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      catalog_type == o.catalog_type &&
      errors == o.errors &&
      item_id == o.item_id &&
      item_response_kind == o.item_response_kind
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


206
207
208
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



212
213
214
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 212

def hash
  [catalog_type, errors, item_id, item_response_kind].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @catalog_type.nil?
    invalid_properties.push('invalid value for "catalog_type", catalog_type cannot be nil.')
  end

  if @errors.nil?
    invalid_properties.push('invalid value for "errors", errors cannot be nil.')
  end

  if @item_response_kind.nil?
    invalid_properties.push('invalid value for "item_response_kind", item_response_kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/pinterest_sdk/models/catalogs_retail_item_error_response.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @catalog_type.nil?
  catalog_type_validator = EnumAttributeValidator.new('String', ["RETAIL"])
  return false unless catalog_type_validator.valid?(@catalog_type)
  return false if @errors.nil?
  return false if @item_response_kind.nil?
  item_response_kind_validator = EnumAttributeValidator.new('String', ["retail_item_error"])
  return false unless item_response_kind_validator.valid?(@item_response_kind)
  true
end