Class: PinterestSdkClient::CatalogsUpdatableHotelAttributes

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsUpdatableHotelAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsUpdatableHotelAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsUpdatableHotelAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'base_price')
    self.base_price = attributes[:'base_price']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'custom_label_0')
    self.custom_label_0 = attributes[:'custom_label_0']
  end

  if attributes.key?(:'custom_label_1')
    self.custom_label_1 = attributes[:'custom_label_1']
  end

  if attributes.key?(:'custom_label_2')
    self.custom_label_2 = attributes[:'custom_label_2']
  end

  if attributes.key?(:'custom_label_3')
    self.custom_label_3 = attributes[:'custom_label_3']
  end

  if attributes.key?(:'custom_label_4')
    self.custom_label_4 = attributes[:'custom_label_4']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'guest_ratings')
    self.guest_ratings = attributes[:'guest_ratings']
  end

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'neighborhood')
    if (value = attributes[:'neighborhood']).is_a?(Array)
      self.neighborhood = value
    end
  end

  if attributes.key?(:'sale_price')
    self.sale_price = attributes[:'sale_price']
  end
end

Instance Attribute Details

#addressObject

Hotel address



19
20
21
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 19

def address
  @address
end

#base_priceObject

Base price of the hotel room per night followed by the ISO currency code



22
23
24
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 22

def base_price
  @base_price
end

#brandObject

The brand to which this hotel belongs to.



25
26
27
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 25

def brand
  @brand
end

#categoryObject

The type of property. The category can be any type of internal description desired.



28
29
30
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 28

def category
  @category
end

#custom_label_0Object

Custom grouping of hotels



31
32
33
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 31

def custom_label_0
  @custom_label_0
end

#custom_label_1Object

Custom grouping of hotels



34
35
36
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 34

def custom_label_1
  @custom_label_1
end

#custom_label_2Object

Custom grouping of hotels



37
38
39
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 37

def custom_label_2
  @custom_label_2
end

#custom_label_3Object

Custom grouping of hotels



40
41
42
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 40

def custom_label_3
  @custom_label_3
end

#custom_label_4Object

Custom grouping of hotels



43
44
45
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 43

def custom_label_4
  @custom_label_4
end

#descriptionObject

Brief description of the hotel.



46
47
48
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 46

def description
  @description
end

#guest_ratingsObject

If specified, you must provide all properties



49
50
51
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 49

def guest_ratings
  @guest_ratings
end

#latitudeObject

Latitude of the hotel.



52
53
54
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 52

def latitude
  @latitude
end

Link to the product page



55
56
57
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 55

def link
  @link
end

#longitudeObject

Longitude of the hotel.



58
59
60
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 58

def longitude
  @longitude
end

#nameObject

The hotel's name.



61
62
63
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 61

def name
  @name
end

#neighborhoodObject

A list of neighborhoods where the hotel is located



64
65
66
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 64

def neighborhood
  @neighborhood
end

#sale_priceObject

Sale price of a hotel room per night. Used to advertise discounts off the regular price of the hotel.



67
68
69
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 67

def sale_price
  @sale_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 70

def self.attribute_map
  {
    :'address' => :'address',
    :'base_price' => :'base_price',
    :'brand' => :'brand',
    :'category' => :'category',
    :'custom_label_0' => :'custom_label_0',
    :'custom_label_1' => :'custom_label_1',
    :'custom_label_2' => :'custom_label_2',
    :'custom_label_3' => :'custom_label_3',
    :'custom_label_4' => :'custom_label_4',
    :'description' => :'description',
    :'guest_ratings' => :'guest_ratings',
    :'latitude' => :'latitude',
    :'link' => :'link',
    :'longitude' => :'longitude',
    :'name' => :'name',
    :'neighborhood' => :'neighborhood',
    :'sale_price' => :'sale_price'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 126

def self.openapi_nullable
  Set.new([
    :'base_price',
    :'brand',
    :'category',
    :'custom_label_0',
    :'custom_label_1',
    :'custom_label_2',
    :'custom_label_3',
    :'custom_label_4',
    :'description',
    :'link',
    :'longitude',
    :'name',
    :'neighborhood',
    :'sale_price'
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 103

def self.openapi_types
  {
    :'address' => :'CatalogsHotelAddress',
    :'base_price' => :'String',
    :'brand' => :'String',
    :'category' => :'String',
    :'custom_label_0' => :'String',
    :'custom_label_1' => :'String',
    :'custom_label_2' => :'String',
    :'custom_label_3' => :'String',
    :'custom_label_4' => :'String',
    :'description' => :'String',
    :'guest_ratings' => :'CatalogsHotelGuestRatings',
    :'latitude' => :'Float',
    :'link' => :'String',
    :'longitude' => :'Float',
    :'name' => :'String',
    :'neighborhood' => :'Array<String>',
    :'sale_price' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address == o.address &&
      base_price == o.base_price &&
      brand == o.brand &&
      category == o.category &&
      custom_label_0 == o.custom_label_0 &&
      custom_label_1 == o.custom_label_1 &&
      custom_label_2 == o.custom_label_2 &&
      custom_label_3 == o.custom_label_3 &&
      custom_label_4 == o.custom_label_4 &&
      description == o.description &&
      guest_ratings == o.guest_ratings &&
      latitude == o.latitude &&
      link == o.link &&
      longitude == o.longitude &&
      name == o.name &&
      neighborhood == o.neighborhood &&
      sale_price == o.sale_price
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 279

def hash
  [address, base_price, brand, category, custom_label_0, custom_label_1, custom_label_2, custom_label_3, custom_label_4, description, guest_ratings, latitude, link, longitude, name, neighborhood, sale_price].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
245
# File 'lib/pinterest_sdk/models/catalogs_updatable_hotel_attributes.rb', line 242

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end