Class: PinterestSdkClient::ConversionDeletionRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/conversion_deletion_request.rb

Overview

Conversion deletion request

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConversionDeletionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ConversionDeletionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ConversionDeletionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  else
    self.created_time = nil
  end

  if attributes.key?(:'processed_time')
    self.processed_time = attributes[:'processed_time']
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  else
    self.request_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#created_timeObject

Timestamp when the conversion deletion request was succesfully created.



20
21
22
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 20

def created_time
  @created_time
end

#processed_timeObject

Timestamp when the conversion deletion request was processed.



23
24
25
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 23

def processed_time
  @processed_time
end

#request_idObject

Unique identifier of the conversion deletion request



26
27
28
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 26

def request_id
  @request_id
end

#statusObject

Represents the status of the conversion deletion request. "PENDING" or "SUBMITTED". "PENDING" meaning the Advertiser can cancel the request. The advertiser has a 7 day time window after the conversion deletion request was submitted to cancel it. "SUBMITTED" meaning that the Data Deletion process has begun and can no longer be canceled.



29
30
31
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 29

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 54

def self.attribute_map
  {
    :'created_time' => :'created_time',
    :'processed_time' => :'processed_time',
    :'request_id' => :'request_id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
88
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 84

def self.openapi_nullable
  Set.new([
    :'processed_time',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 74

def self.openapi_types
  {
    :'created_time' => :'Date',
    :'processed_time' => :'Date',
    :'request_id' => :'String',
    :'status' => :'ConversionDeletionRequestStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_time == o.created_time &&
      processed_time == o.processed_time &&
      request_id == o.request_id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 228

def hash
  [created_time, processed_time, request_id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @request_id.nil?
    invalid_properties.push('invalid value for "request_id", request_id cannot be nil.')
  end

  if @request_id.to_s.length > 18
    invalid_properties.push('invalid value for "request_id", the character length must be smaller than or equal to 18.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @request_id !~ pattern
    invalid_properties.push("invalid value for \"request_id\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
168
# File 'lib/pinterest_sdk/models/conversion_deletion_request.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_time.nil?
  return false if @request_id.nil?
  return false if @request_id.to_s.length > 18
  return false if @request_id !~ Regexp.new(/^\d+$/)
  return false if @status.nil?
  true
end