Class: PinterestSdkClient::ConversionEqsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/conversion_eqs_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ConversionEqsApi

Returns a new instance of ConversionEqsApi.



19
20
21
# File 'lib/pinterest_sdk/api/conversion_eqs_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/conversion_eqs_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#conversion_eqs_list(lookback_period, ad_account_id, opts = {}) ⇒ Array<EventQualityScore>

Get event quality score (EQS) Get the Event Quality Score (EQS) of your conversion signals. Event Quality Score indicates how effective the customer information and event insights (metadata) passed with your web, app and offline conversion events may be at matching to a Pinterest user.

Parameters:

  • lookback_period (LookbackPeriodOptions)

    Lookback window (number of days).

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



30
31
32
33
# File 'lib/pinterest_sdk/api/conversion_eqs_api.rb', line 30

def conversion_eqs_list(lookback_period, , opts = {})
  data, _status_code, _headers = conversion_eqs_list_with_http_info(lookback_period, , opts)
  data
end

#conversion_eqs_list_with_http_info(lookback_period, ad_account_id, opts = {}) ⇒ Array<(Array<EventQualityScore>, Integer, Hash)>

Get event quality score (EQS) Get the Event Quality Score (EQS) of your conversion signals. Event Quality Score indicates how effective the customer information and event insights (metadata) passed with your web, app and offline conversion events may be at matching to a Pinterest user.

Parameters:

  • lookback_period (LookbackPeriodOptions)

    Lookback window (number of days).

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(Array<EventQualityScore>, Integer, Hash)>)

    Array data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/pinterest_sdk/api/conversion_eqs_api.rb', line 43

def conversion_eqs_list_with_http_info(lookback_period, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ConversionEqsApi.conversion_eqs_list ...'
  end
  # verify the required parameter 'lookback_period' is set
  if @api_client.config.client_side_validation && lookback_period.nil?
    fail ArgumentError, "Missing the required parameter 'lookback_period' when calling ConversionEqsApi.conversion_eqs_list"
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ConversionEqsApi.conversion_eqs_list"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling ConversionEqsApi.conversion_eqs_list, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling ConversionEqsApi.conversion_eqs_list, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/conversion_eqs'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'lookback_period'] = lookback_period
  query_params[:'source_platform'] = opts[:'source_platform'] if !opts[:'source_platform'].nil?
  query_params[:'ingestion_source'] = opts[:'ingestion_source'] if !opts[:'ingestion_source'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<EventQualityScore>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials']

  new_options = opts.merge(
    :operation => :"ConversionEqsApi.conversion_eqs_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ConversionEqsApi#conversion_eqs_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end