Class: PinterestSdkClient::ConversionEventsDataItemsCustomDataContentsItems

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConversionEventsDataItemsCustomDataContentsItems

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ConversionEventsDataItemsCustomDataContentsItems` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ConversionEventsDataItemsCustomDataContentsItems`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'item_brand')
    self.item_brand = attributes[:'item_brand']
  end

  if attributes.key?(:'item_brand_id')
    self.item_brand_id = attributes[:'item_brand_id']
  end

  if attributes.key?(:'item_category')
    self.item_category = attributes[:'item_category']
  end

  if attributes.key?(:'item_name')
    self.item_name = attributes[:'item_name']
  end

  if attributes.key?(:'item_price')
    self.item_price = attributes[:'item_price']
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  end
end

Instance Attribute Details

#idObject

The id of a product. We recommend using this if you are a merchant for AddToCart and Checkouts. For detail, please check here (Install the Pinterest tag section).



19
20
21
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 19

def id
  @id
end

#item_brandObject

The brand of a product.



22
23
24
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 22

def item_brand
  @item_brand
end

#item_brand_idObject

The brand ID of a product.



25
26
27
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 25

def item_brand_id
  @item_brand_id
end

#item_categoryObject

The category of a product.



28
29
30
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 28

def item_category
  @item_category
end

#item_nameObject

The name of a product.



31
32
33
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 31

def item_name
  @item_name
end

#item_priceObject

The price of a product. Accepted as a string in the request; it will be parsed into a double. This is the original item value before any discount. We recommend using this if you are a merchant for PageVisit, AddToCart and Checkouts. For detail, please check here (Install the Pinterest tag section).



34
35
36
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 34

def item_price
  @item_price
end

#quantityObject

The amount of a product. We recommend using this if you are a merchant for AddToCart and Checkouts. For detail, please check here (Install the Pinterest tag section).



37
38
39
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 37

def quantity
  @quantity
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'item_brand' => :'item_brand',
    :'item_brand_id' => :'item_brand_id',
    :'item_category' => :'item_category',
    :'item_name' => :'item_name',
    :'item_price' => :'item_price',
    :'quantity' => :'quantity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'item_brand' => :'String',
    :'item_brand_id' => :'String',
    :'item_category' => :'String',
    :'item_name' => :'String',
    :'item_price' => :'String',
    :'quantity' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      item_brand == o.item_brand &&
      item_brand_id == o.item_brand_id &&
      item_category == o.item_category &&
      item_name == o.item_name &&
      item_price == o.item_price &&
      quantity == o.quantity
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 182

def hash
  [id, item_brand, item_brand_id, item_category, item_name, item_price, quantity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@item_brand_id.nil? && @item_brand_id.to_s.length > 64
    invalid_properties.push('invalid value for "item_brand_id", the character length must be smaller than or equal to 64.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
# File 'lib/pinterest_sdk/models/conversion_events_data_items_custom_data_contents_items.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@item_brand_id.nil? && @item_brand_id.to_s.length > 64
  true
end