Class: PinterestSdkClient::ConversionProductReport
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ConversionProductReport
- Defined in:
- lib/pinterest_sdk/models/conversion_product_report.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#message ⇒ Object
Message returned from the create report request.
-
#report_status ⇒ Object
Async report status.
-
#size ⇒ Object
Size of the report in bytes.
-
#token ⇒ Object
Token returned from the create report request.
-
#url ⇒ Object
URL of the report.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversionProductReport
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConversionProductReport
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ConversionProductReport` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ConversionProductReport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'report_status') self.report_status = attributes[:'report_status'] end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#message ⇒ Object
Message returned from the create report request
19 20 21 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 19 def end |
#report_status ⇒ Object
Async report status
22 23 24 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 22 def report_status @report_status end |
#size ⇒ Object
Size of the report in bytes
25 26 27 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 25 def size @size end |
#token ⇒ Object
Token returned from the create report request
28 29 30 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 28 def token @token end |
#url ⇒ Object
URL of the report
31 32 33 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 31 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 56 def self.attribute_map { :'message' => :'message', :'report_status' => :'report_status', :'size' => :'size', :'token' => :'token', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 77 def self.openapi_types { :'message' => :'String', :'report_status' => :'BulkReportingJobStatus', :'size' => :'Float', :'token' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && report_status == o.report_status && size == o.size && token == o.token && url == o.url end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 165 def hash [, report_status, size, token, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 |
# File 'lib/pinterest_sdk/models/conversion_product_report.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |