Class: PinterestSdkClient::ConversionTagV3GoalMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ConversionTagV3GoalMetadata
- Defined in:
- lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attribution_windows ⇒ Object
Returns the value of attribute attribution_windows.
-
#conversion_event ⇒ Object
Returns the value of attribute conversion_event.
-
#conversion_tag_id ⇒ Object
Returns the value of attribute conversion_tag_id.
-
#cpa_goal_value_in_micro_currency ⇒ Object
Returns the value of attribute cpa_goal_value_in_micro_currency.
-
#is_roas_optimized ⇒ Object
Pinterest Performance+ ROAS bidding.
-
#reporting_event ⇒ Object
Event name for custom or standard events mapped to an oCPM model.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversionTagV3GoalMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConversionTagV3GoalMetadata
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ConversionTagV3GoalMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ConversionTagV3GoalMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attribution_windows') self.attribution_windows = attributes[:'attribution_windows'] end if attributes.key?(:'conversion_event') self.conversion_event = attributes[:'conversion_event'] end if attributes.key?(:'conversion_tag_id') self.conversion_tag_id = attributes[:'conversion_tag_id'] end if attributes.key?(:'cpa_goal_value_in_micro_currency') self.cpa_goal_value_in_micro_currency = attributes[:'cpa_goal_value_in_micro_currency'] end if attributes.key?(:'is_roas_optimized') self.is_roas_optimized = attributes[:'is_roas_optimized'] end if attributes.key?(:'reporting_event') self.reporting_event = attributes[:'reporting_event'] end end |
Instance Attribute Details
#attribution_windows ⇒ Object
Returns the value of attribute attribution_windows.
18 19 20 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 18 def attribution_windows @attribution_windows end |
#conversion_event ⇒ Object
Returns the value of attribute conversion_event.
20 21 22 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 20 def conversion_event @conversion_event end |
#conversion_tag_id ⇒ Object
Returns the value of attribute conversion_tag_id.
22 23 24 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 22 def conversion_tag_id @conversion_tag_id end |
#cpa_goal_value_in_micro_currency ⇒ Object
Returns the value of attribute cpa_goal_value_in_micro_currency.
24 25 26 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 24 def cpa_goal_value_in_micro_currency @cpa_goal_value_in_micro_currency end |
#is_roas_optimized ⇒ Object
Pinterest Performance+ ROAS bidding. When enabled, Pinterest will optimize for conversion value instead of conversion volume. Only supported when conversion_event is set to \"CHECKOUT\" and bid_strategy_type is set to \"AUTOMATIC_BID\". This parameter is not enabled for all advertisers. Learn more.
27 28 29 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 27 def is_roas_optimized @is_roas_optimized end |
#reporting_event ⇒ Object
Event name for custom or standard events mapped to an oCPM model
30 31 32 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 30 def reporting_event @reporting_event end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 55 def self.attribute_map { :'attribution_windows' => :'attribution_windows', :'conversion_event' => :'conversion_event', :'conversion_tag_id' => :'conversion_tag_id', :'cpa_goal_value_in_micro_currency' => :'cpa_goal_value_in_micro_currency', :'is_roas_optimized' => :'is_roas_optimized', :'reporting_event' => :'reporting_event' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 221 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 89 def self.openapi_nullable Set.new([ :'is_roas_optimized', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 77 def self.openapi_types { :'attribution_windows' => :'AttributionWindows', :'conversion_event' => :'ConversionEvent', :'conversion_tag_id' => :'String', :'cpa_goal_value_in_micro_currency' => :'String', :'is_roas_optimized' => :'Boolean', :'reporting_event' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && attribution_windows == o.attribution_windows && conversion_event == o.conversion_event && conversion_tag_id == o.conversion_tag_id && cpa_goal_value_in_micro_currency == o.cpa_goal_value_in_micro_currency && is_roas_optimized == o.is_roas_optimized && reporting_event == o.reporting_event end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 214 def hash [attribution_windows, conversion_event, conversion_tag_id, cpa_goal_value_in_micro_currency, is_roas_optimized, reporting_event].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@conversion_tag_id.nil? && @conversion_tag_id !~ pattern invalid_properties.push("invalid value for \"conversion_tag_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@cpa_goal_value_in_micro_currency.nil? && @cpa_goal_value_in_micro_currency !~ pattern invalid_properties.push("invalid value for \"cpa_goal_value_in_micro_currency\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 |
# File 'lib/pinterest_sdk/models/conversion_tag_v3_goal_metadata.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@conversion_tag_id.nil? && @conversion_tag_id !~ Regexp.new(/^\d+$/) return false if !@cpa_goal_value_in_micro_currency.nil? && @cpa_goal_value_in_micro_currency !~ Regexp.new(/^\d+$/) true end |