Class: PinterestSdkClient::CreateMembershipOrPartnershipInvitesBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CreateMembershipOrPartnershipInvitesBody
- Defined in:
- lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb
Overview
Body to be used on path to send Members or Partners Invite or Request
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#business_role ⇒ Object
Returns the value of attribute business_role.
-
#invite_type ⇒ Object
Returns the value of attribute invite_type.
-
#members ⇒ Object
A list of usernames, emails, or a mix of them.
-
#partners ⇒ Object
A list of partner_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMembershipOrPartnershipInvitesBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateMembershipOrPartnershipInvitesBody
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CreateMembershipOrPartnershipInvitesBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CreateMembershipOrPartnershipInvitesBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'business_role') self.business_role = attributes[:'business_role'] else self.business_role = nil end if attributes.key?(:'invite_type') self.invite_type = attributes[:'invite_type'] else self.invite_type = nil end if attributes.key?(:'members') if (value = attributes[:'members']).is_a?(Array) self.members = value end end if attributes.key?(:'partners') if (value = attributes[:'partners']).is_a?(Array) self.partners = value end end end |
Instance Attribute Details
#business_role ⇒ Object
Returns the value of attribute business_role.
19 20 21 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 19 def business_role @business_role end |
#invite_type ⇒ Object
Returns the value of attribute invite_type.
21 22 23 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 21 def invite_type @invite_type end |
#members ⇒ Object
A list of usernames, emails, or a mix of them. Should be used if invite_type is MEMBER_INVITE
24 25 26 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 24 def members @members end |
#partners ⇒ Object
A list of partner_id. Should be used if invite_type is PARTNER_INVITE or PARTNER_REQUEST
27 28 29 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 27 def partners @partners end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 52 def self.attribute_map { :'business_role' => :'business_role', :'invite_type' => :'invite_type', :'members' => :'members', :'partners' => :'partners' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 72 def self.openapi_types { :'business_role' => :'BusinessRoleForInvite', :'invite_type' => :'InviteType', :'members' => :'Array<String>', :'partners' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && business_role == o.business_role && invite_type == o.invite_type && members == o.members && partners == o.partners end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 248 def hash [business_role, invite_type, members, partners].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @business_role.nil? invalid_properties.push('invalid value for "business_role", business_role cannot be nil.') end if @invite_type.nil? invalid_properties.push('invalid value for "invite_type", invite_type cannot be nil.') end if !@members.nil? && @members.length > 50 invalid_properties.push('invalid value for "members", number of items must be less than or equal to 50.') end if !@members.nil? && @members.length < 1 invalid_properties.push('invalid value for "members", number of items must be greater than or equal to 1.') end if !@partners.nil? && @partners.length > 50 invalid_properties.push('invalid value for "partners", number of items must be less than or equal to 50.') end if !@partners.nil? && @partners.length < 1 invalid_properties.push('invalid value for "partners", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/pinterest_sdk/models/create_membership_or_partnership_invites_body.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @business_role.nil? return false if @invite_type.nil? return false if !@members.nil? && @members.length > 50 return false if !@members.nil? && @members.length < 1 return false if !@partners.nil? && @partners.length > 50 return false if !@partners.nil? && @partners.length < 1 true end |