Class: PinterestSdkClient::CustomerList

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/customer_list.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerList

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/pinterest_sdk/models/customer_list.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CustomerList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CustomerList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'exceptions')
    self.exceptions = attributes[:'exceptions']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'is_nca')
    self.is_nca = attributes[:'is_nca']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'num_batches')
    self.num_batches = attributes[:'num_batches']
  end

  if attributes.key?(:'num_removed_user_records')
    self.num_removed_user_records = attributes[:'num_removed_user_records']
  end

  if attributes.key?(:'num_uploaded_user_records')
    self.num_uploaded_user_records = attributes[:'num_uploaded_user_records']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end
end

Instance Attribute Details

#ad_account_idObject

Associated ad account ID.



19
20
21
# File 'lib/pinterest_sdk/models/customer_list.rb', line 19

def 
  
end

#created_timeObject

Creation time. Unix timestamp in seconds.



22
23
24
# File 'lib/pinterest_sdk/models/customer_list.rb', line 22

def created_time
  @created_time
end

#exceptionsObject

Customer list errors.



25
26
27
# File 'lib/pinterest_sdk/models/customer_list.rb', line 25

def exceptions
  @exceptions
end

#idObject

Customer list ID.



28
29
30
# File 'lib/pinterest_sdk/models/customer_list.rb', line 28

def id
  @id
end

#is_ncaObject

Whether the list was uploaded for new customer acquisition (expanded matching). Immutable after creation.



31
32
33
# File 'lib/pinterest_sdk/models/customer_list.rb', line 31

def is_nca
  @is_nca
end

#nameObject

Customer list name.



34
35
36
# File 'lib/pinterest_sdk/models/customer_list.rb', line 34

def name
  @name
end

#num_batchesObject

Total number of list updates. List creation counts as one batch. Each Append or Remove API call counts as another. List creation via the Ads Manager UI could result in more than one batch since the UI breaks up large lists.



37
38
39
# File 'lib/pinterest_sdk/models/customer_list.rb', line 37

def num_batches
  @num_batches
end

#num_removed_user_recordsObject

Number of removed user records. In a Remove API call, this counter increases even if the user is not found in the list.



40
41
42
# File 'lib/pinterest_sdk/models/customer_list.rb', line 40

def num_removed_user_records
  @num_removed_user_records
end

#num_uploaded_user_recordsObject

Number of uploaded user records. In an Append API call, this counter increases even if the uploaded user is already in the list.



43
44
45
# File 'lib/pinterest_sdk/models/customer_list.rb', line 43

def num_uploaded_user_records
  @num_uploaded_user_records
end

#statusObject

Customer list status. TOO_SMALL means the list has fewer than 100 Pinterest users.



46
47
48
# File 'lib/pinterest_sdk/models/customer_list.rb', line 46

def status
  @status
end

#typeObject

Always customerlist.



49
50
51
# File 'lib/pinterest_sdk/models/customer_list.rb', line 49

def type
  @type
end

#updated_timeObject

Last update time. Unix timestamp in seconds.



52
53
54
# File 'lib/pinterest_sdk/models/customer_list.rb', line 52

def updated_time
  @updated_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/pinterest_sdk/models/customer_list.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/pinterest_sdk/models/customer_list.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pinterest_sdk/models/customer_list.rb', line 77

def self.attribute_map
  {
    :'ad_account_id' => :'ad_account_id',
    :'created_time' => :'created_time',
    :'exceptions' => :'exceptions',
    :'id' => :'id',
    :'is_nca' => :'is_nca',
    :'name' => :'name',
    :'num_batches' => :'num_batches',
    :'num_removed_user_records' => :'num_removed_user_records',
    :'num_uploaded_user_records' => :'num_uploaded_user_records',
    :'status' => :'status',
    :'type' => :'type',
    :'updated_time' => :'updated_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/pinterest_sdk/models/customer_list.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/pinterest_sdk/models/customer_list.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/pinterest_sdk/models/customer_list.rb', line 105

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'created_time' => :'Float',
    :'exceptions' => :'Object',
    :'id' => :'String',
    :'is_nca' => :'Boolean',
    :'name' => :'String',
    :'num_batches' => :'Float',
    :'num_removed_user_records' => :'Float',
    :'num_uploaded_user_records' => :'Float',
    :'status' => :'CustomerListStatus',
    :'type' => :'String',
    :'updated_time' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/pinterest_sdk/models/customer_list.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      created_time == o.created_time &&
      exceptions == o.exceptions &&
      id == o.id &&
      is_nca == o.is_nca &&
      name == o.name &&
      num_batches == o.num_batches &&
      num_removed_user_records == o.num_removed_user_records &&
      num_uploaded_user_records == o.num_uploaded_user_records &&
      status == o.status &&
      type == o.type &&
      updated_time == o.updated_time
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


283
284
285
# File 'lib/pinterest_sdk/models/customer_list.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



289
290
291
# File 'lib/pinterest_sdk/models/customer_list.rb', line 289

def hash
  [, created_time, exceptions, id, is_nca, name, num_batches, num_removed_user_records, num_uploaded_user_records, status, type, updated_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/pinterest_sdk/models/customer_list.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 18
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 18.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/pinterest_sdk/models/customer_list.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



224
225
226
227
228
229
230
231
# File 'lib/pinterest_sdk/models/customer_list.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id.to_s.length > 18
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @name.nil?
  true
end