Class: PinterestSdkClient::CustomerListCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CustomerListCreate
- Defined in:
- lib/pinterest_sdk/models/customer_list_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#is_nca ⇒ Object
Whether the list was uploaded for new customer acquisition (expanded matching).
-
#list_type ⇒ Object
Type of customer list (e.g., EMAIL, IDFA, MAID).
-
#name ⇒ Object
Customer list name.
-
#records ⇒ Object
Records list.
-
#records_v2 ⇒ Object
Multi-field record format.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerListCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerListCreate
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CustomerListCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CustomerListCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_nca') self.is_nca = attributes[:'is_nca'] end if attributes.key?(:'list_type') self.list_type = attributes[:'list_type'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'records') self.records = attributes[:'records'] end if attributes.key?(:'records_v2') if (value = attributes[:'records_v2']).is_a?(Array) self.records_v2 = value end end end |
Instance Attribute Details
#is_nca ⇒ Object
Whether the list was uploaded for new customer acquisition (expanded matching). Immutable after creation.
20 21 22 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 20 def is_nca @is_nca end |
#list_type ⇒ Object
Type of customer list (e.g., EMAIL, IDFA, MAID).
23 24 25 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 23 def list_type @list_type end |
#name ⇒ Object
Customer list name.
26 27 28 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 26 def name @name end |
#records ⇒ Object
Records list. Can be any combination of emails, MAIDs, or IDFAs. Emails must be lowercase and can be plain text or hashed using SHA1, SHA256, or MD5. MAIDs and IDFAs must be hashed with SHA1, SHA256, or MD5.
29 30 31 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 29 def records @records end |
#records_v2 ⇒ Object
Multi-field record format. Array of objects with optional email, maid, ip_address, user_agent, external_id, hashed_pinner_id, hashed_phone_number, and liveramp_envelope per row. Provide exactly one of records or records_v2.
32 33 34 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 32 def records_v2 @records_v2 end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 57 def self.attribute_map { :'is_nca' => :'is_nca', :'list_type' => :'list_type', :'name' => :'name', :'records' => :'records', :'records_v2' => :'records_v2' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 192 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 78 def self.openapi_types { :'is_nca' => :'Boolean', :'list_type' => :'UserListType', :'name' => :'String', :'records' => :'String', :'records_v2' => :'Array<CustomerListRecordRow>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && is_nca == o.is_nca && list_type == o.list_type && name == o.name && records == o.records && records_v2 == o.records_v2 end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 185 def hash [is_nca, list_type, name, records, records_v2].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/customer_list_create.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |