Class: PinterestSdkClient::CustomerListRecordRow

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/customer_list_record_row.rb

Overview

A single row in a multi-field customer list (v2 format).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerListRecordRow

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CustomerListRecordRow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CustomerListRecordRow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'hashed_phone_number')
    self.hashed_phone_number = attributes[:'hashed_phone_number']
  end

  if attributes.key?(:'hashed_pinner_id')
    self.hashed_pinner_id = attributes[:'hashed_pinner_id']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'liveramp_envelope')
    self.liveramp_envelope = attributes[:'liveramp_envelope']
  end

  if attributes.key?(:'maid')
    self.maid = attributes[:'maid']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end
end

Instance Attribute Details

#emailObject

Email address (plain or hashed with SHA1, SHA256, or MD5).



20
21
22
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 20

def email
  @email
end

#external_idObject

External ID identifier (not hashed).



23
24
25
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 23

def external_id
  @external_id
end

#hashed_phone_numberObject

Hashed phone number (hashed with SHA1, SHA256, or MD5).



26
27
28
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 26

def hashed_phone_number
  @hashed_phone_number
end

#hashed_pinner_idObject

Hashed pinner ID (hashed with SHA1, SHA256, or MD5).



29
30
31
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 29

def hashed_pinner_id
  @hashed_pinner_id
end

#ip_addressObject

IP address (not hashed).



32
33
34
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 32

def ip_address
  @ip_address
end

#liveramp_envelopeObject

LiveRamp envelope identifier (Base64-encoded, not hashed).



35
36
37
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 35

def liveramp_envelope
  @liveramp_envelope
end

#maidObject

Mobile advertising ID (plain or hashed with SHA1, SHA256, or MD5).



38
39
40
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 38

def maid
  @maid
end

#user_agentObject

User agent string (not hashed).



41
42
43
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 41

def user_agent
  @user_agent
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 44

def self.attribute_map
  {
    :'email' => :'email',
    :'external_id' => :'external_id',
    :'hashed_phone_number' => :'hashed_phone_number',
    :'hashed_pinner_id' => :'hashed_pinner_id',
    :'ip_address' => :'ip_address',
    :'liveramp_envelope' => :'liveramp_envelope',
    :'maid' => :'maid',
    :'user_agent' => :'user_agent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 68

def self.openapi_types
  {
    :'email' => :'String',
    :'external_id' => :'String',
    :'hashed_phone_number' => :'String',
    :'hashed_pinner_id' => :'String',
    :'ip_address' => :'String',
    :'liveramp_envelope' => :'String',
    :'maid' => :'String',
    :'user_agent' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      external_id == o.external_id &&
      hashed_phone_number == o.hashed_phone_number &&
      hashed_pinner_id == o.hashed_pinner_id &&
      ip_address == o.ip_address &&
      liveramp_envelope == o.liveramp_envelope &&
      maid == o.maid &&
      user_agent == o.user_agent
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


168
169
170
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



174
175
176
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 174

def hash
  [email, external_id, hashed_phone_number, hashed_pinner_id, ip_address, liveramp_envelope, maid, user_agent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



146
147
148
149
# File 'lib/pinterest_sdk/models/customer_list_record_row.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end