Class: PinterestSdkClient::CustomerListUpdateWithRequiredBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CustomerListUpdateWithRequiredBody
- Defined in:
- lib/pinterest_sdk/models/customer_list_update_with_required_body.rb
Overview
Resource create or update operation model with required body fields (no OptionalProperties).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#operation_type ⇒ Object
Customer list update operation type (add or remove).
-
#records ⇒ Object
Records list.
-
#records_v2 ⇒ Object
Multi-field record format.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerListUpdateWithRequiredBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerListUpdateWithRequiredBody
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CustomerListUpdateWithRequiredBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CustomerListUpdateWithRequiredBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] else self.operation_type = nil end if attributes.key?(:'records') self.records = attributes[:'records'] end if attributes.key?(:'records_v2') if (value = attributes[:'records_v2']).is_a?(Array) self.records_v2 = value end end end |
Instance Attribute Details
#operation_type ⇒ Object
Customer list update operation type (add or remove). Only valid in update request body.
20 21 22 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 20 def operation_type @operation_type end |
#records ⇒ Object
Records list. Can be any combination of emails, MAIDs, or IDFAs. Emails must be lowercase and can be plain text or hashed using SHA1, SHA256, or MD5. MAIDs and IDFAs must be hashed with SHA1, SHA256, or MD5.
23 24 25 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 23 def records @records end |
#records_v2 ⇒ Object
Multi-field record format. Array of objects with optional email, maid, ip_address, user_agent, external_id, hashed_pinner_id, hashed_phone_number, and liveramp_envelope per row. Provide exactly one of records or records_v2.
26 27 28 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 26 def records_v2 @records_v2 end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 51 def self.attribute_map { :'operation_type' => :'operation_type', :'records' => :'records', :'records_v2' => :'records_v2' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 70 def self.openapi_types { :'operation_type' => :'UserListOperationType', :'records' => :'String', :'records_v2' => :'Array<CustomerListRecordRow>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && operation_type == o.operation_type && records == o.records && records_v2 == o.records_v2 end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 165 def hash [operation_type, records, records_v2].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @operation_type.nil? invalid_properties.push('invalid value for "operation_type", operation_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 135 |
# File 'lib/pinterest_sdk/models/customer_list_update_with_required_body.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @operation_type.nil? true end |