Class: PinterestSdkClient::CustomerListUploadsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/customer_list_uploads_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CustomerListUploadsApi

Returns a new instance of CustomerListUploadsApi.



19
20
21
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#customer_list_uploads_create(ad_account_id, customer_list_id, customer_list_upload_create_request, opts = {}) ⇒ CustomerListUploadCreateResponse

Create customer list upload Create a customer list upload request for multipart S3 upload. Note: Each part must be at least 5mb; however the last part can be any size greater than 0. Clients with smaller files can request a single part count. This minimal part size restriction is defined by the AWS S3 API. Please review the update customer list endpoint documentation for additional information.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_create_request (CustomerListUploadCreateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



29
30
31
32
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 29

def customer_list_uploads_create(, customer_list_id, customer_list_upload_create_request, opts = {})
  data, _status_code, _headers = customer_list_uploads_create_with_http_info(, customer_list_id, customer_list_upload_create_request, opts)
  data
end

#customer_list_uploads_create_with_http_info(ad_account_id, customer_list_id, customer_list_upload_create_request, opts = {}) ⇒ Array<(CustomerListUploadCreateResponse, Integer, Hash)>

Create customer list upload Create a customer list upload request for multipart S3 upload. Note: Each part must be at least 5mb; however the last part can be any size greater than 0. Clients with smaller files can request a single part count. This minimal part size restriction is defined by the AWS S3 API. Please review the update customer list endpoint documentation for additional information.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_create_request (CustomerListUploadCreateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 41

def customer_list_uploads_create_with_http_info(, customer_list_id, customer_list_upload_create_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CustomerListUploadsApi.customer_list_uploads_create ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_create"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListUploadsApi.customer_list_uploads_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_id' is set
  if @api_client.config.client_side_validation && customer_list_id.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_create"
  end
  if @api_client.config.client_side_validation && customer_list_id.to_s.length > 18
    fail ArgumentError, 'invalid value for "customer_list_id" when calling CustomerListUploadsApi.customer_list_uploads_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && customer_list_id !~ pattern
    fail ArgumentError, "invalid value for 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_upload_create_request' is set
  if @api_client.config.client_side_validation && customer_list_upload_create_request.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_upload_create_request' when calling CustomerListUploadsApi.customer_list_uploads_create"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{customer_list_id}', CGI.escape(customer_list_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_list_upload_create_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CustomerListUploadCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CustomerListUploadsApi.customer_list_uploads_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CustomerListUploadsApi#customer_list_uploads_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#customer_list_uploads_get(ad_account_id, customer_list_id, customer_list_upload_id, opts = {}) ⇒ CustomerListUpload

Get customer list upload Get the metadata for a given upload by its ID.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_id (String)

    Customer List Upload ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



127
128
129
130
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 127

def customer_list_uploads_get(, customer_list_id, customer_list_upload_id, opts = {})
  data, _status_code, _headers = customer_list_uploads_get_with_http_info(, customer_list_id, customer_list_upload_id, opts)
  data
end

#customer_list_uploads_get_with_http_info(ad_account_id, customer_list_id, customer_list_upload_id, opts = {}) ⇒ Array<(CustomerListUpload, Integer, Hash)>

Get customer list upload Get the metadata for a given upload by its ID.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_id (String)

    Customer List Upload ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomerListUpload, Integer, Hash)>)

    CustomerListUpload data, response status code and response headers



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 139

def customer_list_uploads_get_with_http_info(, customer_list_id, customer_list_upload_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CustomerListUploadsApi.customer_list_uploads_get ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_get"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListUploadsApi.customer_list_uploads_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_get, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_id' is set
  if @api_client.config.client_side_validation && customer_list_id.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_get"
  end
  if @api_client.config.client_side_validation && customer_list_id.to_s.length > 18
    fail ArgumentError, 'invalid value for "customer_list_id" when calling CustomerListUploadsApi.customer_list_uploads_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && customer_list_id !~ pattern
    fail ArgumentError, "invalid value for 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_get, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_upload_id' is set
  if @api_client.config.client_side_validation && customer_list_upload_id.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_upload_id' when calling CustomerListUploadsApi.customer_list_uploads_get"
  end
  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && customer_list_upload_id !~ pattern
    fail ArgumentError, "invalid value for 'customer_list_upload_id' when calling CustomerListUploadsApi.customer_list_uploads_get, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads/{customer_list_upload_id}'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{customer_list_id}', CGI.escape(customer_list_id.to_s)).sub('{customer_list_upload_id}', CGI.escape(customer_list_upload_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CustomerListUpload'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CustomerListUploadsApi.customer_list_uploads_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CustomerListUploadsApi#customer_list_uploads_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#customer_list_uploads_run(ad_account_id, customer_list_id, customer_list_upload_id, opts = {}) ⇒ CustomerListUpload

Run customer list upload Begin processing a customer list upload.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_id (String)

    Customer List Upload ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



225
226
227
228
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 225

def customer_list_uploads_run(, customer_list_id, customer_list_upload_id, opts = {})
  data, _status_code, _headers = customer_list_uploads_run_with_http_info(, customer_list_id, customer_list_upload_id, opts)
  data
end

#customer_list_uploads_run_with_http_info(ad_account_id, customer_list_id, customer_list_upload_id, opts = {}) ⇒ Array<(CustomerListUpload, Integer, Hash)>

Run customer list upload Begin processing a customer list upload.

Parameters:

  • ad_account_id (String)
  • customer_list_id (String)

    Customer list ID.

  • customer_list_upload_id (String)

    Customer List Upload ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomerListUpload, Integer, Hash)>)

    CustomerListUpload data, response status code and response headers



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/pinterest_sdk/api/customer_list_uploads_api.rb', line 237

def customer_list_uploads_run_with_http_info(, customer_list_id, customer_list_upload_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CustomerListUploadsApi.customer_list_uploads_run ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_run"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListUploadsApi.customer_list_uploads_run, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListUploadsApi.customer_list_uploads_run, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_id' is set
  if @api_client.config.client_side_validation && customer_list_id.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_run"
  end
  if @api_client.config.client_side_validation && customer_list_id.to_s.length > 18
    fail ArgumentError, 'invalid value for "customer_list_id" when calling CustomerListUploadsApi.customer_list_uploads_run, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && customer_list_id !~ pattern
    fail ArgumentError, "invalid value for 'customer_list_id' when calling CustomerListUploadsApi.customer_list_uploads_run, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'customer_list_upload_id' is set
  if @api_client.config.client_side_validation && customer_list_upload_id.nil?
    fail ArgumentError, "Missing the required parameter 'customer_list_upload_id' when calling CustomerListUploadsApi.customer_list_uploads_run"
  end
  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && customer_list_upload_id !~ pattern
    fail ArgumentError, "invalid value for 'customer_list_upload_id' when calling CustomerListUploadsApi.customer_list_uploads_run, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads/{customer_list_upload_id}/run'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{customer_list_id}', CGI.escape(customer_list_id.to_s)).sub('{customer_list_upload_id}', CGI.escape(customer_list_upload_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CustomerListUpload'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"CustomerListUploadsApi.customer_list_uploads_run",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CustomerListUploadsApi#customer_list_uploads_run\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end