Class: PinterestSdkClient::CustomerSegment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CustomerSegment
- Defined in:
- lib/pinterest_sdk/models/customer_segment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
The ID of the ad account that this customer segment belongs to.
-
#audience_ids ⇒ Object
Audience IDs included in the customer segment.
-
#created_time ⇒ Object
Customer segment created time.
-
#id ⇒ Object
Customer segment ID.
-
#name ⇒ Object
Customer segment name.
-
#status ⇒ Object
Indicates whether the customer segment is active or deleted.
-
#updated_time ⇒ Object
Customer segment updated time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerSegment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerSegment
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CustomerSegment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CustomerSegment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'audience_ids') if (value = attributes[:'audience_ids']).is_a?(Array) self.audience_ids = value end else self.audience_ids = nil end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
The ID of the ad account that this customer segment belongs to.
19 20 21 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 19 def ad_account_id @ad_account_id end |
#audience_ids ⇒ Object
Audience IDs included in the customer segment.
22 23 24 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 22 def audience_ids @audience_ids end |
#created_time ⇒ Object
Customer segment created time. Unix timestamp in seconds.
25 26 27 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 25 def created_time @created_time end |
#id ⇒ Object
Customer segment ID.
28 29 30 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 28 def id @id end |
#name ⇒ Object
Customer segment name.
31 32 33 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 31 def name @name end |
#status ⇒ Object
Indicates whether the customer segment is active or deleted.
34 35 36 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 34 def status @status end |
#updated_time ⇒ Object
Customer segment updated time. Unix timestamp in seconds.
37 38 39 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 37 def updated_time @updated_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 62 def self.attribute_map { :'ad_account_id' => :'ad_account_id', :'audience_ids' => :'audience_ids', :'created_time' => :'created_time', :'id' => :'id', :'name' => :'name', :'status' => :'status', :'updated_time' => :'updated_time' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 85 def self.openapi_types { :'ad_account_id' => :'String', :'audience_ids' => :'Array<String>', :'created_time' => :'Integer', :'id' => :'String', :'name' => :'String', :'status' => :'TargetingTemplateStatus', :'updated_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && audience_ids == o.audience_ids && created_time == o.created_time && id == o.id && name == o.name && status == o.status && updated_time == o.updated_time end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 263 def hash [ad_account_id, audience_ids, created_time, id, name, status, updated_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end if @audience_ids.nil? invalid_properties.push('invalid value for "audience_ids", audience_ids cannot be nil.') end pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 185 186 187 188 189 |
# File 'lib/pinterest_sdk/models/customer_segment.rb', line 182 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if @audience_ids.nil? return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) return false if @name.nil? true end |