Class: PinterestSdkClient::CustomerSegmentApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::CustomerSegmentApi
- Defined in:
- lib/pinterest_sdk/api/customer_segment_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#customer_segment_create(ad_account_id, customer_segment_create, opts = {}) ⇒ CustomerSegment
Create customer segments Customer segments allow advertisers to define existing customers for Pinterest Performance+ campaigns.
-
#customer_segment_create_with_http_info(ad_account_id, customer_segment_create, opts = {}) ⇒ Array<(CustomerSegment, Integer, Hash)>
Create customer segments Customer segments allow advertisers to define existing customers for Pinterest Performance+ campaigns.
-
#customer_segment_list(ad_account_id, opts = {}) ⇒ CustomerSegmentList200Response
List customer segments Get a list of the customer segments in the specified
ad_account_id. -
#customer_segment_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(CustomerSegmentList200Response, Integer, Hash)>
List customer segments Get a list of the customer segments in the specified `ad_account_id`.
-
#customer_segment_update(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) ⇒ nil
Update customer segments Update the customer segment given advertiser ID and customer segment ID.
-
#customer_segment_update_with_http_info(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update customer segments Update the customer segment given advertiser ID and customer segment ID.
-
#initialize(api_client = ApiClient.default) ⇒ CustomerSegmentApi
constructor
A new instance of CustomerSegmentApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CustomerSegmentApi
Returns a new instance of CustomerSegmentApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#customer_segment_create(ad_account_id, customer_segment_create, opts = {}) ⇒ CustomerSegment
Create customer segments Customer segments allow advertisers to define existing customers for Pinterest Performance+ campaigns. Customer segments are made up of audience lists.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 28 def customer_segment_create(ad_account_id, customer_segment_create, opts = {}) data, _status_code, _headers = customer_segment_create_with_http_info(ad_account_id, customer_segment_create, opts) data end |
#customer_segment_create_with_http_info(ad_account_id, customer_segment_create, opts = {}) ⇒ Array<(CustomerSegment, Integer, Hash)>
Create customer segments Customer segments allow advertisers to define existing customers for Pinterest Performance+ campaigns. Customer segments are made up of audience lists.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 39 def customer_segment_create_with_http_info(ad_account_id, customer_segment_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerSegmentApi.customer_segment_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerSegmentApi.customer_segment_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerSegmentApi.customer_segment_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerSegmentApi.customer_segment_create, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_segment_create' is set if @api_client.config.client_side_validation && customer_segment_create.nil? fail ArgumentError, "Missing the required parameter 'customer_segment_create' when calling CustomerSegmentApi.customer_segment_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_segments'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_segment_create) # return_type return_type = opts[:debug_return_type] || 'CustomerSegment' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerSegmentApi.customer_segment_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerSegmentApi#customer_segment_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#customer_segment_list(ad_account_id, opts = {}) ⇒ CustomerSegmentList200Response
List customer segments
Get a list of the customer segments in the specified ad_account_id.
115 116 117 118 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 115 def customer_segment_list(ad_account_id, opts = {}) data, _status_code, _headers = customer_segment_list_with_http_info(ad_account_id, opts) data end |
#customer_segment_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(CustomerSegmentList200Response, Integer, Hash)>
List customer segments Get a list of the customer segments in the specified `ad_account_id`.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 130 def customer_segment_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerSegmentApi.customer_segment_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerSegmentApi.customer_segment_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerSegmentApi.customer_segment_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerSegmentApi.customer_segment_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CustomerSegmentApi.customer_segment_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CustomerSegmentApi.customer_segment_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_segments'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_sizing'] = opts[:'include_sizing'] if !opts[:'include_sizing'].nil? query_params[:'search_query'] = opts[:'search_query'] if !opts[:'search_query'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CustomerSegmentList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerSegmentApi.customer_segment_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerSegmentApi#customer_segment_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#customer_segment_update(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) ⇒ nil
Update customer segments Update the customer segment given advertiser ID and customer segment ID
206 207 208 209 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 206 def customer_segment_update(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) customer_segment_update_with_http_info(ad_account_id, customer_segment_update_request_update_with_required_body, opts) nil end |
#customer_segment_update_with_http_info(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update customer segments Update the customer segment given advertiser ID and customer segment ID
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pinterest_sdk/api/customer_segment_api.rb', line 217 def customer_segment_update_with_http_info(ad_account_id, customer_segment_update_request_update_with_required_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerSegmentApi.customer_segment_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerSegmentApi.customer_segment_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerSegmentApi.customer_segment_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerSegmentApi.customer_segment_update, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_segment_update_request_update_with_required_body' is set if @api_client.config.client_side_validation && customer_segment_update_request_update_with_required_body.nil? fail ArgumentError, "Missing the required parameter 'customer_segment_update_request_update_with_required_body' when calling CustomerSegmentApi.customer_segment_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_segments'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_segment_update_request_update_with_required_body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerSegmentApi.customer_segment_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerSegmentApi#customer_segment_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |