Class: PinterestSdkClient::DeleteBusinessPartnersDelete
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::DeleteBusinessPartnersDelete
- Defined in:
- lib/pinterest_sdk/models/delete_business_partners_delete.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#partner_ids ⇒ Object
A list of partner ids to be deleted.
-
#partner_type ⇒ Object
Returns the value of attribute partner_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeleteBusinessPartnersDelete
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeleteBusinessPartnersDelete
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::DeleteBusinessPartnersDelete` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::DeleteBusinessPartnersDelete`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'partner_ids') if (value = attributes[:'partner_ids']).is_a?(Array) self.partner_ids = value end else self.partner_ids = nil end if attributes.key?(:'partner_type') self.partner_type = attributes[:'partner_type'] end end |
Instance Attribute Details
#partner_ids ⇒ Object
A list of partner ids to be deleted
19 20 21 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 19 def partner_ids @partner_ids end |
#partner_type ⇒ Object
Returns the value of attribute partner_type.
21 22 23 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 21 def partner_type @partner_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 46 def self.attribute_map { :'partner_ids' => :'partner_ids', :'partner_type' => :'partner_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 76 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 72 def self.openapi_nullable Set.new([ :'partner_type' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 64 def self.openapi_types { :'partner_ids' => :'Array<String>', :'partner_type' => :'NullablePartnerType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && partner_ids == o.partner_ids && partner_type == o.partner_type end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 172 def hash [partner_ids, partner_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @partner_ids.nil? invalid_properties.push('invalid value for "partner_ids", partner_ids cannot be nil.') end if @partner_ids.length > 50 invalid_properties.push('invalid value for "partner_ids", number of items must be less than or equal to 50.') end if @partner_ids.length < 1 invalid_properties.push('invalid value for "partner_ids", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 |
# File 'lib/pinterest_sdk/models/delete_business_partners_delete.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @partner_ids.nil? return false if @partner_ids.length > 50 return false if @partner_ids.length < 1 true end |