Class: PinterestSdkClient::Keyword
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::Keyword
- Defined in:
- lib/pinterest_sdk/models/keyword.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#archived ⇒ Object
Returns the value of attribute archived.
-
#bid ⇒ Object
Note: bid field has been deprecated.
-
#id ⇒ Object
Keyword ID .
-
#match_type ⇒ Object
Keyword match type.
-
#parent_id ⇒ Object
Keyword parent entity ID (advertiser, campaign, ad group).
-
#parent_type ⇒ Object
Parent entity type (advertiser, campaign, ad group).
-
#type ⇒ Object
Always keyword.
-
#value ⇒ Object
Keyword value (120 chars max).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Keyword
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Keyword
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::Keyword` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::Keyword`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'archived') self.archived = attributes[:'archived'] end if attributes.key?(:'bid') self.bid = attributes[:'bid'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'match_type') self.match_type = attributes[:'match_type'] else self.match_type = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] else self.parent_id = nil end if attributes.key?(:'parent_type') self.parent_type = attributes[:'parent_type'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end end |
Instance Attribute Details
#archived ⇒ Object
Returns the value of attribute archived.
18 19 20 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 18 def archived @archived end |
#bid ⇒ Object
Note: bid field has been deprecated. Input will not be set and field will return null. Keyword custom bid in microcurrency - null if inherited from parent ad group.
21 22 23 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 21 def bid @bid end |
#id ⇒ Object
Keyword ID .
24 25 26 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 24 def id @id end |
#match_type ⇒ Object
Keyword match type
27 28 29 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 27 def match_type @match_type end |
#parent_id ⇒ Object
Keyword parent entity ID (advertiser, campaign, ad group).
30 31 32 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 30 def parent_id @parent_id end |
#parent_type ⇒ Object
Parent entity type (advertiser, campaign, ad group).
33 34 35 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 33 def parent_type @parent_type end |
#type ⇒ Object
Always keyword
36 37 38 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 36 def type @type end |
#value ⇒ Object
Keyword value (120 chars max).
39 40 41 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 39 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 64 def self.attribute_map { :'archived' => :'archived', :'bid' => :'bid', :'id' => :'id', :'match_type' => :'match_type', :'parent_id' => :'parent_id', :'parent_type' => :'parent_type', :'type' => :'type', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 278 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 102 def self.openapi_nullable Set.new([ :'bid', :'match_type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 88 def self.openapi_types { :'archived' => :'Boolean', :'bid' => :'Integer', :'id' => :'String', :'match_type' => :'MatchType', :'parent_id' => :'String', :'parent_type' => :'String', :'type' => :'String', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && archived == o.archived && bid == o.bid && id == o.id && match_type == o.match_type && parent_id == o.parent_id && parent_type == o.parent_type && type == o.type && value == o.value end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 271 def hash [archived, bid, id, match_type, parent_id, parent_type, type, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @parent_id.nil? invalid_properties.push('invalid value for "parent_id", parent_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @parent_id !~ pattern invalid_properties.push("invalid value for \"parent_id\", must conform to the pattern #{pattern}.") end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 206 |
# File 'lib/pinterest_sdk/models/keyword.rb', line 198 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id !~ Regexp.new(/^\d+$/) return false if @parent_id.nil? return false if @parent_id !~ Regexp.new(/^\d+$/) return false if @value.nil? true end |