Class: PinterestSdkClient::LabelCreateItem

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/label_create_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LabelCreateItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::LabelCreateItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::LabelCreateItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'label_type')
    self.label_type = attributes[:'label_type']
  else
    self.label_type = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end
end

Instance Attribute Details

#label_typeObject

Returns the value of attribute label_type.



18
19
20
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 18

def label_type
  @label_type
end

#valueObject

Label name. 100-character limit.



21
22
23
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 21

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 46

def self.attribute_map
  {
    :'label_type' => :'label_type',
    :'value' => :'value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 64

def self.openapi_types
  {
    :'label_type' => :'LabelType',
    :'value' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      label_type == o.label_type &&
      value == o.value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 177

def hash
  [label_type, value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @label_type.nil?
    invalid_properties.push('invalid value for "label_type", label_type cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @value.to_s.length > 100
    invalid_properties.push('invalid value for "value", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
133
134
# File 'lib/pinterest_sdk/models/label_create_item.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @label_type.nil?
  return false if @value.nil?
  return false if @value.to_s.length > 100
  true
end