Class: PinterestSdkClient::LabelsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/labels_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ LabelsApi

Returns a new instance of LabelsApi.



19
20
21
# File 'lib/pinterest_sdk/api/labels_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/labels_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#labels_apply(ad_account_id, label_id, labeled_entities_create, opts = {}) ⇒ LabeledEntities

Apply label to entity Closed beta Apply a label to one or more campaigns. Future releases may support labels for other entities in addition to campaigns. Currently, you can apply brand and custom labels. Future releases will provide more options. Note: You can only apply one brand label to a campaign. You can apply up to 30 custom labels to a campaign.

Parameters:

  • ad_account_id (String)
  • label_id (String)

    Label ID.

  • labeled_entities_create (LabeledEntitiesCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



29
30
31
32
# File 'lib/pinterest_sdk/api/labels_api.rb', line 29

def labels_apply(, label_id, labeled_entities_create, opts = {})
  data, _status_code, _headers = labels_apply_with_http_info(, label_id, labeled_entities_create, opts)
  data
end

#labels_apply_with_http_info(ad_account_id, label_id, labeled_entities_create, opts = {}) ⇒ Array<(LabeledEntities, Integer, Hash)>

Apply label to entity Closed beta Apply a label to one or more campaigns. Future releases may support labels for other entities in addition to campaigns. Currently, you can apply brand and custom labels. Future releases will provide more options. Note: You can only apply one brand label to a campaign. You can apply up to 30 custom labels to a campaign.

Parameters:

  • ad_account_id (String)
  • label_id (String)

    Label ID.

  • labeled_entities_create (LabeledEntitiesCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LabeledEntities, Integer, Hash)>)

    LabeledEntities data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/pinterest_sdk/api/labels_api.rb', line 41

def labels_apply_with_http_info(, label_id, labeled_entities_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LabelsApi.labels_apply ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LabelsApi.labels_apply"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling LabelsApi.labels_apply, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling LabelsApi.labels_apply, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'label_id' is set
  if @api_client.config.client_side_validation && label_id.nil?
    fail ArgumentError, "Missing the required parameter 'label_id' when calling LabelsApi.labels_apply"
  end
  # verify the required parameter 'labeled_entities_create' is set
  if @api_client.config.client_side_validation && labeled_entities_create.nil?
    fail ArgumentError, "Missing the required parameter 'labeled_entities_create' when calling LabelsApi.labels_apply"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/labels/{label_id}/apply'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{label_id}', CGI.escape(label_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(labeled_entities_create)

  # return_type
  return_type = opts[:debug_return_type] || 'LabeledEntities'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"LabelsApi.labels_apply",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LabelsApi#labels_apply\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#labels_create(ad_account_id, label_create_request, opts = {}) ⇒ LabelsResponse

Create labels Closed beta Apply one or more labels to a campaign. Future releases may support labels for other entities. Currently, you can apply brand and custom labels. Future releases will provide more options. Note: You can only apply one brand label to a campaign. You can apply 30 custom labels to a campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • label_create_request (LabelCreateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



117
118
119
120
# File 'lib/pinterest_sdk/api/labels_api.rb', line 117

def labels_create(, label_create_request, opts = {})
  data, _status_code, _headers = labels_create_with_http_info(, label_create_request, opts)
  data
end

#labels_create_with_http_info(ad_account_id, label_create_request, opts = {}) ⇒ Array<(LabelsResponse, Integer, Hash)>

Create labels Closed beta Apply one or more labels to a campaign. Future releases may support labels for other entities. Currently, you can apply brand and custom labels. Future releases will provide more options. Note: You can only apply one brand label to a campaign. You can apply 30 custom labels to a campaign.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • label_create_request (LabelCreateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LabelsResponse, Integer, Hash)>)

    LabelsResponse data, response status code and response headers



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/pinterest_sdk/api/labels_api.rb', line 128

def labels_create_with_http_info(, label_create_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LabelsApi.labels_create ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LabelsApi.labels_create"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling LabelsApi.labels_create, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling LabelsApi.labels_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'label_create_request' is set
  if @api_client.config.client_side_validation && label_create_request.nil?
    fail ArgumentError, "Missing the required parameter 'label_create_request' when calling LabelsApi.labels_create"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/labels'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(label_create_request)

  # return_type
  return_type = opts[:debug_return_type] || 'LabelsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"LabelsApi.labels_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LabelsApi#labels_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#labels_list(ad_account_id, opts = {}) ⇒ LabelsList200Response

List labels Closed beta See a list of labels for assets that your account owns, and filter the list by different criteria. If no filter is provided, it will default to labels associated with the ad account id.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :campaign_ids (Array<String>)

    List of Campaign Ids to use to filter the results.

  • :label_ids (Array<String>)

    List of Label Ids to use to filter the results.

  • :entity_statuses (Array<QueryLabelEntityStatusesItems>)

    Label entity status

  • :label_types (Array<QueryLabelTypesItems>)

    Label type.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



205
206
207
208
# File 'lib/pinterest_sdk/api/labels_api.rb', line 205

def labels_list(, opts = {})
  data, _status_code, _headers = labels_list_with_http_info(, opts)
  data
end

#labels_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(LabelsList200Response, Integer, Hash)>

List labels Closed beta See a list of labels for assets that your account owns, and filter the list by different criteria. If no filter is provided, it will default to labels associated with the ad account id.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :campaign_ids (Array<String>)

    List of Campaign Ids to use to filter the results.

  • :label_ids (Array<String>)

    List of Label Ids to use to filter the results.

  • :entity_statuses (Array<QueryLabelEntityStatusesItems>)

    Label entity status

  • :label_types (Array<QueryLabelTypesItems>)

    Label type.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:

  • (Array<(LabelsList200Response, Integer, Hash)>)

    LabelsList200Response data, response status code and response headers



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/pinterest_sdk/api/labels_api.rb', line 221

def labels_list_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LabelsApi.labels_list ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LabelsApi.labels_list"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling LabelsApi.labels_list, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling LabelsApi.labels_list, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'campaign_ids'].nil? && opts[:'campaign_ids'].length > 250
    fail ArgumentError, 'invalid value for "opts[:"campaign_ids"]" when calling LabelsApi.labels_list, number of items must be less than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'campaign_ids'].nil? && opts[:'campaign_ids'].length < 1
    fail ArgumentError, 'invalid value for "opts[:"campaign_ids"]" when calling LabelsApi.labels_list, number of items must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'label_ids'].nil? && opts[:'label_ids'].length > 250
    fail ArgumentError, 'invalid value for "opts[:"label_ids"]" when calling LabelsApi.labels_list, number of items must be less than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'label_ids'].nil? && opts[:'label_ids'].length < 1
    fail ArgumentError, 'invalid value for "opts[:"label_ids"]" when calling LabelsApi.labels_list, number of items must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LabelsApi.labels_list, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LabelsApi.labels_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/labels'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'campaign_ids'] = @api_client.build_collection_param(opts[:'campaign_ids'], :multi) if !opts[:'campaign_ids'].nil?
  query_params[:'label_ids'] = @api_client.build_collection_param(opts[:'label_ids'], :multi) if !opts[:'label_ids'].nil?
  query_params[:'entity_statuses'] = @api_client.build_collection_param(opts[:'entity_statuses'], :multi) if !opts[:'entity_statuses'].nil?
  query_params[:'label_types'] = @api_client.build_collection_param(opts[:'label_types'], :multi) if !opts[:'label_types'].nil?
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'LabelsList200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"LabelsApi.labels_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LabelsApi#labels_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#labels_remove(ad_account_id, label_id, labeled_entities_create, opts = {}) ⇒ LabeledEntities

Remove label from entities Closed beta Remove a label from one or more entities.

Parameters:

  • ad_account_id (String)
  • label_id (String)

    Label ID.

  • labeled_entities_create (LabeledEntitiesCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



315
316
317
318
# File 'lib/pinterest_sdk/api/labels_api.rb', line 315

def labels_remove(, label_id, labeled_entities_create, opts = {})
  data, _status_code, _headers = labels_remove_with_http_info(, label_id, labeled_entities_create, opts)
  data
end

#labels_remove_with_http_info(ad_account_id, label_id, labeled_entities_create, opts = {}) ⇒ Array<(LabeledEntities, Integer, Hash)>

Remove label from entities Closed beta Remove a label from one or more entities.

Parameters:

  • ad_account_id (String)
  • label_id (String)

    Label ID.

  • labeled_entities_create (LabeledEntitiesCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LabeledEntities, Integer, Hash)>)

    LabeledEntities data, response status code and response headers



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/pinterest_sdk/api/labels_api.rb', line 327

def labels_remove_with_http_info(, label_id, labeled_entities_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LabelsApi.labels_remove ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LabelsApi.labels_remove"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling LabelsApi.labels_remove, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling LabelsApi.labels_remove, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'label_id' is set
  if @api_client.config.client_side_validation && label_id.nil?
    fail ArgumentError, "Missing the required parameter 'label_id' when calling LabelsApi.labels_remove"
  end
  # verify the required parameter 'labeled_entities_create' is set
  if @api_client.config.client_side_validation && labeled_entities_create.nil?
    fail ArgumentError, "Missing the required parameter 'labeled_entities_create' when calling LabelsApi.labels_remove"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/labels/{label_id}/remove'.sub('{ad_account_id}', CGI.escape(.to_s)).sub('{label_id}', CGI.escape(label_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(labeled_entities_create)

  # return_type
  return_type = opts[:debug_return_type] || 'LabeledEntities'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"LabelsApi.labels_remove",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LabelsApi#labels_remove\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#labels_update(ad_account_id, label_update_request, opts = {}) ⇒ LabelsResponse

Update labels Closed beta Change the properties of one or more labels.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • label_update_request (LabelUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



403
404
405
406
# File 'lib/pinterest_sdk/api/labels_api.rb', line 403

def labels_update(, label_update_request, opts = {})
  data, _status_code, _headers = labels_update_with_http_info(, label_update_request, opts)
  data
end

#labels_update_with_http_info(ad_account_id, label_update_request, opts = {}) ⇒ Array<(LabelsResponse, Integer, Hash)>

Update labels Closed beta Change the properties of one or more labels.

Parameters:

  • ad_account_id (String)

    Unique identifier of an ad account.

  • label_update_request (LabelUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LabelsResponse, Integer, Hash)>)

    LabelsResponse data, response status code and response headers



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/pinterest_sdk/api/labels_api.rb', line 414

def labels_update_with_http_info(, label_update_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LabelsApi.labels_update ...'
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LabelsApi.labels_update"
  end
  if @api_client.config.client_side_validation && .to_s.length > 18
    fail ArgumentError, 'invalid value for "ad_account_id" when calling LabelsApi.labels_update, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation &&  !~ pattern
    fail ArgumentError, "invalid value for 'ad_account_id' when calling LabelsApi.labels_update, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'label_update_request' is set
  if @api_client.config.client_side_validation && label_update_request.nil?
    fail ArgumentError, "Missing the required parameter 'label_update_request' when calling LabelsApi.labels_update"
  end
  # resource path
  local_var_path = '/ad_accounts/{ad_account_id}/labels'.sub('{ad_account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(label_update_request)

  # return_type
  return_type = opts[:debug_return_type] || 'LabelsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"LabelsApi.labels_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LabelsApi#labels_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end