Class: PinterestSdkClient::LeadForm
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::LeadForm
- Defined in:
- lib/pinterest_sdk/models/lead_form.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
The Ad Account ID that this lead form belongs to.
-
#completion_message ⇒ Object
A message for people who complete the form to let them know what happens next.
-
#created_time ⇒ Object
Lead form creation time.
-
#disclosure_language ⇒ Object
Additional disclosure language to be included in the lead form.
-
#has_accepted_terms ⇒ Object
Whether the advertiser has accepted Pinterest's terms of service for creating a lead ad.
-
#id ⇒ Object
The ID of this lead form.
-
#name ⇒ Object
Internal name of the lead form.
-
#policy_links ⇒ Object
List of additional policy links to be displayed on the lead form.
-
#privacy_policy_link ⇒ Object
A link to the advertiser's privacy policy.
-
#questions ⇒ Object
List of questions to be displayed on the lead form.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_time ⇒ Object
Last update time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LeadForm
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LeadForm
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::LeadForm` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::LeadForm`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'completion_message') self. = attributes[:'completion_message'] else self. = nil end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'disclosure_language') self.disclosure_language = attributes[:'disclosure_language'] end if attributes.key?(:'has_accepted_terms') self.has_accepted_terms = attributes[:'has_accepted_terms'] else self.has_accepted_terms = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'policy_links') if (value = attributes[:'policy_links']).is_a?(Array) self.policy_links = value end end if attributes.key?(:'privacy_policy_link') self.privacy_policy_link = attributes[:'privacy_policy_link'] else self.privacy_policy_link = nil end if attributes.key?(:'questions') if (value = attributes[:'questions']).is_a?(Array) self.questions = value end else self.questions = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
The Ad Account ID that this lead form belongs to.
19 20 21 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 19 def ad_account_id @ad_account_id end |
#completion_message ⇒ Object
A message for people who complete the form to let them know what happens next.
22 23 24 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 22 def @completion_message end |
#created_time ⇒ Object
Lead form creation time. Unix timestamp in seconds.
25 26 27 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 25 def created_time @created_time end |
#disclosure_language ⇒ Object
Additional disclosure language to be included in the lead form.
28 29 30 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 28 def disclosure_language @disclosure_language end |
#has_accepted_terms ⇒ Object
Whether the advertiser has accepted Pinterest's terms of service for creating a lead ad. By sending us TRUE for this parameter, you agree that (i) you will use any personal information received in compliance with the privacy policy you share with Pinterest, and (ii) you will comply with Pinterest's Lead Ad Terms. As a reminder, all advertising on Pinterest is subject to the Pinterest Advertising Services Agreement or an equivalent agreement as set forth on an IO
31 32 33 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 31 def has_accepted_terms @has_accepted_terms end |
#id ⇒ Object
The ID of this lead form
34 35 36 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 34 def id @id end |
#name ⇒ Object
Internal name of the lead form.
37 38 39 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 37 def name @name end |
#policy_links ⇒ Object
List of additional policy links to be displayed on the lead form.
40 41 42 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 40 def policy_links @policy_links end |
#privacy_policy_link ⇒ Object
A link to the advertiser's privacy policy. This will be included in the lead form's disclosure language.
43 44 45 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 43 def privacy_policy_link @privacy_policy_link end |
#questions ⇒ Object
List of questions to be displayed on the lead form.
46 47 48 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 46 def questions @questions end |
#status ⇒ Object
Returns the value of attribute status.
48 49 50 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 48 def status @status end |
#updated_time ⇒ Object
Last update time. Unix timestamp in seconds.
51 52 53 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 51 def updated_time @updated_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
94 95 96 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 94 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 99 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 76 def self.attribute_map { :'ad_account_id' => :'ad_account_id', :'completion_message' => :'completion_message', :'created_time' => :'created_time', :'disclosure_language' => :'disclosure_language', :'has_accepted_terms' => :'has_accepted_terms', :'id' => :'id', :'name' => :'name', :'policy_links' => :'policy_links', :'privacy_policy_link' => :'privacy_policy_link', :'questions' => :'questions', :'status' => :'status', :'updated_time' => :'updated_time' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 384 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 126 127 128 129 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 122 def self.openapi_nullable Set.new([ :'completion_message', :'disclosure_language', :'name', :'privacy_policy_link', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 104 def self.openapi_types { :'ad_account_id' => :'String', :'completion_message' => :'String', :'created_time' => :'Integer', :'disclosure_language' => :'String', :'has_accepted_terms' => :'Boolean', :'id' => :'String', :'name' => :'String', :'policy_links' => :'Array<LeadFormPolicyLink>', :'privacy_policy_link' => :'String', :'questions' => :'Array<LeadFormQuestion>', :'status' => :'LeadFormStatus', :'updated_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 352 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && == o. && created_time == o.created_time && disclosure_language == o.disclosure_language && has_accepted_terms == o.has_accepted_terms && id == o.id && name == o.name && policy_links == o.policy_links && privacy_policy_link == o.privacy_policy_link && questions == o.questions && status == o.status && updated_time == o.updated_time end |
#eql?(o) ⇒ Boolean
371 372 373 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 371 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 377 def hash [ad_account_id, , created_time, disclosure_language, has_accepted_terms, id, name, policy_links, privacy_policy_link, questions, status, updated_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 214 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end if @has_accepted_terms.nil? invalid_properties.push('invalid value for "has_accepted_terms", has_accepted_terms cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if !@policy_links.nil? && @policy_links.length > 3 invalid_properties.push('invalid value for "policy_links", number of items must be less than or equal to 3.') end if !@policy_links.nil? && @policy_links.length < 0 invalid_properties.push('invalid value for "policy_links", number of items must be greater than or equal to 0.') end if @questions.nil? invalid_properties.push('invalid value for "questions", questions cannot be nil.') end if @questions.length > 10 invalid_properties.push('invalid value for "questions", number of items must be less than or equal to 10.') end if @questions.length < 0 invalid_properties.push('invalid value for "questions", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 406 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/pinterest_sdk/models/lead_form.rb', line 260 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if @has_accepted_terms.nil? return false if @id.nil? return false if @id !~ Regexp.new(/^\d+$/) return false if !@policy_links.nil? && @policy_links.length > 3 return false if !@policy_links.nil? && @policy_links.length < 0 return false if @questions.nil? return false if @questions.length > 10 return false if @questions.length < 0 true end |