Class: PinterestSdkClient::LeadFormsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::LeadFormsApi
- Defined in:
- lib/pinterest_sdk/api/lead_forms_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LeadFormsApi
constructor
A new instance of LeadFormsApi.
-
#lead_form_get(lead_form_id, ad_account_id, opts = {}) ⇒ LeadForm
Get lead form by id This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Gets a lead form given it's ID.
-
#lead_form_get_with_http_info(lead_form_id, ad_account_id, opts = {}) ⇒ Array<(LeadForm, Integer, Hash)>
Get lead form by id This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Gets a lead form given it's ID.
-
#lead_form_test_create(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) ⇒ LeadFormTest
Create lead form test data Create lead form test data based on the list of answers provided as part of the body.
-
#lead_form_test_create_with_http_info(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) ⇒ Array<(LeadFormTest, Integer, Hash)>
Create lead form test data Create lead form test data based on the list of answers provided as part of the body.
-
#lead_forms_create(ad_account_id, lead_form_create, opts = {}) ⇒ LeadFormsCreate200Response
Create lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Create lead forms.
-
#lead_forms_create_with_http_info(ad_account_id, lead_form_create, opts = {}) ⇒ Array<(LeadFormsCreate200Response, Integer, Hash)>
Create lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Create lead forms.
-
#lead_forms_list(ad_account_id, opts = {}) ⇒ LeadFormsList200Response
List lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. List lead forms associated with an ad account ID.
-
#lead_forms_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(LeadFormsList200Response, Integer, Hash)>
List lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. List lead forms associated with an ad account ID.
-
#lead_forms_update(ad_account_id, lead_form_batch_update, opts = {}) ⇒ LeadFormsCreate200Response
Update lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Update lead forms.
-
#lead_forms_update_with_http_info(ad_account_id, lead_form_batch_update, opts = {}) ⇒ Array<(LeadFormsCreate200Response, Integer, Hash)>
Update lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Update lead forms.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LeadFormsApi
Returns a new instance of LeadFormsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#lead_form_get(lead_form_id, ad_account_id, opts = {}) ⇒ LeadForm
Get lead form by id This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Gets a lead form given it's ID. It must also be associated with the provided ad account ID. For more, see Lead ads.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 28 def lead_form_get(lead_form_id, ad_account_id, opts = {}) data, _status_code, _headers = lead_form_get_with_http_info(lead_form_id, ad_account_id, opts) data end |
#lead_form_get_with_http_info(lead_form_id, ad_account_id, opts = {}) ⇒ Array<(LeadForm, Integer, Hash)>
Get lead form by id This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Gets a lead form given it's ID. It must also be associated with the provided ad account ID. For more, see Lead ads.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 39 def lead_form_get_with_http_info(lead_form_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadFormsApi.lead_form_get ...' end # verify the required parameter 'lead_form_id' is set if @api_client.config.client_side_validation && lead_form_id.nil? fail ArgumentError, "Missing the required parameter 'lead_form_id' when calling LeadFormsApi.lead_form_get" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && lead_form_id !~ pattern fail ArgumentError, "invalid value for 'lead_form_id' when calling LeadFormsApi.lead_form_get, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadFormsApi.lead_form_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadFormsApi.lead_form_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadFormsApi.lead_form_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/lead_forms/{lead_form_id}'.sub('{lead_form_id}', CGI.escape(lead_form_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LeadForm' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadFormsApi.lead_form_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadFormsApi#lead_form_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lead_form_test_create(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) ⇒ LeadFormTest
Create lead form test data Create lead form test data based on the list of answers provided as part of the body. - List of answers should follow the questions creation order.
112 113 114 115 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 112 def lead_form_test_create(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) data, _status_code, _headers = lead_form_test_create_with_http_info(ad_account_id, lead_form_id, lead_form_test_create, opts) data end |
#lead_form_test_create_with_http_info(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) ⇒ Array<(LeadFormTest, Integer, Hash)>
Create lead form test data Create lead form test data based on the list of answers provided as part of the body. - List of answers should follow the questions creation order.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 124 def lead_form_test_create_with_http_info(ad_account_id, lead_form_id, lead_form_test_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadFormsApi.lead_form_test_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadFormsApi.lead_form_test_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadFormsApi.lead_form_test_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadFormsApi.lead_form_test_create, must conform to the pattern #{pattern}." end # verify the required parameter 'lead_form_id' is set if @api_client.config.client_side_validation && lead_form_id.nil? fail ArgumentError, "Missing the required parameter 'lead_form_id' when calling LeadFormsApi.lead_form_test_create" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && lead_form_id !~ pattern fail ArgumentError, "invalid value for 'lead_form_id' when calling LeadFormsApi.lead_form_test_create, must conform to the pattern #{pattern}." end # verify the required parameter 'lead_form_test_create' is set if @api_client.config.client_side_validation && lead_form_test_create.nil? fail ArgumentError, "Missing the required parameter 'lead_form_test_create' when calling LeadFormsApi.lead_form_test_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/lead_forms/{lead_form_id}/test'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{lead_form_id}', CGI.escape(lead_form_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lead_form_test_create) # return_type return_type = opts[:debug_return_type] || 'LeadFormTest' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadFormsApi.lead_form_test_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadFormsApi#lead_form_test_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lead_forms_create(ad_account_id, lead_form_create, opts = {}) ⇒ LeadFormsCreate200Response
Create lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Create lead forms. Lead forms are used in lead ads and allow you to control what text appears on the lead form's description, questions and confirmation sections. For more, see Lead ads.
205 206 207 208 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 205 def lead_forms_create(ad_account_id, lead_form_create, opts = {}) data, _status_code, _headers = lead_forms_create_with_http_info(ad_account_id, lead_form_create, opts) data end |
#lead_forms_create_with_http_info(ad_account_id, lead_form_create, opts = {}) ⇒ Array<(LeadFormsCreate200Response, Integer, Hash)>
Create lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Create lead forms. Lead forms are used in lead ads and allow you to control what text appears on the lead form's description, questions and confirmation sections. For more, see Lead ads.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 216 def lead_forms_create_with_http_info(ad_account_id, lead_form_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadFormsApi.lead_forms_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadFormsApi.lead_forms_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadFormsApi.lead_forms_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadFormsApi.lead_forms_create, must conform to the pattern #{pattern}." end # verify the required parameter 'lead_form_create' is set if @api_client.config.client_side_validation && lead_form_create.nil? fail ArgumentError, "Missing the required parameter 'lead_form_create' when calling LeadFormsApi.lead_forms_create" end if @api_client.config.client_side_validation && lead_form_create.length > 30 fail ArgumentError, 'invalid value for "lead_form_create" when calling LeadFormsApi.lead_forms_create, number of items must be less than or equal to 30.' end if @api_client.config.client_side_validation && lead_form_create.length < 1 fail ArgumentError, 'invalid value for "lead_form_create" when calling LeadFormsApi.lead_forms_create, number of items must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/lead_forms'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lead_form_create) # return_type return_type = opts[:debug_return_type] || 'LeadFormsCreate200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadFormsApi.lead_forms_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadFormsApi#lead_forms_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lead_forms_list(ad_account_id, opts = {}) ⇒ LeadFormsList200Response
List lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. List lead forms associated with an ad account ID. For more, see Lead ads.
298 299 300 301 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 298 def lead_forms_list(ad_account_id, opts = {}) data, _status_code, _headers = lead_forms_list_with_http_info(ad_account_id, opts) data end |
#lead_forms_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(LeadFormsList200Response, Integer, Hash)>
List lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. List lead forms associated with an ad account ID. For more, see Lead ads.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 311 def lead_forms_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadFormsApi.lead_forms_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadFormsApi.lead_forms_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadFormsApi.lead_forms_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadFormsApi.lead_forms_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LeadFormsApi.lead_forms_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LeadFormsApi.lead_forms_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/lead_forms'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LeadFormsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadFormsApi.lead_forms_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadFormsApi#lead_forms_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lead_forms_update(ad_account_id, lead_form_batch_update, opts = {}) ⇒ LeadFormsCreate200Response
Update lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Update lead forms. Lead ads help you reach people who are actively looking for, and interested in, your goods and services. The lead form can be associated with an ad to allow people to fill out the form. For more, see Lead ads.
385 386 387 388 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 385 def lead_forms_update(ad_account_id, lead_form_batch_update, opts = {}) data, _status_code, _headers = lead_forms_update_with_http_info(ad_account_id, lead_form_batch_update, opts) data end |
#lead_forms_update_with_http_info(ad_account_id, lead_form_batch_update, opts = {}) ⇒ Array<(LeadFormsCreate200Response, Integer, Hash)>
Update lead forms This feature is currently in beta and not available to all apps, if you're interested in joining the beta, please reach out to your Pinterest account manager. Update lead forms. Lead ads help you reach people who are actively looking for, and interested in, your goods and services. The lead form can be associated with an ad to allow people to fill out the form. For more, see Lead ads.
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/pinterest_sdk/api/lead_forms_api.rb', line 396 def lead_forms_update_with_http_info(ad_account_id, lead_form_batch_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadFormsApi.lead_forms_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadFormsApi.lead_forms_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadFormsApi.lead_forms_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadFormsApi.lead_forms_update, must conform to the pattern #{pattern}." end # verify the required parameter 'lead_form_batch_update' is set if @api_client.config.client_side_validation && lead_form_batch_update.nil? fail ArgumentError, "Missing the required parameter 'lead_form_batch_update' when calling LeadFormsApi.lead_forms_update" end if @api_client.config.client_side_validation && lead_form_batch_update.length > 30 fail ArgumentError, 'invalid value for "lead_form_batch_update" when calling LeadFormsApi.lead_forms_update, number of items must be less than or equal to 30.' end if @api_client.config.client_side_validation && lead_form_batch_update.length < 1 fail ArgumentError, 'invalid value for "lead_form_batch_update" when calling LeadFormsApi.lead_forms_update, number of items must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/lead_forms'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lead_form_batch_update) # return_type return_type = opts[:debug_return_type] || 'LeadFormsCreate200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadFormsApi.lead_forms_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadFormsApi#lead_forms_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |