Class: PinterestSdkClient::LeadSubscriptionPostParamsCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::LeadSubscriptionPostParamsCreate
- Defined in:
- lib/pinterest_sdk/models/lead_subscription_post_params_create.rb
Instance Attribute Summary collapse
-
#lead_form_id ⇒ Object
Lead form ID.
-
#partner_access_token ⇒ Object
Partner access token.
-
#partner_metadata ⇒ Object
Partner metadata.
-
#partner_refresh_token ⇒ Object
Partner refresh token.
-
#webhook_url ⇒ Object
Standard HTTPS webhook URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LeadSubscriptionPostParamsCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LeadSubscriptionPostParamsCreate
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::LeadSubscriptionPostParamsCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::LeadSubscriptionPostParamsCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'lead_form_id') self.lead_form_id = attributes[:'lead_form_id'] end if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] else self.webhook_url = nil end if attributes.key?(:'partner_access_token') self.partner_access_token = attributes[:'partner_access_token'] end if attributes.key?(:'partner_metadata') self. = attributes[:'partner_metadata'] end if attributes.key?(:'partner_refresh_token') self.partner_refresh_token = attributes[:'partner_refresh_token'] end end |
Instance Attribute Details
#lead_form_id ⇒ Object
Lead form ID.
19 20 21 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 19 def lead_form_id @lead_form_id end |
#partner_access_token ⇒ Object
Partner access token. Only for clients that requires authentication. We recommend to avoid this param.
25 26 27 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 25 def partner_access_token @partner_access_token end |
#partner_metadata ⇒ Object
Partner metadata. Only for clients that requires special handling. We recommend to avoid this param.
28 29 30 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 28 def @partner_metadata end |
#partner_refresh_token ⇒ Object
Partner refresh token. Only for clients that requires authentication. We recommend to avoid this param.
31 32 33 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 31 def partner_refresh_token @partner_refresh_token end |
#webhook_url ⇒ Object
Standard HTTPS webhook URL.
22 23 24 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 22 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 34 def self.attribute_map { :'lead_form_id' => :'lead_form_id', :'webhook_url' => :'webhook_url', :'partner_access_token' => :'partner_access_token', :'partner_metadata' => :'partner_metadata', :'partner_refresh_token' => :'partner_refresh_token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
72 73 74 75 76 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 72 def self.openapi_all_of [ :'LeadSubscriptionCreate' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 55 def self.openapi_types { :'lead_form_id' => :'String', :'webhook_url' => :'String', :'partner_access_token' => :'String', :'partner_metadata' => :'PartnerMetadata', :'partner_refresh_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && lead_form_id == o.lead_form_id && webhook_url == o.webhook_url && partner_access_token == o.partner_access_token && == o. && partner_refresh_token == o.partner_refresh_token end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 188 def hash [lead_form_id, webhook_url, partner_access_token, , partner_refresh_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@lead_form_id.nil? && @lead_form_id !~ pattern invalid_properties.push("invalid value for \"lead_form_id\", must conform to the pattern #{pattern}.") end if @webhook_url.nil? invalid_properties.push('invalid value for "webhook_url", webhook_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 |
# File 'lib/pinterest_sdk/models/lead_subscription_post_params_create.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@lead_form_id.nil? && @lead_form_id !~ Regexp.new(/^\d+$/) return false if @webhook_url.nil? true end |