Class: PinterestSdkClient::LocalInventoryItemsBatch

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/local_inventory_items_batch.rb

Overview

Unified model for local inventory items batch operation

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LocalInventoryItemsBatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::LocalInventoryItemsBatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::LocalInventoryItemsBatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  else
    self.batch_id = nil
  end

  if attributes.key?(:'completed_time')
    self.completed_time = attributes[:'completed_time']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  else
    self.created_time = nil
  end

  if attributes.key?(:'operation_results')
    if (value = attributes[:'operation_results']).is_a?(Array)
      self.operation_results = value
    end
  else
    self.operation_results = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#batch_idObject

Id of the batch operation



20
21
22
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 20

def batch_id
  @batch_id
end

#completed_timeObject

Date and time (UTC) of the batch completion: YYYY-MM-DD'T'hh:mm:ss



23
24
25
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 23

def completed_time
  @completed_time
end

#created_timeObject

Date and time (UTC) of the batch creation: YYYY-MM-DD'T'hh:mm:ss



26
27
28
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 26

def created_time
  @created_time
end

#operation_resultsObject

Array of operation results



29
30
31
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 29

def operation_results
  @operation_results
end

#statusObject

Status of the batch: PROCESSING, COMPLETED, FAILED



32
33
34
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 32

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 57

def self.attribute_map
  {
    :'batch_id' => :'batch_id',
    :'completed_time' => :'completed_time',
    :'created_time' => :'created_time',
    :'operation_results' => :'operation_results',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 78

def self.openapi_types
  {
    :'batch_id' => :'String',
    :'completed_time' => :'Time',
    :'created_time' => :'Time',
    :'operation_results' => :'Array<SupplementalOperationResult>',
    :'status' => :'SupplementalItemBatchOperationStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      batch_id == o.batch_id &&
      completed_time == o.completed_time &&
      created_time == o.created_time &&
      operation_results == o.operation_results &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 236

def hash
  [batch_id, completed_time, created_time, operation_results, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @batch_id.nil?
    invalid_properties.push('invalid value for "batch_id", batch_id cannot be nil.')
  end

  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @operation_results.nil?
    invalid_properties.push('invalid value for "operation_results", operation_results cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
# File 'lib/pinterest_sdk/models/local_inventory_items_batch.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @batch_id.nil?
  return false if @created_time.nil?
  return false if @operation_results.nil?
  return false if @status.nil?
  true
end