Class: PinterestSdkClient::MMMReportCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::MMMReportCreate
- Defined in:
- lib/pinterest_sdk/models/mmm_report_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#advertiser_ids ⇒ Object
Advertiser IDs for multi-advertiser report.
-
#columns ⇒ Object
Metric and entity columns.
-
#countries ⇒ Object
A List of countries for filtering.
-
#custom_column_ids ⇒ Object
List of custom column IDs.
-
#end_date ⇒ Object
Metric report end date (UTC).
-
#granularity ⇒ Object
DAY - metrics are broken down daily.
-
#level ⇒ Object
Level of the report.
-
#report_name ⇒ Object
Name of the Marketing Mix Modeling (MMM) report.
-
#start_date ⇒ Object
Metric report start date (UTC).
-
#targeting_types ⇒ Object
List of targeting types.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MMMReportCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MMMReportCreate
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::MMMReportCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::MMMReportCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'advertiser_ids') if (value = attributes[:'advertiser_ids']).is_a?(Array) self.advertiser_ids = value end end if attributes.key?(:'columns') if (value = attributes[:'columns']).is_a?(Array) self.columns = value end else self.columns = nil end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end end if attributes.key?(:'custom_column_ids') if (value = attributes[:'custom_column_ids']).is_a?(Array) self.custom_column_ids = value end end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] else self.end_date = nil end if attributes.key?(:'granularity') self.granularity = attributes[:'granularity'] else self.granularity = nil end if attributes.key?(:'level') self.level = attributes[:'level'] else self.level = nil end if attributes.key?(:'report_name') self.report_name = attributes[:'report_name'] else self.report_name = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] else self.start_date = nil end if attributes.key?(:'targeting_types') if (value = attributes[:'targeting_types']).is_a?(Array) self.targeting_types = value end else self.targeting_types = nil end end |
Instance Attribute Details
#advertiser_ids ⇒ Object
Advertiser IDs for multi-advertiser report
20 21 22 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 20 def advertiser_ids @advertiser_ids end |
#columns ⇒ Object
Metric and entity columns
23 24 25 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 23 def columns @columns end |
#countries ⇒ Object
A List of countries for filtering
26 27 28 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 26 def countries @countries end |
#custom_column_ids ⇒ Object
List of custom column IDs
29 30 31 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 29 def custom_column_ids @custom_column_ids end |
#end_date ⇒ Object
Metric report end date (UTC). Format: YYYY-MM-DD
32 33 34 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 32 def end_date @end_date end |
#granularity ⇒ Object
DAY - metrics are broken down daily. WEEK - metrics are broken down weekly.
35 36 37 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 35 def granularity @granularity end |
#level ⇒ Object
Level of the report
38 39 40 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 38 def level @level end |
#report_name ⇒ Object
Name of the Marketing Mix Modeling (MMM) report
41 42 43 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 41 def report_name @report_name end |
#start_date ⇒ Object
Metric report start date (UTC). Format: YYYY-MM-DD
44 45 46 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 44 def start_date @start_date end |
#targeting_types ⇒ Object
List of targeting types
47 48 49 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 47 def targeting_types @targeting_types end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 72 def self.attribute_map { :'advertiser_ids' => :'advertiser_ids', :'columns' => :'columns', :'countries' => :'countries', :'custom_column_ids' => :'custom_column_ids', :'end_date' => :'end_date', :'granularity' => :'granularity', :'level' => :'level', :'report_name' => :'report_name', :'start_date' => :'start_date', :'targeting_types' => :'targeting_types' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 411 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 98 def self.openapi_types { :'advertiser_ids' => :'Array<String>', :'columns' => :'Array<MMMReportingColumn>', :'countries' => :'Array<TargetingAdvertiserCountry>', :'custom_column_ids' => :'Array<String>', :'end_date' => :'String', :'granularity' => :'MMMReportGranularity', :'level' => :'MMMReportLevel', :'report_name' => :'String', :'start_date' => :'String', :'targeting_types' => :'Array<MMMReportingTargetingType>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 381 def ==(o) return true if self.equal?(o) self.class == o.class && advertiser_ids == o.advertiser_ids && columns == o.columns && countries == o.countries && custom_column_ids == o.custom_column_ids && end_date == o.end_date && granularity == o.granularity && level == o.level && report_name == o.report_name && start_date == o.start_date && targeting_types == o.targeting_types end |
#eql?(o) ⇒ Boolean
398 399 400 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 398 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 404 def hash [advertiser_ids, columns, countries, custom_column_ids, end_date, granularity, level, report_name, start_date, targeting_types].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @columns.nil? invalid_properties.push('invalid value for "columns", columns cannot be nil.') end if !@custom_column_ids.nil? && @custom_column_ids.length > 20 invalid_properties.push('invalid value for "custom_column_ids", number of items must be less than or equal to 20.') end if @end_date.nil? invalid_properties.push('invalid value for "end_date", end_date cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}$/) if @end_date !~ pattern invalid_properties.push("invalid value for \"end_date\", must conform to the pattern #{pattern}.") end if @granularity.nil? invalid_properties.push('invalid value for "granularity", granularity cannot be nil.') end if @level.nil? invalid_properties.push('invalid value for "level", level cannot be nil.') end if @report_name.nil? invalid_properties.push('invalid value for "report_name", report_name cannot be nil.') end if @start_date.nil? invalid_properties.push('invalid value for "start_date", start_date cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}$/) if @start_date !~ pattern invalid_properties.push("invalid value for \"start_date\", must conform to the pattern #{pattern}.") end if @targeting_types.nil? invalid_properties.push('invalid value for "targeting_types", targeting_types cannot be nil.') end if @targeting_types.length > 7 invalid_properties.push('invalid value for "targeting_types", number of items must be less than or equal to 7.') end if @targeting_types.length < 1 invalid_properties.push('invalid value for "targeting_types", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pinterest_sdk/models/mmm_report_create.rb', line 260 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @columns.nil? return false if !@custom_column_ids.nil? && @custom_column_ids.length > 20 return false if @end_date.nil? return false if @end_date !~ Regexp.new(/^\d{4}-\d{2}-\d{2}$/) return false if @granularity.nil? return false if @level.nil? return false if @report_name.nil? return false if @start_date.nil? return false if @start_date !~ Regexp.new(/^\d{4}-\d{2}-\d{2}$/) return false if @targeting_types.nil? return false if @targeting_types.length > 7 return false if @targeting_types.length < 1 true end |