Class: PinterestSdkClient::OauthAccessTokenResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/oauth_access_token_response.rb

Overview

A successful OAuth access token response.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OauthAccessTokenResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::OauthAccessTokenResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::OauthAccessTokenResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  else
    self.access_token = nil
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  else
    self.expires_in = nil
  end

  if attributes.key?(:'response_type')
    self.response_type = attributes[:'response_type']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  else
    self.scope = nil
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  else
    self.token_type = 'bearer'
  end
end

Instance Attribute Details

#access_tokenObject

Returns the value of attribute access_token.



19
20
21
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 19

def access_token
  @access_token
end

#expires_inObject

Returns the value of attribute expires_in.



21
22
23
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 21

def expires_in
  @expires_in
end

#response_typeObject

Returns the value of attribute response_type.



23
24
25
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 23

def response_type
  @response_type
end

#scopeObject

Returns the value of attribute scope.



25
26
27
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 25

def scope
  @scope
end

#token_typeObject

Returns the value of attribute token_type.



27
28
29
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 27

def token_type
  @token_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 52

def self.attribute_map
  {
    :'access_token' => :'access_token',
    :'expires_in' => :'expires_in',
    :'response_type' => :'response_type',
    :'scope' => :'scope',
    :'token_type' => :'token_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



90
91
92
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 90

def self.openapi_discriminator_name
  :'response_type'
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 73

def self.openapi_types
  {
    :'access_token' => :'String',
    :'expires_in' => :'Integer',
    :'response_type' => :'String',
    :'scope' => :'String',
    :'token_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_token == o.access_token &&
      expires_in == o.expires_in &&
      response_type == o.response_type &&
      scope == o.scope &&
      token_type == o.token_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 246

def hash
  [access_token, expires_in, response_type, scope, token_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @access_token.nil?
    invalid_properties.push('invalid value for "access_token", access_token cannot be nil.')
  end

  if @expires_in.nil?
    invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.')
  end

  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  if @token_type.nil?
    invalid_properties.push('invalid value for "token_type", token_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
# File 'lib/pinterest_sdk/models/oauth_access_token_response.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @access_token.nil?
  return false if @expires_in.nil?
  response_type_validator = EnumAttributeValidator.new('String', ["authorization_code", "refresh_token", "client_credentials"])
  return false unless response_type_validator.valid?(@response_type)
  return false if @scope.nil?
  return false if @token_type.nil?
  true
end