Class: PinterestSdkClient::OauthAccessTokenResponseCode

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/oauth_access_token_response_code.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OauthAccessTokenResponseCode

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::OauthAccessTokenResponseCode` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::OauthAccessTokenResponseCode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end

  if attributes.key?(:'refresh_token_expires_at')
    self.refresh_token_expires_at = attributes[:'refresh_token_expires_at']
  end

  if attributes.key?(:'refresh_token_expires_in')
    self.refresh_token_expires_in = attributes[:'refresh_token_expires_in']
  end

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  else
    self.access_token = nil
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  else
    self.expires_in = nil
  end

  if attributes.key?(:'response_type')
    self.response_type = attributes[:'response_type']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  else
    self.scope = nil
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  else
    self.token_type = 'bearer'
  end
end

Instance Attribute Details

#access_tokenObject

Returns the value of attribute access_token.



24
25
26
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 24

def access_token
  @access_token
end

#expires_inObject

Returns the value of attribute expires_in.



26
27
28
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 26

def expires_in
  @expires_in
end

#refresh_tokenObject

Returns the value of attribute refresh_token.



18
19
20
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 18

def refresh_token
  @refresh_token
end

#refresh_token_expires_atObject

Returns the value of attribute refresh_token_expires_at.



20
21
22
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 20

def refresh_token_expires_at
  @refresh_token_expires_at
end

#refresh_token_expires_inObject

Returns the value of attribute refresh_token_expires_in.



22
23
24
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 22

def refresh_token_expires_in
  @refresh_token_expires_in
end

#response_typeObject

Returns the value of attribute response_type.



28
29
30
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 28

def response_type
  @response_type
end

#scopeObject

Returns the value of attribute scope.



30
31
32
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 30

def scope
  @scope
end

#token_typeObject

Returns the value of attribute token_type.



32
33
34
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 32

def token_type
  @token_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 57

def self.attribute_map
  {
    :'refresh_token' => :'refresh_token',
    :'refresh_token_expires_at' => :'refresh_token_expires_at',
    :'refresh_token_expires_in' => :'refresh_token_expires_in',
    :'access_token' => :'access_token',
    :'expires_in' => :'expires_in',
    :'response_type' => :'response_type',
    :'scope' => :'scope',
    :'token_type' => :'token_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 81

def self.openapi_types
  {
    :'refresh_token' => :'String',
    :'refresh_token_expires_at' => :'Integer',
    :'refresh_token_expires_in' => :'Integer',
    :'access_token' => :'String',
    :'expires_in' => :'Integer',
    :'response_type' => :'String',
    :'scope' => :'String',
    :'token_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      refresh_token == o.refresh_token &&
      refresh_token_expires_at == o.refresh_token_expires_at &&
      refresh_token_expires_in == o.refresh_token_expires_in &&
      access_token == o.access_token &&
      expires_in == o.expires_in &&
      response_type == o.response_type &&
      scope == o.scope &&
      token_type == o.token_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 267

def hash
  [refresh_token, refresh_token_expires_at, refresh_token_expires_in, access_token, expires_in, response_type, scope, token_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @access_token.nil?
    invalid_properties.push('invalid value for "access_token", access_token cannot be nil.')
  end

  if @expires_in.nil?
    invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.')
  end

  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  if @token_type.nil?
    invalid_properties.push('invalid value for "token_type", token_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
# File 'lib/pinterest_sdk/models/oauth_access_token_response_code.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @access_token.nil?
  return false if @expires_in.nil?
  response_type_validator = EnumAttributeValidator.new('String', ["authorization_code", "refresh_token", "client_credentials"])
  return false unless response_type_validator.valid?(@response_type)
  return false if @scope.nil?
  return false if @token_type.nil?
  true
end