Class: PinterestSdkClient::OrderLine

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/order_line.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderLine

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/pinterest_sdk/models/order_line.rb', line 136

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::OrderLine` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::OrderLine`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  end

  if attributes.key?(:'campaign_ids')
    if (value = attributes[:'campaign_ids']).is_a?(Array)
      self.campaign_ids = value
    end
  else
    self.campaign_ids = nil
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'paid_budget')
    self.paid_budget = attributes[:'paid_budget']
  end

  if attributes.key?(:'paid_type')
    self.paid_type = attributes[:'paid_type']
  end

  if attributes.key?(:'purchase_order_id')
    self.purchase_order_id = attributes[:'purchase_order_id']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end
end

Instance Attribute Details

#ad_account_idObject

Ad account ID.



19
20
21
# File 'lib/pinterest_sdk/models/order_line.rb', line 19

def 
  
end

#budgetObject

Order line budget in micro currency.



22
23
24
# File 'lib/pinterest_sdk/models/order_line.rb', line 22

def budget
  @budget
end

#campaign_idsObject

Associated List of campaign IDs.



25
26
27
# File 'lib/pinterest_sdk/models/order_line.rb', line 25

def campaign_ids
  @campaign_ids
end

#end_timeObject

End time. Unix timestamp.



28
29
30
# File 'lib/pinterest_sdk/models/order_line.rb', line 28

def end_time
  @end_time
end

#idObject

Order line ID.



31
32
33
# File 'lib/pinterest_sdk/models/order_line.rb', line 31

def id
  @id
end

#nameObject

Order line name.



34
35
36
# File 'lib/pinterest_sdk/models/order_line.rb', line 34

def name
  @name
end

Order line paid budget in micro currency.



37
38
39
# File 'lib/pinterest_sdk/models/order_line.rb', line 37

def paid_budget
  @paid_budget
end

Order line paid type.



40
41
42
# File 'lib/pinterest_sdk/models/order_line.rb', line 40

def paid_type
  @paid_type
end

#purchase_order_idObject

Purchase order ID.



43
44
45
# File 'lib/pinterest_sdk/models/order_line.rb', line 43

def purchase_order_id
  @purchase_order_id
end

#start_timeObject

Start time. Unix timestamp.



46
47
48
# File 'lib/pinterest_sdk/models/order_line.rb', line 46

def start_time
  @start_time
end

#statusObject

Order line status.



49
50
51
# File 'lib/pinterest_sdk/models/order_line.rb', line 49

def status
  @status
end

#typeObject

Always "orderline".



52
53
54
# File 'lib/pinterest_sdk/models/order_line.rb', line 52

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/pinterest_sdk/models/order_line.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/pinterest_sdk/models/order_line.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pinterest_sdk/models/order_line.rb', line 77

def self.attribute_map
  {
    :'ad_account_id' => :'ad_account_id',
    :'budget' => :'budget',
    :'campaign_ids' => :'campaign_ids',
    :'end_time' => :'end_time',
    :'id' => :'id',
    :'name' => :'name',
    :'paid_budget' => :'paid_budget',
    :'paid_type' => :'paid_type',
    :'purchase_order_id' => :'purchase_order_id',
    :'start_time' => :'start_time',
    :'status' => :'status',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/pinterest_sdk/models/order_line.rb', line 346

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
127
128
129
130
131
132
# File 'lib/pinterest_sdk/models/order_line.rb', line 123

def self.openapi_nullable
  Set.new([
    :'budget',
    :'end_time',
    :'name',
    :'paid_budget',
    :'paid_type',
    :'purchase_order_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/pinterest_sdk/models/order_line.rb', line 105

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'budget' => :'Float',
    :'campaign_ids' => :'Array<String>',
    :'end_time' => :'Float',
    :'id' => :'String',
    :'name' => :'String',
    :'paid_budget' => :'Float',
    :'paid_type' => :'OrderLinePaidType',
    :'purchase_order_id' => :'String',
    :'start_time' => :'Float',
    :'status' => :'OrderLineStatus',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/pinterest_sdk/models/order_line.rb', line 314

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      budget == o.budget &&
      campaign_ids == o.campaign_ids &&
      end_time == o.end_time &&
      id == o.id &&
      name == o.name &&
      paid_budget == o.paid_budget &&
      paid_type == o.paid_type &&
      purchase_order_id == o.purchase_order_id &&
      start_time == o.start_time &&
      status == o.status &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


333
334
335
# File 'lib/pinterest_sdk/models/order_line.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



339
340
341
# File 'lib/pinterest_sdk/models/order_line.rb', line 339

def hash
  [, budget, campaign_ids, end_time, id, name, paid_budget, paid_type, purchase_order_id, start_time, status, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pinterest_sdk/models/order_line.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if .nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if @campaign_ids.nil?
    invalid_properties.push('invalid value for "campaign_ids", campaign_ids cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/pinterest_sdk/models/order_line.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



246
247
248
249
250
251
252
253
254
255
# File 'lib/pinterest_sdk/models/order_line.rb', line 246

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if .nil?
  return false if @campaign_ids.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if @status.nil?
  return false if @type.nil?
  true
end