Class: PinterestSdkClient::PinBase

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/pin_base.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PinBase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/pinterest_sdk/models/pin_base.rb', line 145

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::PinBase` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::PinBase`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ai_disclosures')
    self.ai_disclosures = attributes[:'ai_disclosures']
  end

  if attributes.key?(:'board_id')
    self.board_id = attributes[:'board_id']
  end

  if attributes.key?(:'board_owner')
    self.board_owner = attributes[:'board_owner']
  end

  if attributes.key?(:'board_section_id')
    self.board_section_id = attributes[:'board_section_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'creative_type')
    self.creative_type = attributes[:'creative_type']
  end

  if attributes.key?(:'dominant_color')
    self.dominant_color = attributes[:'dominant_color']
  end

  if attributes.key?(:'has_been_promoted')
    self.has_been_promoted = attributes[:'has_been_promoted']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'is_owner')
    self.is_owner = attributes[:'is_owner']
  end

  if attributes.key?(:'is_product')
    self.is_product = attributes[:'is_product']
  end

  if attributes.key?(:'is_standard')
    self.is_standard = attributes[:'is_standard']
  end

  if attributes.key?(:'media')
    self.media = attributes[:'media']
  end

  if attributes.key?(:'parent_pin_id')
    self.parent_pin_id = attributes[:'parent_pin_id']
  end

  if attributes.key?(:'pin_metrics')
    self.pin_metrics = attributes[:'pin_metrics']
  end
end

Instance Attribute Details

#ai_disclosuresObject

AI disclosure declarations the creator has made about this Pin.



19
20
21
# File 'lib/pinterest_sdk/models/pin_base.rb', line 19

def ai_disclosures
  @ai_disclosures
end

#board_idObject

The board to which this Pin belongs.



22
23
24
# File 'lib/pinterest_sdk/models/pin_base.rb', line 22

def board_id
  @board_id
end

#board_ownerObject

Returns the value of attribute board_owner.



24
25
26
# File 'lib/pinterest_sdk/models/pin_base.rb', line 24

def board_owner
  @board_owner
end

#board_section_idObject

The board section to which this Pin belongs.



27
28
29
# File 'lib/pinterest_sdk/models/pin_base.rb', line 27

def board_section_id
  @board_section_id
end

#created_atObject

Returns the value of attribute created_at.



29
30
31
# File 'lib/pinterest_sdk/models/pin_base.rb', line 29

def created_at
  @created_at
end

#creative_typeObject

Returns the value of attribute creative_type.



31
32
33
# File 'lib/pinterest_sdk/models/pin_base.rb', line 31

def creative_type
  @creative_type
end

#dominant_colorObject

Dominant pin color. Hex number, e.g. #6E7874.



34
35
36
# File 'lib/pinterest_sdk/models/pin_base.rb', line 34

def dominant_color
  @dominant_color
end

#has_been_promotedObject

Whether the Pin has been promoted or not.



37
38
39
# File 'lib/pinterest_sdk/models/pin_base.rb', line 37

def has_been_promoted
  @has_been_promoted
end

#idObject

Returns the value of attribute id.



39
40
41
# File 'lib/pinterest_sdk/models/pin_base.rb', line 39

def id
  @id
end

#is_ownerObject

Whether the "operation user_account" is the Pin owner.



42
43
44
# File 'lib/pinterest_sdk/models/pin_base.rb', line 42

def is_owner
  @is_owner
end

#is_productObject

Whether the Pin is a product Pin.



45
46
47
# File 'lib/pinterest_sdk/models/pin_base.rb', line 45

def is_product
  @is_product
end

#is_standardObject

Whether the Pin is standard or not. See documentation on Changes to Pin creation for more information.



48
49
50
# File 'lib/pinterest_sdk/models/pin_base.rb', line 48

def is_standard
  @is_standard
end

#mediaObject

Returns the value of attribute media.



50
51
52
# File 'lib/pinterest_sdk/models/pin_base.rb', line 50

def media
  @media
end

#parent_pin_idObject

The source pin id if this pin was saved from another pin. Learn more.



53
54
55
# File 'lib/pinterest_sdk/models/pin_base.rb', line 53

def parent_pin_id
  @parent_pin_id
end

#pin_metricsObject

Pin metrics with associated time intervals if any.



56
57
58
# File 'lib/pinterest_sdk/models/pin_base.rb', line 56

def pin_metrics
  @pin_metrics
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



102
103
104
# File 'lib/pinterest_sdk/models/pin_base.rb', line 102

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/pinterest_sdk/models/pin_base.rb', line 107

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/pinterest_sdk/models/pin_base.rb', line 81

def self.attribute_map
  {
    :'ai_disclosures' => :'ai_disclosures',
    :'board_id' => :'board_id',
    :'board_owner' => :'board_owner',
    :'board_section_id' => :'board_section_id',
    :'created_at' => :'created_at',
    :'creative_type' => :'creative_type',
    :'dominant_color' => :'dominant_color',
    :'has_been_promoted' => :'has_been_promoted',
    :'id' => :'id',
    :'is_owner' => :'is_owner',
    :'is_product' => :'is_product',
    :'is_standard' => :'is_standard',
    :'media' => :'media',
    :'parent_pin_id' => :'parent_pin_id',
    :'pin_metrics' => :'pin_metrics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/pinterest_sdk/models/pin_base.rb', line 355

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
137
138
139
140
141
# File 'lib/pinterest_sdk/models/pin_base.rb', line 133

def self.openapi_nullable
  Set.new([
    :'board_section_id',
    :'creative_type',
    :'dominant_color',
    :'parent_pin_id',
    :'pin_metrics'
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/pinterest_sdk/models/pin_base.rb', line 112

def self.openapi_types
  {
    :'ai_disclosures' => :'AiDisclosures',
    :'board_id' => :'String',
    :'board_owner' => :'BoardOwner',
    :'board_section_id' => :'String',
    :'created_at' => :'Time',
    :'creative_type' => :'CreativeType',
    :'dominant_color' => :'String',
    :'has_been_promoted' => :'Boolean',
    :'id' => :'String',
    :'is_owner' => :'Boolean',
    :'is_product' => :'Boolean',
    :'is_standard' => :'Boolean',
    :'media' => :'PinMedia',
    :'parent_pin_id' => :'String',
    :'pin_metrics' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/pinterest_sdk/models/pin_base.rb', line 320

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ai_disclosures == o.ai_disclosures &&
      board_id == o.board_id &&
      board_owner == o.board_owner &&
      board_section_id == o.board_section_id &&
      created_at == o.created_at &&
      creative_type == o.creative_type &&
      dominant_color == o.dominant_color &&
      has_been_promoted == o.has_been_promoted &&
      id == o.id &&
      is_owner == o.is_owner &&
      is_product == o.is_product &&
      is_standard == o.is_standard &&
      media == o.media &&
      parent_pin_id == o.parent_pin_id &&
      pin_metrics == o.pin_metrics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


342
343
344
# File 'lib/pinterest_sdk/models/pin_base.rb', line 342

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



348
349
350
# File 'lib/pinterest_sdk/models/pin_base.rb', line 348

def hash
  [ai_disclosures, board_id, board_owner, board_section_id, created_at, creative_type, dominant_color, has_been_promoted, id, is_owner, is_product, is_standard, media, parent_pin_id, pin_metrics].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/pinterest_sdk/models/pin_base.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@board_id.nil? && @board_id !~ pattern
    invalid_properties.push("invalid value for \"board_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@board_section_id.nil? && @board_section_id !~ pattern
    invalid_properties.push("invalid value for \"board_section_id\", must conform to the pattern #{pattern}.")
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@parent_pin_id.nil? && @parent_pin_id !~ pattern
    invalid_properties.push("invalid value for \"parent_pin_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/pinterest_sdk/models/pin_base.rb', line 377

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



256
257
258
259
260
261
262
263
264
# File 'lib/pinterest_sdk/models/pin_base.rb', line 256

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@board_id.nil? && @board_id !~ Regexp.new(/^\d+$/)
  return false if !@board_section_id.nil? && @board_section_id !~ Regexp.new(/^\d+$/)
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if !@parent_pin_id.nil? && @parent_pin_id !~ Regexp.new(/^\d+$/)
  true
end