Class: PinterestSdkClient::PinCreate

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/pin_create.rb

Overview

Resource create operation model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PinCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/pinterest_sdk/models/pin_create.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::PinCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::PinCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ai_disclosures')
    self.ai_disclosures = attributes[:'ai_disclosures']
  end

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'board_id')
    self.board_id = attributes[:'board_id']
  end

  if attributes.key?(:'board_section_id')
    self.board_section_id = attributes[:'board_section_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'dominant_color')
    self.dominant_color = attributes[:'dominant_color']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'media_source')
    self.media_source = attributes[:'media_source']
  end

  if attributes.key?(:'parent_pin_id')
    self.parent_pin_id = attributes[:'parent_pin_id']
  end

  if attributes.key?(:'sponsor_id')
    self.sponsor_id = attributes[:'sponsor_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#ai_disclosuresObject

AI disclosure declarations the creator has made about this Pin.



20
21
22
# File 'lib/pinterest_sdk/models/pin_create.rb', line 20

def ai_disclosures
  @ai_disclosures
end

#alt_textObject

Returns the value of attribute alt_text.



22
23
24
# File 'lib/pinterest_sdk/models/pin_create.rb', line 22

def alt_text
  @alt_text
end

#board_idObject

The board to which this Pin belongs.



25
26
27
# File 'lib/pinterest_sdk/models/pin_create.rb', line 25

def board_id
  @board_id
end

#board_section_idObject

The board section to which this Pin belongs.



28
29
30
# File 'lib/pinterest_sdk/models/pin_create.rb', line 28

def board_section_id
  @board_section_id
end

#descriptionObject

Returns the value of attribute description.



30
31
32
# File 'lib/pinterest_sdk/models/pin_create.rb', line 30

def description
  @description
end

#dominant_colorObject

Dominant pin color. Hex number, e.g. #6E7874.



33
34
35
# File 'lib/pinterest_sdk/models/pin_create.rb', line 33

def dominant_color
  @dominant_color
end

Returns the value of attribute link.



35
36
37
# File 'lib/pinterest_sdk/models/pin_create.rb', line 35

def link
  @link
end

#media_sourceObject

Returns the value of attribute media_source.



37
38
39
# File 'lib/pinterest_sdk/models/pin_create.rb', line 37

def media_source
  @media_source
end

#parent_pin_idObject

The source pin id if this pin was saved from another pin. Learn more.



40
41
42
# File 'lib/pinterest_sdk/models/pin_create.rb', line 40

def parent_pin_id
  @parent_pin_id
end

The sponsor account id to request paid partnership from. Currently the field is only available to a list of users in a closed beta.



43
44
45
# File 'lib/pinterest_sdk/models/pin_create.rb', line 43

def sponsor_id
  @sponsor_id
end

#titleObject

Returns the value of attribute title.



45
46
47
# File 'lib/pinterest_sdk/models/pin_create.rb', line 45

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/pinterest_sdk/models/pin_create.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/pinterest_sdk/models/pin_create.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/pinterest_sdk/models/pin_create.rb', line 48

def self.attribute_map
  {
    :'ai_disclosures' => :'ai_disclosures',
    :'alt_text' => :'alt_text',
    :'board_id' => :'board_id',
    :'board_section_id' => :'board_section_id',
    :'description' => :'description',
    :'dominant_color' => :'dominant_color',
    :'link' => :'link',
    :'media_source' => :'media_source',
    :'parent_pin_id' => :'parent_pin_id',
    :'sponsor_id' => :'sponsor_id',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/pinterest_sdk/models/pin_create.rb', line 346

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/pinterest_sdk/models/pin_create.rb', line 92

def self.openapi_nullable
  Set.new([
    :'alt_text',
    :'board_section_id',
    :'description',
    :'dominant_color',
    :'link',
    :'parent_pin_id',
    :'sponsor_id',
    :'title'
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pinterest_sdk/models/pin_create.rb', line 75

def self.openapi_types
  {
    :'ai_disclosures' => :'AiDisclosures',
    :'alt_text' => :'String',
    :'board_id' => :'String',
    :'board_section_id' => :'String',
    :'description' => :'String',
    :'dominant_color' => :'String',
    :'link' => :'String',
    :'media_source' => :'PinMediaSource',
    :'parent_pin_id' => :'String',
    :'sponsor_id' => :'String',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/pinterest_sdk/models/pin_create.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ai_disclosures == o.ai_disclosures &&
      alt_text == o.alt_text &&
      board_id == o.board_id &&
      board_section_id == o.board_section_id &&
      description == o.description &&
      dominant_color == o.dominant_color &&
      link == o.link &&
      media_source == o.media_source &&
      parent_pin_id == o.parent_pin_id &&
      sponsor_id == o.sponsor_id &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


333
334
335
# File 'lib/pinterest_sdk/models/pin_create.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



339
340
341
# File 'lib/pinterest_sdk/models/pin_create.rb', line 339

def hash
  [ai_disclosures, alt_text, board_id, board_section_id, description, dominant_color, link, media_source, parent_pin_id, sponsor_id, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pinterest_sdk/models/pin_create.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@alt_text.nil? && @alt_text.to_s.length > 500
    invalid_properties.push('invalid value for "alt_text", the character length must be smaller than or equal to 500.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@board_id.nil? && @board_id !~ pattern
    invalid_properties.push("invalid value for \"board_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@board_section_id.nil? && @board_section_id !~ pattern
    invalid_properties.push("invalid value for \"board_section_id\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 800
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 800.')
  end

  if !@link.nil? && @link.to_s.length > 2048
    invalid_properties.push('invalid value for "link", the character length must be smaller than or equal to 2048.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@parent_pin_id.nil? && @parent_pin_id !~ pattern
    invalid_properties.push("invalid value for \"parent_pin_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@sponsor_id.nil? && @sponsor_id !~ pattern
    invalid_properties.push("invalid value for \"sponsor_id\", must conform to the pattern #{pattern}.")
  end

  if !@title.nil? && @title.to_s.length > 100
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/pinterest_sdk/models/pin_create.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/pinterest_sdk/models/pin_create.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@alt_text.nil? && @alt_text.to_s.length > 500
  return false if !@board_id.nil? && @board_id !~ Regexp.new(/^\d+$/)
  return false if !@board_section_id.nil? && @board_section_id !~ Regexp.new(/^\d+$/)
  return false if !@description.nil? && @description.to_s.length > 800
  return false if !@link.nil? && @link.to_s.length > 2048
  return false if !@parent_pin_id.nil? && @parent_pin_id !~ Regexp.new(/^\d+$/)
  return false if !@sponsor_id.nil? && @sponsor_id !~ Regexp.new(/^\d+$/)
  return false if !@title.nil? && @title.to_s.length > 100
  true
end