Class: PinterestSdkClient::PinMediaWithVideo

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/pin_media_with_video.rb

Overview

Pin with video.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PinMediaWithVideo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::PinMediaWithVideo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::PinMediaWithVideo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cover_image_url')
    self.cover_image_url = attributes[:'cover_image_url']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'images')
    self.images = attributes[:'images']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  else
    self.media_type = nil
  end

  if attributes.key?(:'video_url')
    self.video_url = attributes[:'video_url']
  end

  if attributes.key?(:'video_url_hls')
    self.video_url_hls = attributes[:'video_url_hls']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end
end

Instance Attribute Details

#cover_image_urlObject

Returns the value of attribute cover_image_url.



19
20
21
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 19

def cover_image_url
  @cover_image_url
end

#durationObject

Duration (in miliseconds). Field maybe null after creation due to video processing time.



22
23
24
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 22

def duration
  @duration
end

#heightObject

Height (in pixels). Field maybe null after creation due to video processing time.



25
26
27
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 25

def height
  @height
end

#imagesObject

Returns the value of attribute images.



27
28
29
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 27

def images
  @images
end

#media_typeObject

Returns the value of attribute media_type.



29
30
31
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 29

def media_type
  @media_type
end

#video_urlObject

Video url (720p). Note: This field is limited and not available to all apps.



32
33
34
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 32

def video_url
  @video_url
end

#video_url_hlsObject

Video url (HLS). Note: This field is limited and not available to all apps.



35
36
37
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 35

def video_url_hls
  @video_url_hls
end

#widthObject

Width (in pixels). Field maybe null after creation due to video processing time.



38
39
40
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 38

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 63

def self.attribute_map
  {
    :'cover_image_url' => :'cover_image_url',
    :'duration' => :'duration',
    :'height' => :'height',
    :'images' => :'images',
    :'media_type' => :'media_type',
    :'video_url' => :'video_url',
    :'video_url_hls' => :'video_url_hls',
    :'width' => :'width'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
105
106
107
108
109
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 101

def self.openapi_nullable
  Set.new([
    :'duration',
    :'height',
    :'video_url',
    :'video_url_hls',
    :'width'
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 87

def self.openapi_types
  {
    :'cover_image_url' => :'String',
    :'duration' => :'Float',
    :'height' => :'Integer',
    :'images' => :'ImageSize',
    :'media_type' => :'String',
    :'video_url' => :'String',
    :'video_url_hls' => :'String',
    :'width' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cover_image_url == o.cover_image_url &&
      duration == o.duration &&
      height == o.height &&
      images == o.images &&
      media_type == o.media_type &&
      video_url == o.video_url &&
      video_url_hls == o.video_url_hls &&
      width == o.width
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 217

def hash
  [cover_image_url, duration, height, images, media_type, video_url, video_url_hls, width].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @media_type.nil?
    invalid_properties.push('invalid value for "media_type", media_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
# File 'lib/pinterest_sdk/models/pin_media_with_video.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @media_type.nil?
  media_type_validator = EnumAttributeValidator.new('String', ["video"])
  return false unless media_type_validator.valid?(@media_type)
  true
end