Class: PinterestSdkClient::PinRead
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::PinRead
- Defined in:
- lib/pinterest_sdk/models/pin_read.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ai_disclosures ⇒ Object
AI disclosure declarations the creator has made about this Pin.
-
#alt_text ⇒ Object
Returns the value of attribute alt_text.
-
#board_id ⇒ Object
The board to which this Pin belongs.
-
#board_owner ⇒ Object
Returns the value of attribute board_owner.
-
#board_section_id ⇒ Object
The board section to which this Pin belongs.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#creative_type ⇒ Object
Returns the value of attribute creative_type.
-
#description ⇒ Object
Returns the value of attribute description.
-
#dominant_color ⇒ Object
Dominant pin color.
-
#has_been_promoted ⇒ Object
Whether the Pin has been promoted or not.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_owner ⇒ Object
Whether the "operation user_account" is the Pin owner.
-
#is_product ⇒ Object
Whether the Pin is a product Pin.
-
#is_standard ⇒ Object
Whether the Pin is standard or not.
-
#link ⇒ Object
Returns the value of attribute link.
-
#media ⇒ Object
Returns the value of attribute media.
-
#parent_pin_id ⇒ Object
The source pin id if this pin was saved from another pin.
-
#pin_metrics ⇒ Object
Pin metrics with associated time intervals if any.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PinRead
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PinRead
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 172 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::PinRead` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::PinRead`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ai_disclosures') self.ai_disclosures = attributes[:'ai_disclosures'] end if attributes.key?(:'board_id') self.board_id = attributes[:'board_id'] end if attributes.key?(:'board_owner') self.board_owner = attributes[:'board_owner'] end if attributes.key?(:'board_section_id') self.board_section_id = attributes[:'board_section_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'creative_type') self.creative_type = attributes[:'creative_type'] end if attributes.key?(:'dominant_color') self.dominant_color = attributes[:'dominant_color'] end if attributes.key?(:'has_been_promoted') self.has_been_promoted = attributes[:'has_been_promoted'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'is_owner') self.is_owner = attributes[:'is_owner'] end if attributes.key?(:'is_product') self.is_product = attributes[:'is_product'] end if attributes.key?(:'is_standard') self.is_standard = attributes[:'is_standard'] end if attributes.key?(:'media') self.media = attributes[:'media'] end if attributes.key?(:'parent_pin_id') self.parent_pin_id = attributes[:'parent_pin_id'] end if attributes.key?(:'pin_metrics') self.pin_metrics = attributes[:'pin_metrics'] end if attributes.key?(:'alt_text') self.alt_text = attributes[:'alt_text'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'link') self.link = attributes[:'link'] end if attributes.key?(:'title') self.title = attributes[:'title'] end end |
Instance Attribute Details
#ai_disclosures ⇒ Object
AI disclosure declarations the creator has made about this Pin.
19 20 21 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 19 def ai_disclosures @ai_disclosures end |
#alt_text ⇒ Object
Returns the value of attribute alt_text.
58 59 60 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 58 def alt_text @alt_text end |
#board_id ⇒ Object
The board to which this Pin belongs.
22 23 24 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 22 def board_id @board_id end |
#board_owner ⇒ Object
Returns the value of attribute board_owner.
24 25 26 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 24 def board_owner @board_owner end |
#board_section_id ⇒ Object
The board section to which this Pin belongs.
27 28 29 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 27 def board_section_id @board_section_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
29 30 31 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 29 def created_at @created_at end |
#creative_type ⇒ Object
Returns the value of attribute creative_type.
31 32 33 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 31 def creative_type @creative_type end |
#description ⇒ Object
Returns the value of attribute description.
60 61 62 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 60 def description @description end |
#dominant_color ⇒ Object
Dominant pin color. Hex number, e.g. #6E7874.
34 35 36 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 34 def dominant_color @dominant_color end |
#has_been_promoted ⇒ Object
Whether the Pin has been promoted or not.
37 38 39 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 37 def has_been_promoted @has_been_promoted end |
#id ⇒ Object
Returns the value of attribute id.
39 40 41 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 39 def id @id end |
#is_owner ⇒ Object
Whether the "operation user_account" is the Pin owner.
42 43 44 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 42 def is_owner @is_owner end |
#is_product ⇒ Object
Whether the Pin is a product Pin.
45 46 47 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 45 def is_product @is_product end |
#is_standard ⇒ Object
Whether the Pin is standard or not. See documentation on Changes to Pin creation for more information.
48 49 50 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 48 def is_standard @is_standard end |
#link ⇒ Object
Returns the value of attribute link.
62 63 64 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 62 def link @link end |
#media ⇒ Object
Returns the value of attribute media.
50 51 52 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 50 def media @media end |
#parent_pin_id ⇒ Object
The source pin id if this pin was saved from another pin. Learn more.
53 54 55 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 53 def parent_pin_id @parent_pin_id end |
#pin_metrics ⇒ Object
Pin metrics with associated time intervals if any.
56 57 58 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 56 def pin_metrics @pin_metrics end |
#title ⇒ Object
Returns the value of attribute title.
64 65 66 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 64 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
114 115 116 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 114 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
119 120 121 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 119 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 89 def self.attribute_map { :'ai_disclosures' => :'ai_disclosures', :'board_id' => :'board_id', :'board_owner' => :'board_owner', :'board_section_id' => :'board_section_id', :'created_at' => :'created_at', :'creative_type' => :'creative_type', :'dominant_color' => :'dominant_color', :'has_been_promoted' => :'has_been_promoted', :'id' => :'id', :'is_owner' => :'is_owner', :'is_product' => :'is_product', :'is_standard' => :'is_standard', :'media' => :'media', :'parent_pin_id' => :'parent_pin_id', :'pin_metrics' => :'pin_metrics', :'alt_text' => :'alt_text', :'description' => :'description', :'link' => :'link', :'title' => :'title' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 402 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
164 165 166 167 168 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 164 def self.openapi_all_of [ :'PinBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 149 def self.openapi_nullable Set.new([ :'board_section_id', :'creative_type', :'dominant_color', :'parent_pin_id', :'pin_metrics', :'alt_text', :'description', :'link', :'title' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 124 def self.openapi_types { :'ai_disclosures' => :'AiDisclosures', :'board_id' => :'String', :'board_owner' => :'BoardOwner', :'board_section_id' => :'String', :'created_at' => :'Time', :'creative_type' => :'CreativeType', :'dominant_color' => :'String', :'has_been_promoted' => :'Boolean', :'id' => :'String', :'is_owner' => :'Boolean', :'is_product' => :'Boolean', :'is_standard' => :'Boolean', :'media' => :'PinMedia', :'parent_pin_id' => :'String', :'pin_metrics' => :'Object', :'alt_text' => :'String', :'description' => :'String', :'link' => :'String', :'title' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 363 def ==(o) return true if self.equal?(o) self.class == o.class && ai_disclosures == o.ai_disclosures && board_id == o.board_id && board_owner == o.board_owner && board_section_id == o.board_section_id && created_at == o.created_at && creative_type == o.creative_type && dominant_color == o.dominant_color && has_been_promoted == o.has_been_promoted && id == o.id && is_owner == o.is_owner && is_product == o.is_product && is_standard == o.is_standard && media == o.media && parent_pin_id == o.parent_pin_id && pin_metrics == o.pin_metrics && alt_text == o.alt_text && description == o.description && link == o.link && title == o.title end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 395 def hash [ai_disclosures, board_id, board_owner, board_section_id, created_at, creative_type, dominant_color, has_been_promoted, id, is_owner, is_product, is_standard, media, parent_pin_id, pin_metrics, alt_text, description, link, title].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 267 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@board_id.nil? && @board_id !~ pattern invalid_properties.push("invalid value for \"board_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@board_section_id.nil? && @board_section_id !~ pattern invalid_properties.push("invalid value for \"board_section_id\", must conform to the pattern #{pattern}.") end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@parent_pin_id.nil? && @parent_pin_id !~ pattern invalid_properties.push("invalid value for \"parent_pin_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
299 300 301 302 303 304 305 306 307 |
# File 'lib/pinterest_sdk/models/pin_read.rb', line 299 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@board_id.nil? && @board_id !~ Regexp.new(/^\d+$/) return false if !@board_section_id.nil? && @board_section_id !~ Regexp.new(/^\d+$/) return false if @id.nil? return false if @id !~ Regexp.new(/^\d+$/) return false if !@parent_pin_id.nil? && @parent_pin_id !~ Regexp.new(/^\d+$/) true end |