Class: PinterestSdkClient::ProductCategoryDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ProductCategoryDetails
- Defined in:
- lib/pinterest_sdk/models/product_category_details.rb
Overview
Product category details
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#demographics ⇒ Object
Returns the value of attribute demographics.
-
#has_prediction ⇒ Object
Indicates whether the keyword has a prediction available for the next 90 days.
-
#metrics_highlights ⇒ Object
Returns the value of attribute metrics_highlights.
-
#predicted_time_series ⇒ Object
A sequence of weekly observations of the predicted relative search volume for this keyword over the next 3 months.
-
#product_category ⇒ Object
Returns the value of attribute product_category.
-
#related_searches ⇒ Object
Related search terms for this product category.
-
#time_series ⇒ Object
Time series data showing trend values over time, indexed between 0 and 100.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProductCategoryDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProductCategoryDetails
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ProductCategoryDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ProductCategoryDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'demographics') self.demographics = attributes[:'demographics'] end if attributes.key?(:'has_prediction') self.has_prediction = attributes[:'has_prediction'] else self.has_prediction = nil end if attributes.key?(:'metrics_highlights') self.metrics_highlights = attributes[:'metrics_highlights'] end if attributes.key?(:'predicted_time_series') if (value = attributes[:'predicted_time_series']).is_a?(Hash) self.predicted_time_series = value end end if attributes.key?(:'product_category') self.product_category = attributes[:'product_category'] else self.product_category = nil end if attributes.key?(:'related_searches') if (value = attributes[:'related_searches']).is_a?(Array) self. = value end end if attributes.key?(:'time_series') if (value = attributes[:'time_series']).is_a?(Hash) self.time_series = value end end end |
Instance Attribute Details
#demographics ⇒ Object
Returns the value of attribute demographics.
19 20 21 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 19 def demographics @demographics end |
#has_prediction ⇒ Object
Indicates whether the keyword has a prediction available for the next 90 days. This field is only applicable when include_prediction query parameter is set to true. By default, the value is false and no prediction data is included in the response.
22 23 24 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 22 def has_prediction @has_prediction end |
#metrics_highlights ⇒ Object
Returns the value of attribute metrics_highlights.
24 25 26 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 24 def metrics_highlights @metrics_highlights end |
#predicted_time_series ⇒ Object
A sequence of weekly observations of the predicted relative search volume for this keyword over the next 3 months. These values are normalized to a [0-100] range, and can be used to visualize the forecasted user interest in this keyword. Similar to the historical time_series, normalization is applied independently to the predicted time series of each keyword, but the normalize_against_group query parameter can be used in cases where you wish to compare relative predicted volume between keywords. Note: The cut-off date between historical and predicted time series depends on Pinterest data availability. Usually the data needs a few days to be calculated, so the predicted time series may contain some past dates compared to today. Note: The date of each observation is in ISO-8601 format and represents the end of the week. For example, a value of 2024-01-07 would include predicted searches for the week ending on 2024-01-07.
27 28 29 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 27 def predicted_time_series @predicted_time_series end |
#product_category ⇒ Object
Returns the value of attribute product_category.
29 30 31 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 29 def product_category @product_category end |
#related_searches ⇒ Object
Related search terms for this product category
32 33 34 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 32 def end |
#time_series ⇒ Object
Time series data showing trend values over time, indexed between 0 and 100
35 36 37 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 35 def time_series @time_series end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 60 def self.attribute_map { :'demographics' => :'demographics', :'has_prediction' => :'has_prediction', :'metrics_highlights' => :'metrics_highlights', :'predicted_time_series' => :'predicted_time_series', :'product_category' => :'product_category', :'related_searches' => :'related_searches', :'time_series' => :'time_series' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 230 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 83 def self.openapi_types { :'demographics' => :'ProductCategoriesDemographic', :'has_prediction' => :'Boolean', :'metrics_highlights' => :'ProductCategoriesMetricsHighlights', :'predicted_time_series' => :'Hash<String, Float>', :'product_category' => :'ProductCategoryEnum', :'related_searches' => :'Array<String>', :'time_series' => :'Hash<String, Float>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && demographics == o.demographics && has_prediction == o.has_prediction && metrics_highlights == o.metrics_highlights && predicted_time_series == o.predicted_time_series && product_category == o.product_category && == o. && time_series == o.time_series end |
#eql?(o) ⇒ Boolean
217 218 219 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 217 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 223 def hash [demographics, has_prediction, metrics_highlights, predicted_time_series, product_category, , time_series].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @has_prediction.nil? invalid_properties.push('invalid value for "has_prediction", has_prediction cannot be nil.') end if @product_category.nil? invalid_properties.push('invalid value for "product_category", product_category cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 |
# File 'lib/pinterest_sdk/models/product_category_details.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @has_prediction.nil? return false if @product_category.nil? true end |