Class: PinterestSdkClient::PromotionsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::PromotionsApi
- Defined in:
- lib/pinterest_sdk/api/promotions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PromotionsApi
constructor
A new instance of PromotionsApi.
-
#promotions_create(ad_account_id, promotion_create, opts = {}) ⇒ PromotionsResponse
Create promotions Create multiple new promotions.
-
#promotions_create_with_http_info(ad_account_id, promotion_create, opts = {}) ⇒ Array<(PromotionsResponse, Integer, Hash)>
Create promotions Create multiple new promotions.
-
#promotions_delete(promotion_id, ad_account_id, opts = {}) ⇒ Promotion
Delete promotion by id Delete a promotion within Pinterest.
-
#promotions_delete_with_http_info(promotion_id, ad_account_id, opts = {}) ⇒ Array<(Promotion, Integer, Hash)>
Delete promotion by id Delete a promotion within Pinterest.
-
#promotions_get(promotion_id, ad_account_id, opts = {}) ⇒ Promotion
Get promotion by id Get a promotion by its Pinterest-specific id.
-
#promotions_get_with_http_info(promotion_id, ad_account_id, opts = {}) ⇒ Array<(Promotion, Integer, Hash)>
Get promotion by id Get a promotion by its Pinterest-specific id.
-
#promotions_list(ad_account_id, opts = {}) ⇒ PromotionsList200Response
Get promotions Gets all promotions associated with an ad account ID that can be applied to an ad group.
-
#promotions_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(PromotionsList200Response, Integer, Hash)>
Get promotions Gets all promotions associated with an ad account ID that can be applied to an ad group.
-
#promotions_update(ad_account_id, promotion_batch_update, opts = {}) ⇒ PromotionsResponse
Update promotions Update multiple promotions.
-
#promotions_update_with_http_info(ad_account_id, promotion_batch_update, opts = {}) ⇒ Array<(PromotionsResponse, Integer, Hash)>
Update promotions Update multiple promotions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PromotionsApi
19 20 21 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#promotions_create(ad_account_id, promotion_create, opts = {}) ⇒ PromotionsResponse
Create promotions Create multiple new promotions.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 28 def promotions_create(ad_account_id, promotion_create, opts = {}) data, _status_code, _headers = promotions_create_with_http_info(ad_account_id, promotion_create, opts) data end |
#promotions_create_with_http_info(ad_account_id, promotion_create, opts = {}) ⇒ Array<(PromotionsResponse, Integer, Hash)>
Create promotions Create multiple new promotions.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 39 def promotions_create_with_http_info(ad_account_id, promotion_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.promotions_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling PromotionsApi.promotions_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling PromotionsApi.promotions_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling PromotionsApi.promotions_create, must conform to the pattern #{pattern}." end # verify the required parameter 'promotion_create' is set if @api_client.config.client_side_validation && promotion_create.nil? fail ArgumentError, "Missing the required parameter 'promotion_create' when calling PromotionsApi.promotions_create" end if @api_client.config.client_side_validation && promotion_create.length > 30 fail ArgumentError, 'invalid value for "promotion_create" when calling PromotionsApi.promotions_create, number of items must be less than or equal to 30.' end if @api_client.config.client_side_validation && promotion_create.length < 1 fail ArgumentError, 'invalid value for "promotion_create" when calling PromotionsApi.promotions_create, number of items must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(promotion_create) # return_type return_type = opts[:debug_return_type] || 'PromotionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"PromotionsApi.promotions_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#promotions_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#promotions_delete(promotion_id, ad_account_id, opts = {}) ⇒ Promotion
Delete promotion by id Delete a promotion within Pinterest.
119 120 121 122 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 119 def promotions_delete(promotion_id, ad_account_id, opts = {}) data, _status_code, _headers = promotions_delete_with_http_info(promotion_id, ad_account_id, opts) data end |
#promotions_delete_with_http_info(promotion_id, ad_account_id, opts = {}) ⇒ Array<(Promotion, Integer, Hash)>
Delete promotion by id Delete a promotion within Pinterest.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 130 def promotions_delete_with_http_info(promotion_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.promotions_delete ...' end # verify the required parameter 'promotion_id' is set if @api_client.config.client_side_validation && promotion_id.nil? fail ArgumentError, "Missing the required parameter 'promotion_id' when calling PromotionsApi.promotions_delete" end if @api_client.config.client_side_validation && promotion_id.to_s.length > 18 fail ArgumentError, 'invalid value for "promotion_id" when calling PromotionsApi.promotions_delete, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && promotion_id !~ pattern fail ArgumentError, "invalid value for 'promotion_id' when calling PromotionsApi.promotions_delete, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling PromotionsApi.promotions_delete" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling PromotionsApi.promotions_delete, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling PromotionsApi.promotions_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/promotions/{promotion_id}'.sub('{promotion_id}', CGI.escape(promotion_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Promotion' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"PromotionsApi.promotions_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#promotions_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#promotions_get(promotion_id, ad_account_id, opts = {}) ⇒ Promotion
Get promotion by id Get a promotion by its Pinterest-specific id. It must be associated with the provided ad account id.
206 207 208 209 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 206 def promotions_get(promotion_id, ad_account_id, opts = {}) data, _status_code, _headers = promotions_get_with_http_info(promotion_id, ad_account_id, opts) data end |
#promotions_get_with_http_info(promotion_id, ad_account_id, opts = {}) ⇒ Array<(Promotion, Integer, Hash)>
Get promotion by id Get a promotion by its Pinterest-specific id. It must be associated with the provided ad account id.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 217 def promotions_get_with_http_info(promotion_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.promotions_get ...' end # verify the required parameter 'promotion_id' is set if @api_client.config.client_side_validation && promotion_id.nil? fail ArgumentError, "Missing the required parameter 'promotion_id' when calling PromotionsApi.promotions_get" end if @api_client.config.client_side_validation && promotion_id.to_s.length > 18 fail ArgumentError, 'invalid value for "promotion_id" when calling PromotionsApi.promotions_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && promotion_id !~ pattern fail ArgumentError, "invalid value for 'promotion_id' when calling PromotionsApi.promotions_get, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling PromotionsApi.promotions_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling PromotionsApi.promotions_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling PromotionsApi.promotions_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/promotions/{promotion_id}'.sub('{promotion_id}', CGI.escape(promotion_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Promotion' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"PromotionsApi.promotions_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#promotions_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#promotions_list(ad_account_id, opts = {}) ⇒ PromotionsList200Response
Get promotions Gets all promotions associated with an ad account ID that can be applied to an ad group. Can be either internally-saved promotions or external promotions imported from a commerce integration.
295 296 297 298 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 295 def promotions_list(ad_account_id, opts = {}) data, _status_code, _headers = promotions_list_with_http_info(ad_account_id, opts) data end |
#promotions_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(PromotionsList200Response, Integer, Hash)>
Get promotions Gets all promotions associated with an ad account ID that can be applied to an ad group. Can be either internally-saved promotions or external promotions imported from a commerce integration.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 308 def promotions_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.promotions_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling PromotionsApi.promotions_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling PromotionsApi.promotions_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling PromotionsApi.promotions_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling PromotionsApi.promotions_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling PromotionsApi.promotions_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PromotionsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"PromotionsApi.promotions_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#promotions_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#promotions_update(ad_account_id, promotion_batch_update, opts = {}) ⇒ PromotionsResponse
Update promotions Update multiple promotions.
382 383 384 385 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 382 def promotions_update(ad_account_id, promotion_batch_update, opts = {}) data, _status_code, _headers = promotions_update_with_http_info(ad_account_id, promotion_batch_update, opts) data end |
#promotions_update_with_http_info(ad_account_id, promotion_batch_update, opts = {}) ⇒ Array<(PromotionsResponse, Integer, Hash)>
Update promotions Update multiple promotions.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/pinterest_sdk/api/promotions_api.rb', line 393 def promotions_update_with_http_info(ad_account_id, promotion_batch_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.promotions_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling PromotionsApi.promotions_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling PromotionsApi.promotions_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling PromotionsApi.promotions_update, must conform to the pattern #{pattern}." end # verify the required parameter 'promotion_batch_update' is set if @api_client.config.client_side_validation && promotion_batch_update.nil? fail ArgumentError, "Missing the required parameter 'promotion_batch_update' when calling PromotionsApi.promotions_update" end if @api_client.config.client_side_validation && promotion_batch_update.length > 30 fail ArgumentError, 'invalid value for "promotion_batch_update" when calling PromotionsApi.promotions_update, number of items must be less than or equal to 30.' end if @api_client.config.client_side_validation && promotion_batch_update.length < 1 fail ArgumentError, 'invalid value for "promotion_batch_update" when calling PromotionsApi.promotions_update, number of items must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(promotion_batch_update) # return_type return_type = opts[:debug_return_type] || 'PromotionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"PromotionsApi.promotions_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#promotions_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |