Class: PinterestSdkClient::QuizPinData

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/quiz_pin_data.rb

Overview

This field includes all quiz data including questions, options, and results.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ QuizPinData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::QuizPinData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::QuizPinData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'questions')
    if (value = attributes[:'questions']).is_a?(Array)
      self.questions = value
    end
  end

  if attributes.key?(:'results')
    if (value = attributes[:'results']).is_a?(Array)
      self.results = value
    end
  end

  if attributes.key?(:'tie_breaker_custom_result')
    self.tie_breaker_custom_result = attributes[:'tie_breaker_custom_result']
  end

  if attributes.key?(:'tie_breaker_type')
    self.tie_breaker_type = attributes[:'tie_breaker_type']
  end
end

Instance Attribute Details

#questionsObject

Returns the value of attribute questions.



19
20
21
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 19

def questions
  @questions
end

#resultsObject

Returns the value of attribute results.



21
22
23
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 21

def results
  @results
end

#tie_breaker_custom_resultObject

Returns the value of attribute tie_breaker_custom_result.



23
24
25
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 23

def tie_breaker_custom_result
  @tie_breaker_custom_result
end

#tie_breaker_typeObject

Returns the value of attribute tie_breaker_type.



25
26
27
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 25

def tie_breaker_type
  @tie_breaker_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 50

def self.attribute_map
  {
    :'questions' => :'questions',
    :'results' => :'results',
    :'tie_breaker_custom_result' => :'tie_breaker_custom_result',
    :'tie_breaker_type' => :'tie_breaker_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 164

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
84
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 80

def self.openapi_nullable
  Set.new([
    :'tie_breaker_custom_result',
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 70

def self.openapi_types
  {
    :'questions' => :'Array<QuizPinQuestion>',
    :'results' => :'Array<QuizPinResult>',
    :'tie_breaker_custom_result' => :'QuizPinResult',
    :'tie_breaker_type' => :'TieBreakerType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      questions == o.questions &&
      results == o.results &&
      tie_breaker_custom_result == o.tie_breaker_custom_result &&
      tie_breaker_type == o.tie_breaker_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 151

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



157
158
159
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 157

def hash
  [questions, results, tie_breaker_custom_result, tie_breaker_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
# File 'lib/pinterest_sdk/models/quiz_pin_data.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end