Class: PinterestSdkClient::SSIOAccountItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::SSIOAccountItem
- Defined in:
- lib/pinterest_sdk/models/ssio_account_item.rb
Overview
Salesforce account item with billing and terms information.
Instance Attribute Summary collapse
-
#addresses ⇒ Object
Address information that is associated with this account.
-
#id ⇒ Object
Salesforce id for billto_info.
-
#io_terms ⇒ Object
Salesforce text for IO Terms and Conditions.
-
#io_terms_id ⇒ Object
Salesforce id for IO Terms and Conditions.
-
#io_type ⇒ Object
Insertion Order Type - Pinterest Paper or Agency Paper.
-
#row_terms ⇒ Object
Salesforce text for Rest of the World Terms and Conditions.
-
#row_terms_id ⇒ Object
Salesforce id for Rest of the World Terms and Conditions.
-
#us_terms ⇒ Object
Salesforce text for US Terms and Conditions.
-
#us_terms_id ⇒ Object
Salesforce id for US Terms and Conditions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SSIOAccountItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SSIOAccountItem
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::SSIOAccountItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::SSIOAccountItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'addresses') if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'io_terms') self.io_terms = attributes[:'io_terms'] end if attributes.key?(:'io_terms_id') self.io_terms_id = attributes[:'io_terms_id'] end if attributes.key?(:'io_type') self.io_type = attributes[:'io_type'] end if attributes.key?(:'row_terms') self.row_terms = attributes[:'row_terms'] end if attributes.key?(:'row_terms_id') self.row_terms_id = attributes[:'row_terms_id'] end if attributes.key?(:'us_terms') self.us_terms = attributes[:'us_terms'] end if attributes.key?(:'us_terms_id') self.us_terms_id = attributes[:'us_terms_id'] end end |
Instance Attribute Details
#addresses ⇒ Object
Address information that is associated with this account.
20 21 22 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 20 def addresses @addresses end |
#id ⇒ Object
Salesforce id for billto_info
23 24 25 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 23 def id @id end |
#io_terms ⇒ Object
Salesforce text for IO Terms and Conditions
26 27 28 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 26 def io_terms @io_terms end |
#io_terms_id ⇒ Object
Salesforce id for IO Terms and Conditions
29 30 31 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 29 def io_terms_id @io_terms_id end |
#io_type ⇒ Object
Insertion Order Type - Pinterest Paper or Agency Paper
32 33 34 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 32 def io_type @io_type end |
#row_terms ⇒ Object
Salesforce text for Rest of the World Terms and Conditions
35 36 37 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 35 def row_terms @row_terms end |
#row_terms_id ⇒ Object
Salesforce id for Rest of the World Terms and Conditions
38 39 40 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 38 def row_terms_id @row_terms_id end |
#us_terms ⇒ Object
Salesforce text for US Terms and Conditions
41 42 43 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 41 def us_terms @us_terms end |
#us_terms_id ⇒ Object
Salesforce id for US Terms and Conditions
44 45 46 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 44 def us_terms_id @us_terms_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 47 def self.attribute_map { :'addresses' => :'addresses', :'id' => :'id', :'io_terms' => :'io_terms', :'io_terms_id' => :'io_terms_id', :'io_type' => :'io_type', :'row_terms' => :'row_terms', :'row_terms_id' => :'row_terms_id', :'us_terms' => :'us_terms', :'us_terms_id' => :'us_terms_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 72 def self.openapi_types { :'addresses' => :'Array<SSIOAccountAddress>', :'id' => :'String', :'io_terms' => :'String', :'io_terms_id' => :'String', :'io_type' => :'String', :'row_terms' => :'String', :'row_terms_id' => :'String', :'us_terms' => :'String', :'us_terms_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && addresses == o.addresses && id == o.id && io_terms == o.io_terms && io_terms_id == o.io_terms_id && io_type == o.io_type && row_terms == o.row_terms && row_terms_id == o.row_terms_id && us_terms == o.us_terms && us_terms_id == o.us_terms_id end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 186 def hash [addresses, id, io_terms, io_terms_id, io_type, row_terms, row_terms_id, us_terms, us_terms_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 |
# File 'lib/pinterest_sdk/models/ssio_account_item.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |