Class: PinterestSdkClient::SSIOInsertionOrderStatusResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb

Overview

SSIO insertion order status response for a single pin order id lookup.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SSIOInsertionOrderStatusResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::SSIOInsertionOrderStatusResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::SSIOInsertionOrderStatusResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'creation_time')
    self.creation_time = attributes[:'creation_time']
  end

  if attributes.key?(:'pin_order_id')
    self.pin_order_id = attributes[:'pin_order_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#creation_timeObject

Salesforce insertion order creation time



20
21
22
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 20

def creation_time
  @creation_time
end

#pin_order_idObject

Salesforce order id



23
24
25
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 23

def pin_order_id
  @pin_order_id
end

#statusObject

Salesforce insertion order status



26
27
28
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 26

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 29

def self.attribute_map
  {
    :'creation_time' => :'creation_time',
    :'pin_order_id' => :'pin_order_id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 139

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



64
65
66
67
68
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 64

def self.openapi_all_of
  [
  :'SSIOInsertionOrderStatus'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 57

def self.openapi_nullable
  Set.new([
    :'creation_time',
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 48

def self.openapi_types
  {
    :'creation_time' => :'String',
    :'pin_order_id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



116
117
118
119
120
121
122
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 116

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      creation_time == o.creation_time &&
      pin_order_id == o.pin_order_id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


126
127
128
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 126

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



132
133
134
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 132

def hash
  [creation_time, pin_order_id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



101
102
103
104
105
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 101

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 161

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
112
# File 'lib/pinterest_sdk/models/ssio_insertion_order_status_response.rb', line 109

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end