Class: PinterestSdkClient::Schedule

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/schedule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Schedule

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/pinterest_sdk/models/schedule.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::Schedule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::Schedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'delta_value')
    self.delta_value = attributes[:'delta_value']
  end

  if attributes.key?(:'end_timestamp')
    self.end_timestamp = attributes[:'end_timestamp']
  end

  if attributes.key?(:'entity_id')
    self.entity_id = attributes[:'entity_id']
  else
    self.entity_id = nil
  end

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'schedule_action')
    self.schedule_action = attributes[:'schedule_action']
  end

  if attributes.key?(:'schedule_id')
    self.schedule_id = attributes[:'schedule_id']
  else
    self.schedule_id = nil
  end

  if attributes.key?(:'schedule_status')
    self.schedule_status = attributes[:'schedule_status']
  end

  if attributes.key?(:'schedule_type')
    self.schedule_type = attributes[:'schedule_type']
  end

  if attributes.key?(:'start_timestamp')
    self.start_timestamp = attributes[:'start_timestamp']
  end
end

Instance Attribute Details

#delta_valueObject

Returns the value of attribute delta_value.



18
19
20
# File 'lib/pinterest_sdk/models/schedule.rb', line 18

def delta_value
  @delta_value
end

#end_timestampObject

Schedule end time. Unix timestamp in seconds.



21
22
23
# File 'lib/pinterest_sdk/models/schedule.rb', line 21

def end_timestamp
  @end_timestamp
end

#entity_idObject

entity ID.



24
25
26
# File 'lib/pinterest_sdk/models/schedule.rb', line 24

def entity_id
  @entity_id
end

#entity_typeObject

Specify the entity_type to get summary information



27
28
29
# File 'lib/pinterest_sdk/models/schedule.rb', line 27

def entity_type
  @entity_type
end

#nameObject

Schedule name.



30
31
32
# File 'lib/pinterest_sdk/models/schedule.rb', line 30

def name
  @name
end

#schedule_actionObject

The schedule action.



33
34
35
# File 'lib/pinterest_sdk/models/schedule.rb', line 33

def schedule_action
  @schedule_action
end

#schedule_idObject

Schedule ID.



36
37
38
# File 'lib/pinterest_sdk/models/schedule.rb', line 36

def schedule_id
  @schedule_id
end

#schedule_statusObject

Schedule status.



39
40
41
# File 'lib/pinterest_sdk/models/schedule.rb', line 39

def schedule_status
  @schedule_status
end

#schedule_typeObject

The schedule type.



42
43
44
# File 'lib/pinterest_sdk/models/schedule.rb', line 42

def schedule_type
  @schedule_type
end

#start_timestampObject

Schedule start time. Unix timestamp in seconds.



45
46
47
# File 'lib/pinterest_sdk/models/schedule.rb', line 45

def start_timestamp
  @start_timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/pinterest_sdk/models/schedule.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/pinterest_sdk/models/schedule.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/pinterest_sdk/models/schedule.rb', line 70

def self.attribute_map
  {
    :'delta_value' => :'delta_value',
    :'end_timestamp' => :'end_timestamp',
    :'entity_id' => :'entity_id',
    :'entity_type' => :'entity_type',
    :'name' => :'name',
    :'schedule_action' => :'schedule_action',
    :'schedule_id' => :'schedule_id',
    :'schedule_status' => :'schedule_status',
    :'schedule_type' => :'schedule_type',
    :'start_timestamp' => :'start_timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/pinterest_sdk/models/schedule.rb', line 277

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/pinterest_sdk/models/schedule.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/pinterest_sdk/models/schedule.rb', line 96

def self.openapi_types
  {
    :'delta_value' => :'ScheduleDeltaValue',
    :'end_timestamp' => :'Integer',
    :'entity_id' => :'String',
    :'entity_type' => :'AdAccountEntityType',
    :'name' => :'String',
    :'schedule_action' => :'ScheduleAction',
    :'schedule_id' => :'String',
    :'schedule_status' => :'ScheduleStatus',
    :'schedule_type' => :'ScheduleType',
    :'start_timestamp' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/pinterest_sdk/models/schedule.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      delta_value == o.delta_value &&
      end_timestamp == o.end_timestamp &&
      entity_id == o.entity_id &&
      entity_type == o.entity_type &&
      name == o.name &&
      schedule_action == o.schedule_action &&
      schedule_id == o.schedule_id &&
      schedule_status == o.schedule_status &&
      schedule_type == o.schedule_type &&
      start_timestamp == o.start_timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


264
265
266
# File 'lib/pinterest_sdk/models/schedule.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



270
271
272
# File 'lib/pinterest_sdk/models/schedule.rb', line 270

def hash
  [delta_value, end_timestamp, entity_id, entity_type, name, schedule_action, schedule_id, schedule_status, schedule_type, start_timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pinterest_sdk/models/schedule.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @entity_id.nil?
    invalid_properties.push('invalid value for "entity_id", entity_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @entity_id !~ pattern
    invalid_properties.push("invalid value for \"entity_id\", must conform to the pattern #{pattern}.")
  end

  if @schedule_id.nil?
    invalid_properties.push('invalid value for "schedule_id", schedule_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @schedule_id !~ pattern
    invalid_properties.push("invalid value for \"schedule_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/pinterest_sdk/models/schedule.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



206
207
208
209
210
211
212
213
# File 'lib/pinterest_sdk/models/schedule.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @entity_id.nil?
  return false if @entity_id !~ Regexp.new(/^\d+$/)
  return false if @schedule_id.nil?
  return false if @schedule_id !~ Regexp.new(/^\d+$/)
  true
end