Class: PinterestSdkClient::ScheduleCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ScheduleCreate
- Defined in:
- lib/pinterest_sdk/models/schedule_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#delta_value ⇒ Object
Returns the value of attribute delta_value.
-
#end_timestamp ⇒ Object
Schedule end time.
-
#entity_id ⇒ Object
entity ID.
-
#entity_type ⇒ Object
Specify the entity_type to get summary information.
-
#name ⇒ Object
Schedule name.
-
#schedule_action ⇒ Object
The schedule action.
-
#schedule_status ⇒ Object
Schedule status.
-
#schedule_type ⇒ Object
The schedule type.
-
#start_timestamp ⇒ Object
Schedule start time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduleCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScheduleCreate
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ScheduleCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ScheduleCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delta_value') self.delta_value = attributes[:'delta_value'] end if attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] end if attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] else self.entity_id = nil end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'schedule_action') self.schedule_action = attributes[:'schedule_action'] end if attributes.key?(:'schedule_status') self.schedule_status = attributes[:'schedule_status'] end if attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] end if attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] end end |
Instance Attribute Details
#delta_value ⇒ Object
Returns the value of attribute delta_value.
19 20 21 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 19 def delta_value @delta_value end |
#end_timestamp ⇒ Object
Schedule end time. Unix timestamp in seconds.
22 23 24 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 22 def end |
#entity_id ⇒ Object
entity ID.
25 26 27 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 25 def entity_id @entity_id end |
#entity_type ⇒ Object
Specify the entity_type to get summary information
28 29 30 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 28 def entity_type @entity_type end |
#name ⇒ Object
Schedule name.
31 32 33 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 31 def name @name end |
#schedule_action ⇒ Object
The schedule action.
34 35 36 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 34 def schedule_action @schedule_action end |
#schedule_status ⇒ Object
Schedule status.
37 38 39 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 37 def schedule_status @schedule_status end |
#schedule_type ⇒ Object
The schedule type.
40 41 42 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 40 def schedule_type @schedule_type end |
#start_timestamp ⇒ Object
Schedule start time. Unix timestamp in seconds.
43 44 45 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 43 def end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 68 def self.attribute_map { :'delta_value' => :'delta_value', :'end_timestamp' => :'end_timestamp', :'entity_id' => :'entity_id', :'entity_type' => :'entity_type', :'name' => :'name', :'schedule_action' => :'schedule_action', :'schedule_status' => :'schedule_status', :'schedule_type' => :'schedule_type', :'start_timestamp' => :'start_timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 93 def self.openapi_types { :'delta_value' => :'ScheduleDeltaValue', :'end_timestamp' => :'Integer', :'entity_id' => :'String', :'entity_type' => :'AdAccountEntityType', :'name' => :'String', :'schedule_action' => :'ScheduleAction', :'schedule_status' => :'ScheduleStatus', :'schedule_type' => :'ScheduleType', :'start_timestamp' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && delta_value == o.delta_value && == o. && entity_id == o.entity_id && entity_type == o.entity_type && name == o.name && schedule_action == o.schedule_action && schedule_status == o.schedule_status && schedule_type == o.schedule_type && == o. end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 233 def hash [delta_value, , entity_id, entity_type, name, schedule_action, schedule_status, schedule_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @entity_id.nil? invalid_properties.push('invalid value for "entity_id", entity_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @entity_id !~ pattern invalid_properties.push("invalid value for \"entity_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 |
# File 'lib/pinterest_sdk/models/schedule_create.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @entity_id.nil? return false if @entity_id !~ Regexp.new(/^\d+$/) true end |