Class: PinterestSdkClient::SchedulesApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::SchedulesApi
- Defined in:
- lib/pinterest_sdk/api/schedules_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SchedulesApi
constructor
A new instance of SchedulesApi.
-
#schedules_create(ad_account_id, schedule_create, opts = {}) ⇒ Array<SchedulesCreate200ResponseInner>
Create schedules Batch create schedules.
-
#schedules_create_with_http_info(ad_account_id, schedule_create, opts = {}) ⇒ Array<(Array<SchedulesCreate200ResponseInner>, Integer, Hash)>
Create schedules Batch create schedules.
-
#schedules_list(ad_account_id, entity_ids, opts = {}) ⇒ SchedulesList200Response
Get Schedules Get schedules for a specific advertiser.
-
#schedules_list_with_http_info(ad_account_id, entity_ids, opts = {}) ⇒ Array<(SchedulesList200Response, Integer, Hash)>
Get Schedules Get schedules for a specific advertiser.
-
#schedules_update(ad_account_id, schedule_batch_update, opts = {}) ⇒ Array<SchedulesCreate200ResponseInner>
Update schedules Update one or more schedules.
-
#schedules_update_with_http_info(ad_account_id, schedule_batch_update, opts = {}) ⇒ Array<(Array<SchedulesCreate200ResponseInner>, Integer, Hash)>
Update schedules Update one or more schedules.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SchedulesApi
19 20 21 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#schedules_create(ad_account_id, schedule_create, opts = {}) ⇒ Array<SchedulesCreate200ResponseInner>
Create schedules Batch create schedules
28 29 30 31 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 28 def schedules_create(ad_account_id, schedule_create, opts = {}) data, _status_code, _headers = schedules_create_with_http_info(ad_account_id, schedule_create, opts) data end |
#schedules_create_with_http_info(ad_account_id, schedule_create, opts = {}) ⇒ Array<(Array<SchedulesCreate200ResponseInner>, Integer, Hash)>
Create schedules Batch create schedules
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 39 def schedules_create_with_http_info(ad_account_id, schedule_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SchedulesApi.schedules_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling SchedulesApi.schedules_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling SchedulesApi.schedules_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling SchedulesApi.schedules_create, must conform to the pattern #{pattern}." end # verify the required parameter 'schedule_create' is set if @api_client.config.client_side_validation && schedule_create.nil? fail ArgumentError, "Missing the required parameter 'schedule_create' when calling SchedulesApi.schedules_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/schedules'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(schedule_create) # return_type return_type = opts[:debug_return_type] || 'Array<SchedulesCreate200ResponseInner>' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"SchedulesApi.schedules_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SchedulesApi#schedules_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#schedules_list(ad_account_id, entity_ids, opts = {}) ⇒ SchedulesList200Response
Get Schedules Get schedules for a specific advertiser
116 117 118 119 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 116 def schedules_list(ad_account_id, entity_ids, opts = {}) data, _status_code, _headers = schedules_list_with_http_info(ad_account_id, entity_ids, opts) data end |
#schedules_list_with_http_info(ad_account_id, entity_ids, opts = {}) ⇒ Array<(SchedulesList200Response, Integer, Hash)>
Get Schedules Get schedules for a specific advertiser
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 132 def schedules_list_with_http_info(ad_account_id, entity_ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SchedulesApi.schedules_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling SchedulesApi.schedules_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling SchedulesApi.schedules_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling SchedulesApi.schedules_list, must conform to the pattern #{pattern}." end # verify the required parameter 'entity_ids' is set if @api_client.config.client_side_validation && entity_ids.nil? fail ArgumentError, "Missing the required parameter 'entity_ids' when calling SchedulesApi.schedules_list" end if @api_client.config.client_side_validation && entity_ids.length < 1 fail ArgumentError, 'invalid value for "entity_ids" when calling SchedulesApi.schedules_list, number of items must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SchedulesApi.schedules_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SchedulesApi.schedules_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/schedules'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'entity_ids'] = @api_client.build_collection_param(entity_ids, :multi) query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'schedule_statuses'] = @api_client.build_collection_param(opts[:'schedule_statuses'], :multi) if !opts[:'schedule_statuses'].nil? query_params[:'schedule_type'] = opts[:'schedule_type'] if !opts[:'schedule_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SchedulesList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"SchedulesApi.schedules_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SchedulesApi#schedules_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#schedules_update(ad_account_id, schedule_batch_update, opts = {}) ⇒ Array<SchedulesCreate200ResponseInner>
Update schedules Update one or more schedules
217 218 219 220 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 217 def schedules_update(ad_account_id, schedule_batch_update, opts = {}) data, _status_code, _headers = schedules_update_with_http_info(ad_account_id, schedule_batch_update, opts) data end |
#schedules_update_with_http_info(ad_account_id, schedule_batch_update, opts = {}) ⇒ Array<(Array<SchedulesCreate200ResponseInner>, Integer, Hash)>
Update schedules Update one or more schedules
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/pinterest_sdk/api/schedules_api.rb', line 228 def schedules_update_with_http_info(ad_account_id, schedule_batch_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SchedulesApi.schedules_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling SchedulesApi.schedules_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling SchedulesApi.schedules_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling SchedulesApi.schedules_update, must conform to the pattern #{pattern}." end # verify the required parameter 'schedule_batch_update' is set if @api_client.config.client_side_validation && schedule_batch_update.nil? fail ArgumentError, "Missing the required parameter 'schedule_batch_update' when calling SchedulesApi.schedules_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/schedules'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(schedule_batch_update) # return_type return_type = opts[:debug_return_type] || 'Array<SchedulesCreate200ResponseInner>' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"SchedulesApi.schedules_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SchedulesApi#schedules_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |