Class: PinterestSdkClient::SearchApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/search_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SearchApi

Returns a new instance of SearchApi.



19
20
21
# File 'lib/pinterest_sdk/api/search_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/search_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#search_partner_pins(term, country_code, opts = {}) ⇒ SearchPartnerPins200Response

Search pins by a given search term This endpoint is currently in beta and not available to all apps. Learn more. Get the top 10 Pins by a given search term.

Parameters:

  • term (String)

    Search term to look up pins.

  • country_code (String)

    Two letter country code (ISO 3166-1 alpha-2)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :locale (String)

    Search locale.

  • :limit (Integer)

    Max search result size (default to 10)

Returns:



31
32
33
34
# File 'lib/pinterest_sdk/api/search_api.rb', line 31

def search_partner_pins(term, country_code, opts = {})
  data, _status_code, _headers = search_partner_pins_with_http_info(term, country_code, opts)
  data
end

#search_partner_pins_with_http_info(term, country_code, opts = {}) ⇒ Array<(SearchPartnerPins200Response, Integer, Hash)>

Search pins by a given search term This endpoint is currently in beta and not available to all apps. Learn more. Get the top 10 Pins by a given search term.

Parameters:

  • term (String)

    Search term to look up pins.

  • country_code (String)

    Two letter country code (ISO 3166-1 alpha-2)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :locale (String)

    Search locale.

  • :limit (Integer)

    Max search result size (default to 10)

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/pinterest_sdk/api/search_api.rb', line 45

def search_partner_pins_with_http_info(term, country_code, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SearchApi.search_partner_pins ...'
  end
  # verify the required parameter 'term' is set
  if @api_client.config.client_side_validation && term.nil?
    fail ArgumentError, "Missing the required parameter 'term' when calling SearchApi.search_partner_pins"
  end
  # verify the required parameter 'country_code' is set
  if @api_client.config.client_side_validation && country_code.nil?
    fail ArgumentError, "Missing the required parameter 'country_code' when calling SearchApi.search_partner_pins"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 50
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SearchApi.search_partner_pins, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SearchApi.search_partner_pins, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/search/partner/pins'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'term'] = term
  query_params[:'country_code'] = country_code
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'locale'] = opts[:'locale'] if !opts[:'locale'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SearchPartnerPins200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"SearchApi.search_partner_pins",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SearchApi#search_partner_pins\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search_user_boards_get(opts = {}) ⇒ BoardsList200Response

Search user's boards Search for boards for the "operation user_account". This includes boards of all board types. - By default, the "operation user_account" is the token user_account. If using Business Access: Specify an ad_account_id to use the owner of that ad_account as the "operation user_account". See Understanding Business Access for more information.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :query (String)

    Search query. Can contain pin description keywords or comma-separated pin IDs.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:



118
119
120
121
# File 'lib/pinterest_sdk/api/search_api.rb', line 118

def search_user_boards_get(opts = {})
  data, _status_code, _headers = search_user_boards_get_with_http_info(opts)
  data
end

#search_user_boards_get_with_http_info(opts = {}) ⇒ Array<(BoardsList200Response, Integer, Hash)>

Search user's boards Search for boards for the &quot;operation user_account&quot;. This includes boards of all board types. - By default, the &quot;operation user_account&quot; is the token user_account. If using Business Access: Specify an ad_account_id to use the owner of that ad_account as the &quot;operation user_account&quot;. See Understanding Business Access for more information.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :query (String)

    Search query. Can contain pin description keywords or comma-separated pin IDs.

  • :bookmark (String)

    Cursor used to fetch the next page of items

  • :page_size (Integer)

    Maximum number of items to include in a single page. See documentation on Pagination for more information. (default to 25)

Returns:

  • (Array<(BoardsList200Response, Integer, Hash)>)

    BoardsList200Response data, response status code and response headers



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/pinterest_sdk/api/search_api.rb', line 131

def search_user_boards_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SearchApi.search_user_boards_get ...'
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling SearchApi.search_user_boards_get, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling SearchApi.search_user_boards_get, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SearchApi.search_user_boards_get, must be smaller than or equal to 250.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SearchApi.search_user_boards_get, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/search/boards'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?
  query_params[:'query'] = opts[:'query'] if !opts[:'query'].nil?
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BoardsList200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials']

  new_options = opts.merge(
    :operation => :"SearchApi.search_user_boards_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SearchApi#search_user_boards_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search_user_pins_list(query, opts = {}) ⇒ PinsList200Response

Search user's Pins Search for pins for the "operation user_account". - By default, the "operation user_account" is the token user_account. If using Business Access: Specify an ad_account_id to use the owner of that ad_account as the "operation user_account". See Understanding Business Access for more information.

Parameters:

  • query (String)

    Search query. Can contain pin description keywords or comma-separated pin IDs.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :bookmark (String)

    Cursor used to fetch the next page of items

Returns:



203
204
205
206
# File 'lib/pinterest_sdk/api/search_api.rb', line 203

def search_user_pins_list(query, opts = {})
  data, _status_code, _headers = search_user_pins_list_with_http_info(query, opts)
  data
end

#search_user_pins_list_with_http_info(query, opts = {}) ⇒ Array<(PinsList200Response, Integer, Hash)>

Search user's Pins Search for pins for the &quot;operation user_account&quot;. - By default, the &quot;operation user_account&quot; is the token user_account. If using Business Access: Specify an ad_account_id to use the owner of that ad_account as the &quot;operation user_account&quot;. See Understanding Business Access for more information.

Parameters:

  • query (String)

    Search query. Can contain pin description keywords or comma-separated pin IDs.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ad_account_id (String)

    Unique identifier of an ad account.

  • :bookmark (String)

    Cursor used to fetch the next page of items

Returns:

  • (Array<(PinsList200Response, Integer, Hash)>)

    PinsList200Response data, response status code and response headers



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/pinterest_sdk/api/search_api.rb', line 215

def search_user_pins_list_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SearchApi.search_user_pins_list ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling SearchApi.search_user_pins_list"
  end
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18
    fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling SearchApi.search_user_pins_list, the character length must be smaller than or equal to 18.'
  end

  pattern = Regexp.new(/^\d+$/)
  if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling SearchApi.search_user_pins_list, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/search/pins'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil?
  query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PinsList200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"SearchApi.search_user_pins_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SearchApi#search_user_pins_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end