Class: PinterestSdkClient::SummaryPin

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/summary_pin.rb

Overview

Summarized pin information

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SummaryPin

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::SummaryPin` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::SummaryPin`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'media')
    self.media = attributes[:'media']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#alt_textObject

Returns the value of attribute alt_text.



19
20
21
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 19

def alt_text
  @alt_text
end

#descriptionObject

Returns the value of attribute description.



21
22
23
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 21

def description
  @description
end

#idObject

Returns the value of attribute id.



23
24
25
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 23

def id
  @id
end

Returns the value of attribute link.



25
26
27
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 25

def link
  @link
end

#mediaObject

Returns the value of attribute media.



27
28
29
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 27

def media
  @media
end

#titleObject

Returns the value of attribute title.



29
30
31
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 29

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 32

def self.attribute_map
  {
    :'alt_text' => :'alt_text',
    :'description' => :'description',
    :'id' => :'id',
    :'link' => :'link',
    :'media' => :'media',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
72
73
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 66

def self.openapi_nullable
  Set.new([
    :'alt_text',
    :'description',
    :'link',
    :'title'
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 54

def self.openapi_types
  {
    :'alt_text' => :'String',
    :'description' => :'String',
    :'id' => :'String',
    :'link' => :'String',
    :'media' => :'PinMedia',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alt_text == o.alt_text &&
      description == o.description &&
      id == o.id &&
      link == o.link &&
      media == o.media &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 240

def hash
  [alt_text, description, id, link, media, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@alt_text.nil? && @alt_text.to_s.length > 500
    invalid_properties.push('invalid value for "alt_text", the character length must be smaller than or equal to 500.')
  end

  if !@description.nil? && @description.to_s.length > 800
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 800.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@link.nil? && @link.to_s.length > 2048
    invalid_properties.push('invalid value for "link", the character length must be smaller than or equal to 2048.')
  end

  if !@title.nil? && @title.to_s.length > 100
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
161
162
# File 'lib/pinterest_sdk/models/summary_pin.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@alt_text.nil? && @alt_text.to_s.length > 500
  return false if !@description.nil? && @description.to_s.length > 800
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if !@link.nil? && @link.to_s.length > 2048
  return false if !@title.nil? && @title.to_s.length > 100
  true
end