Class: PinterestSdkClient::TargetingTemplate

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/targeting_template.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TargetingTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TargetingTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TargetingTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'auto_targeting_enabled')
    self.auto_targeting_enabled = attributes[:'auto_targeting_enabled']
  else
    self.auto_targeting_enabled = true
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'placement_group')
    self.placement_group = attributes[:'placement_group']
  else
    self.placement_group = 'ALL'
  end

  if attributes.key?(:'sizing')
    self.sizing = attributes[:'sizing']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'targeting_attributes')
    self.targeting_attributes = attributes[:'targeting_attributes']
  else
    self.targeting_attributes = nil
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  end
end

Instance Attribute Details

#ad_account_idObject

The ID of the advertiser that this targeting template belongs to.



19
20
21
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 19

def 
  @ad_account_id
end

#auto_targeting_enabledObject

Enable auto-targeting for ad group. Also known as "expanded targeting".



22
23
24
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 22

def auto_targeting_enabled
  @auto_targeting_enabled
end

#created_timeObject

Targeting template created time. Unix timestamp in seconds.



25
26
27
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 25

def created_time
  @created_time
end

#idObject

Targeting template ID.



28
29
30
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 28

def id
  @id
end

#keywordsObject

Returns the value of attribute keywords.



30
31
32
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 30

def keywords
  @keywords
end

#nameObject

targeting template name



33
34
35
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 33

def name
  @name
end

#placement_groupObject

Returns the value of attribute placement_group.



35
36
37
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 35

def placement_group
  @placement_group
end

#sizingObject

Returns the value of attribute sizing.



37
38
39
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 37

def sizing
  @sizing
end

#statusObject

Indicate targeting template is active or Deleted



40
41
42
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 40

def status
  @status
end

#targeting_attributesObject

targeting profile attributes



43
44
45
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 43

def targeting_attributes
  @targeting_attributes
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



45
46
47
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 45

def tracking_urls
  @tracking_urls
end

#updated_timeObject

Targeting template updated time.Unix timestamp in seconds.



48
49
50
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 48

def updated_time
  @updated_time
end

#validObject

Inform if the targeting template is valid (ex. would be false if has revoked audience)



51
52
53
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 51

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 76

def self.attribute_map
  {
    :'ad_account_id' => :'ad_account_id',
    :'auto_targeting_enabled' => :'auto_targeting_enabled',
    :'created_time' => :'created_time',
    :'id' => :'id',
    :'keywords' => :'keywords',
    :'name' => :'name',
    :'placement_group' => :'placement_group',
    :'sizing' => :'sizing',
    :'status' => :'status',
    :'targeting_attributes' => :'targeting_attributes',
    :'tracking_urls' => :'tracking_urls',
    :'updated_time' => :'updated_time',
    :'valid' => :'valid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 333

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
128
129
130
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 124

def self.openapi_nullable
  Set.new([
    :'sizing',
    :'tracking_urls',
    :'valid'
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 105

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'auto_targeting_enabled' => :'Boolean',
    :'created_time' => :'Integer',
    :'id' => :'String',
    :'keywords' => :'Array<TargetingTemplateKeyword>',
    :'name' => :'String',
    :'placement_group' => :'PlacementGroupType',
    :'sizing' => :'TargetingTemplateAudienceSizing',
    :'status' => :'TargetingTemplateStatus',
    :'targeting_attributes' => :'TargetingSpecOptimal',
    :'tracking_urls' => :'TrackingUrls',
    :'updated_time' => :'Integer',
    :'valid' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      auto_targeting_enabled == o.auto_targeting_enabled &&
      created_time == o.created_time &&
      id == o.id &&
      keywords == o.keywords &&
      name == o.name &&
      placement_group == o.placement_group &&
      sizing == o.sizing &&
      status == o.status &&
      targeting_attributes == o.targeting_attributes &&
      tracking_urls == o.tracking_urls &&
      updated_time == o.updated_time &&
      valid == o.valid
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



326
327
328
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 326

def hash
  [, auto_targeting_enabled, created_time, id, keywords, name, placement_group, sizing, status, targeting_attributes, tracking_urls, updated_time, valid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@ad_account_id.nil? && @ad_account_id !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @targeting_attributes.nil?
    invalid_properties.push('invalid value for "targeting_attributes", targeting_attributes cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
# File 'lib/pinterest_sdk/models/targeting_template.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/)
  return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/)
  return false if @name.nil?
  return false if @targeting_attributes.nil?
  true
end