Class: PinterestSdkClient::TargetingTemplateApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::TargetingTemplateApi
- Defined in:
- lib/pinterest_sdk/api/targeting_template_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TargetingTemplateApi
constructor
A new instance of TargetingTemplateApi.
-
#targeting_template_create(ad_account_id, targeting_template_create, opts = {}) ⇒ TargetingTemplate
Create targeting templates Targeting templates allow advertisers to save a set of targeting details including audience lists, keywords & interest, demographics, and placements to use more than once during the campaign creation process.
-
#targeting_template_create_with_http_info(ad_account_id, targeting_template_create, opts = {}) ⇒ Array<(TargetingTemplate, Integer, Hash)>
Create targeting templates Targeting templates allow advertisers to save a set of targeting details including audience lists, keywords & interest, demographics, and placements to use more than once during the campaign creation process.
-
#targeting_template_list(ad_account_id, opts = {}) ⇒ TargetingTemplateList200Response
List targeting templates Get a list of the targeting templates in the specified
ad_account_id. -
#targeting_template_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(TargetingTemplateList200Response, Integer, Hash)>
List targeting templates Get a list of the targeting templates in the specified `ad_account_id`.
-
#targeting_template_update(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) ⇒ nil
Update targeting templates Update the targeting template given advertiser ID and targeting template ID.
-
#targeting_template_update_with_http_info(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update targeting templates Update the targeting template given advertiser ID and targeting template ID.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TargetingTemplateApi
Returns a new instance of TargetingTemplateApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#targeting_template_create(ad_account_id, targeting_template_create, opts = {}) ⇒ TargetingTemplate
Create targeting templates Targeting templates allow advertisers to save a set of targeting details including audience lists, keywords & interest, demographics, and placements to use more than once during the campaign creation process. Templates can be used to build out basic targeting criteria that you plan to use across campaigns and to reuse performance targeting from prior campaigns for new campaigns.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 28 def targeting_template_create(ad_account_id, targeting_template_create, opts = {}) data, _status_code, _headers = targeting_template_create_with_http_info(ad_account_id, targeting_template_create, opts) data end |
#targeting_template_create_with_http_info(ad_account_id, targeting_template_create, opts = {}) ⇒ Array<(TargetingTemplate, Integer, Hash)>
Create targeting templates Targeting templates allow advertisers to save a set of targeting details including audience lists, keywords & interest, demographics, and placements to use more than once during the campaign creation process. Templates can be used to build out basic targeting criteria that you plan to use across campaigns and to reuse performance targeting from prior campaigns for new campaigns.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 39 def targeting_template_create_with_http_info(ad_account_id, targeting_template_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TargetingTemplateApi.targeting_template_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling TargetingTemplateApi.targeting_template_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling TargetingTemplateApi.targeting_template_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling TargetingTemplateApi.targeting_template_create, must conform to the pattern #{pattern}." end # verify the required parameter 'targeting_template_create' is set if @api_client.config.client_side_validation && targeting_template_create.nil? fail ArgumentError, "Missing the required parameter 'targeting_template_create' when calling TargetingTemplateApi.targeting_template_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/targeting_templates'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(targeting_template_create) # return_type return_type = opts[:debug_return_type] || 'TargetingTemplate' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"TargetingTemplateApi.targeting_template_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TargetingTemplateApi#targeting_template_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#targeting_template_list(ad_account_id, opts = {}) ⇒ TargetingTemplateList200Response
List targeting templates
Get a list of the targeting templates in the specified ad_account_id
115 116 117 118 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 115 def targeting_template_list(ad_account_id, opts = {}) data, _status_code, _headers = targeting_template_list_with_http_info(ad_account_id, opts) data end |
#targeting_template_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(TargetingTemplateList200Response, Integer, Hash)>
List targeting templates Get a list of the targeting templates in the specified `ad_account_id`
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 130 def targeting_template_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TargetingTemplateApi.targeting_template_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling TargetingTemplateApi.targeting_template_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling TargetingTemplateApi.targeting_template_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling TargetingTemplateApi.targeting_template_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling TargetingTemplateApi.targeting_template_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling TargetingTemplateApi.targeting_template_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/targeting_templates'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_sizing'] = opts[:'include_sizing'] if !opts[:'include_sizing'].nil? query_params[:'search_query'] = opts[:'search_query'] if !opts[:'search_query'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TargetingTemplateList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"TargetingTemplateApi.targeting_template_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TargetingTemplateApi#targeting_template_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#targeting_template_update(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) ⇒ nil
Update targeting templates Update the targeting template given advertiser ID and targeting template ID
206 207 208 209 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 206 def targeting_template_update(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) targeting_template_update_with_http_info(ad_account_id, targeting_template_update_request_read_or_update, opts) nil end |
#targeting_template_update_with_http_info(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update targeting templates Update the targeting template given advertiser ID and targeting template ID
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pinterest_sdk/api/targeting_template_api.rb', line 217 def targeting_template_update_with_http_info(ad_account_id, targeting_template_update_request_read_or_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TargetingTemplateApi.targeting_template_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling TargetingTemplateApi.targeting_template_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling TargetingTemplateApi.targeting_template_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling TargetingTemplateApi.targeting_template_update, must conform to the pattern #{pattern}." end # verify the required parameter 'targeting_template_update_request_read_or_update' is set if @api_client.config.client_side_validation && targeting_template_update_request_read_or_update.nil? fail ArgumentError, "Missing the required parameter 'targeting_template_update_request_read_or_update' when calling TargetingTemplateApi.targeting_template_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/targeting_templates'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(targeting_template_update_request_read_or_update) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"TargetingTemplateApi.targeting_template_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TargetingTemplateApi#targeting_template_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |