Class: PinterestSdkClient::TargetingTemplateCreate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/targeting_template_create.rb

Overview

Resource create operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TargetingTemplateCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TargetingTemplateCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TargetingTemplateCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_targeting_enabled')
    self.auto_targeting_enabled = attributes[:'auto_targeting_enabled']
  else
    self.auto_targeting_enabled = true
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'placement_group')
    self.placement_group = attributes[:'placement_group']
  else
    self.placement_group = 'ALL'
  end

  if attributes.key?(:'targeting_attributes')
    self.targeting_attributes = attributes[:'targeting_attributes']
  else
    self.targeting_attributes = nil
  end

  if attributes.key?(:'tracking_urls')
    self.tracking_urls = attributes[:'tracking_urls']
  end
end

Instance Attribute Details

#auto_targeting_enabledObject

Enable auto-targeting for ad group. Also known as "expanded targeting".



20
21
22
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 20

def auto_targeting_enabled
  @auto_targeting_enabled
end

#keywordsObject

Returns the value of attribute keywords.



22
23
24
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 22

def keywords
  @keywords
end

#nameObject

targeting template name



25
26
27
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 25

def name
  @name
end

#placement_groupObject

Returns the value of attribute placement_group.



27
28
29
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 27

def placement_group
  @placement_group
end

#targeting_attributesObject

targeting profile attributes



30
31
32
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 30

def targeting_attributes
  @targeting_attributes
end

#tracking_urlsObject

Returns the value of attribute tracking_urls.



32
33
34
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 32

def tracking_urls
  @tracking_urls
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 57

def self.attribute_map
  {
    :'auto_targeting_enabled' => :'auto_targeting_enabled',
    :'keywords' => :'keywords',
    :'name' => :'name',
    :'placement_group' => :'placement_group',
    :'targeting_attributes' => :'targeting_attributes',
    :'tracking_urls' => :'tracking_urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 91

def self.openapi_nullable
  Set.new([
    :'tracking_urls'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 79

def self.openapi_types
  {
    :'auto_targeting_enabled' => :'Boolean',
    :'keywords' => :'Array<TargetingTemplateKeyword>',
    :'name' => :'String',
    :'placement_group' => :'PlacementGroupType',
    :'targeting_attributes' => :'TargetingSpecOptimal',
    :'tracking_urls' => :'TrackingUrls'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_targeting_enabled == o.auto_targeting_enabled &&
      keywords == o.keywords &&
      name == o.name &&
      placement_group == o.placement_group &&
      targeting_attributes == o.targeting_attributes &&
      tracking_urls == o.tracking_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 214

def hash
  [auto_targeting_enabled, keywords, name, placement_group, targeting_attributes, tracking_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @targeting_attributes.nil?
    invalid_properties.push('invalid value for "targeting_attributes", targeting_attributes cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
# File 'lib/pinterest_sdk/models/targeting_template_create.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @targeting_attributes.nil?
  true
end