Class: PinterestSdkClient::TemplateBasedReportCreate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/template_based_report_create.rb

Overview

Resource create operation model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateBasedReportCreate

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TemplateBasedReportCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TemplateBasedReportCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'report_status')
    self.report_status = attributes[:'report_status']
  else
    self.report_status = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end
end

Instance Attribute Details

#messageObject

Returns the value of attribute message.



19
20
21
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 19

def message
  @message
end

#report_statusObject

Returns the value of attribute report_status.



21
22
23
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 21

def report_status
  @report_status
end

#tokenObject

Returns the value of attribute token.



23
24
25
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 23

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 48

def self.attribute_map
  {
    :'message' => :'message',
    :'report_status' => :'report_status',
    :'token' => :'token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 67

def self.openapi_types
  {
    :'message' => :'String',
    :'report_status' => :'BulkReportingJobStatus',
    :'token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



144
145
146
147
148
149
150
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message == o.message &&
      report_status == o.report_status &&
      token == o.token
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


154
155
156
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



160
161
162
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 160

def hash
  [message, report_status, token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @report_status.nil?
    invalid_properties.push('invalid value for "report_status", report_status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



126
127
128
129
130
# File 'lib/pinterest_sdk/models/template_based_report_create.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @report_status.nil?
  true
end