Class: PinterestSdkClient::TermsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pinterest_sdk/api/terms_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TermsApi

Returns a new instance of TermsApi.



19
20
21
# File 'lib/pinterest_sdk/api/terms_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pinterest_sdk/api/terms_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

List related terms Get a list of terms logically related to each input term. Example: the term 'workout' would list related terms like 'one song workout', 'yoga workout', 'workout motivation', etc.

Parameters:

  • List of input terms.

  • (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/pinterest_sdk/api/terms_api.rb', line 27

def terms_related_list(terms, opts = {})
  data, _status_code, _headers = terms_related_list_with_http_info(terms, opts)
  data
end

List related terms Get a list of terms logically related to each input term. Example: the term 'workout' would list related terms like 'one song workout', 'yoga workout', 'workout motivation', etc.

Parameters:

  • List of input terms.

  • (defaults to: {})

    the optional parameters

Returns:

  • RelatedTerms data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/pinterest_sdk/api/terms_api.rb', line 37

def terms_related_list_with_http_info(terms, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TermsApi.terms_related_list ...'
  end
  # verify the required parameter 'terms' is set
  if @api_client.config.client_side_validation && terms.nil?
    fail ArgumentError, "Missing the required parameter 'terms' when calling TermsApi.terms_related_list"
  end
  # resource path
  local_var_path = '/terms/related'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'terms'] = @api_client.build_collection_param(terms, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RelatedTerms'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"TermsApi.terms_related_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TermsApi#terms_related_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#terms_suggested_list(term, opts = {}) ⇒ Array<String>

List suggested terms Get popular search terms that begin with your input term. Example: 'sport' would return popular terms like 'sports bar' and 'sportswear', but not 'motor sports' since the phrase does not begin with the given term.

Parameters:

  • Input term.

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Max suggested terms to return. (default to 4)

Returns:



92
93
94
95
# File 'lib/pinterest_sdk/api/terms_api.rb', line 92

def terms_suggested_list(term, opts = {})
  data, _status_code, _headers = terms_suggested_list_with_http_info(term, opts)
  data
end

#terms_suggested_list_with_http_info(term, opts = {}) ⇒ Array<(Array<String>, Integer, Hash)>

List suggested terms Get popular search terms that begin with your input term. Example: 'sport' would return popular terms like 'sports bar' and 'sportswear', but not 'motor sports' since the phrase does not begin with the given term.

Parameters:

  • Input term.

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Max suggested terms to return. (default to 4)

Returns:

  • Array data, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/pinterest_sdk/api/terms_api.rb', line 103

def terms_suggested_list_with_http_info(term, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TermsApi.terms_suggested_list ...'
  end
  # verify the required parameter 'term' is set
  if @api_client.config.client_side_validation && term.nil?
    fail ArgumentError, "Missing the required parameter 'term' when calling TermsApi.terms_suggested_list"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TermsApi.terms_suggested_list, must be smaller than or equal to 10.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TermsApi.terms_suggested_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/terms/suggested'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'term'] = term
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<String>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['pinterest_oauth2']

  new_options = opts.merge(
    :operation => :"TermsApi.terms_suggested_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TermsApi#terms_suggested_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end