Class: PinterestSdkClient::TermsOfServiceApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::TermsOfServiceApi
- Defined in:
- lib/pinterest_sdk/api/terms_of_service_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TermsOfServiceApi
constructor
A new instance of TermsOfServiceApi.
-
#terms_of_service_get(ad_account_id, opts = {}) ⇒ TermsOfService
Get terms of service Get the text of the terms of service and see whether the advertiser has accepted the terms of service.
-
#terms_of_service_get_with_http_info(ad_account_id, opts = {}) ⇒ Array<(TermsOfService, Integer, Hash)>
Get terms of service Get the text of the terms of service and see whether the advertiser has accepted the terms of service.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TermsOfServiceApi
Returns a new instance of TermsOfServiceApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/terms_of_service_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/terms_of_service_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#terms_of_service_get(ad_account_id, opts = {}) ⇒ TermsOfService
Get terms of service Get the text of the terms of service and see whether the advertiser has accepted the terms of service.
29 30 31 32 |
# File 'lib/pinterest_sdk/api/terms_of_service_api.rb', line 29 def terms_of_service_get(ad_account_id, opts = {}) data, _status_code, _headers = terms_of_service_get_with_http_info(ad_account_id, opts) data end |
#terms_of_service_get_with_http_info(ad_account_id, opts = {}) ⇒ Array<(TermsOfService, Integer, Hash)>
Get terms of service Get the text of the terms of service and see whether the advertiser has accepted the terms of service.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pinterest_sdk/api/terms_of_service_api.rb', line 41 def terms_of_service_get_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TermsOfServiceApi.terms_of_service_get ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling TermsOfServiceApi.terms_of_service_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling TermsOfServiceApi.terms_of_service_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling TermsOfServiceApi.terms_of_service_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/terms_of_service'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'include_html'] = opts[:'include_html'] if !opts[:'include_html'].nil? query_params[:'tos_type'] = opts[:'tos_type'] if !opts[:'tos_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TermsOfService' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"TermsOfServiceApi.terms_of_service_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TermsOfServiceApi#terms_of_service_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |