Class: PinterestSdkClient::TrackingUrls
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::TrackingUrls
- Defined in:
- lib/pinterest_sdk/models/tracking_urls.rb
Overview
Third-party tracking URLs. Up to three tracking URLs - with a max length of 2,000 - are supported for each event type. Tracking URLs set at the ad group or ad level can override those set at the campaign level. For more information, see <a href="help.pinterest.com/en/business/article/third-party-and-dynamic-tracking" target="_blank">Third-party and dynamic tracking</a>.
Instance Attribute Summary collapse
-
#audience_verification ⇒ Object
Returns the value of attribute audience_verification.
-
#buyable_button ⇒ Object
Returns the value of attribute buyable_button.
-
#click ⇒ Object
Returns the value of attribute click.
-
#engagement ⇒ Object
Returns the value of attribute engagement.
-
#impression ⇒ Object
Returns the value of attribute impression.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TrackingUrls
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TrackingUrls
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TrackingUrls` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TrackingUrls`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'audience_verification') if (value = attributes[:'audience_verification']).is_a?(Array) self.audience_verification = value end end if attributes.key?(:'buyable_button') if (value = attributes[:'buyable_button']).is_a?(Array) self. = value end end if attributes.key?(:'click') if (value = attributes[:'click']).is_a?(Array) self.click = value end end if attributes.key?(:'engagement') if (value = attributes[:'engagement']).is_a?(Array) self.engagement = value end end if attributes.key?(:'impression') if (value = attributes[:'impression']).is_a?(Array) self.impression = value end end end |
Instance Attribute Details
#audience_verification ⇒ Object
Returns the value of attribute audience_verification.
19 20 21 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 19 def audience_verification @audience_verification end |
#buyable_button ⇒ Object
Returns the value of attribute buyable_button.
21 22 23 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 21 def @buyable_button end |
#click ⇒ Object
Returns the value of attribute click.
23 24 25 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 23 def click @click end |
#engagement ⇒ Object
Returns the value of attribute engagement.
25 26 27 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 25 def engagement @engagement end |
#impression ⇒ Object
Returns the value of attribute impression.
27 28 29 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 27 def impression @impression end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 30 def self.attribute_map { :'audience_verification' => :'audience_verification', :'buyable_button' => :'buyable_button', :'click' => :'click', :'engagement' => :'engagement', :'impression' => :'impression' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 51 def self.openapi_types { :'audience_verification' => :'Array<String>', :'buyable_button' => :'Array<String>', :'click' => :'Array<String>', :'engagement' => :'Array<String>', :'impression' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && audience_verification == o.audience_verification && == o. && click == o.click && engagement == o.engagement && impression == o.impression end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 149 def hash [audience_verification, , click, engagement, impression].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 |
# File 'lib/pinterest_sdk/models/tracking_urls.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |