Class: PinterestSdkClient::TrendingProductCategory

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pinterest_sdk/models/trending_product_category.rb

Overview

Trending shopping product category

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TrendingProductCategory

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TrendingProductCategory` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TrendingProductCategory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'engagement_type')
    self.engagement_type = attributes[:'engagement_type']
  else
    self.engagement_type = nil
  end

  if attributes.key?(:'pct_change_mom')
    self.pct_change_mom = attributes[:'pct_change_mom']
  else
    self.pct_change_mom = nil
  end

  if attributes.key?(:'percent_relative_volume')
    self.percent_relative_volume = attributes[:'percent_relative_volume']
  else
    self.percent_relative_volume = nil
  end

  if attributes.key?(:'pinterest_product_category_id')
    self.pinterest_product_category_id = attributes[:'pinterest_product_category_id']
  else
    self.pinterest_product_category_id = nil
  end

  if attributes.key?(:'product_category')
    self.product_category = attributes[:'product_category']
  else
    self.product_category = nil
  end

  if attributes.key?(:'verticals')
    if (value = attributes[:'verticals']).is_a?(Array)
      self.verticals = value
    end
  end
end

Instance Attribute Details

#engagement_typeObject

Engagement type



20
21
22
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 20

def engagement_type
  @engagement_type
end

#pct_change_momObject

Month-over-month change percentage



23
24
25
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 23

def pct_change_mom
  @pct_change_mom
end

#percent_relative_volumeObject

Relative volume percentage



26
27
28
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 26

def percent_relative_volume
  @percent_relative_volume
end

#pinterest_product_category_idObject

Pinterest Product Category Id



29
30
31
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 29

def pinterest_product_category_id
  @pinterest_product_category_id
end

#product_categoryObject

Product Category Name



32
33
34
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 32

def product_category
  @product_category
end

#verticalsObject

Vertical name associated with the product category



35
36
37
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 35

def verticals
  @verticals
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 60

def self.attribute_map
  {
    :'engagement_type' => :'engagement_type',
    :'pct_change_mom' => :'pct_change_mom',
    :'percent_relative_volume' => :'percent_relative_volume',
    :'pinterest_product_category_id' => :'pinterest_product_category_id',
    :'product_category' => :'product_category',
    :'verticals' => :'verticals'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 270

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 82

def self.openapi_types
  {
    :'engagement_type' => :'ProductCategoriesEngagementType',
    :'pct_change_mom' => :'Integer',
    :'percent_relative_volume' => :'Integer',
    :'pinterest_product_category_id' => :'Integer',
    :'product_category' => :'String',
    :'verticals' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      engagement_type == o.engagement_type &&
      pct_change_mom == o.pct_change_mom &&
      percent_relative_volume == o.percent_relative_volume &&
      pinterest_product_category_id == o.pinterest_product_category_id &&
      product_category == o.product_category &&
      verticals == o.verticals
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 263

def hash
  [engagement_type, pct_change_mom, percent_relative_volume, pinterest_product_category_id, product_category, verticals].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @engagement_type.nil?
    invalid_properties.push('invalid value for "engagement_type", engagement_type cannot be nil.')
  end

  if @pct_change_mom.nil?
    invalid_properties.push('invalid value for "pct_change_mom", pct_change_mom cannot be nil.')
  end

  if @percent_relative_volume.nil?
    invalid_properties.push('invalid value for "percent_relative_volume", percent_relative_volume cannot be nil.')
  end

  if @pinterest_product_category_id.nil?
    invalid_properties.push('invalid value for "pinterest_product_category_id", pinterest_product_category_id cannot be nil.')
  end

  if @product_category.nil?
    invalid_properties.push('invalid value for "product_category", product_category cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
# File 'lib/pinterest_sdk/models/trending_product_category.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @engagement_type.nil?
  return false if @pct_change_mom.nil?
  return false if @percent_relative_volume.nil?
  return false if @pinterest_product_category_id.nil?
  return false if @product_category.nil?
  true
end