Class: PinterestSdkClient::TrendingTopic

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/trending_topic.rb

Overview

Individual trending topic within an interest category

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TrendingTopic

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TrendingTopic` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TrendingTopic`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'percent_growth_mom')
    self.percent_growth_mom = attributes[:'percent_growth_mom']
  end

  if attributes.key?(:'pins')
    if (value = attributes[:'pins']).is_a?(Array)
      self.pins = value
    end
  else
    self.pins = nil
  end

  if attributes.key?(:'related_interests')
    if (value = attributes[:'related_interests']).is_a?(Array)
      self.related_interests = value
    end
  else
    self.related_interests = nil
  end

  if attributes.key?(:'related_searches')
    if (value = attributes[:'related_searches']).is_a?(Array)
      self.related_searches = value
    end
  else
    self.related_searches = nil
  end

  if attributes.key?(:'time_series')
    if (value = attributes[:'time_series']).is_a?(Hash)
      self.time_series = value
    end
  else
    self.time_series = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end
end

Instance Attribute Details

#descriptionObject

Description of the trending topic



20
21
22
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 20

def description
  @description
end

#idObject

Unique identifier for the trending topic



23
24
25
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 23

def id
  @id
end

#percent_growth_momObject

Month-over-month growth percentage



26
27
28
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 26

def percent_growth_mom
  @percent_growth_mom
end

#pinsObject

Array of pin images related to this trend (up to 6)



29
30
31
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 29

def pins
  @pins
end

List of related interest categories



32
33
34
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 32

def related_interests
  @related_interests
end

List of related search terms



35
36
37
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 35

def related_searches
  @related_searches
end

#time_seriesObject

Time series data showing trend values over time, with dates as keys and values as numeric



38
39
40
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 38

def time_series
  @time_series
end

#titleObject

Title of the trending topic



41
42
43
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 41

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 44

def self.attribute_map
  {
    :'description' => :'description',
    :'id' => :'id',
    :'percent_growth_mom' => :'percent_growth_mom',
    :'pins' => :'pins',
    :'related_interests' => :'related_interests',
    :'related_searches' => :'related_searches',
    :'time_series' => :'time_series',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 68

def self.openapi_types
  {
    :'description' => :'String',
    :'id' => :'String',
    :'percent_growth_mom' => :'Integer',
    :'pins' => :'Array<TrendingPin>',
    :'related_interests' => :'Array<String>',
    :'related_searches' => :'Array<String>',
    :'time_series' => :'Hash<String, Float>',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      id == o.id &&
      percent_growth_mom == o.percent_growth_mom &&
      pins == o.pins &&
      related_interests == o.related_interests &&
      related_searches == o.related_searches &&
      time_series == o.time_series &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 310

def hash
  [description, id, percent_growth_mom, pins, related_interests, related_searches, time_series, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @pins.nil?
    invalid_properties.push('invalid value for "pins", pins cannot be nil.')
  end

  if @pins.length > 6
    invalid_properties.push('invalid value for "pins", number of items must be less than or equal to 6.')
  end

  if @related_interests.nil?
    invalid_properties.push('invalid value for "related_interests", related_interests cannot be nil.')
  end

  if @related_searches.nil?
    invalid_properties.push('invalid value for "related_searches", related_searches cannot be nil.')
  end

  if @time_series.nil?
    invalid_properties.push('invalid value for "time_series", time_series cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/pinterest_sdk/models/trending_topic.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @description.nil?
  return false if @id.nil?
  return false if @pins.nil?
  return false if @pins.length > 6
  return false if @related_interests.nil?
  return false if @related_searches.nil?
  return false if @time_series.nil?
  return false if @title.nil?
  true
end