Class: PinterestSdkClient::VideoMetadataWithItemType
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::VideoMetadataWithItemType
- Defined in:
- lib/pinterest_sdk/models/video_metadata_with_item_type.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cover_image_url ⇒ Object
Returns the value of attribute cover_image_url.
-
#duration ⇒ Object
Duration (in miliseconds).
-
#height ⇒ Object
Height (in pixels).
-
#item_type ⇒ Object
Discriminator literal identifying this as video metadata inside a
PinMediaMetadatapayload. -
#video_url ⇒ Object
Video url (720p).
-
#video_url_hls ⇒ Object
Video url (HLS).
-
#width ⇒ Object
Width (in pixels).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VideoMetadataWithItemType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VideoMetadataWithItemType
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::VideoMetadataWithItemType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::VideoMetadataWithItemType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cover_image_url') self.cover_image_url = attributes[:'cover_image_url'] end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'item_type') self.item_type = attributes[:'item_type'] else self.item_type = nil end if attributes.key?(:'video_url') self.video_url = attributes[:'video_url'] end if attributes.key?(:'video_url_hls') self.video_url_hls = attributes[:'video_url_hls'] end if attributes.key?(:'width') self.width = attributes[:'width'] end end |
Instance Attribute Details
#cover_image_url ⇒ Object
Returns the value of attribute cover_image_url.
18 19 20 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 18 def cover_image_url @cover_image_url end |
#duration ⇒ Object
Duration (in miliseconds). Field maybe null after creation due to video processing time.
21 22 23 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 21 def duration @duration end |
#height ⇒ Object
Height (in pixels). Field maybe null after creation due to video processing time.
24 25 26 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 24 def height @height end |
#item_type ⇒ Object
Discriminator literal identifying this as video metadata inside a PinMediaMetadata payload.
27 28 29 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 27 def item_type @item_type end |
#video_url ⇒ Object
Video url (720p). Note: This field is limited and not available to all apps.
30 31 32 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 30 def video_url @video_url end |
#video_url_hls ⇒ Object
Video url (HLS). Note: This field is limited and not available to all apps.
33 34 35 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 33 def video_url_hls @video_url_hls end |
#width ⇒ Object
Width (in pixels). Field maybe null after creation due to video processing time.
36 37 38 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 36 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 61 def self.attribute_map { :'cover_image_url' => :'cover_image_url', :'duration' => :'duration', :'height' => :'height', :'item_type' => :'item_type', :'video_url' => :'video_url', :'video_url_hls' => :'video_url_hls', :'width' => :'width' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 97 def self.openapi_nullable Set.new([ :'duration', :'height', :'video_url', :'video_url_hls', :'width' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 84 def self.openapi_types { :'cover_image_url' => :'String', :'duration' => :'Float', :'height' => :'Integer', :'item_type' => :'String', :'video_url' => :'String', :'video_url_hls' => :'String', :'width' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && cover_image_url == o.cover_image_url && duration == o.duration && height == o.height && item_type == o.item_type && video_url == o.video_url && video_url_hls == o.video_url_hls && width == o.width end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 208 def hash [cover_image_url, duration, height, item_type, video_url, video_url_hls, width].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @item_type.nil? invalid_properties.push('invalid value for "item_type", item_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 174 |
# File 'lib/pinterest_sdk/models/video_metadata_with_item_type.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @item_type.nil? item_type_validator = EnumAttributeValidator.new('String', ["video"]) return false unless item_type_validator.valid?(@item_type) true end |