Class: PinterestSdkClient::AdAccount

Inherits:
ApiModelBase show all
Defined in:
lib/pinterest_sdk/models/ad_account.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/pinterest_sdk/models/ad_account.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'owner')
    self.owner = attributes[:'owner']
  end

  if attributes.key?(:'permissions')
    if (value = attributes[:'permissions']).is_a?(Array)
      self.permissions = value
    end
  end

  if attributes.key?(:'time_zone')
    self.time_zone = attributes[:'time_zone']
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end
end

Instance Attribute Details

#countryObject

Returns the value of attribute country.



18
19
20
# File 'lib/pinterest_sdk/models/ad_account.rb', line 18

def country
  @country
end

#created_timeObject

Creation time. Unix timestamp in seconds.



21
22
23
# File 'lib/pinterest_sdk/models/ad_account.rb', line 21

def created_time
  @created_time
end

#currencyObject

Returns the value of attribute currency.



23
24
25
# File 'lib/pinterest_sdk/models/ad_account.rb', line 23

def currency
  @currency
end

#idObject

Returns the value of attribute id.



25
26
27
# File 'lib/pinterest_sdk/models/ad_account.rb', line 25

def id
  @id
end

#nameObject

Ad account name.



28
29
30
# File 'lib/pinterest_sdk/models/ad_account.rb', line 28

def name
  @name
end

#ownerObject

Ad account owner



31
32
33
# File 'lib/pinterest_sdk/models/ad_account.rb', line 31

def owner
  @owner
end

#permissionsObject

Returns the value of attribute permissions.



33
34
35
# File 'lib/pinterest_sdk/models/ad_account.rb', line 33

def permissions
  @permissions
end

#time_zoneObject

The time zone of the ad account, in IANA format (e.g., "America/Los_Angeles"). Adding your local time zone lets you view your campaigns and ad reporting in your preferred time zone. Future reports will be available in both your local time zone and default UTC time zone. Historical data takes 1-2 months to backfill. Your billing and order lines will remain in UTC.



36
37
38
# File 'lib/pinterest_sdk/models/ad_account.rb', line 36

def time_zone
  @time_zone
end

#updated_timeObject

Returns the value of attribute updated_time.



38
39
40
# File 'lib/pinterest_sdk/models/ad_account.rb', line 38

def updated_time
  @updated_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/pinterest_sdk/models/ad_account.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/pinterest_sdk/models/ad_account.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/pinterest_sdk/models/ad_account.rb', line 63

def self.attribute_map
  {
    :'country' => :'country',
    :'created_time' => :'created_time',
    :'currency' => :'currency',
    :'id' => :'id',
    :'name' => :'name',
    :'owner' => :'owner',
    :'permissions' => :'permissions',
    :'time_zone' => :'time_zone',
    :'updated_time' => :'updated_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/pinterest_sdk/models/ad_account.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
108
# File 'lib/pinterest_sdk/models/ad_account.rb', line 103

def self.openapi_nullable
  Set.new([
    :'created_time',
    :'updated_time'
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pinterest_sdk/models/ad_account.rb', line 88

def self.openapi_types
  {
    :'country' => :'Country',
    :'created_time' => :'Integer',
    :'currency' => :'Currency',
    :'id' => :'String',
    :'name' => :'String',
    :'owner' => :'AdAccountOwner',
    :'permissions' => :'Array<BusinessAccessRole>',
    :'time_zone' => :'String',
    :'updated_time' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/pinterest_sdk/models/ad_account.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      created_time == o.created_time &&
      currency == o.currency &&
      id == o.id &&
      name == o.name &&
      owner == o.owner &&
      permissions == o.permissions &&
      time_zone == o.time_zone &&
      updated_time == o.updated_time
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/pinterest_sdk/models/ad_account.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/pinterest_sdk/models/ad_account.rb', line 260

def hash
  [country, created_time, currency, id, name, owner, permissions, time_zone, updated_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/pinterest_sdk/models/ad_account.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 18
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 18.')
  end

  pattern = Regexp.new(/^\d+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@name.nil? && @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/pinterest_sdk/models/ad_account.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
# File 'lib/pinterest_sdk/models/ad_account.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id.to_s.length > 18
  return false if @id !~ Regexp.new(/^\d+$/)
  return false if !@name.nil? && @name.to_s.length > 256
  true
end