Class: PinterestSdkClient::AdAccountCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdAccountCreate
- Defined in:
- lib/pinterest_sdk/models/ad_account_create.rb
Overview
Resource create operation model.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#country ⇒ Object
Returns the value of attribute country.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#name ⇒ Object
Ad account name.
-
#owner_user_id ⇒ Object
Advertiser's owning user ID.
-
#time_zone ⇒ Object
The time zone of the ad account, in IANA format (e.g., "America/Los_Angeles").
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdAccountCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdAccountCreate
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdAccountCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdAccountCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'owner_user_id') self.owner_user_id = attributes[:'owner_user_id'] end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end end |
Instance Attribute Details
#country ⇒ Object
Returns the value of attribute country.
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 19 def country @country end |
#currency ⇒ Object
Returns the value of attribute currency.
21 22 23 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 21 def currency @currency end |
#name ⇒ Object
Ad account name.
24 25 26 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 24 def name @name end |
#owner_user_id ⇒ Object
Advertiser's owning user ID.
27 28 29 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 27 def owner_user_id @owner_user_id end |
#time_zone ⇒ Object
The time zone of the ad account, in IANA format (e.g., "America/Los_Angeles"). Adding your local time zone lets you view your campaigns and ad reporting in your preferred time zone. Future reports will be available in both your local time zone and default UTC time zone. Historical data takes 1-2 months to backfill. Your billing and order lines will remain in UTC.
30 31 32 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 30 def time_zone @time_zone end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 55 def self.attribute_map { :'country' => :'country', :'currency' => :'currency', :'name' => :'name', :'owner_user_id' => :'owner_user_id', :'time_zone' => :'time_zone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 76 def self.openapi_types { :'country' => :'Country', :'currency' => :'Currency', :'name' => :'String', :'owner_user_id' => :'String', :'time_zone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && country == o.country && currency == o.currency && name == o.name && owner_user_id == o.owner_user_id && time_zone == o.time_zone end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 204 def hash [country, currency, name, owner_user_id, time_zone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end pattern = Regexp.new(/^\d+$/) if !@owner_user_id.nil? && @owner_user_id !~ pattern invalid_properties.push("invalid value for \"owner_user_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/ad_account_create.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 256 return false if !@owner_user_id.nil? && @owner_user_id !~ Regexp.new(/^\d+$/) true end |