Class: PinterestSdkClient::AdGroupResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdGroupResponse
- Defined in:
- lib/pinterest_sdk/models/ad_group_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Advertiser ID.
-
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group.
-
#bid_in_micro_currency ⇒ Object
Bid price in micro currency.
-
#bid_multiplier ⇒ Object
<a href=\“/docs/getting-started/using-beta-and-restricted-features/\” target=\“blank>Open beta</a> Bid multiplier for ad group.
-
#bid_strategy_type ⇒ Object
Bid strategy type.
-
#billable_event ⇒ Object
Returns the value of attribute billable_event.
-
#budget_in_micro_currency ⇒ Object
Budget in micro currency.
-
#budget_type ⇒ Object
Returns the value of attribute budget_type.
-
#campaign_id ⇒ Object
Campaign ID of the ad group.
-
#conversion_learning_mode_type ⇒ Object
oCPM learn mode.
-
#created_time ⇒ Object
Ad group creation time.
-
#dca_assets ⇒ Object
- DCA
-
The Dynamic creative assets to use for DCA.
-
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group stop appearing.
-
#feed_profile_id ⇒ Object
Feed Profile ID associated to the adgroup.
-
#id ⇒ Object
Ad group ID.
-
#is_creative_optimization ⇒ Object
Enable creative optimization for the ad group, default value is FALSE.
-
#lifetime_frequency_cap ⇒ Object
Set a limit to the number of times a promoted pin from this campaign can be impressed by a pinner within the past rolling 30 days.
-
#name ⇒ Object
Ad group name.
-
#optimization_goal_metadata ⇒ Object
Optimization goals for objective-based performance campaigns.
-
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
-
#placement_group ⇒ Object
<a href=\“/docs/redoc/#section/Placement-group\”>Placement group</a>.
-
#promotion_application_level ⇒ Object
Specify if the promotion is applied at ad group or item level.
-
#promotion_id ⇒ Object
Promotion ID.
-
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group start to appear.
-
#status ⇒ Object
Ad group/entity status.
-
#summary_status ⇒ Object
Ad group summary status.
-
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
-
#targeting_template_ids ⇒ Object
Targeting template IDs applied to the ad group.
-
#tracking_urls ⇒ Object
Third-party tracking URLs.
JSON object with the format: href=\”/docs/redoc/#section/Tracking-URL-event\“>Tracking event enum</a>\”:[URL string array],…
For example: [\“URL1\”, \“URL2\”], \“click\”: [\“URL1\”, \“URL2\”, \“URL3\”].
Up to three tracking URLs are supported for each event type. -
#type ⇒ Object
Always \“adgroup\”.
-
#updated_time ⇒ Object
Ad group last update time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdGroupResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdGroupResponse
Initializes the object
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 243 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_targeting_enabled') self.auto_targeting_enabled = attributes[:'auto_targeting_enabled'] end if attributes.key?(:'bid_in_micro_currency') self.bid_in_micro_currency = attributes[:'bid_in_micro_currency'] end if attributes.key?(:'bid_strategy_type') self.bid_strategy_type = attributes[:'bid_strategy_type'] end if attributes.key?(:'billable_event') self.billable_event = attributes[:'billable_event'] end if attributes.key?(:'budget_in_micro_currency') self.budget_in_micro_currency = attributes[:'budget_in_micro_currency'] end if attributes.key?(:'budget_type') self.budget_type = attributes[:'budget_type'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'is_creative_optimization') self.is_creative_optimization = attributes[:'is_creative_optimization'] end if attributes.key?(:'lifetime_frequency_cap') self.lifetime_frequency_cap = attributes[:'lifetime_frequency_cap'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'optimization_goal_metadata') self. = attributes[:'optimization_goal_metadata'] end if attributes.key?(:'pacing_delivery_type') self.pacing_delivery_type = attributes[:'pacing_delivery_type'] end if attributes.key?(:'placement_group') self.placement_group = attributes[:'placement_group'] end if attributes.key?(:'promotion_application_level') self.promotion_application_level = attributes[:'promotion_application_level'] end if attributes.key?(:'promotion_id') self.promotion_id = attributes[:'promotion_id'] else self.promotion_id = '0' end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'targeting_spec') self.targeting_spec = attributes[:'targeting_spec'] end if attributes.key?(:'targeting_template_ids') if (value = attributes[:'targeting_template_ids']).is_a?(Array) self.targeting_template_ids = value end end if attributes.key?(:'tracking_urls') self.tracking_urls = attributes[:'tracking_urls'] end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'bid_multiplier') self.bid_multiplier = attributes[:'bid_multiplier'] end if attributes.key?(:'conversion_learning_mode_type') self.conversion_learning_mode_type = attributes[:'conversion_learning_mode_type'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'dca_assets') self.dca_assets = attributes[:'dca_assets'] end if attributes.key?(:'feed_profile_id') self.feed_profile_id = attributes[:'feed_profile_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'summary_status') self.summary_status = attributes[:'summary_status'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'adgroup' end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Advertiser ID.
78 79 80 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 78 def ad_account_id @ad_account_id end |
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group. Default value is True. Also known as <a href=\“help.pinterest.com/en/business/article/performance-plus-targeting\” target=\“_blank\”>\“Pinterest Performance+ targeting\”</a>.
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 19 def auto_targeting_enabled @auto_targeting_enabled end |
#bid_in_micro_currency ⇒ Object
Bid price in micro currency. This field is REQUIRED for the following campaign objective_type/billable_event combinations: AWARENESS/IMPRESSION, CONSIDERATION/CLICKTHROUGH, CATALOG_SALES/CLICKTHROUGH.
22 23 24 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 22 def bid_in_micro_currency @bid_in_micro_currency end |
#bid_multiplier ⇒ Object
<a href=\“/docs/getting-started/using-beta-and-restricted-features/\” target=\“blank>Open beta</a> Bid multiplier for ad group. This value is a double between 0.1 and 10.0. Enter 0 to remove the bid multiplier. - Not currently supported for <a href=\”/docs/api-features/pinterest-performance-plus-setup/\“ target=\”blank\“>Pinterest Performance+ campaigns</a>.
81 82 83 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 81 def bid_multiplier @bid_multiplier end |
#bid_strategy_type ⇒ Object
Bid strategy type. For Campaigns with Video Completion objectives, the only supported bid strategy type is AUTOMATIC_BID, also known as \“Pinterest Performance+ bidding\”.
25 26 27 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 25 def bid_strategy_type @bid_strategy_type end |
#billable_event ⇒ Object
Returns the value of attribute billable_event.
27 28 29 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 27 def billable_event @billable_event end |
#budget_in_micro_currency ⇒ Object
Budget in micro currency. This field is REQUIRED for non-CBO (campaign budget optimization) campaigns. A CBO campaign automatically generates ad group budgets from its campaign budget to maximize campaign outcome. A CBO campaign is limited to 70 or less ad groups.
30 31 32 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 30 def budget_in_micro_currency @budget_in_micro_currency end |
#budget_type ⇒ Object
Returns the value of attribute budget_type.
32 33 34 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 32 def budget_type @budget_type end |
#campaign_id ⇒ Object
Campaign ID of the ad group.
35 36 37 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 35 def campaign_id @campaign_id end |
#conversion_learning_mode_type ⇒ Object
oCPM learn mode
84 85 86 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 84 def conversion_learning_mode_type @conversion_learning_mode_type end |
#created_time ⇒ Object
Ad group creation time. Unix timestamp in seconds.
87 88 89 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 87 def created_time @created_time end |
#dca_assets ⇒ Object
- DCA
-
The Dynamic creative assets to use for DCA. Dynamic Creative Assembly (DCA) accepts basic creative assets of an ad (image, video, title, call to action, logo etc). Then it automatically generates optimized ad combinations based on these assets.
90 91 92 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 90 def dca_assets @dca_assets end |
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group stop appearing. If not specified, ads run indefinitely unless you update the ad group by changing their status to paused. Cannot occur after end_time for parent campaign (if specified). Learn about <a href=\“/docs/api-features/managing-ads/#step-2-create-an-ad-group\” target=\“blank\”>scheduling ads</a>. For certain organizations (<a href=\“/docs/getting-started/using-beta-and-restricted-features/\” target=\“blank\” target=\“blank\”>Closed beta</a>): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.
38 39 40 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 38 def end_time @end_time end |
#feed_profile_id ⇒ Object
Feed Profile ID associated to the adgroup.
93 94 95 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 93 def feed_profile_id @feed_profile_id end |
#id ⇒ Object
Ad group ID.
96 97 98 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 96 def id @id end |
#is_creative_optimization ⇒ Object
Enable creative optimization for the ad group, default value is FALSE. When enabled, you allow Pinterest to automatically turn your product Pins into ads in different formats (collections and shopping) and deliver those ads to users at scale.
41 42 43 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 41 def is_creative_optimization @is_creative_optimization end |
#lifetime_frequency_cap ⇒ Object
Set a limit to the number of times a promoted pin from this campaign can be impressed by a pinner within the past rolling 30 days. Only available for CPM (cost per mille (1000 impressions)) ad groups. A CPM ad group has an IMPRESSION <a href=\“/docs/redoc/#section/Billable-event\”>billable_event</a> value. This field REQUIRES the end_time field.
44 45 46 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 44 def lifetime_frequency_cap @lifetime_frequency_cap end |
#name ⇒ Object
Ad group name.
47 48 49 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 47 def name @name end |
#optimization_goal_metadata ⇒ Object
Optimization goals for objective-based performance campaigns. REQUIRED when campaign’s objective_type is set to ‘\“WEB_CONVERSION\”`.
50 51 52 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 50 def end |
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
52 53 54 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 52 def pacing_delivery_type @pacing_delivery_type end |
#placement_group ⇒ Object
<a href=\“/docs/redoc/#section/Placement-group\”>Placement group</a>.
55 56 57 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 55 def placement_group @placement_group end |
#promotion_application_level ⇒ Object
Specify if the promotion is applied at ad group or item level
58 59 60 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 58 def promotion_application_level @promotion_application_level end |
#promotion_id ⇒ Object
Promotion ID. To clear this field, set to null.
61 62 63 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 61 def promotion_id @promotion_id end |
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group start to appear. If not specified, ads appear during parent campaign’s start_time. Cannot precede start_time for parent campaign (if specified). Learn about <a href=\“/docs/api-features/managing-ads/#step-2-create-an-ad-group\” target=\“blank\”>scheduling ads</a>. For certain organizations (<a href=\“/docs/getting-started/using-beta-and-restricted-features/\” target=\“blank\” target=\“blank\”>Closed beta</a>): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.
64 65 66 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 64 def start_time @start_time end |
#status ⇒ Object
Ad group/entity status.
67 68 69 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 67 def status @status end |
#summary_status ⇒ Object
Ad group summary status.
99 100 101 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 99 def summary_status @summary_status end |
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
69 70 71 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 69 def targeting_spec @targeting_spec end |
#targeting_template_ids ⇒ Object
Targeting template IDs applied to the ad group. We currently only support 1 targeting template per ad group. To use targeting templates, do not set any other targeting fields: targeting_spec, tracking_urls, auto_targeting_enabled, placement_group. To clear all targeting template IDs, set this field to [‘0’].
72 73 74 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 72 def targeting_template_ids @targeting_template_ids end |
#tracking_urls ⇒ Object
Third-party tracking URLs.
JSON object with the format: href=\”/docs/redoc/#section/Tracking-URL-event\“>Tracking event enum</a>\”:[URL string array],…
For example: [\“URL1\”, \“URL2\”], \“click\”: [\“URL1\”, \“URL2\”, \“URL3\”].
Up to three tracking URLs are supported for each event type. Tracking URLs set at the ad group or ad level can override those set at the campaign level. May be null. Pass in an empty object - {} - to remove tracking URLs.
For more information, see <a href=\“help.pinterest.com/en/business/article/third-party-and-dynamic-tracking\” target=\“_blank\”>Third-party and dynamic tracking</a>.
75 76 77 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 75 def tracking_urls @tracking_urls end |
#type ⇒ Object
Always \“adgroup\”.
102 103 104 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 102 def type @type end |
#updated_time ⇒ Object
Ad group last update time. Unix timestamp in seconds.
105 106 107 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 105 def updated_time @updated_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
167 168 169 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 167 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
172 173 174 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 172 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 130 def self.attribute_map { :'auto_targeting_enabled' => :'auto_targeting_enabled', :'bid_in_micro_currency' => :'bid_in_micro_currency', :'bid_strategy_type' => :'bid_strategy_type', :'billable_event' => :'billable_event', :'budget_in_micro_currency' => :'budget_in_micro_currency', :'budget_type' => :'budget_type', :'campaign_id' => :'campaign_id', :'end_time' => :'end_time', :'is_creative_optimization' => :'is_creative_optimization', :'lifetime_frequency_cap' => :'lifetime_frequency_cap', :'name' => :'name', :'optimization_goal_metadata' => :'optimization_goal_metadata', :'pacing_delivery_type' => :'pacing_delivery_type', :'placement_group' => :'placement_group', :'promotion_application_level' => :'promotion_application_level', :'promotion_id' => :'promotion_id', :'start_time' => :'start_time', :'status' => :'status', :'targeting_spec' => :'targeting_spec', :'targeting_template_ids' => :'targeting_template_ids', :'tracking_urls' => :'tracking_urls', :'ad_account_id' => :'ad_account_id', :'bid_multiplier' => :'bid_multiplier', :'conversion_learning_mode_type' => :'conversion_learning_mode_type', :'created_time' => :'created_time', :'dca_assets' => :'dca_assets', :'feed_profile_id' => :'feed_profile_id', :'id' => :'id', :'summary_status' => :'summary_status', :'type' => :'type', :'updated_time' => :'updated_time' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 611 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
235 236 237 238 239 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 235 def self.openapi_all_of [ :'AdGroupCommon' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 214 def self.openapi_nullable Set.new([ :'auto_targeting_enabled', :'bid_in_micro_currency', :'bid_strategy_type', :'budget_in_micro_currency', :'end_time', :'is_creative_optimization', :'optimization_goal_metadata', :'promotion_application_level', :'promotion_id', :'start_time', :'targeting_template_ids', :'tracking_urls', :'bid_multiplier', :'conversion_learning_mode_type', :'dca_assets', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 177 def self.openapi_types { :'auto_targeting_enabled' => :'Boolean', :'bid_in_micro_currency' => :'Integer', :'bid_strategy_type' => :'String', :'billable_event' => :'ActionType', :'budget_in_micro_currency' => :'Integer', :'budget_type' => :'BudgetType', :'campaign_id' => :'String', :'end_time' => :'Integer', :'is_creative_optimization' => :'Boolean', :'lifetime_frequency_cap' => :'Integer', :'name' => :'String', :'optimization_goal_metadata' => :'OptimizationGoalMetadata', :'pacing_delivery_type' => :'PacingDeliveryType', :'placement_group' => :'PlacementGroupType', :'promotion_application_level' => :'String', :'promotion_id' => :'String', :'start_time' => :'Integer', :'status' => :'EntityStatus', :'targeting_spec' => :'TargetingSpec', :'targeting_template_ids' => :'Array<String>', :'tracking_urls' => :'TrackingUrls', :'ad_account_id' => :'String', :'bid_multiplier' => :'Float', :'conversion_learning_mode_type' => :'String', :'created_time' => :'Integer', :'dca_assets' => :'Object', :'feed_profile_id' => :'String', :'id' => :'String', :'summary_status' => :'AdGroupSummaryStatus', :'type' => :'String', :'updated_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 560 def ==(o) return true if self.equal?(o) self.class == o.class && auto_targeting_enabled == o.auto_targeting_enabled && bid_in_micro_currency == o.bid_in_micro_currency && bid_strategy_type == o.bid_strategy_type && billable_event == o.billable_event && budget_in_micro_currency == o.budget_in_micro_currency && budget_type == o.budget_type && campaign_id == o.campaign_id && end_time == o.end_time && is_creative_optimization == o.is_creative_optimization && lifetime_frequency_cap == o.lifetime_frequency_cap && name == o.name && == o. && pacing_delivery_type == o.pacing_delivery_type && placement_group == o.placement_group && promotion_application_level == o.promotion_application_level && promotion_id == o.promotion_id && start_time == o.start_time && status == o.status && targeting_spec == o.targeting_spec && targeting_template_ids == o.targeting_template_ids && tracking_urls == o.tracking_urls && ad_account_id == o.ad_account_id && bid_multiplier == o.bid_multiplier && conversion_learning_mode_type == o.conversion_learning_mode_type && created_time == o.created_time && dca_assets == o.dca_assets && feed_profile_id == o.feed_profile_id && id == o.id && summary_status == o.summary_status && type == o.type && updated_time == o.updated_time end |
#eql?(o) ⇒ Boolean
598 599 600 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 598 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
604 605 606 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 604 def hash [auto_targeting_enabled, bid_in_micro_currency, bid_strategy_type, billable_event, budget_in_micro_currency, budget_type, campaign_id, end_time, is_creative_optimization, lifetime_frequency_cap, name, , pacing_delivery_type, placement_group, promotion_application_level, promotion_id, start_time, status, targeting_spec, targeting_template_ids, tracking_urls, ad_account_id, bid_multiplier, conversion_learning_mode_type, created_time, dca_assets, feed_profile_id, id, summary_status, type, updated_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 390 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[C]?\d+$/) if !@campaign_id.nil? && @campaign_id !~ pattern invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@promotion_id.nil? && @promotion_id !~ pattern invalid_properties.push("invalid value for \"promotion_id\", must conform to the pattern #{pattern}.") end if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1 invalid_properties.push('invalid value for "targeting_template_ids", number of items must be less than or equal to 1.') end pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end if !@bid_multiplier.nil? && @bid_multiplier > 10 invalid_properties.push('invalid value for "bid_multiplier", must be smaller than or equal to 10.') end if !@bid_multiplier.nil? && @bid_multiplier < 0 invalid_properties.push('invalid value for "bid_multiplier", must be greater than or equal to 0.') end pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 633 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/pinterest_sdk/models/ad_group_response.rb', line 430 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' bid_strategy_type_validator = EnumAttributeValidator.new('String', ["AUTOMATIC_BID", "MAX_BID", "TARGET_AVG"]) return false unless bid_strategy_type_validator.valid?(@bid_strategy_type) return false if !@campaign_id.nil? && @campaign_id !~ Regexp.new(/^[C]?\d+$/) promotion_application_level_validator = EnumAttributeValidator.new('String', ["NONE", "ITEM", "AD_GROUP"]) return false unless promotion_application_level_validator.valid?(@promotion_application_level) return false if !@promotion_id.nil? && @promotion_id !~ Regexp.new(/^\d+$/) return false if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1 return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if !@bid_multiplier.nil? && @bid_multiplier > 10 return false if !@bid_multiplier.nil? && @bid_multiplier < 0 conversion_learning_mode_type_validator = EnumAttributeValidator.new('String', ["NOT_ACTIVE", "ACTIVE"]) return false unless conversion_learning_mode_type_validator.valid?(@conversion_learning_mode_type) return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) true end |