Class: PinterestSdkClient::AdGroupUpdateBatchUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdGroupUpdateBatchUpdate
- Defined in:
- lib/pinterest_sdk/models/ad_group_update_batch_update.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group.
-
#bid_in_micro_currency ⇒ Object
Bid price in micro currency.
-
#bid_multiplier ⇒ Object
Open beta Bid multiplier for ad group.
-
#bid_strategy_type ⇒ Object
Returns the value of attribute bid_strategy_type.
-
#billable_event ⇒ Object
Returns the value of attribute billable_event.
-
#budget_in_micro_currency ⇒ Object
Budget in micro currency.
-
#budget_type ⇒ Object
Returns the value of attribute budget_type.
-
#campaign_id ⇒ Object
Campaign ID of the ad group.
-
#customer_segment_id ⇒ Object
Customer segment ID applied to the ad group.
-
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group stop appearing.
-
#ext_features ⇒ Object
Returns the value of attribute ext_features.
-
#feed_profile_id ⇒ Object
Feed Profile ID associated to the adgroup.
-
#id ⇒ Object
Ad group ID.
-
#is_creative_optimization ⇒ Object
Enable creative optimization for the ad group, default value is FALSE.
-
#is_local_inventory ⇒ Object
Indicates whether the ad group should use the local inventory.
-
#lifetime_frequency_cap ⇒ Object
Set a limit to the number of times a promoted pin from this campaign can be impressed by a pinner within the past rolling 30 days.
-
#local_inventory_radius_in_miles ⇒ Object
The targeting radius of the local inventory ads in miles.
-
#name ⇒ Object
Ad group name.
-
#optimization_goal_metadata ⇒ Object
Optimization goals for objective-based performance campaigns.
-
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
-
#performance_plus_campaign_settings ⇒ Object
Pinterest Performance+ campaign settings.
- #placement_group ⇒ Object
-
#placement_traffic_type ⇒ Object
A targeting option that enables advertisers to choose whether to run ads in fullscreen feed, two column feed, or both.
-
#promotion_application_level ⇒ Object
Specify if the promotion is applied at ad group or item level.
-
#promotion_id ⇒ Object
Promotion ID.
-
#promotion_ids ⇒ Object
Promotion IDs list.
-
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group start to appear.
-
#status ⇒ Object
Ad group/entity status.
-
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
-
#targeting_spec_operations ⇒ Object
Returns the value of attribute targeting_spec_operations.
-
#targeting_template_ids ⇒ Object
Targeting template IDs applied to the ad group.
-
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdGroupUpdateBatchUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdGroupUpdateBatchUpdate
Initializes the object
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 237 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdGroupUpdateBatchUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdGroupUpdateBatchUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_targeting_enabled') self.auto_targeting_enabled = attributes[:'auto_targeting_enabled'] end if attributes.key?(:'bid_in_micro_currency') self.bid_in_micro_currency = attributes[:'bid_in_micro_currency'] end if attributes.key?(:'bid_multiplier') self.bid_multiplier = attributes[:'bid_multiplier'] end if attributes.key?(:'bid_strategy_type') self.bid_strategy_type = attributes[:'bid_strategy_type'] end if attributes.key?(:'billable_event') self.billable_event = attributes[:'billable_event'] end if attributes.key?(:'budget_in_micro_currency') self.budget_in_micro_currency = attributes[:'budget_in_micro_currency'] end if attributes.key?(:'budget_type') self.budget_type = attributes[:'budget_type'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'customer_segment_id') self.customer_segment_id = attributes[:'customer_segment_id'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'ext_features') self.ext_features = attributes[:'ext_features'] end if attributes.key?(:'feed_profile_id') self.feed_profile_id = attributes[:'feed_profile_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'is_creative_optimization') self.is_creative_optimization = attributes[:'is_creative_optimization'] end if attributes.key?(:'is_local_inventory') self.is_local_inventory = attributes[:'is_local_inventory'] end if attributes.key?(:'lifetime_frequency_cap') self.lifetime_frequency_cap = attributes[:'lifetime_frequency_cap'] end if attributes.key?(:'local_inventory_radius_in_miles') self.local_inventory_radius_in_miles = attributes[:'local_inventory_radius_in_miles'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'optimization_goal_metadata') self. = attributes[:'optimization_goal_metadata'] end if attributes.key?(:'pacing_delivery_type') self.pacing_delivery_type = attributes[:'pacing_delivery_type'] end if attributes.key?(:'performance_plus_campaign_settings') self.performance_plus_campaign_settings = attributes[:'performance_plus_campaign_settings'] end if attributes.key?(:'placement_group') self.placement_group = attributes[:'placement_group'] end if attributes.key?(:'placement_traffic_type') self.placement_traffic_type = attributes[:'placement_traffic_type'] end if attributes.key?(:'promotion_application_level') self.promotion_application_level = attributes[:'promotion_application_level'] end if attributes.key?(:'promotion_id') self.promotion_id = attributes[:'promotion_id'] else self.promotion_id = '0' end if attributes.key?(:'promotion_ids') if (value = attributes[:'promotion_ids']).is_a?(Array) self.promotion_ids = value end end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'targeting_spec') self.targeting_spec = attributes[:'targeting_spec'] end if attributes.key?(:'targeting_spec_operations') if (value = attributes[:'targeting_spec_operations']).is_a?(Array) self.targeting_spec_operations = value end end if attributes.key?(:'targeting_template_ids') if (value = attributes[:'targeting_template_ids']).is_a?(Array) self.targeting_template_ids = value end end if attributes.key?(:'tracking_urls') self.tracking_urls = attributes[:'tracking_urls'] end end |
Instance Attribute Details
#auto_targeting_enabled ⇒ Object
Enable auto-targeting for ad group. Default value is True. Also known as "Performance+ targeting".
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 19 def auto_targeting_enabled @auto_targeting_enabled end |
#bid_in_micro_currency ⇒ Object
Bid price in micro currency. This field is REQUIRED for the following campaign objective_type/billable_event combinations: AWARENESS/IMPRESSION, CONSIDERATION/CLICKTHROUGH, CATALOG_SALES/CLICKTHROUGH, VIDEO_VIEW/VIDEO_V_50_MRC.
22 23 24 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 22 def bid_in_micro_currency @bid_in_micro_currency end |
#bid_multiplier ⇒ Object
Open beta Bid multiplier for ad group. This value is a double between 0.1 and 10.0. Enter 0 to remove the bid multiplier. - Not currently supported for Performance+ campaigns.
25 26 27 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 25 def bid_multiplier @bid_multiplier end |
#bid_strategy_type ⇒ Object
Returns the value of attribute bid_strategy_type.
27 28 29 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 27 def bid_strategy_type @bid_strategy_type end |
#billable_event ⇒ Object
Returns the value of attribute billable_event.
29 30 31 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 29 def billable_event @billable_event end |
#budget_in_micro_currency ⇒ Object
Budget in micro currency. This field is REQUIRED for non-CBO (campaign budget optimization) campaigns. A CBO campaign automatically generates ad group budgets from its campaign budget to maximize campaign outcome. A CBO campaign is limited to 70 or less ad groups.
32 33 34 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 32 def budget_in_micro_currency @budget_in_micro_currency end |
#budget_type ⇒ Object
Returns the value of attribute budget_type.
34 35 36 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 34 def budget_type @budget_type end |
#campaign_id ⇒ Object
Campaign ID of the ad group.
37 38 39 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 37 def campaign_id @campaign_id end |
#customer_segment_id ⇒ Object
Customer segment ID applied to the ad group. We currently only support 1 customer segment per ad group. To use customer segments, do not set the targeting_template_ids field as well as the AUDIENCE_INCLUDE field of the targeting_spec. To clear the customer segment ID, set this field to '0'.
40 41 42 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 40 def customer_segment_id @customer_segment_id end |
#end_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group stop appearing. If not specified, ads run indefinitely unless you update the ad group by changing their status to paused. Cannot occur after end_time for parent campaign (if specified). Learn about scheduling ads. For certain organizations (Closed beta): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.
43 44 45 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 43 def end_time @end_time end |
#ext_features ⇒ Object
Returns the value of attribute ext_features.
45 46 47 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 45 def ext_features @ext_features end |
#feed_profile_id ⇒ Object
Feed Profile ID associated to the adgroup.
48 49 50 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 48 def feed_profile_id @feed_profile_id end |
#id ⇒ Object
Ad group ID.
51 52 53 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 51 def id @id end |
#is_creative_optimization ⇒ Object
Enable creative optimization for the ad group, default value is FALSE. When enabled, you allow Pinterest to automatically turn your product Pins into ads in different formats (collections and shopping) and deliver those ads to users at scale.
54 55 56 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 54 def is_creative_optimization @is_creative_optimization end |
#is_local_inventory ⇒ Object
Indicates whether the ad group should use the local inventory.
57 58 59 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 57 def is_local_inventory @is_local_inventory end |
#lifetime_frequency_cap ⇒ Object
Set a limit to the number of times a promoted pin from this campaign can be impressed by a pinner within the past rolling 30 days. Only available for CPM (cost per mille (1000 impressions)) ad groups. A CPM ad group has an IMPRESSION billable_event value. This field REQUIRES the end_time field.
60 61 62 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 60 def lifetime_frequency_cap @lifetime_frequency_cap end |
#local_inventory_radius_in_miles ⇒ Object
The targeting radius of the local inventory ads in miles.
63 64 65 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 63 def local_inventory_radius_in_miles @local_inventory_radius_in_miles end |
#name ⇒ Object
Ad group name.
66 67 68 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 66 def name @name end |
#optimization_goal_metadata ⇒ Object
Optimization goals for objective-based performance campaigns. REQUIRED when campaign's objective_type is set to \"WEB_CONVERSION\".
69 70 71 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 69 def end |
#pacing_delivery_type ⇒ Object
Returns the value of attribute pacing_delivery_type.
71 72 73 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 71 def pacing_delivery_type @pacing_delivery_type end |
#performance_plus_campaign_settings ⇒ Object
Pinterest Performance+ campaign settings.
74 75 76 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 74 def performance_plus_campaign_settings @performance_plus_campaign_settings end |
#placement_group ⇒ Object
77 78 79 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 77 def placement_group @placement_group end |
#placement_traffic_type ⇒ Object
A targeting option that enables advertisers to choose whether to run ads in fullscreen feed, two column feed, or both
80 81 82 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 80 def placement_traffic_type @placement_traffic_type end |
#promotion_application_level ⇒ Object
Specify if the promotion is applied at ad group or item level
83 84 85 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 83 def promotion_application_level @promotion_application_level end |
#promotion_id ⇒ Object
Promotion ID. To clear this field, set to null.
86 87 88 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 86 def promotion_id @promotion_id end |
#promotion_ids ⇒ Object
Promotion IDs list. To clear this field, set to an empty array [].
89 90 91 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 89 def promotion_ids @promotion_ids end |
#start_time ⇒ Object
Timestamp in Unix format for scheduling when ads in the ad group start to appear. If not specified, ads appear during parent campaign's start_time. Cannot precede start_time for parent campaign (if specified). Learn about scheduling ads. For certain organizations (Closed beta): Supported for campaigns with Campaign Budget Optimization (CBO). For all organizations: Supported for campaigns without CBO.
92 93 94 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 92 def start_time @start_time end |
#status ⇒ Object
Ad group/entity status.
95 96 97 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 95 def status @status end |
#targeting_spec ⇒ Object
Returns the value of attribute targeting_spec.
97 98 99 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 97 def targeting_spec @targeting_spec end |
#targeting_spec_operations ⇒ Object
Returns the value of attribute targeting_spec_operations.
99 100 101 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 99 def targeting_spec_operations @targeting_spec_operations end |
#targeting_template_ids ⇒ Object
Targeting template IDs applied to the ad group. We currently only support 1 targeting template per ad group. To use targeting templates, do not set any other targeting fields: targeting_spec, tracking_urls, auto_targeting_enabled, placement_group. To clear all targeting template IDs, set this field to ['0'].
102 103 104 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 102 def targeting_template_ids @targeting_template_ids end |
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
104 105 106 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 104 def tracking_urls @tracking_urls end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
167 168 169 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 167 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
172 173 174 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 172 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 129 def self.attribute_map { :'auto_targeting_enabled' => :'auto_targeting_enabled', :'bid_in_micro_currency' => :'bid_in_micro_currency', :'bid_multiplier' => :'bid_multiplier', :'bid_strategy_type' => :'bid_strategy_type', :'billable_event' => :'billable_event', :'budget_in_micro_currency' => :'budget_in_micro_currency', :'budget_type' => :'budget_type', :'campaign_id' => :'campaign_id', :'customer_segment_id' => :'customer_segment_id', :'end_time' => :'end_time', :'ext_features' => :'ext_features', :'feed_profile_id' => :'feed_profile_id', :'id' => :'id', :'is_creative_optimization' => :'is_creative_optimization', :'is_local_inventory' => :'is_local_inventory', :'lifetime_frequency_cap' => :'lifetime_frequency_cap', :'local_inventory_radius_in_miles' => :'local_inventory_radius_in_miles', :'name' => :'name', :'optimization_goal_metadata' => :'optimization_goal_metadata', :'pacing_delivery_type' => :'pacing_delivery_type', :'performance_plus_campaign_settings' => :'performance_plus_campaign_settings', :'placement_group' => :'placement_group', :'placement_traffic_type' => :'placement_traffic_type', :'promotion_application_level' => :'promotion_application_level', :'promotion_id' => :'promotion_id', :'promotion_ids' => :'promotion_ids', :'start_time' => :'start_time', :'status' => :'status', :'targeting_spec' => :'targeting_spec', :'targeting_spec_operations' => :'targeting_spec_operations', :'targeting_template_ids' => :'targeting_template_ids', :'tracking_urls' => :'tracking_urls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 596 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 215 def self.openapi_nullable Set.new([ :'auto_targeting_enabled', :'bid_in_micro_currency', :'bid_strategy_type', :'budget_in_micro_currency', :'end_time', :'ext_features', :'is_creative_optimization', :'optimization_goal_metadata', :'performance_plus_campaign_settings', :'placement_traffic_type', :'promotion_application_level', :'promotion_id', :'start_time', :'targeting_template_ids', :'tracking_urls' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 177 def self.openapi_types { :'auto_targeting_enabled' => :'Boolean', :'bid_in_micro_currency' => :'Integer', :'bid_multiplier' => :'Float', :'bid_strategy_type' => :'BidStrategyType', :'billable_event' => :'ActionType', :'budget_in_micro_currency' => :'Integer', :'budget_type' => :'BudgetType', :'campaign_id' => :'String', :'customer_segment_id' => :'String', :'end_time' => :'Integer', :'ext_features' => :'AdgroupTrackingFeatures', :'feed_profile_id' => :'String', :'id' => :'String', :'is_creative_optimization' => :'Boolean', :'is_local_inventory' => :'Boolean', :'lifetime_frequency_cap' => :'Integer', :'local_inventory_radius_in_miles' => :'Float', :'name' => :'String', :'optimization_goal_metadata' => :'NullableOptimizationGoalMetadata', :'pacing_delivery_type' => :'PacingDeliveryType', :'performance_plus_campaign_settings' => :'PerformancePlusCampaignSettings', :'placement_group' => :'PlacementGroupType', :'placement_traffic_type' => :'PlacementTrafficType', :'promotion_application_level' => :'PromotionApplicationLevel', :'promotion_id' => :'String', :'promotion_ids' => :'Array<String>', :'start_time' => :'Integer', :'status' => :'EntityStatus', :'targeting_spec' => :'TargetingSpecOptimal', :'targeting_spec_operations' => :'Array<TargetingSpecOperations>', :'targeting_template_ids' => :'Array<String>', :'tracking_urls' => :'AdGroupTrackingURLs' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 544 def ==(o) return true if self.equal?(o) self.class == o.class && auto_targeting_enabled == o.auto_targeting_enabled && bid_in_micro_currency == o.bid_in_micro_currency && bid_multiplier == o.bid_multiplier && bid_strategy_type == o.bid_strategy_type && billable_event == o.billable_event && budget_in_micro_currency == o.budget_in_micro_currency && budget_type == o.budget_type && campaign_id == o.campaign_id && customer_segment_id == o.customer_segment_id && end_time == o.end_time && ext_features == o.ext_features && feed_profile_id == o.feed_profile_id && id == o.id && is_creative_optimization == o.is_creative_optimization && is_local_inventory == o.is_local_inventory && lifetime_frequency_cap == o.lifetime_frequency_cap && local_inventory_radius_in_miles == o.local_inventory_radius_in_miles && name == o.name && == o. && pacing_delivery_type == o.pacing_delivery_type && performance_plus_campaign_settings == o.performance_plus_campaign_settings && placement_group == o.placement_group && placement_traffic_type == o.placement_traffic_type && promotion_application_level == o.promotion_application_level && promotion_id == o.promotion_id && promotion_ids == o.promotion_ids && start_time == o.start_time && status == o.status && targeting_spec == o.targeting_spec && targeting_spec_operations == o.targeting_spec_operations && targeting_template_ids == o.targeting_template_ids && tracking_urls == o.tracking_urls end |
#eql?(o) ⇒ Boolean
583 584 585 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 583 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
589 590 591 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 589 def hash [auto_targeting_enabled, bid_in_micro_currency, bid_multiplier, bid_strategy_type, billable_event, budget_in_micro_currency, budget_type, campaign_id, customer_segment_id, end_time, ext_features, feed_profile_id, id, is_creative_optimization, is_local_inventory, lifetime_frequency_cap, local_inventory_radius_in_miles, name, , pacing_delivery_type, performance_plus_campaign_settings, placement_group, placement_traffic_type, promotion_application_level, promotion_id, promotion_ids, start_time, status, targeting_spec, targeting_spec_operations, targeting_template_ids, tracking_urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 392 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@bid_multiplier.nil? && @bid_multiplier > 10 invalid_properties.push('invalid value for "bid_multiplier", must be smaller than or equal to 10.') end if !@bid_multiplier.nil? && @bid_multiplier < 0 invalid_properties.push('invalid value for "bid_multiplier", must be greater than or equal to 0.') end pattern = Regexp.new(/^[C]?\d+$/) if !@campaign_id.nil? && @campaign_id !~ pattern invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@customer_segment_id.nil? && @customer_segment_id !~ pattern invalid_properties.push("invalid value for \"customer_segment_id\", must conform to the pattern #{pattern}.") end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 18 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 18.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@promotion_id.nil? && @promotion_id !~ pattern invalid_properties.push("invalid value for \"promotion_id\", must conform to the pattern #{pattern}.") end if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1 invalid_properties.push('invalid value for "targeting_template_ids", number of items must be less than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
618 619 620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 618 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/pinterest_sdk/models/ad_group_update_batch_update.rb', line 440 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@bid_multiplier.nil? && @bid_multiplier > 10 return false if !@bid_multiplier.nil? && @bid_multiplier < 0 return false if !@campaign_id.nil? && @campaign_id !~ Regexp.new(/^[C]?\d+$/) return false if !@customer_segment_id.nil? && @customer_segment_id !~ Regexp.new(/^\d+$/) return false if @id.nil? return false if @id.to_s.length > 18 return false if @id !~ Regexp.new(/^\d+$/) return false if !@promotion_id.nil? && @promotion_id !~ Regexp.new(/^\d+$/) return false if !@targeting_template_ids.nil? && @targeting_template_ids.length > 1 true end |