Class: PinterestSdkClient::AdResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdResponse
- Defined in:
- lib/pinterest_sdk/models/ad_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
The ID of the advertiser that this ad belongs to.
-
#ad_group_id ⇒ Object
ID of the ad group that contains the ad.
-
#android_deep_link ⇒ Object
Deep link URL for Android devices.
-
#campaign_id ⇒ Object
ID of the ad campaign that contains this ad.
-
#carousel_android_deep_links ⇒ Object
Comma-separated deep links for the carousel pin on Android.
-
#carousel_destination_urls ⇒ Object
Comma-separated destination URLs for the carousel pin to promote.
-
#carousel_ios_deep_links ⇒ Object
Comma-separated deep links for the carousel pin on iOS.
-
#click_tracking_url ⇒ Object
Tracking url for the ad clicks.
-
#collection_items_destination_url_template ⇒ Object
Destination URL template for all items within a collections drawer.
-
#created_time ⇒ Object
Pin creation time.
-
#creative_type ⇒ Object
Returns the value of attribute creative_type.
-
#customizable_cta_type ⇒ Object
Returns the value of attribute customizable_cta_type.
-
#destination_url ⇒ Object
Destination URL.
-
#disclosure_type ⇒ Object
Returns the value of attribute disclosure_type.
-
#disclosure_url ⇒ Object
URL for a page that provides disclosures about a pharmaceutical product, such as potential side effects.
-
#grid_click_type ⇒ Object
Returns the value of attribute grid_click_type.
-
#id ⇒ Object
The ID of this ad.
-
#ios_deep_link ⇒ Object
Deep link URL for iOS devices.
-
#is_pin_deleted ⇒ Object
Is original pin deleted?.
-
#is_removable ⇒ Object
Is pin repinnable?.
-
#lead_form_id ⇒ Object
Lead form ID for lead ad generation.
-
#name ⇒ Object
Name of the ad - 255 chars max.
-
#pin_id ⇒ Object
Pin ID.
-
#quiz_pin_data ⇒ Object
Before creating a quiz ad, you must create an organic Pin using POST/Create Pin for each result in the quiz.
-
#rejected_reasons ⇒ Object
Enum reason why the pin was rejected.
-
#rejection_labels ⇒ Object
Text reason why the pin was rejected.
-
#review_status ⇒ Object
Ad review status.
-
#status ⇒ Object
Returns the value of attribute status.
-
#summary_status ⇒ Object
Ad summary status.
-
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
-
#type ⇒ Object
Always \“ad\”.
-
#updated_time ⇒ Object
Last update time.
-
#view_tracking_url ⇒ Object
Tracking URL for ad impressions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdResponse
Initializes the object
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 254 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_group_id') self.ad_group_id = attributes[:'ad_group_id'] end if attributes.key?(:'android_deep_link') self.android_deep_link = attributes[:'android_deep_link'] end if attributes.key?(:'carousel_android_deep_links') if (value = attributes[:'carousel_android_deep_links']).is_a?(Array) self.carousel_android_deep_links = value end end if attributes.key?(:'carousel_destination_urls') if (value = attributes[:'carousel_destination_urls']).is_a?(Array) self.carousel_destination_urls = value end end if attributes.key?(:'carousel_ios_deep_links') if (value = attributes[:'carousel_ios_deep_links']).is_a?(Array) self.carousel_ios_deep_links = value end end if attributes.key?(:'click_tracking_url') self.click_tracking_url = attributes[:'click_tracking_url'] end if attributes.key?(:'creative_type') self.creative_type = attributes[:'creative_type'] end if attributes.key?(:'customizable_cta_type') self.customizable_cta_type = attributes[:'customizable_cta_type'] end if attributes.key?(:'destination_url') self.destination_url = attributes[:'destination_url'] end if attributes.key?(:'disclosure_type') self.disclosure_type = attributes[:'disclosure_type'] end if attributes.key?(:'disclosure_url') self.disclosure_url = attributes[:'disclosure_url'] end if attributes.key?(:'grid_click_type') self.grid_click_type = attributes[:'grid_click_type'] end if attributes.key?(:'ios_deep_link') self.ios_deep_link = attributes[:'ios_deep_link'] end if attributes.key?(:'is_pin_deleted') self.is_pin_deleted = attributes[:'is_pin_deleted'] end if attributes.key?(:'is_removable') self.is_removable = attributes[:'is_removable'] end if attributes.key?(:'lead_form_id') self.lead_form_id = attributes[:'lead_form_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'quiz_pin_data') self.quiz_pin_data = attributes[:'quiz_pin_data'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'tracking_urls') self.tracking_urls = attributes[:'tracking_urls'] end if attributes.key?(:'view_tracking_url') self.view_tracking_url = attributes[:'view_tracking_url'] end if attributes.key?(:'pin_id') self.pin_id = attributes[:'pin_id'] end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'collection_items_destination_url_template') self.collection_items_destination_url_template = attributes[:'collection_items_destination_url_template'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'rejected_reasons') if (value = attributes[:'rejected_reasons']).is_a?(Array) self.rejected_reasons = value end end if attributes.key?(:'rejection_labels') if (value = attributes[:'rejection_labels']).is_a?(Array) self.rejection_labels = value end end if attributes.key?(:'review_status') self.review_status = attributes[:'review_status'] end if attributes.key?(:'summary_status') self.summary_status = attributes[:'summary_status'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
The ID of the advertiser that this ad belongs to.
79 80 81 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 79 def ad_account_id @ad_account_id end |
#ad_group_id ⇒ Object
ID of the ad group that contains the ad.
19 20 21 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 19 def ad_group_id @ad_group_id end |
#android_deep_link ⇒ Object
Deep link URL for Android devices.
22 23 24 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 22 def android_deep_link @android_deep_link end |
#campaign_id ⇒ Object
ID of the ad campaign that contains this ad.
82 83 84 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 82 def campaign_id @campaign_id end |
#carousel_android_deep_links ⇒ Object
Comma-separated deep links for the carousel pin on Android.
25 26 27 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 25 def carousel_android_deep_links @carousel_android_deep_links end |
#carousel_destination_urls ⇒ Object
Comma-separated destination URLs for the carousel pin to promote.
28 29 30 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 28 def carousel_destination_urls @carousel_destination_urls end |
#carousel_ios_deep_links ⇒ Object
Comma-separated deep links for the carousel pin on iOS.
31 32 33 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 31 def carousel_ios_deep_links @carousel_ios_deep_links end |
#click_tracking_url ⇒ Object
Tracking url for the ad clicks.
34 35 36 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 34 def click_tracking_url @click_tracking_url end |
#collection_items_destination_url_template ⇒ Object
Destination URL template for all items within a collections drawer.
85 86 87 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 85 def collection_items_destination_url_template @collection_items_destination_url_template end |
#created_time ⇒ Object
Pin creation time. Unix timestamp in seconds.
88 89 90 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 88 def created_time @created_time end |
#creative_type ⇒ Object
Returns the value of attribute creative_type.
36 37 38 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 36 def creative_type @creative_type end |
#customizable_cta_type ⇒ Object
Returns the value of attribute customizable_cta_type.
38 39 40 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 38 def customizable_cta_type @customizable_cta_type end |
#destination_url ⇒ Object
Destination URL.
41 42 43 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 41 def destination_url @destination_url end |
#disclosure_type ⇒ Object
Returns the value of attribute disclosure_type.
43 44 45 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 43 def disclosure_type @disclosure_type end |
#disclosure_url ⇒ Object
URL for a page that provides disclosures about a pharmaceutical product, such as potential side effects. Make sure the URL takes the user directly to the disclosure content and the referenced site is secure.
46 47 48 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 46 def disclosure_url @disclosure_url end |
#grid_click_type ⇒ Object
Returns the value of attribute grid_click_type.
48 49 50 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 48 def grid_click_type @grid_click_type end |
#id ⇒ Object
The ID of this ad.
91 92 93 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 91 def id @id end |
#ios_deep_link ⇒ Object
Deep link URL for iOS devices.
51 52 53 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 51 def ios_deep_link @ios_deep_link end |
#is_pin_deleted ⇒ Object
Is original pin deleted?
54 55 56 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 54 def is_pin_deleted @is_pin_deleted end |
#is_removable ⇒ Object
Is pin repinnable?
57 58 59 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 57 def is_removable @is_removable end |
#lead_form_id ⇒ Object
Lead form ID for lead ad generation.
60 61 62 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 60 def lead_form_id @lead_form_id end |
#name ⇒ Object
Name of the ad - 255 chars max.
63 64 65 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 63 def name @name end |
#pin_id ⇒ Object
Pin ID.
76 77 78 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 76 def pin_id @pin_id end |
#quiz_pin_data ⇒ Object
Before creating a quiz ad, you must create an organic Pin using POST/Create Pin for each result in the quiz. Quiz ads cannot be saved by a Pinner. Quiz ad results can be saved.
66 67 68 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 66 def quiz_pin_data @quiz_pin_data end |
#rejected_reasons ⇒ Object
Enum reason why the pin was rejected. Returned if review_status is \“REJECTED\”.
94 95 96 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 94 def rejected_reasons @rejected_reasons end |
#rejection_labels ⇒ Object
Text reason why the pin was rejected. Returned if review_status is \“REJECTED\”.
97 98 99 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 97 def rejection_labels @rejection_labels end |
#review_status ⇒ Object
Ad review status
100 101 102 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 100 def review_status @review_status end |
#status ⇒ Object
Returns the value of attribute status.
68 69 70 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 68 def status @status end |
#summary_status ⇒ Object
Ad summary status
103 104 105 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 103 def summary_status @summary_status end |
#tracking_urls ⇒ Object
Returns the value of attribute tracking_urls.
70 71 72 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 70 def tracking_urls @tracking_urls end |
#type ⇒ Object
Always \“ad\”.
106 107 108 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 106 def type @type end |
#updated_time ⇒ Object
Last update time. Unix timestamp in seconds.
109 110 111 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 109 def updated_time @updated_time end |
#view_tracking_url ⇒ Object
Tracking URL for ad impressions.
73 74 75 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 73 def view_tracking_url @view_tracking_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
173 174 175 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 173 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
178 179 180 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 178 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 134 def self.attribute_map { :'ad_group_id' => :'ad_group_id', :'android_deep_link' => :'android_deep_link', :'carousel_android_deep_links' => :'carousel_android_deep_links', :'carousel_destination_urls' => :'carousel_destination_urls', :'carousel_ios_deep_links' => :'carousel_ios_deep_links', :'click_tracking_url' => :'click_tracking_url', :'creative_type' => :'creative_type', :'customizable_cta_type' => :'customizable_cta_type', :'destination_url' => :'destination_url', :'disclosure_type' => :'disclosure_type', :'disclosure_url' => :'disclosure_url', :'grid_click_type' => :'grid_click_type', :'ios_deep_link' => :'ios_deep_link', :'is_pin_deleted' => :'is_pin_deleted', :'is_removable' => :'is_removable', :'lead_form_id' => :'lead_form_id', :'name' => :'name', :'quiz_pin_data' => :'quiz_pin_data', :'status' => :'status', :'tracking_urls' => :'tracking_urls', :'view_tracking_url' => :'view_tracking_url', :'pin_id' => :'pin_id', :'ad_account_id' => :'ad_account_id', :'campaign_id' => :'campaign_id', :'collection_items_destination_url_template' => :'collection_items_destination_url_template', :'created_time' => :'created_time', :'id' => :'id', :'rejected_reasons' => :'rejected_reasons', :'rejection_labels' => :'rejection_labels', :'review_status' => :'review_status', :'summary_status' => :'summary_status', :'type' => :'type', :'updated_time' => :'updated_time' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 615 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
245 246 247 248 249 250 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 245 def self.openapi_all_of [ :'AdCommon', :'AdPinId' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 222 def self.openapi_nullable Set.new([ :'android_deep_link', :'carousel_android_deep_links', :'carousel_destination_urls', :'carousel_ios_deep_links', :'click_tracking_url', :'customizable_cta_type', :'destination_url', :'disclosure_type', :'disclosure_url', :'grid_click_type', :'ios_deep_link', :'lead_form_id', :'name', :'quiz_pin_data', :'tracking_urls', :'view_tracking_url', :'collection_items_destination_url_template', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 183 def self.openapi_types { :'ad_group_id' => :'String', :'android_deep_link' => :'String', :'carousel_android_deep_links' => :'Array<String>', :'carousel_destination_urls' => :'Array<String>', :'carousel_ios_deep_links' => :'Array<String>', :'click_tracking_url' => :'String', :'creative_type' => :'CreativeType', :'customizable_cta_type' => :'CustomizableCTAType', :'destination_url' => :'String', :'disclosure_type' => :'DisclosureType', :'disclosure_url' => :'String', :'grid_click_type' => :'GridClickType', :'ios_deep_link' => :'String', :'is_pin_deleted' => :'Boolean', :'is_removable' => :'Boolean', :'lead_form_id' => :'String', :'name' => :'String', :'quiz_pin_data' => :'QuizPinData', :'status' => :'EntityStatus', :'tracking_urls' => :'TrackingUrls', :'view_tracking_url' => :'String', :'pin_id' => :'String', :'ad_account_id' => :'String', :'campaign_id' => :'String', :'collection_items_destination_url_template' => :'String', :'created_time' => :'Integer', :'id' => :'String', :'rejected_reasons' => :'Array<String>', :'rejection_labels' => :'Array<String>', :'review_status' => :'String', :'summary_status' => :'PinPromotionSummaryStatus', :'type' => :'String', :'updated_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 562 def ==(o) return true if self.equal?(o) self.class == o.class && ad_group_id == o.ad_group_id && android_deep_link == o.android_deep_link && carousel_android_deep_links == o.carousel_android_deep_links && carousel_destination_urls == o.carousel_destination_urls && carousel_ios_deep_links == o.carousel_ios_deep_links && click_tracking_url == o.click_tracking_url && creative_type == o.creative_type && customizable_cta_type == o.customizable_cta_type && destination_url == o.destination_url && disclosure_type == o.disclosure_type && disclosure_url == o.disclosure_url && grid_click_type == o.grid_click_type && ios_deep_link == o.ios_deep_link && is_pin_deleted == o.is_pin_deleted && is_removable == o.is_removable && lead_form_id == o.lead_form_id && name == o.name && quiz_pin_data == o.quiz_pin_data && status == o.status && tracking_urls == o.tracking_urls && view_tracking_url == o.view_tracking_url && pin_id == o.pin_id && ad_account_id == o.ad_account_id && campaign_id == o.campaign_id && collection_items_destination_url_template == o.collection_items_destination_url_template && created_time == o.created_time && id == o.id && rejected_reasons == o.rejected_reasons && rejection_labels == o.rejection_labels && review_status == o.review_status && summary_status == o.summary_status && type == o.type && updated_time == o.updated_time end |
#eql?(o) ⇒ Boolean
602 603 604 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 602 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
608 609 610 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 608 def hash [ad_group_id, android_deep_link, carousel_android_deep_links, carousel_destination_urls, carousel_ios_deep_links, click_tracking_url, creative_type, customizable_cta_type, destination_url, disclosure_type, disclosure_url, grid_click_type, ios_deep_link, is_pin_deleted, is_removable, lead_form_id, name, quiz_pin_data, status, tracking_urls, view_tracking_url, pin_id, ad_account_id, campaign_id, collection_items_destination_url_template, created_time, id, rejected_reasons, rejection_labels, review_status, summary_status, type, updated_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 413 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^(AG)?\d+$/) if !@ad_group_id.nil? && @ad_group_id !~ pattern invalid_properties.push("invalid value for \"ad_group_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^(AG)?\d+$/) if !@lead_form_id.nil? && @lead_form_id !~ pattern invalid_properties.push("invalid value for \"lead_form_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@pin_id.nil? && @pin_id !~ pattern invalid_properties.push("invalid value for \"pin_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@campaign_id.nil? && @campaign_id !~ pattern invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 637 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/pinterest_sdk/models/ad_response.rb', line 451 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ad_group_id.nil? && @ad_group_id !~ Regexp.new(/^(AG)?\d+$/) return false if !@lead_form_id.nil? && @lead_form_id !~ Regexp.new(/^(AG)?\d+$/) return false if !@pin_id.nil? && @pin_id !~ Regexp.new(/^\d+$/) return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if !@campaign_id.nil? && @campaign_id !~ Regexp.new(/^\d+$/) return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) review_status_validator = EnumAttributeValidator.new('String', ["OTHER", "PENDING", "REJECTED", "APPROVED"]) return false unless review_status_validator.valid?(@review_status) true end |