Class: PinterestSdkClient::AdsAnalyticsCreateAsyncResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AdsAnalyticsCreateAsyncResponse
- Defined in:
- lib/pinterest_sdk/models/ads_analytics_create_async_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#message ⇒ Object
Returns the value of attribute message.
-
#report_status ⇒ Object
Returns the value of attribute report_status.
-
#token ⇒ Object
Returns the value of attribute token.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdsAnalyticsCreateAsyncResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdsAnalyticsCreateAsyncResponse
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AdsAnalyticsCreateAsyncResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AdsAnalyticsCreateAsyncResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'report_status') self.report_status = attributes[:'report_status'] end if attributes.key?(:'token') self.token = attributes[:'token'] end end |
Instance Attribute Details
#message ⇒ Object
Returns the value of attribute message.
18 19 20 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 18 def end |
#report_status ⇒ Object
Returns the value of attribute report_status.
20 21 22 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 20 def report_status @report_status end |
#token ⇒ Object
Returns the value of attribute token.
22 23 24 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 22 def token @token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 47 def self.attribute_map { :'message' => :'message', :'report_status' => :'report_status', :'token' => :'token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 75 def self.openapi_nullable Set.new([ :'message', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 66 def self.openapi_types { :'message' => :'String', :'report_status' => :'BulkReportingJobStatus', :'token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && report_status == o.report_status && token == o.token end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 143 def hash [, report_status, token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 |
# File 'lib/pinterest_sdk/models/ads_analytics_create_async_response.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |