Class: PinterestSdkClient::AssetIdPermissions
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::AssetIdPermissions
- Defined in:
- lib/pinterest_sdk/models/asset_id_permissions.rb
Overview
An object containing the permissions a business member has on the asset.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset_group_info ⇒ Object
An object containing all the information specific to the provided asset group.
-
#asset_id ⇒ Object
Unique identifier of a business asset.
-
#asset_type ⇒ Object
Returns the value of attribute asset_type.
-
#permissions ⇒ Object
Permission levels member or partner has on an asset.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssetIdPermissions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AssetIdPermissions
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::AssetIdPermissions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::AssetIdPermissions`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_group_info') self.asset_group_info = attributes[:'asset_group_info'] end if attributes.key?(:'asset_id') self.asset_id = attributes[:'asset_id'] else self.asset_id = nil end if attributes.key?(:'asset_type') self.asset_type = attributes[:'asset_type'] else self.asset_type = nil end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end else self. = nil end end |
Instance Attribute Details
#asset_group_info ⇒ Object
An object containing all the information specific to the provided asset group. This field will be populated only if asset_type equals 'ASSET_GROUP'.
20 21 22 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 20 def asset_group_info @asset_group_info end |
#asset_id ⇒ Object
Unique identifier of a business asset.
23 24 25 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 23 def asset_id @asset_id end |
#asset_type ⇒ Object
Returns the value of attribute asset_type.
25 26 27 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 25 def asset_type @asset_type end |
#permissions ⇒ Object
Permission levels member or partner has on an asset.
28 29 30 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 28 def @permissions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 53 def self.attribute_map { :'asset_group_info' => :'asset_group_info', :'asset_id' => :'asset_id', :'asset_type' => :'asset_type', :'permissions' => :'permissions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 73 def self.openapi_types { :'asset_group_info' => :'AssetGroupBinding', :'asset_id' => :'String', :'asset_type' => :'AssetTypeResponse', :'permissions' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && asset_group_info == o.asset_group_info && asset_id == o.asset_id && asset_type == o.asset_type && == o. end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 237 def hash [asset_group_info, asset_id, asset_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @asset_id.nil? invalid_properties.push('invalid value for "asset_id", asset_id cannot be nil.') end if @asset_id.to_s.length > 20 invalid_properties.push('invalid value for "asset_id", the character length must be smaller than or equal to 20.') end if @asset_id.to_s.length < 1 invalid_properties.push('invalid value for "asset_id", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^\d+$/) if @asset_id !~ pattern invalid_properties.push("invalid value for \"asset_id\", must conform to the pattern #{pattern}.") end if @asset_type.nil? invalid_properties.push('invalid value for "asset_type", asset_type cannot be nil.') end if @permissions.nil? invalid_properties.push('invalid value for "permissions", permissions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/pinterest_sdk/models/asset_id_permissions.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @asset_id.nil? return false if @asset_id.to_s.length > 20 return false if @asset_id.to_s.length < 1 return false if @asset_id !~ Regexp.new(/^\d+$/) return false if @asset_type.nil? return false if @permissions.nil? true end |