Class: PinterestSdkClient::AudiencesApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::AudiencesApi
- Defined in:
- lib/pinterest_sdk/api/audiences_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#audiences_create(ad_account_id, ad_accounts_audience_create, opts = {}) ⇒ AdAccountsAudience
Create audience Create a new audience for the ad account.
-
#audiences_create_with_http_info(ad_account_id, ad_accounts_audience_create, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Create audience Create a new audience for the ad account.
-
#audiences_get(audience_id, ad_account_id, opts = {}) ⇒ AdAccountsAudience
Get audience Get a specific audience given the audience ID.
-
#audiences_get_with_http_info(audience_id, ad_account_id, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Get audience Get a specific audience given the audience ID.
-
#audiences_list(ad_account_id, opts = {}) ⇒ AudiencesList200Response
List audiences Get list of audiences for the ad account.
-
#audiences_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(AudiencesList200Response, Integer, Hash)>
List audiences Get list of audiences for the ad account.
-
#audiences_update(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) ⇒ AdAccountsAudience
Update audience Update an existing audience for the ad account.
-
#audiences_update_with_http_info(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Update audience Update an existing audience for the ad account.
-
#initialize(api_client = ApiClient.default) ⇒ AudiencesApi
constructor
A new instance of AudiencesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AudiencesApi
Returns a new instance of AudiencesApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#audiences_create(ad_account_id, ad_accounts_audience_create, opts = {}) ⇒ AdAccountsAudience
Create audience Create a new audience for the ad account.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 28 def audiences_create(ad_account_id, ad_accounts_audience_create, opts = {}) data, _status_code, _headers = audiences_create_with_http_info(ad_account_id, ad_accounts_audience_create, opts) data end |
#audiences_create_with_http_info(ad_account_id, ad_accounts_audience_create, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Create audience Create a new audience for the ad account.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 39 def audiences_create_with_http_info(ad_account_id, ad_accounts_audience_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AudiencesApi.audiences_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling AudiencesApi.audiences_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling AudiencesApi.audiences_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling AudiencesApi.audiences_create, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_accounts_audience_create' is set if @api_client.config.client_side_validation && ad_accounts_audience_create.nil? fail ArgumentError, "Missing the required parameter 'ad_accounts_audience_create' when calling AudiencesApi.audiences_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/audiences'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(ad_accounts_audience_create) # return_type return_type = opts[:debug_return_type] || 'AdAccountsAudience' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"AudiencesApi.audiences_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AudiencesApi#audiences_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#audiences_get(audience_id, ad_account_id, opts = {}) ⇒ AdAccountsAudience
Get audience Get a specific audience given the audience ID.
111 112 113 114 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 111 def audiences_get(audience_id, ad_account_id, opts = {}) data, _status_code, _headers = audiences_get_with_http_info(audience_id, ad_account_id, opts) data end |
#audiences_get_with_http_info(audience_id, ad_account_id, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Get audience Get a specific audience given the audience ID.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 122 def audiences_get_with_http_info(audience_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AudiencesApi.audiences_get ...' end # verify the required parameter 'audience_id' is set if @api_client.config.client_side_validation && audience_id.nil? fail ArgumentError, "Missing the required parameter 'audience_id' when calling AudiencesApi.audiences_get" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && audience_id !~ pattern fail ArgumentError, "invalid value for 'audience_id' when calling AudiencesApi.audiences_get, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling AudiencesApi.audiences_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling AudiencesApi.audiences_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling AudiencesApi.audiences_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/audiences/{audience_id}'.sub('{audience_id}', CGI.escape(audience_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AdAccountsAudience' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"AudiencesApi.audiences_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AudiencesApi#audiences_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#audiences_list(ad_account_id, opts = {}) ⇒ AudiencesList200Response
List audiences Get list of audiences for the ad account.
198 199 200 201 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 198 def audiences_list(ad_account_id, opts = {}) data, _status_code, _headers = audiences_list_with_http_info(ad_account_id, opts) data end |
#audiences_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(AudiencesList200Response, Integer, Hash)>
List audiences Get list of audiences for the ad account.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 213 def audiences_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AudiencesApi.audiences_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling AudiencesApi.audiences_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling AudiencesApi.audiences_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling AudiencesApi.audiences_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling AudiencesApi.audiences_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling AudiencesApi.audiences_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/audiences'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'ownership_type'] = opts[:'ownership_type'] if !opts[:'ownership_type'].nil? query_params[:'exclude_nca'] = opts[:'exclude_nca'] if !opts[:'exclude_nca'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AudiencesList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"AudiencesApi.audiences_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AudiencesApi#audiences_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#audiences_update(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) ⇒ AdAccountsAudience
Update audience Update an existing audience for the ad account.
290 291 292 293 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 290 def audiences_update(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) data, _status_code, _headers = audiences_update_with_http_info(audience_id, ad_account_id, ad_accounts_audience_update, opts) data end |
#audiences_update_with_http_info(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) ⇒ Array<(AdAccountsAudience, Integer, Hash)>
Update audience Update an existing audience for the ad account.
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/pinterest_sdk/api/audiences_api.rb', line 302 def audiences_update_with_http_info(audience_id, ad_account_id, ad_accounts_audience_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AudiencesApi.audiences_update ...' end # verify the required parameter 'audience_id' is set if @api_client.config.client_side_validation && audience_id.nil? fail ArgumentError, "Missing the required parameter 'audience_id' when calling AudiencesApi.audiences_update" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && audience_id !~ pattern fail ArgumentError, "invalid value for 'audience_id' when calling AudiencesApi.audiences_update, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling AudiencesApi.audiences_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling AudiencesApi.audiences_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling AudiencesApi.audiences_update, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_accounts_audience_update' is set if @api_client.config.client_side_validation && ad_accounts_audience_update.nil? fail ArgumentError, "Missing the required parameter 'ad_accounts_audience_update' when calling AudiencesApi.audiences_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/audiences/{audience_id}'.sub('{audience_id}', CGI.escape(audience_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(ad_accounts_audience_update) # return_type return_type = opts[:debug_return_type] || 'AdAccountsAudience' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"AudiencesApi.audiences_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AudiencesApi#audiences_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |