Class: PinterestSdkClient::BulkCampaignDeliveryEstimatesItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BulkCampaignDeliveryEstimatesItem
- Defined in:
- lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb
Overview
Delivery estimate result for a single campaign within a bulk request.
Instance Attribute Summary collapse
-
#adgroup_audience_sizes ⇒ Object
Range audience sizes for each ad group, in the same order as the ad groups in the request.
-
#conversion_rate ⇒ Object
Conversion rate estimate.
-
#conversion_rates ⇒ Object
Conversion rate estimates.
-
#curves ⇒ Object
Estimated curves.
-
#derived_metrics ⇒ Object
Returns the value of attribute derived_metrics.
-
#errors ⇒ Object
Errors encountered during estimation for this campaign.
-
#estimate_id ⇒ Object
UUID used to track delivery estimates when they are generated as part of a saved campaign.
-
#max_potential_spend ⇒ Object
Maximum potential spend estimate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkCampaignDeliveryEstimatesItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BulkCampaignDeliveryEstimatesItem
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BulkCampaignDeliveryEstimatesItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BulkCampaignDeliveryEstimatesItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'adgroup_audience_sizes') if (value = attributes[:'adgroup_audience_sizes']).is_a?(Array) self.adgroup_audience_sizes = value end end if attributes.key?(:'conversion_rate') self.conversion_rate = attributes[:'conversion_rate'] end if attributes.key?(:'conversion_rates') if (value = attributes[:'conversion_rates']).is_a?(Array) self.conversion_rates = value end end if attributes.key?(:'curves') if (value = attributes[:'curves']).is_a?(Array) self.curves = value end end if attributes.key?(:'derived_metrics') self.derived_metrics = attributes[:'derived_metrics'] end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'estimate_id') self.estimate_id = attributes[:'estimate_id'] end if attributes.key?(:'max_potential_spend') self.max_potential_spend = attributes[:'max_potential_spend'] end end |
Instance Attribute Details
#adgroup_audience_sizes ⇒ Object
Range audience sizes for each ad group, in the same order as the ad groups in the request.
20 21 22 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 20 def adgroup_audience_sizes @adgroup_audience_sizes end |
#conversion_rate ⇒ Object
Conversion rate estimate. Used to translate impressions into conversions for oCPM ads, adapted based on the input conversion event and attribution windows.
23 24 25 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 23 def conversion_rate @conversion_rate end |
#conversion_rates ⇒ Object
Conversion rate estimates. Used to translate impressions into conversions for oCPM ads based on different conversion event and attribution windows settings.
26 27 28 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 26 def conversion_rates @conversion_rates end |
#curves ⇒ Object
Estimated curves. Each curve will pertain to a single estimation type.
29 30 31 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 29 def curves @curves end |
#derived_metrics ⇒ Object
Returns the value of attribute derived_metrics.
31 32 33 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 31 def derived_metrics @derived_metrics end |
#errors ⇒ Object
Errors encountered during estimation for this campaign.
34 35 36 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 34 def errors @errors end |
#estimate_id ⇒ Object
UUID used to track delivery estimates when they are generated as part of a saved campaign.
37 38 39 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 37 def estimate_id @estimate_id end |
#max_potential_spend ⇒ Object
Maximum potential spend estimate.
40 41 42 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 40 def max_potential_spend @max_potential_spend end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 43 def self.attribute_map { :'adgroup_audience_sizes' => :'adgroup_audience_sizes', :'conversion_rate' => :'conversion_rate', :'conversion_rates' => :'conversion_rates', :'curves' => :'curves', :'derived_metrics' => :'derived_metrics', :'errors' => :'errors', :'estimate_id' => :'estimate_id', :'max_potential_spend' => :'max_potential_spend' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 67 def self.openapi_types { :'adgroup_audience_sizes' => :'Array<CampaignPlanningAdGroupAudienceSize>', :'conversion_rate' => :'Float', :'conversion_rates' => :'Array<CampaignPlanningConversionRate>', :'curves' => :'Array<CampaignPlanningCurveEstimate>', :'derived_metrics' => :'CampaignDeliveryEstimatesDerivedMetrics', :'errors' => :'Array<CampaignPlanningResponseError>', :'estimate_id' => :'String', :'max_potential_spend' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && adgroup_audience_sizes == o.adgroup_audience_sizes && conversion_rate == o.conversion_rate && conversion_rates == o.conversion_rates && curves == o.curves && derived_metrics == o.derived_metrics && errors == o.errors && estimate_id == o.estimate_id && max_potential_spend == o.max_potential_spend end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 200 def hash [adgroup_audience_sizes, conversion_rate, conversion_rates, curves, derived_metrics, errors, estimate_id, max_potential_spend].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@curves.nil? && @curves.length > 20 invalid_properties.push('invalid value for "curves", number of items must be less than or equal to 20.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 |
# File 'lib/pinterest_sdk/models/bulk_campaign_delivery_estimates_item.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@curves.nil? && @curves.length > 20 true end |