Class: PinterestSdkClient::BusinessAssets
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::BusinessAssets
- Defined in:
- lib/pinterest_sdk/models/business_assets.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset_group_info ⇒ Object
An object containing all the information specific to the provided asset group.
-
#asset_id ⇒ Object
Unique identifier of a business asset.
-
#asset_type ⇒ Object
Returns the value of attribute asset_type.
-
#catalog_info ⇒ Object
An object containing all the information specific to the provided catalog.
-
#permissions ⇒ Object
Permission levels the requesting business has on an asset.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BusinessAssets
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BusinessAssets
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::BusinessAssets` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::BusinessAssets`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_group_info') self.asset_group_info = attributes[:'asset_group_info'] end if attributes.key?(:'asset_id') self.asset_id = attributes[:'asset_id'] end if attributes.key?(:'asset_type') self.asset_type = attributes[:'asset_type'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'catalog_info') self.catalog_info = attributes[:'catalog_info'] end end |
Instance Attribute Details
#asset_group_info ⇒ Object
An object containing all the information specific to the provided asset group. This field will be populated only if asset_type equals 'ASSET_GROUP'.
19 20 21 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 19 def asset_group_info @asset_group_info end |
#asset_id ⇒ Object
Unique identifier of a business asset.
22 23 24 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 22 def asset_id @asset_id end |
#asset_type ⇒ Object
Returns the value of attribute asset_type.
24 25 26 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 24 def asset_type @asset_type end |
#catalog_info ⇒ Object
An object containing all the information specific to the provided catalog. This field will be populated only if asset_type equals 'CATALOG'.
30 31 32 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 30 def catalog_info @catalog_info end |
#permissions ⇒ Object
Permission levels the requesting business has on an asset.
27 28 29 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 27 def @permissions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 55 def self.attribute_map { :'asset_group_info' => :'asset_group_info', :'asset_id' => :'asset_id', :'asset_type' => :'asset_type', :'permissions' => :'permissions', :'catalog_info' => :'catalog_info' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
93 94 95 96 97 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 93 def self.openapi_all_of [ :'BaseBusinessAssets' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 76 def self.openapi_types { :'asset_group_info' => :'AssetGroupBinding', :'asset_id' => :'String', :'asset_type' => :'AssetTypeResponse', :'permissions' => :'Array<String>', :'catalog_info' => :'CatalogBinding' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && asset_group_info == o.asset_group_info && asset_id == o.asset_id && asset_type == o.asset_type && == o. && catalog_info == o.catalog_info end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 212 def hash [asset_group_info, asset_id, asset_type, , catalog_info].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@asset_id.nil? && @asset_id.to_s.length > 20 invalid_properties.push('invalid value for "asset_id", the character length must be smaller than or equal to 20.') end if !@asset_id.nil? && @asset_id.to_s.length < 1 invalid_properties.push('invalid value for "asset_id", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^\d+$/) if !@asset_id.nil? && @asset_id !~ pattern invalid_properties.push("invalid value for \"asset_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 |
# File 'lib/pinterest_sdk/models/business_assets.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@asset_id.nil? && @asset_id.to_s.length > 20 return false if !@asset_id.nil? && @asset_id.to_s.length < 1 return false if !@asset_id.nil? && @asset_id !~ Regexp.new(/^\d+$/) true end |