Class: PinterestSdkClient::CampaignDeliveryEstimatesCampaign
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CampaignDeliveryEstimatesCampaign
- Defined in:
- lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb
Overview
Campaign configuration for delivery estimates.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_groups ⇒ Object
Returns the value of attribute ad_groups.
-
#budget_duration_type ⇒ Object
Duration type of the budget.
-
#daily_spend_cap ⇒ Object
Campaign daily spend cap.
-
#end_date ⇒ Object
End date of the date range for an ad campaign, pattern YYYY-MM-DD.
-
#lifetime_spend_cap ⇒ Object
Campaign total spending cap.
-
#objective_type ⇒ Object
Returns the value of attribute objective_type.
-
#start_date ⇒ Object
Start date of the date range for an ad campaign, pattern YYYY-MM-DD.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignDeliveryEstimatesCampaign
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignDeliveryEstimatesCampaign
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CampaignDeliveryEstimatesCampaign` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CampaignDeliveryEstimatesCampaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_groups') if (value = attributes[:'ad_groups']).is_a?(Array) self.ad_groups = value end else self.ad_groups = nil end if attributes.key?(:'budget_duration_type') self.budget_duration_type = attributes[:'budget_duration_type'] else self.budget_duration_type = nil end if attributes.key?(:'daily_spend_cap') self.daily_spend_cap = attributes[:'daily_spend_cap'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'lifetime_spend_cap') self.lifetime_spend_cap = attributes[:'lifetime_spend_cap'] end if attributes.key?(:'objective_type') self.objective_type = attributes[:'objective_type'] else self.objective_type = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] else self.start_date = nil end end |
Instance Attribute Details
#ad_groups ⇒ Object
Returns the value of attribute ad_groups.
19 20 21 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 19 def ad_groups @ad_groups end |
#budget_duration_type ⇒ Object
Duration type of the budget
22 23 24 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 22 def budget_duration_type @budget_duration_type end |
#daily_spend_cap ⇒ Object
Campaign daily spend cap. When the budget_duration_type is FIXED_DAILY or FLEXIBLE_DAILY, this field is required.
25 26 27 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 25 def daily_spend_cap @daily_spend_cap end |
#end_date ⇒ Object
End date of the date range for an ad campaign, pattern YYYY-MM-DD. Required when budget_duration_type is LIFETIME.
28 29 30 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 28 def end_date @end_date end |
#lifetime_spend_cap ⇒ Object
Campaign total spending cap. When the budget_duration_type is LIFETIME, this field is required. The end date field is also required for lifetime spending.
31 32 33 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 31 def lifetime_spend_cap @lifetime_spend_cap end |
#objective_type ⇒ Object
Returns the value of attribute objective_type.
33 34 35 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 33 def objective_type @objective_type end |
#start_date ⇒ Object
Start date of the date range for an ad campaign, pattern YYYY-MM-DD.
36 37 38 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 36 def start_date @start_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 61 def self.attribute_map { :'ad_groups' => :'ad_groups', :'budget_duration_type' => :'budget_duration_type', :'daily_spend_cap' => :'daily_spend_cap', :'end_date' => :'end_date', :'lifetime_spend_cap' => :'lifetime_spend_cap', :'objective_type' => :'objective_type', :'start_date' => :'start_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 84 def self.openapi_types { :'ad_groups' => :'Array<AdGroupDeliveryEstimates>', :'budget_duration_type' => :'BudgetDurationType', :'daily_spend_cap' => :'Integer', :'end_date' => :'String', :'lifetime_spend_cap' => :'Integer', :'objective_type' => :'DeliveryEstimateObjectiveType', :'start_date' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && ad_groups == o.ad_groups && budget_duration_type == o.budget_duration_type && daily_spend_cap == o.daily_spend_cap && end_date == o.end_date && lifetime_spend_cap == o.lifetime_spend_cap && objective_type == o.objective_type && start_date == o.start_date end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 304 def hash [ad_groups, budget_duration_type, daily_spend_cap, end_date, lifetime_spend_cap, objective_type, start_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_groups.nil? invalid_properties.push('invalid value for "ad_groups", ad_groups cannot be nil.') end if @ad_groups.length > 10 invalid_properties.push('invalid value for "ad_groups", number of items must be less than or equal to 10.') end if @ad_groups.length < 1 invalid_properties.push('invalid value for "ad_groups", number of items must be greater than or equal to 1.') end if @budget_duration_type.nil? invalid_properties.push('invalid value for "budget_duration_type", budget_duration_type cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}$/) if !@end_date.nil? && @end_date !~ pattern invalid_properties.push("invalid value for \"end_date\", must conform to the pattern #{pattern}.") end if @objective_type.nil? invalid_properties.push('invalid value for "objective_type", objective_type cannot be nil.') end if @start_date.nil? invalid_properties.push('invalid value for "start_date", start_date cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}$/) if @start_date !~ pattern invalid_properties.push("invalid value for \"start_date\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pinterest_sdk/models/campaign_delivery_estimates_campaign.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_groups.nil? return false if @ad_groups.length > 10 return false if @ad_groups.length < 1 return false if @budget_duration_type.nil? return false if !@end_date.nil? && @end_date !~ Regexp.new(/^\d{4}-\d{2}-\d{2}$/) return false if @objective_type.nil? return false if @start_date.nil? return false if @start_date !~ Regexp.new(/^\d{4}-\d{2}-\d{2}$/) true end |