Class: PinterestSdkClient::CatalogReportsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::CatalogReportsApi
- Defined in:
- lib/pinterest_sdk/api/catalog_reports_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ CatalogReportsApi
constructor
A new instance of CatalogReportsApi.
-
#reports_create(catalogs_report_parameters, opts = {}) ⇒ CatalogsCreateReportResponse
Build catalogs report Async request to create a report of the catalog owned by the "operation user_account".
-
#reports_create_with_http_info(catalogs_report_parameters, opts = {}) ⇒ Array<(CatalogsCreateReportResponse, Integer, Hash)>
Build catalogs report Async request to create a report of the catalog owned by the "operation user_account".
-
#reports_get(token, opts = {}) ⇒ CatalogsReport
Get catalogs report This returns a URL to a report given a token returned from Build catalogs report.
-
#reports_get_with_http_info(token, opts = {}) ⇒ Array<(CatalogsReport, Integer, Hash)>
Get catalogs report This returns a URL to a report given a token returned from Build catalogs report.
-
#reports_stats(parameters, opts = {}) ⇒ ReportsStats200Response
List report stats List aggregated numbers of issues for a catalog owned by the "operation user_account".
-
#reports_stats_with_http_info(parameters, opts = {}) ⇒ Array<(ReportsStats200Response, Integer, Hash)>
List report stats List aggregated numbers of issues for a catalog owned by the "operation user_account".
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CatalogReportsApi
Returns a new instance of CatalogReportsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#reports_create(catalogs_report_parameters, opts = {}) ⇒ CatalogsCreateReportResponse
Build catalogs report
Async request to create a report of the catalog owned by the "operation user_account". This endpoint generates a report upon receiving the first approved request of the day. Any following requests with identical parameters will yield the same report even if data has changed. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: The All Items report is limited to 25 million items per catalog.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 28 def reports_create(catalogs_report_parameters, opts = {}) data, _status_code, _headers = reports_create_with_http_info(catalogs_report_parameters, opts) data end |
#reports_create_with_http_info(catalogs_report_parameters, opts = {}) ⇒ Array<(CatalogsCreateReportResponse, Integer, Hash)>
Build catalogs report Async request to create a report of the catalog owned by the "operation user_account". This endpoint generates a report upon receiving the first approved request of the day. Any following requests with identical parameters will yield the same report even if data has changed. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager. Note: The All Items report is limited to 25 million items per catalog.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 39 def reports_create_with_http_info(catalogs_report_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CatalogReportsApi.reports_create ...' end # verify the required parameter 'catalogs_report_parameters' is set if @api_client.config.client_side_validation && catalogs_report_parameters.nil? fail ArgumentError, "Missing the required parameter 'catalogs_report_parameters' when calling CatalogReportsApi.reports_create" end if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18 fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogReportsApi.reports_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogReportsApi.reports_create, must conform to the pattern #{pattern}." end # resource path local_var_path = '/catalogs/reports' # query parameters query_params = opts[:query_params] || {} query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(catalogs_report_parameters) # return_type return_type = opts[:debug_return_type] || 'CatalogsCreateReportResponse' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CatalogReportsApi.reports_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CatalogReportsApi#reports_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#reports_get(token, opts = {}) ⇒ CatalogsReport
Get catalogs report
This returns a URL to a report given a token returned from Build catalogs report. You can use the URL to download the report. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.
108 109 110 111 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 108 def reports_get(token, opts = {}) data, _status_code, _headers = reports_get_with_http_info(token, opts) data end |
#reports_get_with_http_info(token, opts = {}) ⇒ Array<(CatalogsReport, Integer, Hash)>
Get catalogs report This returns a URL to a report given a token returned from Build catalogs report. You can use the URL to download the report. - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 119 def reports_get_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CatalogReportsApi.reports_get ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling CatalogReportsApi.reports_get" end if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18 fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogReportsApi.reports_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogReportsApi.reports_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/catalogs/reports' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CatalogsReport' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CatalogReportsApi.reports_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CatalogReportsApi#reports_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#reports_stats(parameters, opts = {}) ⇒ ReportsStats200Response
List report stats
List aggregated numbers of issues for a catalog owned by the "operation user_account". - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an ad_account_id (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.
186 187 188 189 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 186 def reports_stats(parameters, opts = {}) data, _status_code, _headers = reports_stats_with_http_info(parameters, opts) data end |
#reports_stats_with_http_info(parameters, opts = {}) ⇒ Array<(ReportsStats200Response, Integer, Hash)>
List report stats List aggregated numbers of issues for a catalog owned by the "operation user_account". - By default, the "operation user_account" is the token user_account. Optional: Business Access: Specify an `ad_account_id` (obtained via List ad accounts) to use the owner of that ad_account as the "operation user_account". In order to do this, the token user_account must have one of the following Business Access roles on the ad_account: Owner, Admin, Catalogs Manager.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pinterest_sdk/api/catalog_reports_api.rb', line 199 def reports_stats_with_http_info(parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CatalogReportsApi.reports_stats ...' end # verify the required parameter 'parameters' is set if @api_client.config.client_side_validation && parameters.nil? fail ArgumentError, "Missing the required parameter 'parameters' when calling CatalogReportsApi.reports_stats" end if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'].to_s.length > 18 fail ArgumentError, 'invalid value for "opts[:"ad_account_id"]" when calling CatalogReportsApi.reports_stats, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && !opts[:'ad_account_id'].nil? && opts[:'ad_account_id'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"ad_account_id\"]' when calling CatalogReportsApi.reports_stats, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CatalogReportsApi.reports_stats, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CatalogReportsApi.reports_stats, must be greater than or equal to 1.' end # resource path local_var_path = '/catalogs/reports/stats' # query parameters query_params = opts[:query_params] || {} query_params[:'parameters'] = parameters query_params[:'ad_account_id'] = opts[:'ad_account_id'] if !opts[:'ad_account_id'].nil? query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ReportsStats200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CatalogReportsApi.reports_stats", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CatalogReportsApi#reports_stats\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |