Class: PinterestSdkClient::CatalogsFeedIngestionErrors
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsFeedIngestionErrors
- Defined in:
- lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb
Instance Attribute Summary collapse
-
#account_flagged ⇒ Object
We detected an issue with your account and are not currently ingesting your items.
-
#fetch_google_sheet_not_shared ⇒ Object
Update your Google Sheets sharing settings to 'Anyone with link' as a Viewer so that Pinterest can access your file.
-
#image_file_not_accessible ⇒ Object
Image files are unreadable.
-
#image_file_not_found ⇒ Object
Image files are unreadable.
-
#image_invalid_file ⇒ Object
Image files are unreadable.
-
#image_level_internal_error ⇒ Object
We experienced a technical difficulty and were unable to download some images.
-
#image_malformed_url ⇒ Object
Image files are unreadable.
-
#large_product_count_decrease ⇒ Object
The product count has decreased by more than 99% compared to the last successful ingestion.
-
#line_level_internal_error ⇒ Object
We experienced a technical difficulty and were unable to ingest this some items.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsFeedIngestionErrors
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsFeedIngestionErrors
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedIngestionErrors` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedIngestionErrors`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_flagged') self.account_flagged = attributes[:'account_flagged'] end if attributes.key?(:'fetch_google_sheet_not_shared') self.fetch_google_sheet_not_shared = attributes[:'fetch_google_sheet_not_shared'] end if attributes.key?(:'image_file_not_accessible') self.image_file_not_accessible = attributes[:'image_file_not_accessible'] end if attributes.key?(:'image_file_not_found') self.image_file_not_found = attributes[:'image_file_not_found'] end if attributes.key?(:'image_invalid_file') self.image_invalid_file = attributes[:'image_invalid_file'] end if attributes.key?(:'image_level_internal_error') self.image_level_internal_error = attributes[:'image_level_internal_error'] end if attributes.key?(:'image_malformed_url') self.image_malformed_url = attributes[:'image_malformed_url'] end if attributes.key?(:'large_product_count_decrease') self.large_product_count_decrease = attributes[:'large_product_count_decrease'] end if attributes.key?(:'line_level_internal_error') self.line_level_internal_error = attributes[:'line_level_internal_error'] end end |
Instance Attribute Details
#account_flagged ⇒ Object
We detected an issue with your account and are not currently ingesting your items. Please review our policies at policy.pinterest.com/community-guidelines#section-spam or contact us at help.pinterest.com/contact for more information.
19 20 21 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 19 def account_flagged @account_flagged end |
#fetch_google_sheet_not_shared ⇒ Object
Update your Google Sheets sharing settings to 'Anyone with link' as a Viewer so that Pinterest can access your file.
22 23 24 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 22 def fetch_google_sheet_not_shared @fetch_google_sheet_not_shared end |
#image_file_not_accessible ⇒ Object
Image files are unreadable. Please upload new files to continue.
25 26 27 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 25 def image_file_not_accessible @image_file_not_accessible end |
#image_file_not_found ⇒ Object
Image files are unreadable. Please upload new files to continue.
28 29 30 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 28 def image_file_not_found @image_file_not_found end |
#image_invalid_file ⇒ Object
Image files are unreadable. Please upload new files to continue.
31 32 33 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 31 def image_invalid_file @image_invalid_file end |
#image_level_internal_error ⇒ Object
We experienced a technical difficulty and were unable to download some images. The next download attempt will happen in 24 hours.
34 35 36 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 34 def image_level_internal_error @image_level_internal_error end |
#image_malformed_url ⇒ Object
Image files are unreadable. Please check your link and upload new files to continue.
37 38 39 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 37 def image_malformed_url @image_malformed_url end |
#large_product_count_decrease ⇒ Object
The product count has decreased by more than 99% compared to the last successful ingestion.
40 41 42 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 40 def large_product_count_decrease @large_product_count_decrease end |
#line_level_internal_error ⇒ Object
We experienced a technical difficulty and were unable to ingest this some items. The next ingestion will happen in 24 hours.
43 44 45 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 43 def line_level_internal_error @line_level_internal_error end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 46 def self.attribute_map { :'account_flagged' => :'ACCOUNT_FLAGGED', :'fetch_google_sheet_not_shared' => :'FETCH_GOOGLE_SHEET_NOT_SHARED', :'image_file_not_accessible' => :'IMAGE_FILE_NOT_ACCESSIBLE', :'image_file_not_found' => :'IMAGE_FILE_NOT_FOUND', :'image_invalid_file' => :'IMAGE_INVALID_FILE', :'image_level_internal_error' => :'IMAGE_LEVEL_INTERNAL_ERROR', :'image_malformed_url' => :'IMAGE_MALFORMED_URL', :'large_product_count_decrease' => :'LARGE_PRODUCT_COUNT_DECREASE', :'line_level_internal_error' => :'LINE_LEVEL_INTERNAL_ERROR' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 71 def self.openapi_types { :'account_flagged' => :'Integer', :'fetch_google_sheet_not_shared' => :'Integer', :'image_file_not_accessible' => :'Integer', :'image_file_not_found' => :'Integer', :'image_invalid_file' => :'Integer', :'image_level_internal_error' => :'Integer', :'image_malformed_url' => :'Integer', :'large_product_count_decrease' => :'Integer', :'line_level_internal_error' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && account_flagged == o.account_flagged && fetch_google_sheet_not_shared == o.fetch_google_sheet_not_shared && image_file_not_accessible == o.image_file_not_accessible && image_file_not_found == o.image_file_not_found && image_invalid_file == o.image_invalid_file && image_level_internal_error == o.image_level_internal_error && image_malformed_url == o.image_malformed_url && large_product_count_decrease == o.large_product_count_decrease && line_level_internal_error == o.line_level_internal_error end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 183 def hash [account_flagged, fetch_google_sheet_not_shared, image_file_not_accessible, image_file_not_found, image_invalid_file, image_level_internal_error, image_malformed_url, large_product_count_decrease, line_level_internal_error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/pinterest_sdk/models/catalogs_feed_ingestion_errors.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |