Class: PinterestSdkClient::CatalogsFeedProcessingResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsFeedProcessingResult
- Defined in:
- lib/pinterest_sdk/models/catalogs_feed_processing_result.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#ingestion_details ⇒ Object
Returns the value of attribute ingestion_details.
-
#product_counts ⇒ Object
Returns the value of attribute product_counts.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#validation_details ⇒ Object
Returns the value of attribute validation_details.
-
#video_counts ⇒ Object
Returns the value of attribute video_counts.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsFeedProcessingResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsFeedProcessingResult
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedProcessingResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedProcessingResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'ingestion_details') self.ingestion_details = attributes[:'ingestion_details'] else self.ingestion_details = nil end if attributes.key?(:'product_counts') self.product_counts = attributes[:'product_counts'] else self.product_counts = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'validation_details') self.validation_details = attributes[:'validation_details'] else self.validation_details = nil end if attributes.key?(:'video_counts') self.video_counts = attributes[:'video_counts'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
18 19 20 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 18 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
20 21 22 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 20 def id @id end |
#ingestion_details ⇒ Object
Returns the value of attribute ingestion_details.
24 25 26 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 24 def ingestion_details @ingestion_details end |
#product_counts ⇒ Object
Returns the value of attribute product_counts.
26 27 28 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 26 def product_counts @product_counts end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 28 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
22 23 24 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 22 def updated_at @updated_at end |
#validation_details ⇒ Object
Returns the value of attribute validation_details.
30 31 32 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 30 def validation_details @validation_details end |
#video_counts ⇒ Object
Returns the value of attribute video_counts.
32 33 34 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 32 def video_counts @video_counts end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 57 def self.attribute_map { :'created_at' => :'created_at', :'id' => :'id', :'updated_at' => :'updated_at', :'ingestion_details' => :'ingestion_details', :'product_counts' => :'product_counts', :'status' => :'status', :'validation_details' => :'validation_details', :'video_counts' => :'video_counts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
102 103 104 105 106 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 102 def self.openapi_all_of [ :'CatalogsDbItem' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 95 def self.openapi_nullable Set.new([ :'product_counts', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 81 def self.openapi_types { :'created_at' => :'Time', :'id' => :'String', :'updated_at' => :'Time', :'ingestion_details' => :'CatalogsFeedIngestionDetails', :'product_counts' => :'CatalogsFeedProductCounts', :'status' => :'CatalogsFeedProcessingStatus', :'validation_details' => :'CatalogsFeedValidationDetails', :'video_counts' => :'CatalogsFeedVideoCounts' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 278 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && id == o.id && updated_at == o.updated_at && ingestion_details == o.ingestion_details && product_counts == o.product_counts && status == o.status && validation_details == o.validation_details && video_counts == o.video_counts end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 299 def hash [created_at, id, updated_at, ingestion_details, product_counts, status, validation_details, video_counts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @ingestion_details.nil? invalid_properties.push('invalid value for "ingestion_details", ingestion_details cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @validation_details.nil? invalid_properties.push('invalid value for "validation_details", validation_details cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pinterest_sdk/models/catalogs_feed_processing_result.rb', line 205 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @id.nil? return false if @updated_at.nil? return false if @ingestion_details.nil? return false if @status.nil? return false if @validation_details.nil? true end |