Class: PinterestSdkClient::CatalogsFeedValidationErrors
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsFeedValidationErrors
- Defined in:
- lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb
Instance Attribute Summary collapse
-
#adult_invalid ⇒ Object
Some items have invalid adult values.
-
#adwords_format_invalid ⇒ Object
Some adwords links contain too many characters.
-
#availability_invalid ⇒ Object
Some items are missing an availability value in their product metadata, those items will not be published.
-
#blocklisted_image_signature ⇒ Object
Some items were not published because they don’t meet Pinterest’s Merchant Guidelines.
-
#delimiter_error ⇒ Object
Your feed includes data with formatting errors.
-
#description_missing ⇒ Object
Some items are missing a description in their product metadata, those items will not be published.
-
#duplicate_products ⇒ Object
Some products are duplicated.
-
#encoding_error ⇒ Object
Your feed includes data with an unsupported encoding format.
-
#feed_length_too_long ⇒ Object
Your feed contains too many items, some items will not be published.
-
#feed_too_small ⇒ Object
Your feed couldn’t be validated because the file doesn’t contain the minimum number of lines required.
-
#fetch_error ⇒ Object
Pinterest couldn’t download your feed.
-
#fetch_inactive_feed_error ⇒ Object
Your feed wasn’t ingested because it hasn’t changed in the previous 90 days.
-
#image_link_invalid ⇒ Object
Some image links are formatted incorrectly.
-
#image_link_length_too_long ⇒ Object
Some items have image_link URLs that contain too many characters, so those items will not be published.
-
#image_link_missing ⇒ Object
Some items are missing an image link URL in their product metadata, those items will not be published.
-
#internal_service_error ⇒ Object
We experienced a technical difficulty and were unable to ingest your feed.
-
#invalid_domain ⇒ Object
Some of your product link values don’t match the verified domain associated with this account.
-
#item_main_image_download_failure ⇒ Object
Some items’ main images can’t be found.
-
#itemid_missing ⇒ Object
Some items are missing an item id in their product metadata, those items will not be published.
-
#link_format_invalid ⇒ Object
Some link values are formatted incorrectly.
-
#link_length_too_long ⇒ Object
Some product links contain too many characters, those items will not be published.
-
#list_price_invalid ⇒ Object
Some items have list price formatting errors in their product metadata, those items will not be published.
-
#malformed_xml ⇒ Object
Your feed couldn’t be validated because the xml file is formatted incorrectly.
-
#max_items_per_item_group_exceeded ⇒ Object
Some items exceed the maximum number of items per item group, those items will not be published.
-
#no_verified_domain ⇒ Object
Your merchant domain needs to be claimed.
-
#parse_line_error ⇒ Object
Your feed contains formatting errors for some items.
-
#pinjoin_content_unsafe ⇒ Object
Some items were not published because they don’t meet Pinterest’s Merchant Guidelines.
-
#price_cannot_be_determined ⇒ Object
Some items were not published because price cannot be determined.
-
#price_missing ⇒ Object
Some products are missing a price, those items will not be published.
-
#product_link_missing ⇒ Object
Some items are missing a link URL in their product metadata, those items will not be published.
-
#product_price_invalid ⇒ Object
Some items have price formatting errors in their product metadata, those items will not be published.
-
#required_columns_missing ⇒ Object
Your feed is missing some required column headers.
-
#title_missing ⇒ Object
Some items are missing a title in their product metadata, those items will not be published.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsFeedValidationErrors
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsFeedValidationErrors
Initializes the object
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 213 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedValidationErrors` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedValidationErrors`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'adult_invalid') self.adult_invalid = attributes[:'adult_invalid'] end if attributes.key?(:'adwords_format_invalid') self.adwords_format_invalid = attributes[:'adwords_format_invalid'] end if attributes.key?(:'availability_invalid') self.availability_invalid = attributes[:'availability_invalid'] end if attributes.key?(:'blocklisted_image_signature') self.blocklisted_image_signature = attributes[:'blocklisted_image_signature'] end if attributes.key?(:'delimiter_error') self.delimiter_error = attributes[:'delimiter_error'] end if attributes.key?(:'description_missing') self.description_missing = attributes[:'description_missing'] end if attributes.key?(:'duplicate_products') self.duplicate_products = attributes[:'duplicate_products'] end if attributes.key?(:'encoding_error') self.encoding_error = attributes[:'encoding_error'] end if attributes.key?(:'feed_length_too_long') self.feed_length_too_long = attributes[:'feed_length_too_long'] end if attributes.key?(:'feed_too_small') self.feed_too_small = attributes[:'feed_too_small'] end if attributes.key?(:'fetch_error') self.fetch_error = attributes[:'fetch_error'] end if attributes.key?(:'fetch_inactive_feed_error') self.fetch_inactive_feed_error = attributes[:'fetch_inactive_feed_error'] end if attributes.key?(:'image_link_invalid') self.image_link_invalid = attributes[:'image_link_invalid'] end if attributes.key?(:'image_link_length_too_long') self.image_link_length_too_long = attributes[:'image_link_length_too_long'] end if attributes.key?(:'image_link_missing') self.image_link_missing = attributes[:'image_link_missing'] end if attributes.key?(:'internal_service_error') self.internal_service_error = attributes[:'internal_service_error'] end if attributes.key?(:'invalid_domain') self.invalid_domain = attributes[:'invalid_domain'] end if attributes.key?(:'item_main_image_download_failure') self.item_main_image_download_failure = attributes[:'item_main_image_download_failure'] end if attributes.key?(:'itemid_missing') self.itemid_missing = attributes[:'itemid_missing'] end if attributes.key?(:'link_format_invalid') self.link_format_invalid = attributes[:'link_format_invalid'] end if attributes.key?(:'link_length_too_long') self.link_length_too_long = attributes[:'link_length_too_long'] end if attributes.key?(:'list_price_invalid') self.list_price_invalid = attributes[:'list_price_invalid'] end if attributes.key?(:'malformed_xml') self.malformed_xml = attributes[:'malformed_xml'] end if attributes.key?(:'max_items_per_item_group_exceeded') self.max_items_per_item_group_exceeded = attributes[:'max_items_per_item_group_exceeded'] end if attributes.key?(:'no_verified_domain') self.no_verified_domain = attributes[:'no_verified_domain'] end if attributes.key?(:'parse_line_error') self.parse_line_error = attributes[:'parse_line_error'] end if attributes.key?(:'pinjoin_content_unsafe') self.pinjoin_content_unsafe = attributes[:'pinjoin_content_unsafe'] end if attributes.key?(:'price_cannot_be_determined') self.price_cannot_be_determined = attributes[:'price_cannot_be_determined'] end if attributes.key?(:'price_missing') self.price_missing = attributes[:'price_missing'] end if attributes.key?(:'product_link_missing') self.product_link_missing = attributes[:'product_link_missing'] end if attributes.key?(:'product_price_invalid') self.product_price_invalid = attributes[:'product_price_invalid'] end if attributes.key?(:'required_columns_missing') self.required_columns_missing = attributes[:'required_columns_missing'] end if attributes.key?(:'title_missing') self.title_missing = attributes[:'title_missing'] end end |
Instance Attribute Details
#adult_invalid ⇒ Object
Some items have invalid adult values.
19 20 21 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 19 def adult_invalid @adult_invalid end |
#adwords_format_invalid ⇒ Object
Some adwords links contain too many characters.
22 23 24 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 22 def adwords_format_invalid @adwords_format_invalid end |
#availability_invalid ⇒ Object
Some items are missing an availability value in their product metadata, those items will not be published.
25 26 27 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 25 def availability_invalid @availability_invalid end |
#blocklisted_image_signature ⇒ Object
Some items were not published because they don’t meet Pinterest’s Merchant Guidelines.
28 29 30 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 28 def blocklisted_image_signature @blocklisted_image_signature end |
#delimiter_error ⇒ Object
Your feed includes data with formatting errors.
31 32 33 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 31 def delimiter_error @delimiter_error end |
#description_missing ⇒ Object
Some items are missing a description in their product metadata, those items will not be published.
34 35 36 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 34 def description_missing @description_missing end |
#duplicate_products ⇒ Object
Some products are duplicated.
37 38 39 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 37 def duplicate_products @duplicate_products end |
#encoding_error ⇒ Object
Your feed includes data with an unsupported encoding format.
40 41 42 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 40 def encoding_error @encoding_error end |
#feed_length_too_long ⇒ Object
Your feed contains too many items, some items will not be published.
43 44 45 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 43 def feed_length_too_long @feed_length_too_long end |
#feed_too_small ⇒ Object
Your feed couldn’t be validated because the file doesn’t contain the minimum number of lines required.
46 47 48 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 46 def feed_too_small @feed_too_small end |
#fetch_error ⇒ Object
Pinterest couldn’t download your feed.
49 50 51 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 49 def fetch_error @fetch_error end |
#fetch_inactive_feed_error ⇒ Object
Your feed wasn’t ingested because it hasn’t changed in the previous 90 days.
52 53 54 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 52 def fetch_inactive_feed_error @fetch_inactive_feed_error end |
#image_link_invalid ⇒ Object
Some image links are formatted incorrectly.
55 56 57 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 55 def image_link_invalid @image_link_invalid end |
#image_link_length_too_long ⇒ Object
Some items have image_link URLs that contain too many characters, so those items will not be published.
58 59 60 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 58 def image_link_length_too_long @image_link_length_too_long end |
#image_link_missing ⇒ Object
Some items are missing an image link URL in their product metadata, those items will not be published.
61 62 63 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 61 def image_link_missing @image_link_missing end |
#internal_service_error ⇒ Object
We experienced a technical difficulty and were unable to ingest your feed. The next ingestion will happen in 24 hours.
64 65 66 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 64 def internal_service_error @internal_service_error end |
#invalid_domain ⇒ Object
Some of your product link values don’t match the verified domain associated with this account.
67 68 69 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 67 def invalid_domain @invalid_domain end |
#item_main_image_download_failure ⇒ Object
Some items’ main images can’t be found.
70 71 72 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 70 def item_main_image_download_failure @item_main_image_download_failure end |
#itemid_missing ⇒ Object
Some items are missing an item id in their product metadata, those items will not be published.
73 74 75 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 73 def itemid_missing @itemid_missing end |
#link_format_invalid ⇒ Object
Some link values are formatted incorrectly.
76 77 78 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 76 def link_format_invalid @link_format_invalid end |
#link_length_too_long ⇒ Object
Some product links contain too many characters, those items will not be published.
79 80 81 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 79 def link_length_too_long @link_length_too_long end |
#list_price_invalid ⇒ Object
Some items have list price formatting errors in their product metadata, those items will not be published.
82 83 84 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 82 def list_price_invalid @list_price_invalid end |
#malformed_xml ⇒ Object
Your feed couldn’t be validated because the xml file is formatted incorrectly.
85 86 87 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 85 def malformed_xml @malformed_xml end |
#max_items_per_item_group_exceeded ⇒ Object
Some items exceed the maximum number of items per item group, those items will not be published.
88 89 90 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 88 def max_items_per_item_group_exceeded @max_items_per_item_group_exceeded end |
#no_verified_domain ⇒ Object
Your merchant domain needs to be claimed.
91 92 93 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 91 def no_verified_domain @no_verified_domain end |
#parse_line_error ⇒ Object
Your feed contains formatting errors for some items.
94 95 96 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 94 def parse_line_error @parse_line_error end |
#pinjoin_content_unsafe ⇒ Object
Some items were not published because they don’t meet Pinterest’s Merchant Guidelines.
97 98 99 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 97 def pinjoin_content_unsafe @pinjoin_content_unsafe end |
#price_cannot_be_determined ⇒ Object
Some items were not published because price cannot be determined. The price, list price, and sale price are all different, so those items will not be published.
100 101 102 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 100 def price_cannot_be_determined @price_cannot_be_determined end |
#price_missing ⇒ Object
Some products are missing a price, those items will not be published.
103 104 105 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 103 def price_missing @price_missing end |
#product_link_missing ⇒ Object
Some items are missing a link URL in their product metadata, those items will not be published.
106 107 108 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 106 def product_link_missing @product_link_missing end |
#product_price_invalid ⇒ Object
Some items have price formatting errors in their product metadata, those items will not be published.
109 110 111 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 109 def product_price_invalid @product_price_invalid end |
#required_columns_missing ⇒ Object
Your feed is missing some required column headers.
112 113 114 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 112 def required_columns_missing @required_columns_missing end |
#title_missing ⇒ Object
Some items are missing a title in their product metadata, those items will not be published.
115 116 117 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 115 def title_missing @title_missing end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
157 158 159 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 157 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
162 163 164 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 162 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 118 def self.attribute_map { :'adult_invalid' => :'ADULT_INVALID', :'adwords_format_invalid' => :'ADWORDS_FORMAT_INVALID', :'availability_invalid' => :'AVAILABILITY_INVALID', :'blocklisted_image_signature' => :'BLOCKLISTED_IMAGE_SIGNATURE', :'delimiter_error' => :'DELIMITER_ERROR', :'description_missing' => :'DESCRIPTION_MISSING', :'duplicate_products' => :'DUPLICATE_PRODUCTS', :'encoding_error' => :'ENCODING_ERROR', :'feed_length_too_long' => :'FEED_LENGTH_TOO_LONG', :'feed_too_small' => :'FEED_TOO_SMALL', :'fetch_error' => :'FETCH_ERROR', :'fetch_inactive_feed_error' => :'FETCH_INACTIVE_FEED_ERROR', :'image_link_invalid' => :'IMAGE_LINK_INVALID', :'image_link_length_too_long' => :'IMAGE_LINK_LENGTH_TOO_LONG', :'image_link_missing' => :'IMAGE_LINK_MISSING', :'internal_service_error' => :'INTERNAL_SERVICE_ERROR', :'invalid_domain' => :'INVALID_DOMAIN', :'item_main_image_download_failure' => :'ITEM_MAIN_IMAGE_DOWNLOAD_FAILURE', :'itemid_missing' => :'ITEMID_MISSING', :'link_format_invalid' => :'LINK_FORMAT_INVALID', :'link_length_too_long' => :'LINK_LENGTH_TOO_LONG', :'list_price_invalid' => :'LIST_PRICE_INVALID', :'malformed_xml' => :'MALFORMED_XML', :'max_items_per_item_group_exceeded' => :'MAX_ITEMS_PER_ITEM_GROUP_EXCEEDED', :'no_verified_domain' => :'NO_VERIFIED_DOMAIN', :'parse_line_error' => :'PARSE_LINE_ERROR', :'pinjoin_content_unsafe' => :'PINJOIN_CONTENT_UNSAFE', :'price_cannot_be_determined' => :'PRICE_CANNOT_BE_DETERMINED', :'price_missing' => :'PRICE_MISSING', :'product_link_missing' => :'PRODUCT_LINK_MISSING', :'product_price_invalid' => :'PRODUCT_PRICE_INVALID', :'required_columns_missing' => :'REQUIRED_COLUMNS_MISSING', :'title_missing' => :'TITLE_MISSING' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 430 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
206 207 208 209 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 206 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 167 def self.openapi_types { :'adult_invalid' => :'Integer', :'adwords_format_invalid' => :'Integer', :'availability_invalid' => :'Integer', :'blocklisted_image_signature' => :'Integer', :'delimiter_error' => :'Integer', :'description_missing' => :'Integer', :'duplicate_products' => :'Integer', :'encoding_error' => :'Integer', :'feed_length_too_long' => :'Integer', :'feed_too_small' => :'Integer', :'fetch_error' => :'Integer', :'fetch_inactive_feed_error' => :'Integer', :'image_link_invalid' => :'Integer', :'image_link_length_too_long' => :'Integer', :'image_link_missing' => :'Integer', :'internal_service_error' => :'Integer', :'invalid_domain' => :'Integer', :'item_main_image_download_failure' => :'Integer', :'itemid_missing' => :'Integer', :'link_format_invalid' => :'Integer', :'link_length_too_long' => :'Integer', :'list_price_invalid' => :'Integer', :'malformed_xml' => :'Integer', :'max_items_per_item_group_exceeded' => :'Integer', :'no_verified_domain' => :'Integer', :'parse_line_error' => :'Integer', :'pinjoin_content_unsafe' => :'Integer', :'price_cannot_be_determined' => :'Integer', :'price_missing' => :'Integer', :'product_link_missing' => :'Integer', :'product_price_invalid' => :'Integer', :'required_columns_missing' => :'Integer', :'title_missing' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 377 def ==(o) return true if self.equal?(o) self.class == o.class && adult_invalid == o.adult_invalid && adwords_format_invalid == o.adwords_format_invalid && availability_invalid == o.availability_invalid && blocklisted_image_signature == o.blocklisted_image_signature && delimiter_error == o.delimiter_error && description_missing == o.description_missing && duplicate_products == o.duplicate_products && encoding_error == o.encoding_error && feed_length_too_long == o.feed_length_too_long && feed_too_small == o.feed_too_small && fetch_error == o.fetch_error && fetch_inactive_feed_error == o.fetch_inactive_feed_error && image_link_invalid == o.image_link_invalid && image_link_length_too_long == o.image_link_length_too_long && image_link_missing == o.image_link_missing && internal_service_error == o.internal_service_error && invalid_domain == o.invalid_domain && item_main_image_download_failure == o.item_main_image_download_failure && itemid_missing == o.itemid_missing && link_format_invalid == o.link_format_invalid && link_length_too_long == o.link_length_too_long && list_price_invalid == o.list_price_invalid && malformed_xml == o.malformed_xml && max_items_per_item_group_exceeded == o.max_items_per_item_group_exceeded && no_verified_domain == o.no_verified_domain && parse_line_error == o.parse_line_error && pinjoin_content_unsafe == o.pinjoin_content_unsafe && price_cannot_be_determined == o.price_cannot_be_determined && price_missing == o.price_missing && product_link_missing == o.product_link_missing && product_price_invalid == o.product_price_invalid && required_columns_missing == o.required_columns_missing && title_missing == o.title_missing end |
#eql?(o) ⇒ Boolean
417 418 419 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 417 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
423 424 425 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 423 def hash [adult_invalid, adwords_format_invalid, availability_invalid, blocklisted_image_signature, delimiter_error, description_missing, duplicate_products, encoding_error, feed_length_too_long, feed_too_small, fetch_error, fetch_inactive_feed_error, image_link_invalid, image_link_length_too_long, image_link_missing, internal_service_error, invalid_domain, item_main_image_download_failure, itemid_missing, link_format_invalid, link_length_too_long, list_price_invalid, malformed_xml, max_items_per_item_group_exceeded, no_verified_domain, parse_line_error, pinjoin_content_unsafe, price_cannot_be_determined, price_missing, product_link_missing, product_price_invalid, required_columns_missing, title_missing].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
362 363 364 365 366 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 362 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 452 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
370 371 372 373 |
# File 'lib/pinterest_sdk/models/catalogs_feed_validation_errors.rb', line 370 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |