Class: PinterestSdkClient::CatalogsFeedsCreateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsFeedsCreateRequest
- Defined in:
- lib/pinterest_sdk/models/catalogs_feeds_create_request.rb
Overview
Request object for creating a feed. Please, be aware that "default_country" and "default_locale" are not required in the spec for forward compatibility but for now the API will not accept requests without those fields.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#credentials ⇒ Object
Returns the value of attribute credentials.
-
#default_availability ⇒ Object
Returns the value of attribute default_availability.
-
#default_country ⇒ Object
Returns the value of attribute default_country.
-
#default_currency ⇒ Object
Returns the value of attribute default_currency.
-
#default_locale ⇒ Object
Returns the value of attribute default_locale.
-
#format ⇒ Object
Returns the value of attribute format.
-
#location ⇒ Object
The URL where a feed is available for download.
-
#name ⇒ Object
A human-friendly name associated to a given feed.
-
#preferred_processing_schedule ⇒ Object
Returns the value of attribute preferred_processing_schedule.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsFeedsCreateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsFeedsCreateRequest
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsFeedsCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsFeedsCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'credentials') self.credentials = attributes[:'credentials'] end if attributes.key?(:'default_availability') self.default_availability = attributes[:'default_availability'] end if attributes.key?(:'default_country') self.default_country = attributes[:'default_country'] end if attributes.key?(:'default_currency') self.default_currency = attributes[:'default_currency'] end if attributes.key?(:'default_locale') self.default_locale = attributes[:'default_locale'] end if attributes.key?(:'format') self.format = attributes[:'format'] else self.format = nil end if attributes.key?(:'location') self.location = attributes[:'location'] else self.location = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'preferred_processing_schedule') self.preferred_processing_schedule = attributes[:'preferred_processing_schedule'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'ACTIVE' end end |
Instance Attribute Details
#credentials ⇒ Object
Returns the value of attribute credentials.
19 20 21 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 19 def credentials @credentials end |
#default_availability ⇒ Object
Returns the value of attribute default_availability.
21 22 23 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 21 def default_availability @default_availability end |
#default_country ⇒ Object
Returns the value of attribute default_country.
23 24 25 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 23 def default_country @default_country end |
#default_currency ⇒ Object
Returns the value of attribute default_currency.
25 26 27 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 25 def default_currency @default_currency end |
#default_locale ⇒ Object
Returns the value of attribute default_locale.
27 28 29 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 27 def default_locale @default_locale end |
#format ⇒ Object
Returns the value of attribute format.
29 30 31 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 29 def format @format end |
#location ⇒ Object
The URL where a feed is available for download. This URL is what Pinterest will use to download a feed for processing.
32 33 34 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 32 def location @location end |
#name ⇒ Object
A human-friendly name associated to a given feed.
35 36 37 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 35 def name @name end |
#preferred_processing_schedule ⇒ Object
Returns the value of attribute preferred_processing_schedule.
37 38 39 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 37 def preferred_processing_schedule @preferred_processing_schedule end |
#status ⇒ Object
Returns the value of attribute status.
39 40 41 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 39 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 64 def self.attribute_map { :'credentials' => :'credentials', :'default_availability' => :'default_availability', :'default_country' => :'default_country', :'default_currency' => :'default_currency', :'default_locale' => :'default_locale', :'format' => :'format', :'location' => :'location', :'name' => :'name', :'preferred_processing_schedule' => :'preferred_processing_schedule', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 106 def self.openapi_nullable Set.new([ :'credentials', :'default_availability', :'default_currency', :'preferred_processing_schedule', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 90 def self.openapi_types { :'credentials' => :'CatalogsFeedCredentials', :'default_availability' => :'ProductAvailabilityType', :'default_country' => :'Country', :'default_currency' => :'NullableCurrency', :'default_locale' => :'CatalogsFeedsCreateRequestDefaultLocale', :'format' => :'CatalogsFormat', :'location' => :'String', :'name' => :'String', :'preferred_processing_schedule' => :'CatalogsFeedProcessingSchedule', :'status' => :'CatalogsStatus' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 253 def ==(o) return true if self.equal?(o) self.class == o.class && credentials == o.credentials && default_availability == o.default_availability && default_country == o.default_country && default_currency == o.default_currency && default_locale == o.default_locale && format == o.format && location == o.location && name == o.name && preferred_processing_schedule == o.preferred_processing_schedule && status == o.status end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 276 def hash [credentials, default_availability, default_country, default_currency, default_locale, format, location, name, preferred_processing_schedule, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 182 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @format.nil? invalid_properties.push('invalid value for "format", format cannot be nil.') end if @location.nil? invalid_properties.push('invalid value for "location", location cannot be nil.') end pattern = Regexp.new(/^(http|https|ftp|sftp):\/\//) if @location !~ pattern invalid_properties.push("invalid value for \"location\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 |
# File 'lib/pinterest_sdk/models/catalogs_feeds_create_request.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @format.nil? return false if @location.nil? return false if @location !~ Regexp.new(/^(http|https|ftp|sftp):\/\//) return false if @name.nil? true end |