Class: PinterestSdkClient::CatalogsProductGroupCreateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::CatalogsProductGroupCreateRequest
- Defined in:
- lib/pinterest_sdk/models/catalogs_product_group_create_request.rb
Overview
Request object for creating a product group.
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#feed_id ⇒ Object
Catalog Feed id pertaining to the catalog product group.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#is_featured ⇒ Object
boolean indicator of whether the product group is being featured or not.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogsProductGroupCreateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogsProductGroupCreateRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::CatalogsProductGroupCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::CatalogsProductGroupCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'feed_id') self.feed_id = attributes[:'feed_id'] else self.feed_id = nil end if attributes.key?(:'filters') self.filters = attributes[:'filters'] else self.filters = nil end if attributes.key?(:'is_featured') self.is_featured = attributes[:'is_featured'] else self.is_featured = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
19 20 21 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 19 def description @description end |
#feed_id ⇒ Object
Catalog Feed id pertaining to the catalog product group.
22 23 24 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 22 def feed_id @feed_id end |
#filters ⇒ Object
Returns the value of attribute filters.
24 25 26 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 24 def filters @filters end |
#is_featured ⇒ Object
boolean indicator of whether the product group is being featured or not
27 28 29 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 27 def is_featured @is_featured end |
#name ⇒ Object
Returns the value of attribute name.
29 30 31 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 29 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 32 def self.attribute_map { :'description' => :'description', :'feed_id' => :'feed_id', :'filters' => :'filters', :'is_featured' => :'is_featured', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 68 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 64 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 53 def self.openapi_types { :'description' => :'String', :'feed_id' => :'String', :'filters' => :'CatalogsProductGroupFiltersRequest', :'is_featured' => :'Boolean', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && feed_id == o.feed_id && filters == o.filters && is_featured == o.is_featured && name == o.name end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 206 def hash [description, feed_id, filters, is_featured, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @feed_id.nil? invalid_properties.push('invalid value for "feed_id", feed_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @feed_id !~ pattern invalid_properties.push("invalid value for \"feed_id\", must conform to the pattern #{pattern}.") end if @filters.nil? invalid_properties.push('invalid value for "filters", filters cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 145 146 147 148 149 |
# File 'lib/pinterest_sdk/models/catalogs_product_group_create_request.rb', line 142 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @feed_id.nil? return false if @feed_id !~ Regexp.new(/^\d+$/) return false if @filters.nil? return false if @name.nil? true end |