Class: PinterestSdkClient::ConversionDeletionRequestsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::ConversionDeletionRequestsApi
- Defined in:
- lib/pinterest_sdk/api/conversion_deletion_requests_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#conversion_deletion_request_create(ad_account_id, conversion_deletion_request_create, opts = {}) ⇒ ConversionDeletionRequest
Create a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_create_with_http_info(ad_account_id, conversion_deletion_request_create, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Create a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_delete(request_id, ad_account_id, opts = {}) ⇒ ConversionDeletionRequest
Delete a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_delete_with_http_info(request_id, ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Delete a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_get(request_id, ad_account_id, opts = {}) ⇒ ConversionDeletionRequest
Get a single conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_get_with_http_info(request_id, ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Get a single conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_list(ad_account_id, opts = {}) ⇒ ConversionDeletionRequestList200Response
List conversion deletion requests This endpoint is currently in beta and not available to all apps. Learn more.
-
#conversion_deletion_request_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequestList200Response, Integer, Hash)>
List conversion deletion requests This endpoint is currently in beta and not available to all apps. Learn more.
-
#initialize(api_client = ApiClient.default) ⇒ ConversionDeletionRequestsApi
constructor
A new instance of ConversionDeletionRequestsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConversionDeletionRequestsApi
Returns a new instance of ConversionDeletionRequestsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#conversion_deletion_request_create(ad_account_id, conversion_deletion_request_create, opts = {}) ⇒ ConversionDeletionRequest
Create a conversion deletion request
This endpoint is currently in beta and not available to all apps. Learn more. Create a request to delete conversion data for a list of user emails and/or EPIKs, limited to the specified ad_account_id. After 72 hours the request is processed and submitted to our deletion process. Then the deletion process ensures deletion within a 30 days period, once the request is submitted to the deletion process it cannot be canceled.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 28 def conversion_deletion_request_create(ad_account_id, conversion_deletion_request_create, opts = {}) data, _status_code, _headers = conversion_deletion_request_create_with_http_info(ad_account_id, conversion_deletion_request_create, opts) data end |
#conversion_deletion_request_create_with_http_info(ad_account_id, conversion_deletion_request_create, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Create a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more. Create a request to delete conversion data for a list of user emails and/or EPIKs, limited to the specified `ad_account_id`. After 72 hours the request is processed and submitted to our deletion process. Then the deletion process ensures deletion within a 30 days period, once the request is submitted to the deletion process it cannot be canceled.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 39 def conversion_deletion_request_create_with_http_info(ad_account_id, conversion_deletion_request_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversionDeletionRequestsApi.conversion_deletion_request_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_create, must conform to the pattern #{pattern}." end # verify the required parameter 'conversion_deletion_request_create' is set if @api_client.config.client_side_validation && conversion_deletion_request_create.nil? fail ArgumentError, "Missing the required parameter 'conversion_deletion_request_create' when calling ConversionDeletionRequestsApi.conversion_deletion_request_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/conversion_deletion_requests'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(conversion_deletion_request_create) # return_type return_type = opts[:debug_return_type] || 'ConversionDeletionRequest' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"ConversionDeletionRequestsApi.conversion_deletion_request_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversionDeletionRequestsApi#conversion_deletion_request_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#conversion_deletion_request_delete(request_id, ad_account_id, opts = {}) ⇒ ConversionDeletionRequest
Delete a conversion deletion request
This endpoint is currently in beta and not available to all apps. Learn more. Delete a conversion deletion request from ad_account_id with request_id. This will cancel the request and prevent it from being processed. This can only be done if the request is in the PENDING status and before the 72 hours mark.
111 112 113 114 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 111 def conversion_deletion_request_delete(request_id, ad_account_id, opts = {}) data, _status_code, _headers = conversion_deletion_request_delete_with_http_info(request_id, ad_account_id, opts) data end |
#conversion_deletion_request_delete_with_http_info(request_id, ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Delete a conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more. Delete a conversion deletion request from `ad_account_id` with `request_id`. This will cancel the request and prevent it from being processed. This can only be done if the request is in the `PENDING` status and before the 72 hours mark.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 122 def conversion_deletion_request_delete_with_http_info(request_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversionDeletionRequestsApi.conversion_deletion_request_delete ...' end # verify the required parameter 'request_id' is set if @api_client.config.client_side_validation && request_id.nil? fail ArgumentError, "Missing the required parameter 'request_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete" end if @api_client.config.client_side_validation && request_id.to_s.length > 18 fail ArgumentError, 'invalid value for "request_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && request_id !~ pattern fail ArgumentError, "invalid value for 'request_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/conversion_deletion_requests/{request_id}'.sub('{request_id}', CGI.escape(request_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConversionDeletionRequest' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"ConversionDeletionRequestsApi.conversion_deletion_request_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversionDeletionRequestsApi#conversion_deletion_request_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#conversion_deletion_request_get(request_id, ad_account_id, opts = {}) ⇒ ConversionDeletionRequest
Get a single conversion deletion request
This endpoint is currently in beta and not available to all apps. Learn more. Get a single conversion deletion request from ad_account_id with request_id.
198 199 200 201 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 198 def conversion_deletion_request_get(request_id, ad_account_id, opts = {}) data, _status_code, _headers = conversion_deletion_request_get_with_http_info(request_id, ad_account_id, opts) data end |
#conversion_deletion_request_get_with_http_info(request_id, ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequest, Integer, Hash)>
Get a single conversion deletion request This endpoint is currently in beta and not available to all apps. Learn more. Get a single conversion deletion request from `ad_account_id` with `request_id`.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 209 def conversion_deletion_request_get_with_http_info(request_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversionDeletionRequestsApi.conversion_deletion_request_get ...' end # verify the required parameter 'request_id' is set if @api_client.config.client_side_validation && request_id.nil? fail ArgumentError, "Missing the required parameter 'request_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_get" end if @api_client.config.client_side_validation && request_id.to_s.length > 18 fail ArgumentError, 'invalid value for "request_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && request_id !~ pattern fail ArgumentError, "invalid value for 'request_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_get, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/conversion_deletion_requests/{request_id}'.sub('{request_id}', CGI.escape(request_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConversionDeletionRequest' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"ConversionDeletionRequestsApi.conversion_deletion_request_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversionDeletionRequestsApi#conversion_deletion_request_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#conversion_deletion_request_list(ad_account_id, opts = {}) ⇒ ConversionDeletionRequestList200Response
List conversion deletion requests
This endpoint is currently in beta and not available to all apps. Learn more. Get a list of the conversion deletion requests for the specified ad_account_id.
287 288 289 290 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 287 def conversion_deletion_request_list(ad_account_id, opts = {}) data, _status_code, _headers = conversion_deletion_request_list_with_http_info(ad_account_id, opts) data end |
#conversion_deletion_request_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(ConversionDeletionRequestList200Response, Integer, Hash)>
List conversion deletion requests This endpoint is currently in beta and not available to all apps. Learn more. Get a list of the conversion deletion requests for the specified `ad_account_id`.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/pinterest_sdk/api/conversion_deletion_requests_api.rb', line 300 def conversion_deletion_request_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversionDeletionRequestsApi.conversion_deletion_request_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ConversionDeletionRequestsApi.conversion_deletion_request_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ConversionDeletionRequestsApi.conversion_deletion_request_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ConversionDeletionRequestsApi.conversion_deletion_request_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ConversionDeletionRequestsApi.conversion_deletion_request_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/conversion_deletion_requests'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConversionDeletionRequestList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"ConversionDeletionRequestsApi.conversion_deletion_request_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversionDeletionRequestsApi#conversion_deletion_request_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |