Class: PinterestSdkClient::ConversionEventResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ConversionEventResponse
- Defined in:
- lib/pinterest_sdk/models/conversion_event_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Id of the ad account.
-
#conversion_event ⇒ Object
Returns the value of attribute conversion_event.
-
#conversion_tag_id ⇒ Object
Id of the tag.
-
#created_time ⇒ Object
Creation date in epoch format.
-
#reporting_conversion_event ⇒ Object
For advertiser-defined events, the reporting event label shown in optimization UIs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversionEventResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConversionEventResponse
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ConversionEventResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ConversionEventResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'conversion_event') self.conversion_event = attributes[:'conversion_event'] end if attributes.key?(:'conversion_tag_id') self.conversion_tag_id = attributes[:'conversion_tag_id'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'reporting_conversion_event') self.reporting_conversion_event = attributes[:'reporting_conversion_event'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Id of the ad account.
19 20 21 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 19 def ad_account_id @ad_account_id end |
#conversion_event ⇒ Object
Returns the value of attribute conversion_event.
21 22 23 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 21 def conversion_event @conversion_event end |
#conversion_tag_id ⇒ Object
Id of the tag.
24 25 26 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 24 def conversion_tag_id @conversion_tag_id end |
#created_time ⇒ Object
Creation date in epoch format.
27 28 29 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 27 def created_time @created_time end |
#reporting_conversion_event ⇒ Object
For advertiser-defined events, the reporting event label shown in optimization UIs.
30 31 32 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 30 def reporting_conversion_event @reporting_conversion_event end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 55 def self.attribute_map { :'ad_account_id' => :'ad_account_id', :'conversion_event' => :'conversion_event', :'conversion_tag_id' => :'conversion_tag_id', :'created_time' => :'created_time', :'reporting_conversion_event' => :'reporting_conversion_event' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 76 def self.openapi_types { :'ad_account_id' => :'String', :'conversion_event' => :'ConversionTagType', :'conversion_tag_id' => :'String', :'created_time' => :'Integer', :'reporting_conversion_event' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && conversion_event == o.conversion_event && conversion_tag_id == o.conversion_tag_id && created_time == o.created_time && reporting_conversion_event == o.reporting_conversion_event end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 206 def hash [ad_account_id, conversion_event, conversion_tag_id, created_time, reporting_conversion_event].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@conversion_tag_id.nil? && @conversion_tag_id !~ pattern invalid_properties.push("invalid value for \"conversion_tag_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/pinterest_sdk/models/conversion_event_response.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if !@conversion_tag_id.nil? && @conversion_tag_id !~ Regexp.new(/^\d+$/) true end |