Class: PinterestSdkClient::CustomerListsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::CustomerListsApi
- Defined in:
- lib/pinterest_sdk/api/customer_lists_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#customer_lists_create(ad_account_id, customer_list_create, opts = {}) ⇒ CustomerList
Create customer lists Create a customer list from your records (hashed or plain-text email addresses, or hashed MAIDs or IDFAs).
-
#customer_lists_create_with_http_info(ad_account_id, customer_list_create, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Create customer lists Create a customer list from your records (hashed or plain-text email addresses, or hashed MAIDs or IDFAs).
-
#customer_lists_get(ad_account_id, customer_list_id, opts = {}) ⇒ CustomerList
Get customer list Gets a specific customer list given the customer list ID.
-
#customer_lists_get_with_http_info(ad_account_id, customer_list_id, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Get customer list Gets a specific customer list given the customer list ID.
-
#customer_lists_list(ad_account_id, opts = {}) ⇒ CustomerListsList200Response
Get customer lists Get a set of customer lists including id and name based on the filters provided.
-
#customer_lists_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(CustomerListsList200Response, Integer, Hash)>
Get customer lists Get a set of customer lists including id and name based on the filters provided.
-
#customer_lists_update(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) ⇒ CustomerList
Update customer list Append or remove records to/from an existing customer list.
-
#customer_lists_update_with_http_info(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Update customer list Append or remove records to/from an existing customer list.
-
#initialize(api_client = ApiClient.default) ⇒ CustomerListsApi
constructor
A new instance of CustomerListsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CustomerListsApi
Returns a new instance of CustomerListsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#customer_lists_create(ad_account_id, customer_list_create, opts = {}) ⇒ CustomerList
Create customer lists
Create a customer list from your records (hashed or plain-text email addresses, or hashed MAIDs or IDFAs). A customer list is one of the four types of Pinterest audiences: for more information, see Audience targeting or the Audiences section of the ads management guide. Please review our requirements for what type of information is allowed when uploading a customer list. When you create a customer list, the system scans the list for existing Pinterest accounts; the list must include at least 100 Pinterest accounts. Your original list will be deleted when the matching process is complete. The filtered list – containing only the Pinterest accounts that were included in your starting list – is what will be used to create the audience. To use your customer list after creating it, convert it into a customer list audience by passing the CUSTOMER_LIST audience type at the create audience endpoint.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 28 def customer_lists_create(ad_account_id, customer_list_create, opts = {}) data, _status_code, _headers = customer_lists_create_with_http_info(ad_account_id, customer_list_create, opts) data end |
#customer_lists_create_with_http_info(ad_account_id, customer_list_create, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Create customer lists Create a customer list from your records (hashed or plain-text email addresses, or hashed MAIDs or IDFAs). A customer list is one of the four types of Pinterest audiences: for more information, see Audience targeting or the Audiences section of the ads management guide. Please review our requirements for what type of information is allowed when uploading a customer list. When you create a customer list, the system scans the list for existing Pinterest accounts; the list must include at least 100 Pinterest accounts. Your original list will be deleted when the matching process is complete. The filtered list – containing only the Pinterest accounts that were included in your starting list – is what will be used to create the audience. To use your customer list after creating it, convert it into a customer list audience by passing the `CUSTOMER_LIST` audience type at the create audience endpoint.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 39 def customer_lists_create_with_http_info(ad_account_id, customer_list_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerListsApi.customer_lists_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListsApi.customer_lists_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListsApi.customer_lists_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListsApi.customer_lists_create, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_list_create' is set if @api_client.config.client_side_validation && customer_list_create.nil? fail ArgumentError, "Missing the required parameter 'customer_list_create' when calling CustomerListsApi.customer_lists_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_lists'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_list_create) # return_type return_type = opts[:debug_return_type] || 'CustomerList' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerListsApi.customer_lists_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerListsApi#customer_lists_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#customer_lists_get(ad_account_id, customer_list_id, opts = {}) ⇒ CustomerList
Get customer list Gets a specific customer list given the customer list ID.
111 112 113 114 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 111 def customer_lists_get(ad_account_id, customer_list_id, opts = {}) data, _status_code, _headers = customer_lists_get_with_http_info(ad_account_id, customer_list_id, opts) data end |
#customer_lists_get_with_http_info(ad_account_id, customer_list_id, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Get customer list Gets a specific customer list given the customer list ID.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 122 def customer_lists_get_with_http_info(ad_account_id, customer_list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerListsApi.customer_lists_get ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListsApi.customer_lists_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListsApi.customer_lists_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListsApi.customer_lists_get, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_list_id' is set if @api_client.config.client_side_validation && customer_list_id.nil? fail ArgumentError, "Missing the required parameter 'customer_list_id' when calling CustomerListsApi.customer_lists_get" end if @api_client.config.client_side_validation && customer_list_id.to_s.length > 18 fail ArgumentError, 'invalid value for "customer_list_id" when calling CustomerListsApi.customer_lists_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && customer_list_id !~ pattern fail ArgumentError, "invalid value for 'customer_list_id' when calling CustomerListsApi.customer_lists_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{customer_list_id}', CGI.escape(customer_list_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CustomerList' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"CustomerListsApi.customer_lists_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerListsApi#customer_lists_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#customer_lists_list(ad_account_id, opts = {}) ⇒ CustomerListsList200Response
Get customer lists Get a set of customer lists including id and name based on the filters provided. (Customer lists are a type of audience.) For more information, see Audience targeting or the Audiences section of the ads management guide.
201 202 203 204 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 201 def customer_lists_list(ad_account_id, opts = {}) data, _status_code, _headers = customer_lists_list_with_http_info(ad_account_id, opts) data end |
#customer_lists_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(CustomerListsList200Response, Integer, Hash)>
Get customer lists Get a set of customer lists including id and name based on the filters provided. (Customer lists are a type of audience.) For more information, see Audience targeting or the Audiences section of the ads management guide.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 215 def customer_lists_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerListsApi.customer_lists_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListsApi.customer_lists_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListsApi.customer_lists_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListsApi.customer_lists_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CustomerListsApi.customer_lists_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling CustomerListsApi.customer_lists_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_lists'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'exclude_nca'] = opts[:'exclude_nca'] if !opts[:'exclude_nca'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CustomerListsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerListsApi.customer_lists_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerListsApi#customer_lists_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#customer_lists_update(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) ⇒ CustomerList
Update customer list Append or remove records to/from an existing customer list. (A customer list is one of the four types of Pinterest audiences.) When you add records to an existing customer list, the system scans the additions for existing Pinterest accounts; those are the records that will be added to your "CUSTOMER_LIST" audience. Your original list of records to add will be deleted when the matching process is complete. For more information, see Audience targeting or the Audiences section of the ads management guide.
291 292 293 294 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 291 def customer_lists_update(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) data, _status_code, _headers = customer_lists_update_with_http_info(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts) data end |
#customer_lists_update_with_http_info(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) ⇒ Array<(CustomerList, Integer, Hash)>
Update customer list Append or remove records to/from an existing customer list. (A customer list is one of the four types of Pinterest audiences.) When you add records to an existing customer list, the system scans the additions for existing Pinterest accounts; those are the records that will be added to your "CUSTOMER_LIST" audience. Your original list of records to add will be deleted when the matching process is complete. For more information, see Audience targeting or the Audiences section of the ads management guide.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/pinterest_sdk/api/customer_lists_api.rb', line 303 def customer_lists_update_with_http_info(ad_account_id, customer_list_id, customer_list_update_with_required_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerListsApi.customer_lists_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling CustomerListsApi.customer_lists_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling CustomerListsApi.customer_lists_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling CustomerListsApi.customer_lists_update, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_list_id' is set if @api_client.config.client_side_validation && customer_list_id.nil? fail ArgumentError, "Missing the required parameter 'customer_list_id' when calling CustomerListsApi.customer_lists_update" end if @api_client.config.client_side_validation && customer_list_id.to_s.length > 18 fail ArgumentError, 'invalid value for "customer_list_id" when calling CustomerListsApi.customer_lists_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && customer_list_id !~ pattern fail ArgumentError, "invalid value for 'customer_list_id' when calling CustomerListsApi.customer_lists_update, must conform to the pattern #{pattern}." end # verify the required parameter 'customer_list_update_with_required_body' is set if @api_client.config.client_side_validation && customer_list_update_with_required_body.nil? fail ArgumentError, "Missing the required parameter 'customer_list_update_with_required_body' when calling CustomerListsApi.customer_lists_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{customer_list_id}', CGI.escape(customer_list_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_list_update_with_required_body) # return_type return_type = opts[:debug_return_type] || 'CustomerList' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"CustomerListsApi.customer_lists_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerListsApi#customer_lists_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |