Class: PinterestSdkClient::EntityHistory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::EntityHistory
- Defined in:
- lib/pinterest_sdk/models/entity_history.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#change_timestamp ⇒ Object
A Unix timestamp representing the time of the change in seconds.
-
#data_changes ⇒ Object
Properties associated with a particular change to an entity's data.
-
#entity_id ⇒ Object
The id of the entity that was changed.
-
#entity_name ⇒ Object
The name of the entity that was changed.
-
#ldap ⇒ Object
The LDAP of the user who initiated the change; only pertinent for changes initiated by internal users.
-
#operation ⇒ Object
The type of operation that caused the change.
-
#user_id ⇒ Object
The id of the user who initiated the change.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EntityHistory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EntityHistory
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::EntityHistory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::EntityHistory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'change_timestamp') self. = attributes[:'change_timestamp'] end if attributes.key?(:'data_changes') if (value = attributes[:'data_changes']).is_a?(Array) self.data_changes = value end end if attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] end if attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] end if attributes.key?(:'ldap') self.ldap = attributes[:'ldap'] end if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end end |
Instance Attribute Details
#change_timestamp ⇒ Object
A Unix timestamp representing the time of the change in seconds
19 20 21 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 19 def @change_timestamp end |
#data_changes ⇒ Object
Properties associated with a particular change to an entity's data
22 23 24 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 22 def data_changes @data_changes end |
#entity_id ⇒ Object
The id of the entity that was changed
25 26 27 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 25 def entity_id @entity_id end |
#entity_name ⇒ Object
The name of the entity that was changed
28 29 30 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 28 def entity_name @entity_name end |
#ldap ⇒ Object
The LDAP of the user who initiated the change; only pertinent for changes initiated by internal users
31 32 33 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 31 def ldap @ldap end |
#operation ⇒ Object
The type of operation that caused the change
34 35 36 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 34 def operation @operation end |
#user_id ⇒ Object
The id of the user who initiated the change
37 38 39 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 37 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 62 def self.attribute_map { :'change_timestamp' => :'change_timestamp', :'data_changes' => :'data_changes', :'entity_id' => :'entity_id', :'entity_name' => :'entity_name', :'ldap' => :'ldap', :'operation' => :'operation', :'user_id' => :'user_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 85 def self.openapi_types { :'change_timestamp' => :'Integer', :'data_changes' => :'Array<EntityDataChangeHistory>', :'entity_id' => :'String', :'entity_name' => :'String', :'ldap' => :'String', :'operation' => :'ChangeHistoryOperationType', :'user_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 209 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && data_changes == o.data_changes && entity_id == o.entity_id && entity_name == o.entity_name && ldap == o.ldap && operation == o.operation && user_id == o.user_id end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 229 def hash [, data_changes, entity_id, entity_name, ldap, operation, user_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@entity_id.nil? && @entity_id !~ pattern invalid_properties.push("invalid value for \"entity_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@user_id.nil? && @user_id !~ pattern invalid_properties.push("invalid value for \"user_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 |
# File 'lib/pinterest_sdk/models/entity_history.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@entity_id.nil? && @entity_id !~ Regexp.new(/^\d+$/) return false if !@user_id.nil? && @user_id !~ Regexp.new(/^\d+$/) true end |