Class: PinterestSdkClient::IntegrationMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::IntegrationMetadata
- Defined in:
- lib/pinterest_sdk/models/integration_metadata.rb
Overview
Integration metadata
Instance Attribute Summary collapse
-
#additional_id_1 ⇒ Object
Returns the value of attribute additional_id_1.
-
#connected_advertiser_id ⇒ Object
Returns the value of attribute connected_advertiser_id.
-
#connected_lba_id ⇒ Object
Returns the value of attribute connected_lba_id.
-
#connected_merchant_id ⇒ Object
Returns the value of attribute connected_merchant_id.
-
#connected_tag_id ⇒ Object
Returns the value of attribute connected_tag_id.
-
#connected_user_id ⇒ Object
Returns the value of attribute connected_user_id.
-
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
-
#external_business_id ⇒ Object
External business ID for the integration.
-
#id ⇒ Object
Returns the value of attribute id.
-
#partner_access_token_expiry ⇒ Object
Returns the value of attribute partner_access_token_expiry.
-
#partner_metadata ⇒ Object
Returns the value of attribute partner_metadata.
-
#partner_refresh_token_expiry ⇒ Object
Returns the value of attribute partner_refresh_token_expiry.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#updated_timestamp ⇒ Object
Returns the value of attribute updated_timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationMetadata
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::IntegrationMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::IntegrationMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'additional_id_1') self.additional_id_1 = attributes[:'additional_id_1'] end if attributes.key?(:'connected_advertiser_id') self.connected_advertiser_id = attributes[:'connected_advertiser_id'] end if attributes.key?(:'connected_lba_id') self.connected_lba_id = attributes[:'connected_lba_id'] end if attributes.key?(:'connected_merchant_id') self.connected_merchant_id = attributes[:'connected_merchant_id'] end if attributes.key?(:'connected_tag_id') self.connected_tag_id = attributes[:'connected_tag_id'] end if attributes.key?(:'connected_user_id') self.connected_user_id = attributes[:'connected_user_id'] end if attributes.key?(:'created_timestamp') self. = attributes[:'created_timestamp'] end if attributes.key?(:'external_business_id') self.external_business_id = attributes[:'external_business_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'partner_access_token_expiry') self.partner_access_token_expiry = attributes[:'partner_access_token_expiry'] end if attributes.key?(:'partner_metadata') self. = attributes[:'partner_metadata'] end if attributes.key?(:'partner_refresh_token_expiry') self.partner_refresh_token_expiry = attributes[:'partner_refresh_token_expiry'] end if attributes.key?(:'scopes') self.scopes = attributes[:'scopes'] end if attributes.key?(:'updated_timestamp') self. = attributes[:'updated_timestamp'] end end |
Instance Attribute Details
#additional_id_1 ⇒ Object
Returns the value of attribute additional_id_1.
19 20 21 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 19 def additional_id_1 @additional_id_1 end |
#connected_advertiser_id ⇒ Object
Returns the value of attribute connected_advertiser_id.
21 22 23 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 21 def connected_advertiser_id @connected_advertiser_id end |
#connected_lba_id ⇒ Object
Returns the value of attribute connected_lba_id.
23 24 25 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 23 def connected_lba_id @connected_lba_id end |
#connected_merchant_id ⇒ Object
Returns the value of attribute connected_merchant_id.
25 26 27 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 25 def connected_merchant_id @connected_merchant_id end |
#connected_tag_id ⇒ Object
Returns the value of attribute connected_tag_id.
27 28 29 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 27 def connected_tag_id @connected_tag_id end |
#connected_user_id ⇒ Object
Returns the value of attribute connected_user_id.
29 30 31 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 29 def connected_user_id @connected_user_id end |
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
31 32 33 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 31 def @created_timestamp end |
#external_business_id ⇒ Object
External business ID for the integration.
34 35 36 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 34 def external_business_id @external_business_id end |
#id ⇒ Object
Returns the value of attribute id.
36 37 38 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 36 def id @id end |
#partner_access_token_expiry ⇒ Object
Returns the value of attribute partner_access_token_expiry.
38 39 40 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 38 def partner_access_token_expiry @partner_access_token_expiry end |
#partner_metadata ⇒ Object
Returns the value of attribute partner_metadata.
40 41 42 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 40 def @partner_metadata end |
#partner_refresh_token_expiry ⇒ Object
Returns the value of attribute partner_refresh_token_expiry.
42 43 44 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 42 def partner_refresh_token_expiry @partner_refresh_token_expiry end |
#scopes ⇒ Object
Returns the value of attribute scopes.
44 45 46 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 44 def scopes @scopes end |
#updated_timestamp ⇒ Object
Returns the value of attribute updated_timestamp.
46 47 48 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 46 def @updated_timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 49 def self.attribute_map { :'additional_id_1' => :'additional_id_1', :'connected_advertiser_id' => :'connected_advertiser_id', :'connected_lba_id' => :'connected_lba_id', :'connected_merchant_id' => :'connected_merchant_id', :'connected_tag_id' => :'connected_tag_id', :'connected_user_id' => :'connected_user_id', :'created_timestamp' => :'created_timestamp', :'external_business_id' => :'external_business_id', :'id' => :'id', :'partner_access_token_expiry' => :'partner_access_token_expiry', :'partner_metadata' => :'partner_metadata', :'partner_refresh_token_expiry' => :'partner_refresh_token_expiry', :'scopes' => :'scopes', :'updated_timestamp' => :'updated_timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 249 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 79 def self.openapi_types { :'additional_id_1' => :'String', :'connected_advertiser_id' => :'String', :'connected_lba_id' => :'String', :'connected_merchant_id' => :'String', :'connected_tag_id' => :'String', :'connected_user_id' => :'String', :'created_timestamp' => :'Float', :'external_business_id' => :'String', :'id' => :'String', :'partner_access_token_expiry' => :'Float', :'partner_metadata' => :'String', :'partner_refresh_token_expiry' => :'Float', :'scopes' => :'String', :'updated_timestamp' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && additional_id_1 == o.additional_id_1 && connected_advertiser_id == o.connected_advertiser_id && connected_lba_id == o.connected_lba_id && connected_merchant_id == o.connected_merchant_id && connected_tag_id == o.connected_tag_id && connected_user_id == o.connected_user_id && == o. && external_business_id == o.external_business_id && id == o.id && partner_access_token_expiry == o.partner_access_token_expiry && == o. && partner_refresh_token_expiry == o.partner_refresh_token_expiry && scopes == o.scopes && == o. end |
#eql?(o) ⇒ Boolean
236 237 238 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 236 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 242 def hash [additional_id_1, connected_advertiser_id, connected_lba_id, connected_merchant_id, connected_tag_id, connected_user_id, , external_business_id, id, partner_access_token_expiry, , partner_refresh_token_expiry, scopes, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 |
# File 'lib/pinterest_sdk/models/integration_metadata.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) true end |