Class: PinterestSdkClient::IntegrationRecord
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::IntegrationRecord
- Defined in:
- lib/pinterest_sdk/models/integration_record.rb
Overview
Integration record
Instance Attribute Summary collapse
-
#additional_id_1 ⇒ Object
Returns the value of attribute additional_id_1.
-
#connected_advertiser_id ⇒ Object
Returns the value of attribute connected_advertiser_id.
-
#connected_lba_id ⇒ Object
Returns the value of attribute connected_lba_id.
-
#connected_merchant_id ⇒ Object
Returns the value of attribute connected_merchant_id.
-
#connected_tag_id ⇒ Object
Returns the value of attribute connected_tag_id.
-
#connected_user_id ⇒ Object
Returns the value of attribute connected_user_id.
-
#created_time ⇒ Object
Returns the value of attribute created_time.
-
#external_business_id ⇒ Object
Returns the value of attribute external_business_id.
-
#id ⇒ Object
Integration record ID.
-
#partner_access_token ⇒ Object
Returns the value of attribute partner_access_token.
-
#partner_access_token_expiry ⇒ Object
Returns the value of attribute partner_access_token_expiry.
-
#partner_metadata ⇒ Object
Returns the value of attribute partner_metadata.
-
#partner_primary_email ⇒ Object
Returns the value of attribute partner_primary_email.
-
#partner_refresh_token ⇒ Object
Returns the value of attribute partner_refresh_token.
-
#partner_refresh_token_expiry ⇒ Object
Returns the value of attribute partner_refresh_token_expiry.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#updated_time ⇒ Object
Returns the value of attribute updated_time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationRecord
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 131 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::IntegrationRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::IntegrationRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'additional_id_1') self.additional_id_1 = attributes[:'additional_id_1'] end if attributes.key?(:'connected_advertiser_id') self.connected_advertiser_id = attributes[:'connected_advertiser_id'] end if attributes.key?(:'connected_lba_id') self.connected_lba_id = attributes[:'connected_lba_id'] end if attributes.key?(:'connected_merchant_id') self.connected_merchant_id = attributes[:'connected_merchant_id'] end if attributes.key?(:'connected_tag_id') self.connected_tag_id = attributes[:'connected_tag_id'] end if attributes.key?(:'connected_user_id') self.connected_user_id = attributes[:'connected_user_id'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'external_business_id') self.external_business_id = attributes[:'external_business_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'partner_access_token') self.partner_access_token = attributes[:'partner_access_token'] end if attributes.key?(:'partner_access_token_expiry') self.partner_access_token_expiry = attributes[:'partner_access_token_expiry'] end if attributes.key?(:'partner_metadata') self. = attributes[:'partner_metadata'] end if attributes.key?(:'partner_primary_email') self.partner_primary_email = attributes[:'partner_primary_email'] end if attributes.key?(:'partner_refresh_token') self.partner_refresh_token = attributes[:'partner_refresh_token'] end if attributes.key?(:'partner_refresh_token_expiry') self.partner_refresh_token_expiry = attributes[:'partner_refresh_token_expiry'] end if attributes.key?(:'scopes') self.scopes = attributes[:'scopes'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end end |
Instance Attribute Details
#additional_id_1 ⇒ Object
Returns the value of attribute additional_id_1.
19 20 21 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 19 def additional_id_1 @additional_id_1 end |
#connected_advertiser_id ⇒ Object
Returns the value of attribute connected_advertiser_id.
21 22 23 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 21 def connected_advertiser_id @connected_advertiser_id end |
#connected_lba_id ⇒ Object
Returns the value of attribute connected_lba_id.
23 24 25 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 23 def connected_lba_id @connected_lba_id end |
#connected_merchant_id ⇒ Object
Returns the value of attribute connected_merchant_id.
25 26 27 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 25 def connected_merchant_id @connected_merchant_id end |
#connected_tag_id ⇒ Object
Returns the value of attribute connected_tag_id.
27 28 29 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 27 def connected_tag_id @connected_tag_id end |
#connected_user_id ⇒ Object
Returns the value of attribute connected_user_id.
29 30 31 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 29 def connected_user_id @connected_user_id end |
#created_time ⇒ Object
Returns the value of attribute created_time.
31 32 33 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 31 def created_time @created_time end |
#external_business_id ⇒ Object
Returns the value of attribute external_business_id.
33 34 35 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 33 def external_business_id @external_business_id end |
#id ⇒ Object
Integration record ID.
36 37 38 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 36 def id @id end |
#partner_access_token ⇒ Object
Returns the value of attribute partner_access_token.
38 39 40 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 38 def partner_access_token @partner_access_token end |
#partner_access_token_expiry ⇒ Object
Returns the value of attribute partner_access_token_expiry.
40 41 42 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 40 def partner_access_token_expiry @partner_access_token_expiry end |
#partner_metadata ⇒ Object
Returns the value of attribute partner_metadata.
42 43 44 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 42 def @partner_metadata end |
#partner_primary_email ⇒ Object
Returns the value of attribute partner_primary_email.
44 45 46 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 44 def partner_primary_email @partner_primary_email end |
#partner_refresh_token ⇒ Object
Returns the value of attribute partner_refresh_token.
46 47 48 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 46 def partner_refresh_token @partner_refresh_token end |
#partner_refresh_token_expiry ⇒ Object
Returns the value of attribute partner_refresh_token_expiry.
48 49 50 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 48 def partner_refresh_token_expiry @partner_refresh_token_expiry end |
#scopes ⇒ Object
Returns the value of attribute scopes.
50 51 52 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 50 def scopes @scopes end |
#updated_time ⇒ Object
Returns the value of attribute updated_time.
52 53 54 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 52 def updated_time @updated_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 55 def self.attribute_map { :'additional_id_1' => :'additional_id_1', :'connected_advertiser_id' => :'connected_advertiser_id', :'connected_lba_id' => :'connected_lba_id', :'connected_merchant_id' => :'connected_merchant_id', :'connected_tag_id' => :'connected_tag_id', :'connected_user_id' => :'connected_user_id', :'created_time' => :'created_time', :'external_business_id' => :'external_business_id', :'id' => :'id', :'partner_access_token' => :'partner_access_token', :'partner_access_token_expiry' => :'partner_access_token_expiry', :'partner_metadata' => :'partner_metadata', :'partner_primary_email' => :'partner_primary_email', :'partner_refresh_token' => :'partner_refresh_token', :'partner_refresh_token_expiry' => :'partner_refresh_token_expiry', :'scopes' => :'scopes', :'updated_time' => :'updated_time' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 296 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 111 def self.openapi_nullable Set.new([ :'additional_id_1', :'connected_advertiser_id', :'connected_lba_id', :'connected_merchant_id', :'connected_tag_id', :'external_business_id', :'partner_access_token', :'partner_access_token_expiry', :'partner_metadata', :'partner_primary_email', :'partner_refresh_token', :'partner_refresh_token_expiry', :'scopes', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 88 def self.openapi_types { :'additional_id_1' => :'String', :'connected_advertiser_id' => :'String', :'connected_lba_id' => :'String', :'connected_merchant_id' => :'String', :'connected_tag_id' => :'String', :'connected_user_id' => :'String', :'created_time' => :'Integer', :'external_business_id' => :'String', :'id' => :'String', :'partner_access_token' => :'String', :'partner_access_token_expiry' => :'Integer', :'partner_metadata' => :'String', :'partner_primary_email' => :'String', :'partner_refresh_token' => :'String', :'partner_refresh_token_expiry' => :'Integer', :'scopes' => :'String', :'updated_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && additional_id_1 == o.additional_id_1 && connected_advertiser_id == o.connected_advertiser_id && connected_lba_id == o.connected_lba_id && connected_merchant_id == o.connected_merchant_id && connected_tag_id == o.connected_tag_id && connected_user_id == o.connected_user_id && created_time == o.created_time && external_business_id == o.external_business_id && id == o.id && partner_access_token == o.partner_access_token && partner_access_token_expiry == o.partner_access_token_expiry && == o. && partner_primary_email == o.partner_primary_email && partner_refresh_token == o.partner_refresh_token && partner_refresh_token_expiry == o.partner_refresh_token_expiry && scopes == o.scopes && updated_time == o.updated_time end |
#eql?(o) ⇒ Boolean
283 284 285 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 283 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 289 def hash [additional_id_1, connected_advertiser_id, connected_lba_id, connected_merchant_id, connected_tag_id, connected_user_id, created_time, external_business_id, id, partner_access_token, partner_access_token_expiry, , partner_primary_email, partner_refresh_token, partner_refresh_token_expiry, scopes, updated_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 218 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 |
# File 'lib/pinterest_sdk/models/integration_record.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id !~ Regexp.new(/^\d+$/) true end |