Class: PinterestSdkClient::InviteBusinessRoleBinding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::InviteBusinessRoleBinding
- Defined in:
- lib/pinterest_sdk/models/invite_business_role_binding.rb
Overview
An invite object if the invite/request was successfully updated. Will only be provided if the an invite/request is successfully updated.
Instance Attribute Summary collapse
-
#created_by_business_id ⇒ Object
Unique identifier for the business that created the invite/request.
-
#created_by_user_id ⇒ Object
Unique identifier for the user that created the invite/request.
-
#id ⇒ Object
Unique identifier of the invite/request.
-
#invite_data ⇒ Object
Returns the value of attribute invite_data.
-
#is_received_invite ⇒ Object
Indicates whether the invite/request was received.
-
#user ⇒ Object
Metadata for the member/partner that was sent the invite/request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InviteBusinessRoleBinding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InviteBusinessRoleBinding
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::InviteBusinessRoleBinding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::InviteBusinessRoleBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_by_business_id') self.created_by_business_id = attributes[:'created_by_business_id'] end if attributes.key?(:'created_by_user_id') self.created_by_user_id = attributes[:'created_by_user_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'invite_data') self.invite_data = attributes[:'invite_data'] end if attributes.key?(:'is_received_invite') self.is_received_invite = attributes[:'is_received_invite'] end if attributes.key?(:'user') self.user = attributes[:'user'] end end |
Instance Attribute Details
#created_by_business_id ⇒ Object
Unique identifier for the business that created the invite/request.
20 21 22 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 20 def created_by_business_id @created_by_business_id end |
#created_by_user_id ⇒ Object
Unique identifier for the user that created the invite/request.
23 24 25 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 23 def created_by_user_id @created_by_user_id end |
#id ⇒ Object
Unique identifier of the invite/request.
26 27 28 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 26 def id @id end |
#invite_data ⇒ Object
Returns the value of attribute invite_data.
28 29 30 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 28 def invite_data @invite_data end |
#is_received_invite ⇒ Object
Indicates whether the invite/request was received.
31 32 33 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 31 def is_received_invite @is_received_invite end |
#user ⇒ Object
Metadata for the member/partner that was sent the invite/request.
34 35 36 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 34 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 37 def self.attribute_map { :'created_by_business_id' => :'created_by_business_id', :'created_by_user_id' => :'created_by_user_id', :'id' => :'id', :'invite_data' => :'invite_data', :'is_received_invite' => :'is_received_invite', :'user' => :'user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 59 def self.openapi_types { :'created_by_business_id' => :'String', :'created_by_user_id' => :'String', :'id' => :'String', :'invite_data' => :'InviteDataResponse', :'is_received_invite' => :'Boolean', :'user' => :'BusinessAccessUserSummary' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && created_by_business_id == o.created_by_business_id && created_by_user_id == o.created_by_user_id && id == o.id && invite_data == o.invite_data && is_received_invite == o.is_received_invite && user == o.user end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 174 def hash [created_by_business_id, created_by_user_id, id, invite_data, is_received_invite, user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 |
# File 'lib/pinterest_sdk/models/invite_business_role_binding.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) true end |