Class: PinterestSdkClient::LeadAdsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::LeadAdsApi
- Defined in:
- lib/pinterest_sdk/api/lead_ads_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#ad_accounts_subscriptions_del_by_id(ad_account_id, subscription_id, opts = {}) ⇒ LeadSubscription
Delete lead ads subscription Delete an existing lead ads webhook subscription by ID.
-
#ad_accounts_subscriptions_del_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Delete lead ads subscription Delete an existing lead ads webhook subscription by ID.
-
#ad_accounts_subscriptions_get_by_id(ad_account_id, subscription_id, opts = {}) ⇒ LeadSubscription
Get lead ads subscription by ID Get an existing lead ads webhook subscription by ID.
-
#ad_accounts_subscriptions_get_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Get lead ads subscription by ID Get an existing lead ads webhook subscription by ID.
-
#ad_accounts_subscriptions_get_list(ad_account_id, opts = {}) ⇒ AdAccountsSubscriptionsGetList200Response
Get lead ads subscriptions Get the advertiser's list of lead ads subscriptions.
-
#ad_accounts_subscriptions_get_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(AdAccountsSubscriptionsGetList200Response, Integer, Hash)>
Get lead ads subscriptions Get the advertiser's list of lead ads subscriptions.
-
#ad_accounts_subscriptions_post(ad_account_id, lead_subscription_post_params_create, opts = {}) ⇒ LeadSubscription
Create lead ads subscription Create a lead ads webhook subscription.
-
#ad_accounts_subscriptions_post_with_http_info(ad_account_id, lead_subscription_post_params_create, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Create lead ads subscription Create a lead ads webhook subscription.
-
#initialize(api_client = ApiClient.default) ⇒ LeadAdsApi
constructor
A new instance of LeadAdsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LeadAdsApi
Returns a new instance of LeadAdsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#ad_accounts_subscriptions_del_by_id(ad_account_id, subscription_id, opts = {}) ⇒ LeadSubscription
Delete lead ads subscription Delete an existing lead ads webhook subscription by ID. - Only requests for the OWNER or ADMIN of the ad_account will be allowed.'
28 29 30 31 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 28 def ad_accounts_subscriptions_del_by_id(ad_account_id, subscription_id, opts = {}) data, _status_code, _headers = ad_accounts_subscriptions_del_by_id_with_http_info(ad_account_id, subscription_id, opts) data end |
#ad_accounts_subscriptions_del_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Delete lead ads subscription Delete an existing lead ads webhook subscription by ID. - Only requests for the OWNER or ADMIN of the ad_account will be allowed.'
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 39 def ad_accounts_subscriptions_del_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadAdsApi.ad_accounts_subscriptions_del_by_id ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_del_by_id" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadAdsApi.ad_accounts_subscriptions_del_by_id, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_del_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'subscription_id' is set if @api_client.config.client_side_validation && subscription_id.nil? fail ArgumentError, "Missing the required parameter 'subscription_id' when calling LeadAdsApi.ad_accounts_subscriptions_del_by_id" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && subscription_id !~ pattern fail ArgumentError, "invalid value for 'subscription_id' when calling LeadAdsApi.ad_accounts_subscriptions_del_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads/subscriptions/{subscription_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{subscription_id}', CGI.escape(subscription_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LeadSubscription' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadAdsApi.ad_accounts_subscriptions_del_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadAdsApi#ad_accounts_subscriptions_del_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ad_accounts_subscriptions_get_by_id(ad_account_id, subscription_id, opts = {}) ⇒ LeadSubscription
Get lead ads subscription by ID Get an existing lead ads webhook subscription by ID. - Only requests for the OWNER or ADMIN of the ad_account will be allowed.'
111 112 113 114 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 111 def ad_accounts_subscriptions_get_by_id(ad_account_id, subscription_id, opts = {}) data, _status_code, _headers = ad_accounts_subscriptions_get_by_id_with_http_info(ad_account_id, subscription_id, opts) data end |
#ad_accounts_subscriptions_get_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Get lead ads subscription by ID Get an existing lead ads webhook subscription by ID. - Only requests for the OWNER or ADMIN of the ad_account will be allowed.'
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 122 def ad_accounts_subscriptions_get_by_id_with_http_info(ad_account_id, subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadAdsApi.ad_accounts_subscriptions_get_by_id ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_by_id" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadAdsApi.ad_accounts_subscriptions_get_by_id, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'subscription_id' is set if @api_client.config.client_side_validation && subscription_id.nil? fail ArgumentError, "Missing the required parameter 'subscription_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_by_id" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && subscription_id !~ pattern fail ArgumentError, "invalid value for 'subscription_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads/subscriptions/{subscription_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{subscription_id}', CGI.escape(subscription_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LeadSubscription' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"LeadAdsApi.ad_accounts_subscriptions_get_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadAdsApi#ad_accounts_subscriptions_get_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ad_accounts_subscriptions_get_list(ad_account_id, opts = {}) ⇒ AdAccountsSubscriptionsGetList200Response
Get lead ads subscriptions Get the advertiser's list of lead ads subscriptions. Only requests for the OWNER or ADMIN of the ad_account will be allowed.
195 196 197 198 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 195 def ad_accounts_subscriptions_get_list(ad_account_id, opts = {}) data, _status_code, _headers = ad_accounts_subscriptions_get_list_with_http_info(ad_account_id, opts) data end |
#ad_accounts_subscriptions_get_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(AdAccountsSubscriptionsGetList200Response, Integer, Hash)>
Get lead ads subscriptions Get the advertiser's list of lead ads subscriptions. Only requests for the OWNER or ADMIN of the ad_account will be allowed.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 207 def ad_accounts_subscriptions_get_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadAdsApi.ad_accounts_subscriptions_get_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadAdsApi.ad_accounts_subscriptions_get_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_get_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LeadAdsApi.ad_accounts_subscriptions_get_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling LeadAdsApi.ad_accounts_subscriptions_get_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads/subscriptions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AdAccountsSubscriptionsGetList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadAdsApi.ad_accounts_subscriptions_get_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadAdsApi#ad_accounts_subscriptions_get_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ad_accounts_subscriptions_post(ad_account_id, lead_subscription_post_params_create, opts = {}) ⇒ LeadSubscription
Create lead ads subscription Create a lead ads webhook subscription. Subscriptions allow Pinterest to deliver lead data from Ads Manager directly to the subscriber. Subscriptions can exist for a specific lead form or at ad account level. - Only requests for the OWNER or ADMIN of the ad_account will be allowed. - Advertisers can set up multiple integrations using ad_account_id + lead_form_id but only one integration per unique records. - For data security, egress lead data is encrypted with AES-256-GCM.
280 281 282 283 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 280 def ad_accounts_subscriptions_post(ad_account_id, lead_subscription_post_params_create, opts = {}) data, _status_code, _headers = ad_accounts_subscriptions_post_with_http_info(ad_account_id, lead_subscription_post_params_create, opts) data end |
#ad_accounts_subscriptions_post_with_http_info(ad_account_id, lead_subscription_post_params_create, opts = {}) ⇒ Array<(LeadSubscription, Integer, Hash)>
Create lead ads subscription Create a lead ads webhook subscription. Subscriptions allow Pinterest to deliver lead data from Ads Manager directly to the subscriber. Subscriptions can exist for a specific lead form or at ad account level. - Only requests for the OWNER or ADMIN of the ad_account will be allowed. - Advertisers can set up multiple integrations using ad_account_id + lead_form_id but only one integration per unique records. - For data security, egress lead data is encrypted with AES-256-GCM.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/pinterest_sdk/api/lead_ads_api.rb', line 291 def ad_accounts_subscriptions_post_with_http_info(ad_account_id, lead_subscription_post_params_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadAdsApi.ad_accounts_subscriptions_post ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_post" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadAdsApi.ad_accounts_subscriptions_post, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadAdsApi.ad_accounts_subscriptions_post, must conform to the pattern #{pattern}." end # verify the required parameter 'lead_subscription_post_params_create' is set if @api_client.config.client_side_validation && lead_subscription_post_params_create.nil? fail ArgumentError, "Missing the required parameter 'lead_subscription_post_params_create' when calling LeadAdsApi.ad_accounts_subscriptions_post" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads/subscriptions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lead_subscription_post_params_create) # return_type return_type = opts[:debug_return_type] || 'LeadSubscription' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadAdsApi.ad_accounts_subscriptions_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadAdsApi#ad_accounts_subscriptions_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |