Class: PinterestSdkClient::LeadsExportApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::LeadsExportApi
- Defined in:
- lib/pinterest_sdk/api/leads_export_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LeadsExportApi
constructor
A new instance of LeadsExportApi.
-
#leads_export_create(ad_account_id, leads_exports_create, opts = {}) ⇒ LeadsExports
Create a request to export leads collected from a lead ad **This feature is currently in beta and not available to all apps.
-
#leads_export_create_with_http_info(ad_account_id, leads_exports_create, opts = {}) ⇒ Array<(LeadsExports, Integer, Hash)>
Create a request to export leads collected from a lead ad **This feature is currently in beta and not available to all apps.
-
#leads_export_get(ad_account_id, leads_export_id, opts = {}) ⇒ LeadsExportResponseData
Get the lead export from the lead export create call **This feature is currently in beta and not available to all apps.
-
#leads_export_get_with_http_info(ad_account_id, leads_export_id, opts = {}) ⇒ Array<(LeadsExportResponseData, Integer, Hash)>
Get the lead export from the lead export create call **This feature is currently in beta and not available to all apps.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LeadsExportApi
Returns a new instance of LeadsExportApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#leads_export_create(ad_account_id, leads_exports_create, opts = {}) ⇒ LeadsExports
Create a request to export leads collected from a lead ad
This feature is currently in beta and not available to all apps. If you're interested in joining the beta, please reach out to your Pinterest account manager. Create an export of leads collected from a lead ad. This returns a leads_export_id token that you can use to download the export when it is ready. Note: Lead ad data will be available up to 30 days after the lead has been submitted. For more, see Lead ads.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 28 def leads_export_create(ad_account_id, leads_exports_create, opts = {}) data, _status_code, _headers = leads_export_create_with_http_info(ad_account_id, leads_exports_create, opts) data end |
#leads_export_create_with_http_info(ad_account_id, leads_exports_create, opts = {}) ⇒ Array<(LeadsExports, Integer, Hash)>
Create a request to export leads collected from a lead ad This feature is currently in beta and not available to all apps. If you're interested in joining the beta, please reach out to your Pinterest account manager. Create an export of leads collected from a lead ad. This returns a `leads_export_id` token that you can use to download the export when it is ready. Note: Lead ad data will be available up to 30 days after the lead has been submitted. For more, see Lead ads.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 39 def leads_export_create_with_http_info(ad_account_id, leads_exports_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadsExportApi.leads_export_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadsExportApi.leads_export_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadsExportApi.leads_export_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadsExportApi.leads_export_create, must conform to the pattern #{pattern}." end # verify the required parameter 'leads_exports_create' is set if @api_client.config.client_side_validation && leads_exports_create.nil? fail ArgumentError, "Missing the required parameter 'leads_exports_create' when calling LeadsExportApi.leads_export_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads_export'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(leads_exports_create) # return_type return_type = opts[:debug_return_type] || 'LeadsExports' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadsExportApi.leads_export_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadsExportApi#leads_export_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#leads_export_get(ad_account_id, leads_export_id, opts = {}) ⇒ LeadsExportResponseData
Get the lead export from the lead export create call This feature is currently in beta and not available to all apps. If you're interested in joining the beta, please reach out to your Pinterest account manager. Get the export of leads collected from a lead ad. This returns a URL to a list of lead export given a lead_export_id token returned from the create a lead export call. You can use the URL to download the report. Note: Lead ad data will be available up to 30 days after the lead has been submitted. For more, see Lead ads.
111 112 113 114 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 111 def leads_export_get(ad_account_id, leads_export_id, opts = {}) data, _status_code, _headers = leads_export_get_with_http_info(ad_account_id, leads_export_id, opts) data end |
#leads_export_get_with_http_info(ad_account_id, leads_export_id, opts = {}) ⇒ Array<(LeadsExportResponseData, Integer, Hash)>
Get the lead export from the lead export create call This feature is currently in beta and not available to all apps. If you're interested in joining the beta, please reach out to your Pinterest account manager. Get the export of leads collected from a lead ad. This returns a URL to a list of lead export given a lead_export_id token returned from the create a lead export call. You can use the URL to download the report. Note: Lead ad data will be available up to 30 days after the lead has been submitted. For more, see Lead ads.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/pinterest_sdk/api/leads_export_api.rb', line 122 def leads_export_get_with_http_info(ad_account_id, leads_export_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LeadsExportApi.leads_export_get ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling LeadsExportApi.leads_export_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling LeadsExportApi.leads_export_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling LeadsExportApi.leads_export_get, must conform to the pattern #{pattern}." end # verify the required parameter 'leads_export_id' is set if @api_client.config.client_side_validation && leads_export_id.nil? fail ArgumentError, "Missing the required parameter 'leads_export_id' when calling LeadsExportApi.leads_export_get" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && leads_export_id !~ pattern fail ArgumentError, "invalid value for 'leads_export_id' when calling LeadsExportApi.leads_export_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/leads_export/{leads_export_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{leads_export_id}', CGI.escape(leads_export_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LeadsExportResponseData' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"LeadsExportApi.leads_export_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LeadsExportApi#leads_export_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |