Class: PinterestSdkClient::LocalInventoryItemResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::LocalInventoryItemResponse
- Defined in:
- lib/pinterest_sdk/models/local_inventory_item_response.rb
Overview
Local inventory item response
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_link ⇒ Object
Ad link for the item.
-
#availability ⇒ Object
Availability status of the item.
-
#created_at ⇒ Object
The millisecond timestamp when the local inventory item was created.
-
#item_id ⇒ Object
The catalog item id in the merchant namespace.
-
#last_updated_time ⇒ Object
The millisecond timestamp when the local inventory item was lastly modified by the merchant.
-
#price ⇒ Object
The price of the product.
-
#sale_price ⇒ Object
The sale price of the product.
-
#store_metadata ⇒ Object
Store metadata for this local inventory item.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LocalInventoryItemResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LocalInventoryItemResponse
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::LocalInventoryItemResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::LocalInventoryItemResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_link') self.ad_link = attributes[:'ad_link'] end if attributes.key?(:'availability') self.availability = attributes[:'availability'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] else self.item_id = nil end if attributes.key?(:'last_updated_time') self.last_updated_time = attributes[:'last_updated_time'] else self.last_updated_time = nil end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'sale_price') self.sale_price = attributes[:'sale_price'] end if attributes.key?(:'store_metadata') self. = attributes[:'store_metadata'] else self. = nil end end |
Instance Attribute Details
#ad_link ⇒ Object
Ad link for the item
20 21 22 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 20 def ad_link @ad_link end |
#availability ⇒ Object
Availability status of the item
23 24 25 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 23 def availability @availability end |
#created_at ⇒ Object
The millisecond timestamp when the local inventory item was created
26 27 28 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 26 def created_at @created_at end |
#item_id ⇒ Object
The catalog item id in the merchant namespace
29 30 31 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 29 def item_id @item_id end |
#last_updated_time ⇒ Object
The millisecond timestamp when the local inventory item was lastly modified by the merchant.
32 33 34 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 32 def last_updated_time @last_updated_time end |
#price ⇒ Object
The price of the product. It supports the following formats, "49.99 USD", "49.99USD" and "49.99". If the currency is not included, we default to US dollars.
35 36 37 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 35 def price @price end |
#sale_price ⇒ Object
The sale price of the product. It supports the following formats, "24.99 USD", "24.99USD" and "24.99". If the currency is not included, we default to US dollars.
38 39 40 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 38 def sale_price @sale_price end |
#store_metadata ⇒ Object
Store metadata for this local inventory item
41 42 43 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 41 def end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 66 def self.attribute_map { :'ad_link' => :'ad_link', :'availability' => :'availability', :'created_at' => :'created_at', :'item_id' => :'item_id', :'last_updated_time' => :'last_updated_time', :'price' => :'price', :'sale_price' => :'sale_price', :'store_metadata' => :'store_metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 90 def self.openapi_types { :'ad_link' => :'String', :'availability' => :'ItemAvailability', :'created_at' => :'Integer', :'item_id' => :'String', :'last_updated_time' => :'Integer', :'price' => :'String', :'sale_price' => :'String', :'store_metadata' => :'StoreMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && ad_link == o.ad_link && availability == o.availability && created_at == o.created_at && item_id == o.item_id && last_updated_time == o.last_updated_time && price == o.price && sale_price == o.sale_price && == o. end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 264 def hash [ad_link, availability, created_at, item_id, last_updated_time, price, sale_price, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @item_id.nil? invalid_properties.push('invalid value for "item_id", item_id cannot be nil.') end if @last_updated_time.nil? invalid_properties.push('invalid value for "last_updated_time", last_updated_time cannot be nil.') end if .nil? invalid_properties.push('invalid value for "store_metadata", store_metadata cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 |
# File 'lib/pinterest_sdk/models/local_inventory_item_response.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @item_id.nil? return false if @last_updated_time.nil? return false if .nil? true end |