Class: PinterestSdkClient::OauthAccessTokenResponseRefresh
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::OauthAccessTokenResponseRefresh
- Defined in:
- lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb
Overview
A successful OAuth access token response for the refresh token flow.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Returns the value of attribute access_token.
-
#expires_in ⇒ Object
Returns the value of attribute expires_in.
-
#refresh_token ⇒ Object
Returns the value of attribute refresh_token.
-
#refresh_token_expires_at ⇒ Object
Returns the value of attribute refresh_token_expires_at.
-
#refresh_token_expires_in ⇒ Object
Returns the value of attribute refresh_token_expires_in.
-
#response_type ⇒ Object
Returns the value of attribute response_type.
-
#scope ⇒ Object
Returns the value of attribute scope.
-
#token_type ⇒ Object
Returns the value of attribute token_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OauthAccessTokenResponseRefresh
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OauthAccessTokenResponseRefresh
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::OauthAccessTokenResponseRefresh` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::OauthAccessTokenResponseRefresh`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] else self.access_token = nil end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] else self.expires_in = nil end if attributes.key?(:'response_type') self.response_type = attributes[:'response_type'] end if attributes.key?(:'scope') self.scope = attributes[:'scope'] else self.scope = nil end if attributes.key?(:'token_type') self.token_type = attributes[:'token_type'] else self.token_type = 'bearer' end if attributes.key?(:'refresh_token') self.refresh_token = attributes[:'refresh_token'] else self.refresh_token = nil end if attributes.key?(:'refresh_token_expires_at') self.refresh_token_expires_at = attributes[:'refresh_token_expires_at'] else self.refresh_token_expires_at = nil end if attributes.key?(:'refresh_token_expires_in') self.refresh_token_expires_in = attributes[:'refresh_token_expires_in'] else self.refresh_token_expires_in = nil end end |
Instance Attribute Details
#access_token ⇒ Object
Returns the value of attribute access_token.
19 20 21 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 19 def access_token @access_token end |
#expires_in ⇒ Object
Returns the value of attribute expires_in.
21 22 23 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 21 def expires_in @expires_in end |
#refresh_token ⇒ Object
Returns the value of attribute refresh_token.
29 30 31 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 29 def refresh_token @refresh_token end |
#refresh_token_expires_at ⇒ Object
Returns the value of attribute refresh_token_expires_at.
31 32 33 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 31 def refresh_token_expires_at @refresh_token_expires_at end |
#refresh_token_expires_in ⇒ Object
Returns the value of attribute refresh_token_expires_in.
33 34 35 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 33 def refresh_token_expires_in @refresh_token_expires_in end |
#response_type ⇒ Object
Returns the value of attribute response_type.
23 24 25 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 23 def response_type @response_type end |
#scope ⇒ Object
Returns the value of attribute scope.
25 26 27 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 25 def scope @scope end |
#token_type ⇒ Object
Returns the value of attribute token_type.
27 28 29 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 27 def token_type @token_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 58 def self.attribute_map { :'access_token' => :'access_token', :'expires_in' => :'expires_in', :'response_type' => :'response_type', :'scope' => :'scope', :'token_type' => :'token_type', :'refresh_token' => :'refresh_token', :'refresh_token_expires_at' => :'refresh_token_expires_at', :'refresh_token_expires_in' => :'refresh_token_expires_in' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 326 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 82 def self.openapi_types { :'access_token' => :'String', :'expires_in' => :'Integer', :'response_type' => :'String', :'scope' => :'String', :'token_type' => :'String', :'refresh_token' => :'String', :'refresh_token_expires_at' => :'Integer', :'refresh_token_expires_in' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && access_token == o.access_token && expires_in == o.expires_in && response_type == o.response_type && scope == o.scope && token_type == o.token_type && refresh_token == o.refresh_token && refresh_token_expires_at == o.refresh_token_expires_at && refresh_token_expires_in == o.refresh_token_expires_in end |
#eql?(o) ⇒ Boolean
313 314 315 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 313 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
319 320 321 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 319 def hash [access_token, expires_in, response_type, scope, token_type, refresh_token, refresh_token_expires_at, refresh_token_expires_in].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @access_token.nil? invalid_properties.push('invalid value for "access_token", access_token cannot be nil.') end if @expires_in.nil? invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.') end if @scope.nil? invalid_properties.push('invalid value for "scope", scope cannot be nil.') end if @token_type.nil? invalid_properties.push('invalid value for "token_type", token_type cannot be nil.') end if @refresh_token.nil? invalid_properties.push('invalid value for "refresh_token", refresh_token cannot be nil.') end if @refresh_token_expires_at.nil? invalid_properties.push('invalid value for "refresh_token_expires_at", refresh_token_expires_at cannot be nil.') end if @refresh_token_expires_in.nil? invalid_properties.push('invalid value for "refresh_token_expires_in", refresh_token_expires_in cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pinterest_sdk/models/oauth_access_token_response_refresh.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @access_token.nil? return false if @expires_in.nil? response_type_validator = EnumAttributeValidator.new('String', ["authorization_code", "refresh_token", "client_credentials"]) return false unless response_type_validator.valid?(@response_type) return false if @scope.nil? return false if @token_type.nil? return false if @refresh_token.nil? return false if @refresh_token_expires_at.nil? return false if @refresh_token_expires_in.nil? true end |