Class: PinterestSdkClient::OrderLinesApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::OrderLinesApi
- Defined in:
- lib/pinterest_sdk/api/order_lines_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ OrderLinesApi
constructor
A new instance of OrderLinesApi.
-
#order_lines_get(order_line_id, ad_account_id, opts = {}) ⇒ OrderLine
Get order line Get a specific existing order line associated with an ad account.
-
#order_lines_get_with_http_info(order_line_id, ad_account_id, opts = {}) ⇒ Array<(OrderLine, Integer, Hash)>
Get order line Get a specific existing order line associated with an ad account.
-
#order_lines_list(ad_account_id, opts = {}) ⇒ OrderLinesList200Response
Get order lines.
-
#order_lines_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(OrderLinesList200Response, Integer, Hash)>
Get order lines.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrderLinesApi
Returns a new instance of OrderLinesApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#order_lines_get(order_line_id, ad_account_id, opts = {}) ⇒ OrderLine
Get order line Get a specific existing order line associated with an ad account.
28 29 30 31 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 28 def order_lines_get(order_line_id, ad_account_id, opts = {}) data, _status_code, _headers = order_lines_get_with_http_info(order_line_id, ad_account_id, opts) data end |
#order_lines_get_with_http_info(order_line_id, ad_account_id, opts = {}) ⇒ Array<(OrderLine, Integer, Hash)>
Get order line Get a specific existing order line associated with an ad account.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 39 def order_lines_get_with_http_info(order_line_id, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrderLinesApi.order_lines_get ...' end # verify the required parameter 'order_line_id' is set if @api_client.config.client_side_validation && order_line_id.nil? fail ArgumentError, "Missing the required parameter 'order_line_id' when calling OrderLinesApi.order_lines_get" end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && order_line_id !~ pattern fail ArgumentError, "invalid value for 'order_line_id' when calling OrderLinesApi.order_lines_get, must conform to the pattern #{pattern}." end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling OrderLinesApi.order_lines_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling OrderLinesApi.order_lines_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling OrderLinesApi.order_lines_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/order_lines/{order_line_id}'.sub('{order_line_id}', CGI.escape(order_line_id.to_s)).sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrderLine' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"OrderLinesApi.order_lines_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrderLinesApi#order_lines_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#order_lines_list(ad_account_id, opts = {}) ⇒ OrderLinesList200Response
Get order lines. List existing order lines associated with an ad account.
113 114 115 116 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 113 def order_lines_list(ad_account_id, opts = {}) data, _status_code, _headers = order_lines_list_with_http_info(ad_account_id, opts) data end |
#order_lines_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(OrderLinesList200Response, Integer, Hash)>
Get order lines. List existing order lines associated with an ad account.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/pinterest_sdk/api/order_lines_api.rb', line 126 def order_lines_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrderLinesApi.order_lines_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling OrderLinesApi.order_lines_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling OrderLinesApi.order_lines_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling OrderLinesApi.order_lines_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling OrderLinesApi.order_lines_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling OrderLinesApi.order_lines_list, must be greater than or equal to 1.' end # resource path local_var_path = '/ad_accounts/{ad_account_id}/order_lines'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrderLinesList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"OrderLinesApi.order_lines_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrderLinesApi#order_lines_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |