Class: PinterestSdkClient::PinMediaSourceVideoID
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::PinMediaSourceVideoID
- Defined in:
- lib/pinterest_sdk/models/pin_media_source_video_id.rb
Overview
Video ID-based media source.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cover_image_content_type ⇒ Object
Content type for cover image Base64.
-
#cover_image_data ⇒ Object
Cover image Base64.
-
#cover_image_key_frame_time ⇒ Object
Keyframe timestamp for cover image (seconds).
-
#cover_image_url ⇒ Object
Cover image URL.
-
#is_standard ⇒ Object
Set the parameter to false to create the new simplified Pin instead of the standard pin.
-
#media_id ⇒ Object
Returns the value of attribute media_id.
-
#source_type ⇒ Object
Returns the value of attribute source_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PinMediaSourceVideoID
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PinMediaSourceVideoID
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::PinMediaSourceVideoID` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::PinMediaSourceVideoID`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cover_image_content_type') self.cover_image_content_type = attributes[:'cover_image_content_type'] end if attributes.key?(:'cover_image_data') self.cover_image_data = attributes[:'cover_image_data'] end if attributes.key?(:'cover_image_key_frame_time') self.cover_image_key_frame_time = attributes[:'cover_image_key_frame_time'] end if attributes.key?(:'cover_image_url') self.cover_image_url = attributes[:'cover_image_url'] end if attributes.key?(:'is_standard') self.is_standard = attributes[:'is_standard'] else self.is_standard = true end if attributes.key?(:'media_id') self.media_id = attributes[:'media_id'] else self.media_id = nil end if attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] else self.source_type = nil end end |
Instance Attribute Details
#cover_image_content_type ⇒ Object
Content type for cover image Base64.
20 21 22 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 20 def cover_image_content_type @cover_image_content_type end |
#cover_image_data ⇒ Object
Cover image Base64.
23 24 25 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 23 def cover_image_data @cover_image_data end |
#cover_image_key_frame_time ⇒ Object
Keyframe timestamp for cover image (seconds). If entered time exceeds video duration, the last frame is used.
26 27 28 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 26 def cover_image_key_frame_time @cover_image_key_frame_time end |
#cover_image_url ⇒ Object
Cover image URL.
29 30 31 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 29 def cover_image_url @cover_image_url end |
#is_standard ⇒ Object
Set the parameter to false to create the new simplified Pin instead of the standard pin. Currently the field is only available to a list of beta users.
32 33 34 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 32 def is_standard @is_standard end |
#media_id ⇒ Object
Returns the value of attribute media_id.
34 35 36 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 34 def media_id @media_id end |
#source_type ⇒ Object
Returns the value of attribute source_type.
36 37 38 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 36 def source_type @source_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 61 def self.attribute_map { :'cover_image_content_type' => :'cover_image_content_type', :'cover_image_data' => :'cover_image_data', :'cover_image_key_frame_time' => :'cover_image_key_frame_time', :'cover_image_url' => :'cover_image_url', :'is_standard' => :'is_standard', :'media_id' => :'media_id', :'source_type' => :'source_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 259 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 84 def self.openapi_types { :'cover_image_content_type' => :'ContentType', :'cover_image_data' => :'String', :'cover_image_key_frame_time' => :'Integer', :'cover_image_url' => :'String', :'is_standard' => :'Boolean', :'media_id' => :'String', :'source_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && cover_image_content_type == o.cover_image_content_type && cover_image_data == o.cover_image_data && cover_image_key_frame_time == o.cover_image_key_frame_time && cover_image_url == o.cover_image_url && is_standard == o.is_standard && media_id == o.media_id && source_type == o.source_type end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 252 def hash [cover_image_content_type, cover_image_data, cover_image_key_frame_time, cover_image_url, is_standard, media_id, source_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@cover_image_key_frame_time.nil? && @cover_image_key_frame_time < 0 invalid_properties.push('invalid value for "cover_image_key_frame_time", must be greater than or equal to 0.') end if @media_id.nil? invalid_properties.push('invalid value for "media_id", media_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @media_id !~ pattern invalid_properties.push("invalid value for \"media_id\", must conform to the pattern #{pattern}.") end if @source_type.nil? invalid_properties.push('invalid value for "source_type", source_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/pinterest_sdk/models/pin_media_source_video_id.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@cover_image_key_frame_time.nil? && @cover_image_key_frame_time < 0 return false if @media_id.nil? return false if @media_id !~ Regexp.new(/^\d+$/) return false if @source_type.nil? source_type_validator = EnumAttributeValidator.new('String', ["video_id"]) return false unless source_type_validator.valid?(@source_type) true end |