Class: PinterestSdkClient::ProductGroupPromotionsApi
- Inherits:
-
Object
- Object
- PinterestSdkClient::ProductGroupPromotionsApi
- Defined in:
- lib/pinterest_sdk/api/product_group_promotions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ProductGroupPromotionsApi
constructor
A new instance of ProductGroupPromotionsApi.
-
#product_group_promotions_create(ad_account_id, product_group_promotions_create, opts = {}) ⇒ ProductGroupPromotions
Create product group promotions Add one or more product groups from your catalog to an existing ad group.
-
#product_group_promotions_create_with_http_info(ad_account_id, product_group_promotions_create, opts = {}) ⇒ Array<(ProductGroupPromotions, Integer, Hash)>
Create product group promotions Add one or more product groups from your catalog to an existing ad group.
-
#product_group_promotions_get(ad_account_id, product_group_promotion_id, opts = {}) ⇒ ProductGroupPromotion
Get a product group promotion by id Get a product group promotion by id.
-
#product_group_promotions_get_with_http_info(ad_account_id, product_group_promotion_id, opts = {}) ⇒ Array<(ProductGroupPromotion, Integer, Hash)>
Get a product group promotion by id Get a product group promotion by id.
-
#product_group_promotions_list(ad_account_id, opts = {}) ⇒ ProductGroupPromotionsList200Response
Get product group promotions List existing product group promotions associated with an ad account.
-
#product_group_promotions_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(ProductGroupPromotionsList200Response, Integer, Hash)>
Get product group promotions List existing product group promotions associated with an ad account.
-
#product_group_promotions_update(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) ⇒ ProductGroupPromotions
Update product group promotions Update multiple existing Product Group Promotions (by product_group_id).
-
#product_group_promotions_update_with_http_info(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) ⇒ Array<(ProductGroupPromotions, Integer, Hash)>
Update product group promotions Update multiple existing Product Group Promotions (by product_group_id).
-
#product_groups_analytics(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) ⇒ Array<ProductGroupAnalyticsItems>
Get product group analytics Get analytics for the specified product groups in the specified
ad_account_id, filtered by the specified options. -
#product_groups_analytics_with_http_info(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) ⇒ Array<(Array<ProductGroupAnalyticsItems>, Integer, Hash)>
Get product group analytics Get analytics for the specified product groups in the specified `ad_account_id`, filtered by the specified options.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProductGroupPromotionsApi
Returns a new instance of ProductGroupPromotionsApi.
19 20 21 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#product_group_promotions_create(ad_account_id, product_group_promotions_create, opts = {}) ⇒ ProductGroupPromotions
Create product group promotions Add one or more product groups from your catalog to an existing ad group. (Product groups added to an ad group are a 'product group promotion.')
28 29 30 31 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 28 def product_group_promotions_create(ad_account_id, product_group_promotions_create, opts = {}) data, _status_code, _headers = product_group_promotions_create_with_http_info(ad_account_id, product_group_promotions_create, opts) data end |
#product_group_promotions_create_with_http_info(ad_account_id, product_group_promotions_create, opts = {}) ⇒ Array<(ProductGroupPromotions, Integer, Hash)>
Create product group promotions Add one or more product groups from your catalog to an existing ad group. (Product groups added to an ad group are a 'product group promotion.')
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 39 def product_group_promotions_create_with_http_info(ad_account_id, product_group_promotions_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductGroupPromotionsApi.product_group_promotions_create ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_create" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ProductGroupPromotionsApi.product_group_promotions_create, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_create, must conform to the pattern #{pattern}." end # verify the required parameter 'product_group_promotions_create' is set if @api_client.config.client_side_validation && product_group_promotions_create.nil? fail ArgumentError, "Missing the required parameter 'product_group_promotions_create' when calling ProductGroupPromotionsApi.product_group_promotions_create" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/product_group_promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(product_group_promotions_create) # return_type return_type = opts[:debug_return_type] || 'ProductGroupPromotions' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"ProductGroupPromotionsApi.product_group_promotions_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductGroupPromotionsApi#product_group_promotions_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#product_group_promotions_get(ad_account_id, product_group_promotion_id, opts = {}) ⇒ ProductGroupPromotion
Get a product group promotion by id Get a product group promotion by id
111 112 113 114 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 111 def product_group_promotions_get(ad_account_id, product_group_promotion_id, opts = {}) data, _status_code, _headers = product_group_promotions_get_with_http_info(ad_account_id, product_group_promotion_id, opts) data end |
#product_group_promotions_get_with_http_info(ad_account_id, product_group_promotion_id, opts = {}) ⇒ Array<(ProductGroupPromotion, Integer, Hash)>
Get a product group promotion by id Get a product group promotion by id
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 122 def product_group_promotions_get_with_http_info(ad_account_id, product_group_promotion_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductGroupPromotionsApi.product_group_promotions_get ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_get" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ProductGroupPromotionsApi.product_group_promotions_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_get, must conform to the pattern #{pattern}." end # verify the required parameter 'product_group_promotion_id' is set if @api_client.config.client_side_validation && product_group_promotion_id.nil? fail ArgumentError, "Missing the required parameter 'product_group_promotion_id' when calling ProductGroupPromotionsApi.product_group_promotions_get" end if @api_client.config.client_side_validation && product_group_promotion_id.to_s.length > 18 fail ArgumentError, 'invalid value for "product_group_promotion_id" when calling ProductGroupPromotionsApi.product_group_promotions_get, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && product_group_promotion_id !~ pattern fail ArgumentError, "invalid value for 'product_group_promotion_id' when calling ProductGroupPromotionsApi.product_group_promotions_get, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/product_group_promotions/{product_group_promotion_id}'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)).sub('{product_group_promotion_id}', CGI.escape(product_group_promotion_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProductGroupPromotion' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"ProductGroupPromotionsApi.product_group_promotions_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductGroupPromotionsApi#product_group_promotions_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#product_group_promotions_list(ad_account_id, opts = {}) ⇒ ProductGroupPromotionsList200Response
Get product group promotions List existing product group promotions associated with an ad account. Include either ad_group_id or product_group_promotion_ids in your request. Note: ad_group_ids and product_group_promotion_ids are mutually exclusive parameters. Only provide one. If multiple options are provided, product_group_promotion_ids takes precedence over ad_group_ids. If none are provided, the endpoint returns an error.
203 204 205 206 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 203 def product_group_promotions_list(ad_account_id, opts = {}) data, _status_code, _headers = product_group_promotions_list_with_http_info(ad_account_id, opts) data end |
#product_group_promotions_list_with_http_info(ad_account_id, opts = {}) ⇒ Array<(ProductGroupPromotionsList200Response, Integer, Hash)>
Get product group promotions List existing product group promotions associated with an ad account. Include either ad_group_id or product_group_promotion_ids in your request. Note: ad_group_ids and product_group_promotion_ids are mutually exclusive parameters. Only provide one. If multiple options are provided, product_group_promotion_ids takes precedence over ad_group_ids. If none are provided, the endpoint returns an error.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 219 def product_group_promotions_list_with_http_info(ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductGroupPromotionsApi.product_group_promotions_list ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_list" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ProductGroupPromotionsApi.product_group_promotions_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_list, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 250 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ProductGroupPromotionsApi.product_group_promotions_list, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ProductGroupPromotionsApi.product_group_promotions_list, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'product_group_promotion_ids'].nil? && opts[:'product_group_promotion_ids'].length > 250 fail ArgumentError, 'invalid value for "opts[:"product_group_promotion_ids"]" when calling ProductGroupPromotionsApi.product_group_promotions_list, number of items must be less than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'product_group_promotion_ids'].nil? && opts[:'product_group_promotion_ids'].length < 1 fail ArgumentError, 'invalid value for "opts[:"product_group_promotion_ids"]" when calling ProductGroupPromotionsApi.product_group_promotions_list, number of items must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'ad_group_id'].nil? && opts[:'ad_group_id'].to_s.length > 18 fail ArgumentError, 'invalid value for "opts[:"ad_group_id"]" when calling ProductGroupPromotionsApi.product_group_promotions_list, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && !opts[:'ad_group_id'].nil? && opts[:'ad_group_id'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"ad_group_id\"]' when calling ProductGroupPromotionsApi.product_group_promotions_list, must conform to the pattern #{pattern}." end # resource path local_var_path = '/ad_accounts/{ad_account_id}/product_group_promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'bookmark'] = opts[:'bookmark'] if !opts[:'bookmark'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'product_group_promotion_ids'] = @api_client.build_collection_param(opts[:'product_group_promotion_ids'], :multi) if !opts[:'product_group_promotion_ids'].nil? query_params[:'entity_statuses'] = @api_client.build_collection_param(opts[:'entity_statuses'], :multi) if !opts[:'entity_statuses'].nil? query_params[:'ad_group_id'] = opts[:'ad_group_id'] if !opts[:'ad_group_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProductGroupPromotionsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"ProductGroupPromotionsApi.product_group_promotions_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductGroupPromotionsApi#product_group_promotions_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#product_group_promotions_update(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) ⇒ ProductGroupPromotions
Update product group promotions Update multiple existing Product Group Promotions (by product_group_id)
313 314 315 316 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 313 def product_group_promotions_update(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) data, _status_code, _headers = product_group_promotions_update_with_http_info(ad_account_id, product_group_promotions_update_with_required_body, opts) data end |
#product_group_promotions_update_with_http_info(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) ⇒ Array<(ProductGroupPromotions, Integer, Hash)>
Update product group promotions Update multiple existing Product Group Promotions (by product_group_id)
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 324 def product_group_promotions_update_with_http_info(ad_account_id, product_group_promotions_update_with_required_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductGroupPromotionsApi.product_group_promotions_update ...' end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_update" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ProductGroupPromotionsApi.product_group_promotions_update, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ProductGroupPromotionsApi.product_group_promotions_update, must conform to the pattern #{pattern}." end # verify the required parameter 'product_group_promotions_update_with_required_body' is set if @api_client.config.client_side_validation && product_group_promotions_update_with_required_body.nil? fail ArgumentError, "Missing the required parameter 'product_group_promotions_update_with_required_body' when calling ProductGroupPromotionsApi.product_group_promotions_update" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/product_group_promotions'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(product_group_promotions_update_with_required_body) # return_type return_type = opts[:debug_return_type] || 'ProductGroupPromotions' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2'] = opts.merge( :operation => :"ProductGroupPromotionsApi.product_group_promotions_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductGroupPromotionsApi#product_group_promotions_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#product_groups_analytics(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) ⇒ Array<ProductGroupAnalyticsItems>
Get product group analytics
Get analytics for the specified product groups in the specified ad_account_id, filtered by the specified options. - The token's user_account must either be the Owner of the specified ad account, or have one of the necessary roles granted to them via Business Access: Admin, Analyst, Campaign Manager. - If granularity is not HOUR, you can pull data from up to 90 days before the current date in UTC time, with a maximum time range of 90 days. - If granularity is HOUR, you can pull data from up to 8 days before the current date in UTC time, with a maximum time range of 3 days.
405 406 407 408 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 405 def product_groups_analytics(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) data, _status_code, _headers = product_groups_analytics_with_http_info(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts) data end |
#product_groups_analytics_with_http_info(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) ⇒ Array<(Array<ProductGroupAnalyticsItems>, Integer, Hash)>
Get product group analytics Get analytics for the specified product groups in the specified `ad_account_id`, filtered by the specified options. - The token's user_account must either be the Owner of the specified ad account, or have one of the necessary roles granted to them via Business Access: Admin, Analyst, Campaign Manager. - If granularity is not HOUR, you can pull data from up to 90 days before the current date in UTC time, with a maximum time range of 90 days. - If granularity is HOUR, you can pull data from up to 8 days before the current date in UTC time, with a maximum time range of 3 days.
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/pinterest_sdk/api/product_group_promotions_api.rb', line 425 def product_groups_analytics_with_http_info(start_date, end_date, product_group_ids, columns, granularity, ad_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductGroupPromotionsApi.product_groups_analytics ...' end # verify the required parameter 'start_date' is set if @api_client.config.client_side_validation && start_date.nil? fail ArgumentError, "Missing the required parameter 'start_date' when calling ProductGroupPromotionsApi.product_groups_analytics" end # verify the required parameter 'end_date' is set if @api_client.config.client_side_validation && end_date.nil? fail ArgumentError, "Missing the required parameter 'end_date' when calling ProductGroupPromotionsApi.product_groups_analytics" end # verify the required parameter 'product_group_ids' is set if @api_client.config.client_side_validation && product_group_ids.nil? fail ArgumentError, "Missing the required parameter 'product_group_ids' when calling ProductGroupPromotionsApi.product_groups_analytics" end if @api_client.config.client_side_validation && product_group_ids.length > 250 fail ArgumentError, 'invalid value for "product_group_ids" when calling ProductGroupPromotionsApi.product_groups_analytics, number of items must be less than or equal to 250.' end if @api_client.config.client_side_validation && product_group_ids.length < 1 fail ArgumentError, 'invalid value for "product_group_ids" when calling ProductGroupPromotionsApi.product_groups_analytics, number of items must be greater than or equal to 1.' end # verify the required parameter 'columns' is set if @api_client.config.client_side_validation && columns.nil? fail ArgumentError, "Missing the required parameter 'columns' when calling ProductGroupPromotionsApi.product_groups_analytics" end # verify the required parameter 'granularity' is set if @api_client.config.client_side_validation && granularity.nil? fail ArgumentError, "Missing the required parameter 'granularity' when calling ProductGroupPromotionsApi.product_groups_analytics" end # verify the required parameter 'ad_account_id' is set if @api_client.config.client_side_validation && ad_account_id.nil? fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling ProductGroupPromotionsApi.product_groups_analytics" end if @api_client.config.client_side_validation && ad_account_id.to_s.length > 18 fail ArgumentError, 'invalid value for "ad_account_id" when calling ProductGroupPromotionsApi.product_groups_analytics, the character length must be smaller than or equal to 18.' end pattern = Regexp.new(/^\d+$/) if @api_client.config.client_side_validation && ad_account_id !~ pattern fail ArgumentError, "invalid value for 'ad_account_id' when calling ProductGroupPromotionsApi.product_groups_analytics, must conform to the pattern #{pattern}." end allowable_values = [0, 1, 7, 14, 30, 60] if @api_client.config.client_side_validation && opts[:'click_window_days'] && !allowable_values.include?(opts[:'click_window_days']) fail ArgumentError, "invalid value for \"click_window_days\", must be one of #{allowable_values}" end allowable_values = [0, 1, 7, 14, 30, 60] if @api_client.config.client_side_validation && opts[:'engagement_window_days'] && !allowable_values.include?(opts[:'engagement_window_days']) fail ArgumentError, "invalid value for \"engagement_window_days\", must be one of #{allowable_values}" end allowable_values = [0, 1, 7, 14, 30, 60] if @api_client.config.client_side_validation && opts[:'view_window_days'] && !allowable_values.include?(opts[:'view_window_days']) fail ArgumentError, "invalid value for \"view_window_days\", must be one of #{allowable_values}" end allowable_values = ["TIME_OF_AD_ACTION", "TIME_OF_CONVERSION"] if @api_client.config.client_side_validation && opts[:'conversion_report_time'] && !allowable_values.include?(opts[:'conversion_report_time']) fail ArgumentError, "invalid value for \"conversion_report_time\", must be one of #{allowable_values}" end # resource path local_var_path = '/ad_accounts/{ad_account_id}/product_groups/analytics'.sub('{ad_account_id}', CGI.escape(ad_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'start_date'] = start_date query_params[:'end_date'] = end_date query_params[:'product_group_ids'] = @api_client.build_collection_param(product_group_ids, :multi) query_params[:'columns'] = @api_client.build_collection_param(columns, :csv) query_params[:'granularity'] = granularity query_params[:'click_window_days'] = opts[:'click_window_days'] if !opts[:'click_window_days'].nil? query_params[:'engagement_window_days'] = opts[:'engagement_window_days'] if !opts[:'engagement_window_days'].nil? query_params[:'view_window_days'] = opts[:'view_window_days'] if !opts[:'view_window_days'].nil? query_params[:'conversion_report_time'] = opts[:'conversion_report_time'] if !opts[:'conversion_report_time'].nil? query_params[:'reporting_timezone'] = opts[:'reporting_timezone'] if !opts[:'reporting_timezone'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ProductGroupAnalyticsItems>' # auth_names auth_names = opts[:debug_auth_names] || ['pinterest_oauth2', 'client_credentials'] = opts.merge( :operation => :"ProductGroupPromotionsApi.product_groups_analytics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductGroupPromotionsApi#product_groups_analytics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |