Class: PinterestSdkClient::ScheduleBatchUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::ScheduleBatchUpdate
- Defined in:
- lib/pinterest_sdk/models/schedule_batch_update.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#delta_value ⇒ Object
Returns the value of attribute delta_value.
-
#end_timestamp ⇒ Object
Schedule end time.
-
#entity_id ⇒ Object
entity ID.
-
#entity_type ⇒ Object
Specify the entity_type to get summary information.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Schedule name.
-
#schedule_action ⇒ Object
The schedule action.
-
#schedule_id ⇒ Object
Schedule ID.
-
#schedule_status ⇒ Object
Schedule status.
-
#schedule_type ⇒ Object
The schedule type.
-
#start_timestamp ⇒ Object
Schedule start time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduleBatchUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScheduleBatchUpdate
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::ScheduleBatchUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::ScheduleBatchUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delta_value') self.delta_value = attributes[:'delta_value'] end if attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] end if attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'schedule_action') self.schedule_action = attributes[:'schedule_action'] end if attributes.key?(:'schedule_id') self.schedule_id = attributes[:'schedule_id'] else self.schedule_id = nil end if attributes.key?(:'schedule_status') self.schedule_status = attributes[:'schedule_status'] end if attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] end if attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] end end |
Instance Attribute Details
#delta_value ⇒ Object
Returns the value of attribute delta_value.
18 19 20 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 18 def delta_value @delta_value end |
#end_timestamp ⇒ Object
Schedule end time. Unix timestamp in seconds.
21 22 23 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 21 def @end_timestamp end |
#entity_id ⇒ Object
entity ID.
24 25 26 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 24 def entity_id @entity_id end |
#entity_type ⇒ Object
Specify the entity_type to get summary information
27 28 29 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 27 def entity_type @entity_type end |
#id ⇒ Object
Returns the value of attribute id.
29 30 31 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 29 def id @id end |
#name ⇒ Object
Schedule name.
32 33 34 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 32 def name @name end |
#schedule_action ⇒ Object
The schedule action.
35 36 37 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 35 def schedule_action @schedule_action end |
#schedule_id ⇒ Object
Schedule ID.
38 39 40 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 38 def schedule_id @schedule_id end |
#schedule_status ⇒ Object
Schedule status.
41 42 43 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 41 def schedule_status @schedule_status end |
#schedule_type ⇒ Object
The schedule type.
44 45 46 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 44 def schedule_type @schedule_type end |
#start_timestamp ⇒ Object
Schedule start time. Unix timestamp in seconds.
47 48 49 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 47 def @start_timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 72 def self.attribute_map { :'delta_value' => :'delta_value', :'end_timestamp' => :'end_timestamp', :'entity_id' => :'entity_id', :'entity_type' => :'entity_type', :'id' => :'id', :'name' => :'name', :'schedule_action' => :'schedule_action', :'schedule_id' => :'schedule_id', :'schedule_status' => :'schedule_status', :'schedule_type' => :'schedule_type', :'start_timestamp' => :'start_timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 99 def self.openapi_types { :'delta_value' => :'ScheduleDeltaValue', :'end_timestamp' => :'Integer', :'entity_id' => :'String', :'entity_type' => :'AdAccountEntityType', :'id' => :'String', :'name' => :'String', :'schedule_action' => :'ScheduleAction', :'schedule_id' => :'String', :'schedule_status' => :'ScheduleStatus', :'schedule_type' => :'ScheduleType', :'start_timestamp' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && delta_value == o.delta_value && == o. && entity_id == o.entity_id && entity_type == o.entity_type && id == o.id && name == o.name && schedule_action == o.schedule_action && schedule_id == o.schedule_id && schedule_status == o.schedule_status && schedule_type == o.schedule_type && == o. end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 309 def hash [delta_value, , entity_id, entity_type, id, name, schedule_action, schedule_id, schedule_status, schedule_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@entity_id.nil? && @entity_id !~ pattern invalid_properties.push("invalid value for \"entity_id\", must conform to the pattern #{pattern}.") end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 18 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 18.') end pattern = Regexp.new(/^\d+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @schedule_id.nil? invalid_properties.push('invalid value for "schedule_id", schedule_id cannot be nil.') end pattern = Regexp.new(/^\d+$/) if @schedule_id !~ pattern invalid_properties.push("invalid value for \"schedule_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pinterest_sdk/models/schedule_batch_update.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@entity_id.nil? && @entity_id !~ Regexp.new(/^\d+$/) return false if @id.nil? return false if @id.to_s.length > 18 return false if @id !~ Regexp.new(/^\d+$/) return false if @schedule_id.nil? return false if @schedule_id !~ Regexp.new(/^\d+$/) true end |