Class: PinterestSdkClient::SupplementalOperationResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::SupplementalOperationResult
- Defined in:
- lib/pinterest_sdk/models/supplemental_operation_result.rb
Overview
Result of a supplemental item operation, discriminated by supplemental_type
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#errors ⇒ Object
Array with the validation errors for the item processing record.
-
#item_id ⇒ Object
Catalog item id in the merchant namespace.
-
#status ⇒ Object
Status of the item processing record.
-
#store_code ⇒ Object
Store code for the local inventory item.
-
#supplemental_type ⇒ Object
Returns the value of attribute supplemental_type.
-
#warnings ⇒ Object
Array with the validation warnings for the item processing record.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SupplementalOperationResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SupplementalOperationResult
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::SupplementalOperationResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::SupplementalOperationResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] else self.item_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'store_code') self.store_code = attributes[:'store_code'] else self.store_code = nil end if attributes.key?(:'supplemental_type') self.supplemental_type = attributes[:'supplemental_type'] else self.supplemental_type = nil end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end end end |
Instance Attribute Details
#errors ⇒ Object
Array with the validation errors for the item processing record. A non empty errors list causes the item processing to fail.
20 21 22 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 20 def errors @errors end |
#item_id ⇒ Object
Catalog item id in the merchant namespace
23 24 25 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 23 def item_id @item_id end |
#status ⇒ Object
Status of the item processing record
26 27 28 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 26 def status @status end |
#store_code ⇒ Object
Store code for the local inventory item
29 30 31 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 29 def store_code @store_code end |
#supplemental_type ⇒ Object
Returns the value of attribute supplemental_type.
31 32 33 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 31 def supplemental_type @supplemental_type end |
#warnings ⇒ Object
Array with the validation warnings for the item processing record
34 35 36 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 34 def warnings @warnings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 59 def self.attribute_map { :'errors' => :'errors', :'item_id' => :'item_id', :'status' => :'status', :'store_code' => :'store_code', :'supplemental_type' => :'supplemental_type', :'warnings' => :'warnings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 263 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
99 100 101 102 103 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 99 def self.openapi_all_of [ :'LocalInventoryOperationResult' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 81 def self.openapi_types { :'errors' => :'Array<SupplementalItemValidationEvent>', :'item_id' => :'String', :'status' => :'SupplementalItemProcessingStatus', :'store_code' => :'String', :'supplemental_type' => :'String', :'warnings' => :'Array<SupplementalItemValidationEvent>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && errors == o.errors && item_id == o.item_id && status == o.status && store_code == o.store_code && supplemental_type == o.supplemental_type && warnings == o.warnings end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 256 def hash [errors, item_id, status, store_code, supplemental_type, warnings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @item_id.nil? invalid_properties.push('invalid value for "item_id", item_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @store_code.nil? invalid_properties.push('invalid value for "store_code", store_code cannot be nil.') end if @supplemental_type.nil? invalid_properties.push('invalid value for "supplemental_type", supplemental_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/pinterest_sdk/models/supplemental_operation_result.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @item_id.nil? return false if @status.nil? return false if @store_code.nil? return false if @supplemental_type.nil? supplemental_type_validator = EnumAttributeValidator.new('String', ["LOCAL_INVENTORY"]) return false unless supplemental_type_validator.valid?(@supplemental_type) true end |