Class: PinterestSdkClient::TrendingKeyword
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::TrendingKeyword
- Defined in:
- lib/pinterest_sdk/models/trending_keyword.rb
Instance Attribute Summary collapse
-
#demographics ⇒ Object
Returns the value of attribute demographics.
-
#has_prediction ⇒ Object
Indicates whether the keyword has a prediction available for the next 90 days.
-
#keyword ⇒ Object
The keyword that is trending.
-
#pct_growth_mom ⇒ Object
The month-over-month percent change in search volume for this keyword.
-
#pct_growth_wow ⇒ Object
The week-over-week percent change in search volume for this keyword.
-
#pct_growth_yoy ⇒ Object
The year-over-year percent change in search volume for this keyword.
-
#predicted_time_series ⇒ Object
A sequence of weekly observations of the predicted relative search volume for this keyword over the next 3 months.
-
#time_series ⇒ Object
A sequence of weekly observations of the relative search volume for this keyword over the past year.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TrendingKeyword
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TrendingKeyword
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::TrendingKeyword` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::TrendingKeyword`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'demographics') self.demographics = attributes[:'demographics'] end if attributes.key?(:'has_prediction') self.has_prediction = attributes[:'has_prediction'] end if attributes.key?(:'keyword') self.keyword = attributes[:'keyword'] end if attributes.key?(:'pct_growth_mom') self.pct_growth_mom = attributes[:'pct_growth_mom'] end if attributes.key?(:'pct_growth_wow') self.pct_growth_wow = attributes[:'pct_growth_wow'] end if attributes.key?(:'pct_growth_yoy') self.pct_growth_yoy = attributes[:'pct_growth_yoy'] end if attributes.key?(:'predicted_time_series') self.predicted_time_series = attributes[:'predicted_time_series'] end if attributes.key?(:'time_series') self.time_series = attributes[:'time_series'] end end |
Instance Attribute Details
#demographics ⇒ Object
Returns the value of attribute demographics.
18 19 20 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 18 def demographics @demographics end |
#has_prediction ⇒ Object
Indicates whether the keyword has a prediction available for the next 90 days. This field is only applicable when include_prediction query parameter is set to true. By default, the value is false and no prediction data is included in the response.
21 22 23 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 21 def has_prediction @has_prediction end |
#keyword ⇒ Object
The keyword that is trending.
24 25 26 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 24 def keyword @keyword end |
#pct_growth_mom ⇒ Object
The month-over-month percent change in search volume for this keyword. For example, a value of "400" would represent a 400% increase in searches in the last 30 days compared to the month prior. Note: growth rates are rounded, with a maximum of +/- 10000% change. A value of 10001 indicates that this keyword experienced > 10000% month-over-month growth.
27 28 29 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 27 def pct_growth_mom @pct_growth_mom end |
#pct_growth_wow ⇒ Object
The week-over-week percent change in search volume for this keyword. For example, a value of "50" would represent a 50% increase in searches in the last seven days compared to the week prior. Note: growth rates are rounded, with a maximum of +/- 10000% change. A value of 10001 indicates that this keyword experienced > 10000% week-over-week growth.
30 31 32 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 30 def pct_growth_wow @pct_growth_wow end |
#pct_growth_yoy ⇒ Object
The year-over-year percent change in search volume for this keyword. For example, a value of "-5" would represent a 5% decrease in searches in the last 365 days compared to the month prior. Note: growth rates are rounded, with a maximum of +/- 10000% change. A value of 10001 indicates that this keyword experienced > 10000% year-over-year growth.
33 34 35 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 33 def pct_growth_yoy @pct_growth_yoy end |
#predicted_time_series ⇒ Object
A sequence of weekly observations of the predicted relative search volume for this keyword over the next 3 months. These values are normalized to a [0-100] range, and can be used to visualize the forecasted user interest in this keyword. Similar to the historical time_series, normalization is applied independently to the predicted time series of each keyword, but the normalize_against_group query parameter can be used in cases where you wish to compare relative predicted volume between keywords. Note: The cut-off date between historical and predicted time series depends on Pinterest data availability. Usually the data needs a few days to be calculated, so the predicted time series may contain some past dates compared to today. Note: The date of each observation is in ISO-8601 format and represents the end of the week. For example, a value of 2024-01-07 would include predicted searches for the week ending on 2024-01-07.
36 37 38 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 36 def predicted_time_series @predicted_time_series end |
#time_series ⇒ Object
A sequence of weekly observations of the relative search volume for this keyword over the past year. These values are normalized to a [0-100] range, and can be used to visualize the history of user interest in this keyword. By default, normalization is applied independently to the time series of each keyword, but the normalize_against_group query parameter can be used in cases where you wish to compare relative volume between keywords. Note: The date of each observation is in ISO-8601 format and represents the end of the week. For example, a value of 2023-10-31 would include searches that happened between 2023-10-25 and 2023-10-31.
39 40 41 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 39 def time_series @time_series end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 42 def self.attribute_map { :'demographics' => :'demographics', :'has_prediction' => :'has_prediction', :'keyword' => :'keyword', :'pct_growth_mom' => :'pct_growth_mom', :'pct_growth_wow' => :'pct_growth_wow', :'pct_growth_yoy' => :'pct_growth_yoy', :'predicted_time_series' => :'predicted_time_series', :'time_series' => :'time_series' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 84 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 80 def self.openapi_nullable Set.new([ :'demographics', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 66 def self.openapi_types { :'demographics' => :'TrendingKeywordDemographics', :'has_prediction' => :'Boolean', :'keyword' => :'String', :'pct_growth_mom' => :'Integer', :'pct_growth_wow' => :'Integer', :'pct_growth_yoy' => :'Integer', :'predicted_time_series' => :'PredictedTimeSeries', :'time_series' => :'TimeSeries' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && demographics == o.demographics && has_prediction == o.has_prediction && keyword == o.keyword && pct_growth_mom == o.pct_growth_mom && pct_growth_wow == o.pct_growth_wow && pct_growth_yoy == o.pct_growth_yoy && predicted_time_series == o.predicted_time_series && time_series == o.time_series end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 192 def hash [demographics, has_prediction, keyword, pct_growth_mom, pct_growth_wow, pct_growth_yoy, predicted_time_series, time_series].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@keyword.nil? && @keyword.to_s.length < 1 invalid_properties.push('invalid value for "keyword", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/trending_keyword.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@keyword.nil? && @keyword.to_s.length < 1 true end |