Class: PinterestSdkClient::UserBusinessRoleBinding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PinterestSdkClient::UserBusinessRoleBinding
- Defined in:
- lib/pinterest_sdk/models/user_business_role_binding.rb
Instance Attribute Summary collapse
-
#assets_summary ⇒ Object
Ad accounts and profiles the business member/partner has access to.
-
#business_roles ⇒ Object
The access level a user has on the business.
-
#created_by_business ⇒ Object
Metadata for the business that created the business relationship.
-
#created_by_user ⇒ Object
Metadata for the user that created the business relationship.
-
#created_time ⇒ Object
The time the business relationship was created.
-
#id ⇒ Object
Unique identifier of the business member/business partner/employer.
-
#is_shared_partner ⇒ Object
This field is only relevant when business_role="PARTNER".
-
#user ⇒ Object
Metadata for the business member/business partner/employer.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserBusinessRoleBinding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserBusinessRoleBinding
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PinterestSdkClient::UserBusinessRoleBinding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PinterestSdkClient::UserBusinessRoleBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'assets_summary') self.assets_summary = attributes[:'assets_summary'] end if attributes.key?(:'business_roles') if (value = attributes[:'business_roles']).is_a?(Array) self.business_roles = value end end if attributes.key?(:'created_by_business') self.created_by_business = attributes[:'created_by_business'] end if attributes.key?(:'created_by_user') self.created_by_user = attributes[:'created_by_user'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'is_shared_partner') self.is_shared_partner = attributes[:'is_shared_partner'] end if attributes.key?(:'user') self.user = attributes[:'user'] end end |
Instance Attribute Details
#assets_summary ⇒ Object
Ad accounts and profiles the business member/partner has access to.
19 20 21 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 19 def assets_summary @assets_summary end |
#business_roles ⇒ Object
The access level a user has on the business. This can be EMPLOYEE, BIZ_ADMIN, or PARTNER.
22 23 24 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 22 def business_roles @business_roles end |
#created_by_business ⇒ Object
Metadata for the business that created the business relationship.
25 26 27 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 25 def created_by_business @created_by_business end |
#created_by_user ⇒ Object
Metadata for the user that created the business relationship.
28 29 30 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 28 def created_by_user @created_by_user end |
#created_time ⇒ Object
The time the business relationship was created. Returned in milliseconds.
31 32 33 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 31 def created_time @created_time end |
#id ⇒ Object
Unique identifier of the business member/business partner/employer.
34 35 36 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 34 def id @id end |
#is_shared_partner ⇒ Object
This field is only relevant when business_role="PARTNER". If is_shared_partner=FALSE, the partner can access your business assets. If assets_summary is not empty, the assets listed are your business assets the partner has access to. If is_shared_partner=TRUE, you can access the partner's business asset. If assets_summary is not empty, the assets listed are the partner's business assets you have access to.
37 38 39 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 37 def is_shared_partner @is_shared_partner end |
#user ⇒ Object
Metadata for the business member/business partner/employer.
40 41 42 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 40 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 43 def self.attribute_map { :'assets_summary' => :'assets_summary', :'business_roles' => :'business_roles', :'created_by_business' => :'created_by_business', :'created_by_user' => :'created_by_user', :'created_time' => :'created_time', :'id' => :'id', :'is_shared_partner' => :'is_shared_partner', :'user' => :'user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 208 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 81 def self.openapi_nullable Set.new([ :'assets_summary', :'created_by_business', :'created_by_user', :'created_time', :'user' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 67 def self.openapi_types { :'assets_summary' => :'BusinessMemberAssetsSummary', :'business_roles' => :'Array<String>', :'created_by_business' => :'BusinessAccessUserSummary', :'created_by_user' => :'BusinessAccessUserSummary', :'created_time' => :'Integer', :'id' => :'String', :'is_shared_partner' => :'Boolean', :'user' => :'BusinessAccessUserSummary' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && assets_summary == o.assets_summary && business_roles == o.business_roles && created_by_business == o.created_by_business && created_by_user == o.created_by_user && created_time == o.created_time && id == o.id && is_shared_partner == o.is_shared_partner && user == o.user end |
#eql?(o) ⇒ Boolean
195 196 197 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 195 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 201 def hash [assets_summary, business_roles, created_by_business, created_by_user, created_time, id, is_shared_partner, user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 144 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 |
# File 'lib/pinterest_sdk/models/user_business_role_binding.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) true end |